@@ -1013,16 +1013,17 @@ Composition::getTimeSignatureAtAux(timeT t) const
 {
     ReferenceSegment::iterator i = m_timeSigSegment.findAtOrBefore(t);
 
-    // In negative time, if there's no time signature actually defined
-    // prior to the point of interest then we use the next time
-    // signature after it, so long as it's no later than time zero.
-    // This is the only rational way to deal with count-in bars where
-    // the correct time signature otherwise won't appear until we hit
-    // bar zero.
+    // In time before composition start, if there's no time signature
+    // actually defined prior to the point of interest then we use the
+    // next one after it, so long as it's no later than composition
+    // start.  This is the only rational way to deal with count-in
+    // bars where the correct tempo otherwise won't appear until we
+    // hit bar zero.
 
-    if (t < 0 && i == m_timeSigSegment.end()) {
+    if (t < getStartMarker() && i == m_timeSigSegment.end()) {
         i = m_timeSigSegment.begin();
-        if (i != m_timeSigSegment.end() && (*i)->getAbsoluteTime() > 0) {
+        if (i != m_timeSigSegment.end() &&
+            (*i)->getAbsoluteTime() > getStartMarker()) {
             i  = m_timeSigSegment.end();
         }
     }
@@ -1067,19 +1068,19 @@ Composition::getTempoAtTime(timeT t) const
 {
     ReferenceSegment::iterator i = m_tempoSegment.findAtOrBefore(t);
 
-    // In negative time, if there's no tempo event actually defined
-    // prior to the point of interest then we use the next one after
-    // it, so long as it's no later than time zero.  This is the only
-    // rational way to deal with count-in bars where the correct
-    // tempo otherwise won't appear until we hit bar zero.  See also
-    // getTimeSignatureAt
+    // In time before composition start, if there's no tempo event
+    // actually defined prior to the point of interest then we use the
+    // next one after it, so long as it's no later than composition start.
+    // This is the only rational way to deal with count-in bars where
+    // the correct tempo otherwise won't appear until we hit bar zero.
+    // See also getTimeSignatureAt
 
     if (i == m_tempoSegment.end()) {
-        if (t < 0) {
+        if (t < getStartMarker()) {
 #ifdef DEBUG_TEMPO_STUFF
             RG_DEBUG << "getTempoAtTime(): Negative time " << t << " for tempo, using 0";
 #endif
-            return getTempoAtTime(0);
+            return getTempoAtTime(getStartMarker());
         }
         else return m_defaultTempo;
     }
@@ -1306,8 +1307,6 @@ Composition::compareSignaturesAndTempos(const Composition &other) const
     return true;
 }
 
-#ifndef BUG1627
-// Original version
 RealTime
 Composition::getElapsedRealTime(timeT t) const
 {
@@ -1315,11 +1314,13 @@ Composition::getElapsedRealTime(timeT t) const
 
     ReferenceSegment::iterator i = m_tempoSegment.findAtOrBefore(t);
     if (i == m_tempoSegment.end()) {
-        i = m_tempoSegment.begin();
-        if (t >= 0 ||
-            (i == m_tempoSegment.end() || (*i)->getAbsoluteTime() > 0)) {
-            return time2RealTime(t, m_defaultTempo);
-        }
+        // before any tempo we use the default tempo
+        RealTime ret = time2RealTime(t - getStartMarker(), m_defaultTempo);
+#ifdef DEBUG_TEMPO_STUFF
+        RG_DEBUG << "getElapsedRealTime() 1: " << t << " -> " <<
+            ret << t - getStartMarker();
+#endif
+        return ret;
     }
 
     RealTime elapsed;
@@ -1342,135 +1343,27 @@ Composition::getElapsedRealTime(timeT t) const
     }
 
 #ifdef DEBUG_TEMPO_STUFF
-    RG_DEBUG << "getElapsedRealTime(): " << t << " -> " << elapsed << " (last tempo change at " << (*i)->getAbsoluteTime() << ")";
+    RG_DEBUG << "getElapsedRealTime() 2: " << t << " -> " << elapsed << " (last tempo change at " << (*i)->getAbsoluteTime() << ")";
 #endif
 
     return elapsed;
 }
 
-#else
-// Version with proposed fix for bug #1627
-RealTime
-Composition::getElapsedRealTime(timeT t) const
-{
-    calculateTempoTimestamps();
-
-    // In case we have an anacrusis, make sure we have the proper
-    // start time which could be negative.
-    const timeT start = getStartMarker();
-    const RealTime realStart = time2RealTime(start, m_defaultTempo);
-
-    // Elapsed time is dependent on tempo changes.  Find the previous one.
-    ReferenceSegment::iterator tempoIter = m_tempoSegment.findAtOrBefore(t);
-    // None found?  We should probably use the default tempo.
-    if (tempoIter == m_tempoSegment.end()) {
-        // Try the first, if any.
-        // ??? If present, this will be after t.  So it is useless.
-        // ??? Make this a new firstTempoIter for clarity.
-        tempoIter = m_tempoSegment.begin();
-
-        // If the tempo segment is empty OR the first tempo change is
-        // after the composition start OR t is after the composition start...
-        // ??? We can get rid of the parens by reordering this.  However,
-        //     we should probably reorder this for speed.  The first check
-        //     should be the one that is most frequently true.  And the
-        //     iter check should obviously be before dereferencing.
-        // ??? This will probably always be true since t will always
-        //     be at or after start.  Then again, what if the composition
-        //     start is changed to something large and positive, thus
-        //     cutting off the tempo changes?  Does that delete them?
-        // ??? Previously, this checked against 0.  So it only detected
-        //     anacrusis (negative start time).  With this new version,
-        //     will it be affected by composition start bar which can be
-        //     something other than 1?  The original code translates to
-        //     this:
-        //     If the tempo segment is empty OR the first tempo change
-        //     is after the anacrusis OR t is after the anacrusis.
-        if (t >= start ||
-            (tempoIter == m_tempoSegment.end() ||  // tempo segment empty?
-                 (*tempoIter)->getAbsoluteTime() > start)) {  // tempo change is after composition start?
-            // Perform a simple pulses to seconds conversion using the
-            // default tempo.
-            RealTime rt = time2RealTime(t, m_defaultTempo);
-            rt = rt - realStart;
-            RG_DEBUG << "getElapsedRealTime 1" << t << rt;
-            return rt;
-        }
-
-        // ??? To get here, we would need:
-        //
-        //       - t prior to the first tempo change (easy to do)
-        //       - t prior to the start of the Composition
-        //       - the first tempo change prior to the start of Composition
-        //
-        //     Is this possible?  Can we have an event and a tempo change
-        //     prior to the start of the Composition?  So, set up the
-        //     first condition, then move the Composition start past that
-        //     point.  I have a feeling that might purge the events and
-        //     the tempo change.
-
-        // ??? Previously to get here we would need:
-        //
-        //       - t < 0 (within an anacrusis or some other reason)
-        //       - At least one tempo change at time 0 or earlier
-        //         (e.g. within an anacrusis).  I don't believe we
-        //         support tempo changes at negative time, so it would
-        //         have to be at time zero.
-        //       - t prior to that first tempo change.
-        //       - So given a negative t and tempo change at zero, we
-        //         have what we need to exercise this.
-        //
-        //     Then what happens below in this case?
-
-        // ??? I'm wondering if the original intent of t >= 0 was, "is
-        //     t sensible".  But then anacrusis was added and t >= 0
-        //     inadvertently became, "is t not within the anacrusis".
-    }
-
-    RealTime elapsed;
-
-    tempoT target = -1;
-    timeT nextTempoTime = t;
-
-    if (!getTempoTarget(tempoIter, target, nextTempoTime)) target = -1;
-
-    if (target > 0) {
-        elapsed = getTempoTimestamp(*tempoIter) +
-            time2RealTime(t - (*tempoIter)->getAbsoluteTime(),
-                          tempoT((*tempoIter)->get<Int>(TempoProperty)),
-                          nextTempoTime - (*tempoIter)->getAbsoluteTime(),
-                          target);
-    } else {
-        elapsed = getTempoTimestamp(*tempoIter) +
-            time2RealTime(t - (*tempoIter)->getAbsoluteTime(),
-                          tempoT((*tempoIter)->get<Int>(TempoProperty)));
-    }
-
-#ifdef DEBUG_TEMPO_STUFF
-    RG_DEBUG << "getElapsedRealTime(): " << t << " -> " << elapsed << " (last tempo change at " << (*tempoIter)->getAbsoluteTime() << ")";
-#endif
-
-    elapsed = elapsed - realStart;
-    RG_DEBUG << "getElapsedRealTime 2" << t << elapsed;
-
-    return elapsed;
-}
-#endif
-
-#ifndef BUG1627
-// Original version.
 timeT
 Composition::getElapsedTimeForRealTime(RealTime t) const
 {
     calculateTempoTimestamps();
 
+    RealTime startTime = - getElapsedRealTime(0);
     ReferenceSegment::iterator i = m_tempoSegment.findAtOrBefore(t);
     if (i == m_tempoSegment.end()) {
-        i = m_tempoSegment.begin();
-        if (t >= RealTime::zero()  ||
-            (i == m_tempoSegment.end() || (*i)->getAbsoluteTime() > 0)) {
-            return realTime2Time(t, m_defaultTempo);
-        }
+        // before any tempo use default tempo
+        timeT ret = realTime2Time(t + startTime, m_defaultTempo);
+#ifdef DEBUG_TEMPO_STUFF
+        RG_DEBUG << "getElapsedTimeForRealTime() 1: " << t << " -> "
+                 << ret;
+#endif
+        return ret;
     }
 
     timeT elapsed;
@@ -1498,7 +1391,7 @@ Composition::getElapsedTimeForRealTime(RealTime t) const
         RealTime cfReal = getElapsedRealTime(elapsed);
         timeT cfTimeT = getElapsedTimeForRealTime(cfReal);
         doError = true;
-        RG_DEBUG << "getElapsedTimeForRealTime(): " << t << " -> "
+        RG_DEBUG << "getElapsedTimeForRealTime() 2: " << t << " -> "
              << elapsed << " (error " << (cfReal - t)
              << " or " << (cfTimeT - elapsed) << ", tempo "
              << (*i)->getAbsoluteTime() << ":"
@@ -1508,70 +1401,12 @@ Composition::getElapsedTimeForRealTime(RealTime t) const
     return elapsed;
 }
 
-#else
-// Proposed fix for bug #1627.
-timeT
-Composition::getElapsedTimeForRealTime(RealTime t) const
-{
-    calculateTempoTimestamps();
-
-    // if the composition does not start at bar 1 we must add the
-    // start time here
-    timeT start = getStartMarker();
-    RealTime realStart = time2RealTime(start, m_defaultTempo);
-    t = t + realStart;
-
-    ReferenceSegment::iterator i = m_tempoSegment.findAtOrBefore(t);
-    if (i == m_tempoSegment.end()) {
-        i = m_tempoSegment.begin();
-        if (t >= realStart ||
-            (i == m_tempoSegment.end() || (*i)->getAbsoluteTime() > 0)) {
-            return realTime2Time(t, m_defaultTempo);
-        }
-    }
-
-    timeT elapsed;
-
-    tempoT target = -1;
-    timeT nextTempoTime = 0;
-    if (!getTempoTarget(i, target, nextTempoTime)) target = -1;
-
-    if (target > 0) {
-        elapsed = (*i)->getAbsoluteTime() +
-            realTime2Time(t - getTempoTimestamp(*i),
-                          (tempoT)((*i)->get<Int>(TempoProperty)),
-                          nextTempoTime - (*i)->getAbsoluteTime(),
-                          target);
-    } else {
-        elapsed = (*i)->getAbsoluteTime() +
-            realTime2Time(t - getTempoTimestamp(*i),
-                          (tempoT)((*i)->get<Int>(TempoProperty)));
-    }
-
-#ifdef DEBUG_TEMPO_STUFF
-    static int doError = true;
-    if (doError) {
-        doError = false;
-        RealTime cfReal = getElapsedRealTime(elapsed);
-        timeT cfTimeT = getElapsedTimeForRealTime(cfReal);
-        doError = true;
-        RG_DEBUG << "getElapsedTimeForRealTime(): " << t << " -> "
-             << elapsed << " (error " << (cfReal - t)
-             << " or " << (cfTimeT - elapsed) << ", tempo "
-             << (*i)->getAbsoluteTime() << ":"
-             << (tempoT)((*i)->get<Int>(TempoProperty)) << ")";
-    }
-#endif
-    return elapsed;
-}
-#endif
-
 void
 Composition::calculateTempoTimestamps() const
 {
     if (!m_tempoTimestampsNeedCalculating) return;
 
-    timeT lastTimeT = 0;
+    timeT lastTimeT = getStartMarker(); //0;
     RealTime lastRealTime;
 
     tempoT tempo = m_defaultTempo;
@@ -1700,13 +1535,13 @@ Composition::time2RealTime(timeT time, tempoT tempo,
 timeT
 Composition::realTime2Time(RealTime rt, tempoT tempo)
 {
-    static timeT cdur = Note(Note::Crotchet).getDuration();
+    static const timeT cdur = Note(Note::Crotchet).getDuration();
 
-    double tsec = (double(rt.sec) * cdur) * (tempo / (60.0 * 100000.0));
-    double tnsec = (double(rt.nsec) * cdur) * (tempo / 100000.0);
+    const double tsec = (double(rt.sec) * cdur) * (tempo / (60.0 * 100000.0));
+    const double tnsec = (double(rt.nsec) * cdur) * (tempo / 100000.0);
 
-    double dt = tsec + (tnsec / 60000000000.0);
-    timeT t = (timeT)(dt + (dt < 0 ? -1e-6 : 1e-6));
+    const double dt = tsec + (tnsec / 60000000000.0);
+    const timeT t = (timeT)(dt + (dt < 0 ? -1e-6 : 1e-6));
 
 #ifdef DEBUG_TEMPO_STUFF
     if (!DEBUG_silence_recursive_tempo_printout) {
@@ -1846,6 +1681,9 @@ Composition::getTempoTimestamp(const Event *e)
 void
 Composition::setTempoTimestamp(Event *e, RealTime t)
 {
+#ifdef DEBUG_TEMPO_STUFF
+    RG_DEBUG << "setTempoTimestamp" << *e << t;
+#endif
     e->setMaybe<RealTimeT>(TempoTimestampProperty, t);
 }
 
@@ -2807,6 +2645,16 @@ Composition::detachMarker(const Rosegarden::Marker *marker)
     return false;
 }
 
+Marker *
+Composition::findMarker(int markerID) const
+{
+    for (Marker *marker : m_markers) {
+        if (marker->getID() == markerID)
+            return marker;
+    }
+    return nullptr;
+}
+
 Segment*
 Composition::getSegmentByMarking(const QString& marking) const
 {
