@@ -16,9 +16,6 @@
 #ifndef RG_COMPOSITION_H
 #define RG_COMPOSITION_H
 
-// Enable fixes for bug #1627.
-//#define BUG1627
-
 #include "RealTime.h"
 #include "base/Segment.h"
 #include "Track.h"
@@ -249,6 +246,8 @@ public:
 
     void clearMarkers();
 
+    Marker *findMarker(int markerID) const;
+
 
     //////
     //
@@ -1160,9 +1159,8 @@ protected:
 
     RefreshStatusArray<RefreshStatus> m_refreshStatusArray;
 
-    // User defined markers in the composition
-    //
-    MarkerVector                   m_markers;
+    /// Sorted vector of Markers.  See addMarker().
+    MarkerVector m_markers;
 
     // Trigger segments (unsorted segments fired by events elsewhere)
     //
