@@ -13,16 +13,20 @@
     COPYING included with this distribution for more information.
 */
 
-#include <sstream>
-#include <cstdio>
-
 #include "ControlParameter.h"
+
+#include "base/Event.h"
 #include "base/MidiTypes.h"
 #include "gui/rulers/ControllerEventAdapter.h"
 
+#include <sstream>
+#include <cstdio>
+
+
 namespace Rosegarden
 {
 
+
 ControlParameter::ControlParameter():
     m_name("<unnamed>"),
     m_type(Rosegarden::Controller::EventType),
@@ -132,8 +136,7 @@ ControlParameter::toXmlString() const
 // Return a new event setting our controller to VALUE at TIME
 // @author Tom Breton (Tehom)
 Event *
-ControlParameter::
-newEvent(timeT time, int value) const
+ControlParameter::newEvent(timeT time, int value) const
 {
     Event *event = new Event (getType(), time);
     ControllerEventAdapter(event).setValue(value);
@@ -147,8 +150,7 @@ newEvent(timeT time, int value) const
 // Return whether "e" is this type of controller / pitchbend.
 // @author Tom Breton (Tehom)
 bool
-ControlParameter::
-matches(Event *e) const
+ControlParameter::matches(Event *e) const
 {
     return
         e->isa(m_type) &&
@@ -163,26 +165,146 @@ matches(Event *e) const
 // expression rather than getting a ControlParameter from a ruler or
 // device.  This can't be just a static member of ControlParameter, in
 // order to prevent the "static initialization order fiasco".
-const ControlParameter&
-ControlParameter::
-getPitchBend()
+const ControlParameter &
+ControlParameter::getPitchBend()
 {
-    static const ControlParameter
-        pitchBend(
-                  "PitchBend", Rosegarden::PitchBend::EventType, "<none>",
-                  0, 16383, 8192, MidiByte(1), 4, -1);
+    static const ControlParameter pitchBend(
+            "PitchBend",  // name
+            Rosegarden::PitchBend::EventType,  // type
+            "<none>",  // description
+            0,  // min
+            16383,  // max
+            8192,  // def
+            MidiByte(1),  // controllerNumber  ??? ignored?
+            4,  // colour
+            -1);  // ipbPosition
+
     return pitchBend;
 }
 
-const ControlParameter&
-ControlParameter::
-getExpression()
+const ControlParameter &
+ControlParameter::getExpression()
 {
-    static const ControlParameter
-        expression(
-                  "Expression", Rosegarden::Controller::EventType,
-                  "<none>", 0, 127, 100, MidiByte(11), 2, -1);
+    static const ControlParameter expression(
+            "Expression",  // name
+            Rosegarden::Controller::EventType,  // type
+            "<none>",  // description
+            0,  // min
+            127,  // max
+            127,  // def
+            MidiByte(11),  // controllerNumber
+            2,  // colour
+            -1);  // ipbPosition
+
     return expression;
 }
 
+const ControlParameter &
+ControlParameter::getChannelPressure()
+{
+    static const ControlParameter channelPressure(
+            "Channel Pressure",  // name
+            Rosegarden::ChannelPressure::EventType,  // type
+            "<none>",  // description
+            0,  // min
+            127,  // max
+            0,  // def
+            MidiByte(1),  // controllerNumber  ??? ignored?
+            2,  // colour
+            -1);  // ipbPosition
+
+    return channelPressure;
+}
+
+const ControlParameter &
+ControlParameter::getKeyPressure()
+{
+    static const ControlParameter keyPressure(
+            "Key Pressure",  // name
+            Rosegarden::KeyPressure::EventType,  // type
+            "<none>",  // description
+            0,  // min
+            127,  // max
+            0,  // def
+            MidiByte(1),  // controllerNumber  ??? ignored?
+            2,  // colour
+            -1);  // ipbPosition
+
+    return keyPressure;
+}
+
+const std::vector<ControlParameter> &
+ControlParameter::getDefaultControllers()
+{
+    static std::vector<ControlParameter> controlList;
+
+    if (controlList.empty()) {
+        controlList.push_back(ControlParameter(
+                "Pan",
+                Controller::EventType,
+                "<none>",
+                0,
+                127,
+                64,
+                10,
+                2,
+                0));
+        controlList.push_back(ControlParameter(
+                "Chorus",
+                Controller::EventType,
+                "<none>",
+                0,
+                127,
+                0,
+                93,
+                3,
+                1));
+        controlList.push_back(ControlParameter(
+                "Volume",
+                Controller::EventType,
+                "<none>",
+                0,
+                127,
+                100,
+                7,
+                1,
+                2));
+        controlList.push_back(ControlParameter(
+                "Reverb",
+                Controller::EventType,
+                "<none>",
+                0,
+                127,
+                0,
+                91,
+                3,
+                3));
+        controlList.push_back(ControlParameter(
+                "Sustain",
+                Controller::EventType,
+                "<none>",
+                0,
+                127,
+                0,
+                64,
+                4,
+                -1));
+        controlList.push_back(getExpression());
+        controlList.push_back(ControlParameter(
+                "Modulation",
+                Controller::EventType,
+                "<none>",
+                0,
+                127,
+                0,
+                1,
+                4,
+                -1));
+        controlList.push_back(getPitchBend());
+    }
+
+    return controlList;
+}
+
+
 }
