@@ -31,11 +31,14 @@
 #include <string>
 #include <sstream>
 
+#include <QCoreApplication>
 #include <QString>
 
+
 namespace Rosegarden
 {
 
+
 #if 0
 MidiDevice::MidiDevice():
     Device(0, "Default Midi Device", Device::Midi),
@@ -69,7 +72,7 @@ MidiDevice::MidiDevice(DeviceId id,
     //RG_DEBUG << "create midi device" << name << dir;
     createInstruments(ibase);
     generatePresentationList();
-    generateDefaultControllers();
+    m_controlList = ControlParameter::getDefaultControllers();
     deviceToInstrControllerPush();
 
     // create a default Metronome
@@ -132,8 +135,8 @@ MidiDevice::MidiDevice(const MidiDevice &dev) :
 
     // Copy the instruments
     //
-    InstrumentList insList = dev.getAllInstruments();
-    InstrumentList::iterator iIt = insList.begin();
+    InstrumentVector insList = dev.getAllInstruments();
+    InstrumentVector::iterator iIt = insList.begin();
     for (; iIt != insList.end(); ++iIt)
     {
         Instrument *newInst = new Instrument(**iIt);
@@ -185,8 +188,8 @@ MidiDevice::operator=(const MidiDevice &dev)
 
     // Copy the instruments
     //
-    InstrumentList insList = dev.getAllInstruments();
-    InstrumentList::iterator iIt = insList.begin();
+    InstrumentVector insList = dev.getAllInstruments();
+    InstrumentVector::iterator iIt = insList.begin();
     for (; iIt != insList.end(); ++iIt)
     {
         Instrument *newInst = new Instrument(**iIt);
@@ -250,7 +253,7 @@ MidiDevice::generatePresentationList()
     //
     m_presentationInstrumentList.clear();
 
-    InstrumentList::iterator it;
+    InstrumentVector::iterator it;
     for (it = m_instruments.begin(); it != m_instruments.end(); ++it)
     {
         if ((*it)->getId() >= MidiInstrumentBase) {
@@ -259,44 +262,13 @@ MidiDevice::generatePresentationList()
     }
 }
 
-void
-MidiDevice::generateDefaultControllers()
-{
-    m_controlList.clear();
-
-    static std::string controls[][9] = {
-        { "Pan", Rosegarden::Controller::EventType, "<none>", "0", "127", "64", "10", "2", "0" },
-        { "Chorus", Rosegarden::Controller::EventType, "<none>", "0", "127", "0", "93", "3", "1" },
-        { "Volume", Rosegarden::Controller::EventType, "<none>", "0", "127", "100", "7", "1", "2" },
-        { "Reverb", Rosegarden::Controller::EventType, "<none>", "0", "127", "0", "91", "3", "3" },
-        { "Sustain", Rosegarden::Controller::EventType, "<none>", "0", "127", "0", "64", "4", "-1" },
-        { "Expression", Rosegarden::Controller::EventType, "<none>", "0", "127", "127", "11", "2", "-1" },
-        { "Modulation", Rosegarden::Controller::EventType, "<none>", "0", "127", "0", "1", "4", "-1" },
-        { "PitchBend", Rosegarden::PitchBend::EventType, "<none>", "0", "16383", "8192", "1", "4", "-1" }
-    };
-
-    for (size_t i = 0; i < sizeof(controls) / sizeof(controls[0]); ++i) {
-
-        Rosegarden::ControlParameter con(controls[i][0],
-                                         controls[i][1],
-                                         controls[i][2],
-                                         atoi(controls[i][3].c_str()),
-                                         atoi(controls[i][4].c_str()),
-                                         atoi(controls[i][5].c_str()),
-                                         Rosegarden::MidiByte(atoi(controls[i][6].c_str())),
-                                         atoi(controls[i][7].c_str()),
-                                         atoi(controls[i][8].c_str()));
-        addControlParameter(con, false);
-    }
-}
-
 void
 MidiDevice::deviceToInstrControllerPush()
 {
     // Copy the instruments
     //
 
-    InstrumentList::iterator iIt = m_instruments.begin();
+    InstrumentVector::iterator iIt = m_instruments.begin();
     for (; iIt != m_instruments.end(); ++iIt)
     {
         (*iIt)->clearStaticControllers();
@@ -338,8 +310,8 @@ void
 MidiDevice::clearControlList()
 {
     // Clear down instrument controllers first.
-    InstrumentList insList = getAllInstruments();
-    InstrumentList::iterator iIt = insList.begin();
+    InstrumentVector insList = getAllInstruments();
+    InstrumentVector::iterator iIt = insList.begin();
 
     for(; iIt != insList.end(); ++iIt) {
         (*iIt)->clearStaticControllers();
@@ -589,7 +561,7 @@ MidiDevice::toXmlString() const
     // and now bank information
     //
     BankList::const_iterator it;
-    InstrumentList::const_iterator iit;
+    InstrumentVector::const_iterator iit;
     ProgramList::const_iterator pt;
 
     for (it = m_bankList.begin(); it != m_bankList.end(); ++it)
@@ -658,13 +630,13 @@ MidiDevice::toXmlString() const
 
 // Only copy across non System instruments
 //
-InstrumentList
+InstrumentVector
 MidiDevice::getAllInstruments() const
 {
     return m_instruments;
 }
 
-InstrumentList
+InstrumentVector
 MidiDevice::getPresentationInstruments() const
 {
     return m_presentationInstrumentList;
@@ -895,8 +867,8 @@ void
 MidiDevice::replaceControlParameters(const ControlList &con)
 {
     // Clear down instrument controllers in preparation for replace.
-    InstrumentList insList = getAllInstruments();
-    InstrumentList::iterator iIt = insList.begin();
+    InstrumentVector insList = getAllInstruments();
+    InstrumentVector::iterator iIt = insList.begin();
 
     for(; iIt != insList.end(); ++iIt) {
         (*iIt)->clearStaticControllers();
@@ -919,10 +891,10 @@ void
 MidiDevice::
 conformInstrumentControllers(void)
 {
-    InstrumentList insList = getAllInstruments();
+    InstrumentVector insList = getAllInstruments();
 
     // Treat each instrument
-    for(InstrumentList::iterator iIt = insList.begin();
+    for(InstrumentVector::iterator iIt = insList.begin();
         iIt != insList.end();
         ++iIt) {
         // Get this instrument's static controllers.  As a seperate
@@ -1023,8 +995,8 @@ MidiDevice::addControlToInstrument(const ControlParameter &con) const
 
     // Run through all of this devices instruments and add default controls and
     // values to them.
-    InstrumentList insList = getAllInstruments();
-    InstrumentList::iterator iIt = insList.begin();
+    InstrumentVector insList = getAllInstruments();
+    InstrumentVector::iterator iIt = insList.begin();
 
     for(; iIt != insList.end(); ++iIt) {
         MidiByte controllerNumber = con.getControllerNumber();
@@ -1037,9 +1009,9 @@ void
 MidiDevice::removeControlFromInstrument(
         const ControlParameter &controlParameter) const
 {
-    InstrumentList instrumentList = getAllInstruments();
+    InstrumentVector instrumentList = getAllInstruments();
 
-    for (InstrumentList::iterator instrumentIter = instrumentList.begin();
+    for (InstrumentVector::iterator instrumentIter = instrumentList.begin();
          instrumentIter != instrumentList.end();
          ++instrumentIter) {
         (*instrumentIter)->removeStaticController(
@@ -1076,21 +1048,18 @@ ControlParameter *
 MidiDevice::getControlParameter(
         const std::string &type, Rosegarden::MidiByte controllerNumber)
 {
-    ControlList::iterator it = m_controlList.begin();
-
-    for (; it != m_controlList.end(); ++it)
+    // For each ControlParameter...
+    for (ControlParameter &controlParameter : m_controlList)
     {
-        if (it->getType() == type)
+        if (controlParameter.getType() == type)
         {
             // Return matched on type for most events
-            //
             if (type != Rosegarden::Controller::EventType)
-                return &*it;
+                return &controlParameter;
 
             // Also match controller value for Controller events
-            //
-            if (it->getControllerNumber() == controllerNumber)
-                return  &*it;
+            if (controlParameter.getControllerNumber() == controllerNumber)
+                return  &controlParameter;
         }
     }
 
