@@ -16,12 +16,17 @@
 #ifndef RG_NOTATION_TYPES_H
 #define RG_NOTATION_TYPES_H
 
-#include <list>
-#include <map>
-
 #include <rosegardenprivate_export.h>
 
-#include "Event.h"
+#include "TimeT.h"
+#include "Exception.h"
+#include "PropertyName.h"
+
+#include <list>
+#include <string>
+#include <vector>
+#include <map>
+#include <memory>
 
 /*
  * NotationTypes.h
@@ -61,9 +66,13 @@
  * Program Changes.
  */
 
+
 namespace Rosegarden
 {
 
+
+class Event;
+
 extern ROSEGARDENPRIVATE_EXPORT const int MIN_SUBORDERING;
 
 typedef std::list<int> DurationList;
@@ -433,7 +442,6 @@ public:
     Key(const Key &kc);
 
     ~Key() {
-        delete m_accidentalHeights;
     }
 
     Key &operator=(const Key &kc);
@@ -582,8 +590,9 @@ public:
     Key transpose(int pitchDelta, int heightDelta) const;
 
 private:
+
     std::string m_name;
-    mutable std::vector<int> *m_accidentalHeights;
+    mutable std::shared_ptr<std::vector<int>> m_accidentalHeights;
 
     struct KeyDetails {
         bool   m_sharps;
