@@ -288,7 +288,7 @@ Segment::isPlainlyLinked() const {
 }
 
 bool
-Segment::isLinkedTo(Segment * seg) const {
+Segment::isLinkedTo(const Segment * seg) const {
     if (!m_segmentLinker) return false;
 
     const SegmentLinker * otherSegmentLinker = seg->getLinker();
@@ -725,14 +725,15 @@ Segment::eraseSingle(Event* e)
 
 
 Segment::iterator
-Segment::findSingle(Event* e)
+Segment::findSingle(const Event* e) const
 {
+    Event* e1 = const_cast<Event*>(e);
     iterator res = end();
 
-    std::pair<iterator, iterator> interval = equal_range(e);
+    std::pair<iterator, iterator> interval = equal_range(e1);
 
     for (iterator i = interval.first; i != interval.second; ++i) {
-        if (*i == e) {
+        if (*i == e1) {
             res = i;
             break;
         }
