@@ -17,11 +17,6 @@
 #ifndef RG_SEGMENT_H
 #define RG_SEGMENT_H
 
-#include <set>
-#include <list>
-#include <string>
-#include <memory>
-
 #include "Track.h"
 #include "Event.h"
 #include "base/NotationTypes.h"
@@ -33,9 +28,24 @@
 #include <QColor>
 #include <QSharedPointer>
 
+#include <set>
+#include <list>
+#include <string>
+#include <memory>
+
+
 namespace Rosegarden
 {
 
+
+class SegmentObserver;
+class Quantizer;
+class BasicQuantizer;
+class Composition;
+class SegmentLinker;
+class BasicCommand;
+
+
 /// A refresh flag with a time range.
 class SegmentRefreshStatus : public RefreshStatus
 {
@@ -52,13 +62,6 @@ protected:
     timeT m_to;
 };
 
-class SegmentObserver;
-class Quantizer;
-class BasicQuantizer;
-class Composition;
-class SegmentLinker;
-class BasicCommand;
-
 /// Container of Events.
 /**
  * EventContainer is a precursor to Segment, used in code that needs
@@ -420,13 +423,13 @@ public:
      * Returns an iterator pointing to that specific element,
      * end() otherwise
      */
-    iterator findSingle(Event*);
+    iterator findSingle(const Event*) const;
 
     /**
      * Returns an iterator pointing to the first element starting at
      * or beyond the given absolute time
      */
-    iterator findTime(timeT time)
+    iterator findTime(timeT time) const
     {
         Event temp("temp", time, 0, MIN_SUBORDERING);
         return lower_bound(&temp);
@@ -831,7 +834,7 @@ public:
     /**
      * Return true if the given segment is linked to this.
      */
-    bool isLinkedTo(Segment *) const;
+    bool isLinkedTo(const Segment *) const;
 
     /**
      * Return true if the given segment is a plain link linked to the current
