@@ -52,15 +52,16 @@ SegmentNotationHelper::basicQuantizer() {
     return *(segment().getComposition()->getBasicQuantizer());
 }
 
+#if 0
 const Quantizer &
 SegmentNotationHelper::notationQuantizer() {
     return *(segment().getComposition()->getNotationQuantizer());
 }
+#endif
 
-
-//!!! we need to go very carefully through this file and check calls
-//to getAbsoluteTime/getDuration -- the vast majority should almost
-//certainly now be using getNotationAbsoluteTime/getNotationDuration
+// !!! we need to go very carefully through this file and check calls
+// to getAbsoluteTime/getDuration -- the vast majority should almost
+// certainly now be using getNotationAbsoluteTime/getNotationDuration
 
 Segment::iterator
 SegmentNotationHelper::findNotationAbsoluteTime(timeT t)
@@ -332,7 +333,7 @@ SegmentNotationHelper::findContiguousPrevious(Segment::iterator el)
 
 
 bool
-SegmentNotationHelper::noteIsInChord(Event *note)
+SegmentNotationHelper::noteIsInChord(const Event *note)
 {
     Segment::iterator i = segment().findSingle(note);
     timeT t = note->getNotationAbsoluteTime();
@@ -511,6 +512,8 @@ SegmentNotationHelper::splitIntoTie(Segment::iterator &from, Segment::iterator t
     // if its duration is very close to requested duration, but that's
     // probably not a task for this function
 
+    RG_DEBUG << "Segment before splitIntoTie" << segment();
+
     timeT eventDuration = (*from)->getDuration();
     timeT baseTime = (*from)->getAbsoluteTime();
 
@@ -616,6 +619,8 @@ SegmentNotationHelper::splitIntoTie(Segment::iterator &from, Segment::iterator t
         if (from == end()) from = last;
     }
 
+    RG_DEBUG << "Segment after splitIntoTie" << segment();
+
     return last;
 }
 
@@ -660,7 +665,7 @@ SegmentNotationHelper::makeRestViable(Segment::iterator i)
 
 
 Event *
-SegmentNotationHelper::makeThisNoteViable(Segment::iterator noteItr, bool splitAtBars)
+SegmentNotationHelper::makeThisNoteViable(Segment::iterator noteItr)
 {
     // We don't use quantized values here; we want a precise division.
     // Even if it doesn't look precise on the score (because the score
@@ -698,15 +703,18 @@ SegmentNotationHelper::makeThisNoteViable(Segment::iterator noteItr, bool splitA
     // the duration list (dl).
     while (acc < required) {
         timeT remaining = required - acc;
-        if (splitAtBars) {
-            timeT thisNoteStart = qt + acc;
-            timeT toNextBar =
-                    segment().getBarEndForTime(thisNoteStart) - thisNoteStart;
-            if (toNextBar > 0 && remaining > toNextBar)
-                remaining = toNextBar;
-        }
-        timeT component = Note::getNearestNote(remaining).getDuration();
-        timeT dur = (component > (required - acc) ? (required - acc) : component);
+
+        // Split at bar
+
+        const timeT thisNoteStart = qt + acc;
+        const timeT toNextBar =
+                segment().getBarEndForTime(thisNoteStart) - thisNoteStart;
+        if (toNextBar > 0 && remaining > toNextBar)
+            remaining = toNextBar;
+
+        const timeT component = Note::getNearestNote(remaining).getDuration();
+        const timeT dur =
+                (component > (required - acc) ? (required - acc) : component);
 
         // #1517: In the scenario where there is a whole note (4 beats) in a
         // single measure of 2/2, maxdur == dur and this is exactly as it should
@@ -817,8 +825,8 @@ SegmentNotationHelper::makeThisNoteViable(Segment::iterator noteItr, bool splitA
 }
 
 void
-SegmentNotationHelper::makeNotesViable(Segment::iterator from, Segment::iterator to,
-                                       bool splitAtBars)
+SegmentNotationHelper::makeNotesViable(
+        Segment::iterator from, Segment::iterator to)
 {
 //  std::vector<Event *> toInsert;
 
@@ -831,19 +839,18 @@ SegmentNotationHelper::makeNotesViable(Segment::iterator from, Segment::iterator
         // event that our iterator points to.
         ++j;
 
-        makeThisNoteViable(i, splitAtBars);
+        makeThisNoteViable(i);
     }
 
 }
 
 void
-SegmentNotationHelper::makeNotesViable(timeT startTime, timeT endTime,
-                                       bool splitAtBars)
+SegmentNotationHelper::makeNotesViable(timeT startTime, timeT endTime)
 {
     Segment::iterator from = segment().findTime(startTime);
     Segment::iterator to = segment().findTime(endTime);
 
-    makeNotesViable(from, to, splitAtBars);
+    makeNotesViable(from, to);
 }
 
 
@@ -895,8 +902,12 @@ SegmentNotationHelper::insertNote(Event *modelEvent)
         }
     }
     if (j != end() && (*j)->has(BEAMED_GROUP_TUPLET_BASE)) {
-        duration = duration * (*j)->get<Int>(BEAMED_GROUP_TUPLED_COUNT) /
-            (*j)->get<Int>(BEAMED_GROUP_UNTUPLED_COUNT);
+        int tupled = (*j)->get<Int>(BEAMED_GROUP_TUPLED_COUNT);
+        int untupled = (*j)->get<Int>(BEAMED_GROUP_UNTUPLED_COUNT);
+        duration = getTupletNoteDuration(duration,
+                                         absoluteTime,
+                                         tupled,
+                                         untupled);
     }
 
     RG_DEBUG << "duration" << duration;
@@ -2088,7 +2099,7 @@ SegmentNotationHelper::mergeContiguousRests(timeT startTime,
 
 
 Segment::iterator
-SegmentNotationHelper::collapseNoteAggressively(Event *note,
+SegmentNotationHelper::collapseNoteAggressively(const Event *note,
                                                 timeT rangeEnd)
 {
     Segment::iterator i = segment().findSingle(note);
@@ -2351,6 +2362,34 @@ SegmentNotationHelper::autoSlur(timeT startTime, timeT endTime, bool legatoOnly)
     }
 }
 
+timeT SegmentNotationHelper::getTupletNoteDuration
+(timeT baseDuration, // untupled duration
+ timeT insertionTime,
+ int tupled,
+ int untupled)
+{
+    // find start of tuple
+    timeT baseUnit = baseDuration * tupled;
+    RG_DEBUG << "Base unit:" << baseUnit;
+    int tupletStartRatio = insertionTime / baseUnit;
+    timeT tupletStart = tupletStartRatio * baseUnit;
+    timeT approxNoteDuration = baseDuration * tupled / untupled;
+    RG_DEBUG << "tuplet start:" << tupletStart;
+    double posInTupleD = ((double)(insertionTime - tupletStart) /
+                          (double)approxNoteDuration);
+    int posInTuple = (int)(posInTupleD + 0.5);
+    int posNextInTuple = posInTuple + 1;
+    RG_DEBUG << "next position in tuple" << posNextInTuple;
+    double noteEndTimeD = (double)tupletStart +
+        (double)(posNextInTuple * baseDuration * tupled) /
+        (double)untupled;
+    timeT noteEndTime = (timeT)(noteEndTimeD + 0.5);
+    RG_DEBUG << "note end time:" << noteEndTime;
+    timeT trueDuration = noteEndTime - insertionTime;
+    RG_DEBUG << "true duration:" << trueDuration;
+    return trueDuration;
+}
+
 void SegmentNotationHelper::updateIndications(timeT startTime, timeT endTime)
 {
     RG_DEBUG << "updateIndications" << startTime << endTime;
@@ -2478,6 +2517,7 @@ int SegmentNotationHelper::findBorderTuplet(
 {
     Segment::iterator beginB = segment().findTime(segment().getBarStartForTime((*it)->getAbsoluteTime()));
     Segment::iterator endB = segment().findTime(segment().getBarEndForTime((*it)->getAbsoluteTime()));
+
     int maxcount = 0;
     int count = 0;
     int index = 0;
@@ -2522,5 +2562,4 @@ int SegmentNotationHelper::findBorderTuplet(
     return count;
 }
 
-
 } // end of namespace
