@@ -149,7 +149,7 @@ public:
      * Returns true if the iterator points at a note in a chord
      * e.g. if there are more notes at the same absolute time
      */
-    bool noteIsInChord(Event *note);
+    bool noteIsInChord(const Event *note);
 
     /**
      * Returns an iterator pointing to the note that this one is tied
@@ -361,7 +361,7 @@ public:
      * Split a note or rest up into tied notes or shorter rests of
      * viable lengths (longest possible viable duration first, then
      * longest possible viable component of remainder &c).  Also
-     * optionally split a note or rest at barlines -- this is
+     * splits a note or rest at barlines -- this is
      * actually the most common user-visible use of this function.
      *
      * Note: no checks performed on validity of noteItr, use caution.
@@ -369,23 +369,16 @@ public:
      * Returns the original *noteItr Event if no split and tie occurs
      * or returns the first new event inserted if split and tie occurs
      */
-    Event * makeThisNoteViable(Segment::iterator noteItr, bool splitAtBars = true);
+    Event *makeThisNoteViable(Segment::iterator noteItr);
 
     /**
      * Split notes and rests up into tied notes or shorter rests of
      * viable lengths (longest possible viable duration first, then
      * longest possible viable component of remainder &c).  Also
-     * optionally splits notes and rests at barlines -- this is
+     * splits notes and rests at barlines -- this is
      * actually the most common user-visible use of this function.
      */
-    void makeNotesViable(Segment::iterator from, Segment::iterator to, bool splitAtBars = true);
-
-
-    /**
-     * As above but given a range in time rather than iterators.
-     */
-    void makeNotesViable(timeT startTime, timeT endTime,
-                         bool splitAtBars = true);
+    void makeNotesViable(timeT startTime, timeT endTime);
 
 
     /**
@@ -530,7 +523,7 @@ public:
      * original one if a collapse happened, segment.end() if no
      * collapse or event not found
      */
-    Segment::iterator collapseNoteAggressively(Event *, timeT rangeEnd);
+    Segment::iterator collapseNoteAggressively(const Event *, timeT rangeEnd);
 
 
 
@@ -553,6 +546,12 @@ public:
      */
     void autoSlur(timeT startTime, timeT endTime, bool legatoOnly);
 
+    /// get duration of tuplet note
+    static timeT getTupletNoteDuration(timeT baseDuration, // untupled duration
+                                       timeT insertionTime,
+                                       int tupled,
+                                       int untupled);
+
     /// Remove and adjust slurs as needed for a time range.
     /**
      * ??? This routine really just deals in slurs.  Would a better name be
@@ -561,9 +560,10 @@ public:
      */
     void updateIndications(timeT startTime, timeT endTime);
 
-protected:
+private:
+
     const Quantizer &basicQuantizer();
-    const Quantizer &notationQuantizer();
+    //const Quantizer &notationQuantizer();
 
     /**
      * Collapse multiple consecutive rests into one, in preparation
@@ -630,6 +630,9 @@ protected:
 
     /// find border of tupled
     int findBorderTuplet(Segment::iterator, Segment::iterator &start, Segment::iterator &end);
+
+    void makeNotesViable(Segment::iterator from, Segment::iterator to);
+
 };
 
 }
