@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
     See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
@@ -48,13 +48,13 @@ EventSelection::EventSelection(Segment& t, timeT beginTime, timeT endTime, bool
     Segment::iterator j = t.findTime(endTime);
 
     if (i != t.end()) {
-	m_beginTime = (*i)->getAbsoluteTime();
-	while (i != j) {
-	    m_endTime = (*i)->getAbsoluteTime() + (*i)->getGreaterDuration();
-	    m_segmentEvents.insert(*i);
-	    ++i;
-	}
-	m_haveRealStartTime = true;
+        m_beginTime = (*i)->getAbsoluteTime();
+        while (i != j) {
+            m_endTime = (*i)->getAbsoluteTime() + (*i)->getGreaterDuration();
+            m_segmentEvents.insert(*i);
+            ++i;
+        }
+        m_haveRealStartTime = true;
     }
 
     // Find events overlapping the beginning
@@ -120,8 +120,8 @@ EventSelection::insertThisEvent(Event *e)
     if (contains(e)) return;
 
     if (e->getAbsoluteTime() < m_beginTime || !m_haveRealStartTime) {
-	m_beginTime = e->getAbsoluteTime();
-	m_haveRealStartTime = true;
+        m_beginTime = e->getAbsoluteTime();
+        m_haveRealStartTime = true;
     }
 
     timeT eventDuration = e->getGreaterDuration();
@@ -129,14 +129,14 @@ EventSelection::insertThisEvent(Event *e)
 
     timeT eventEndTime = e->getAbsoluteTime() + eventDuration;
     if (eventEndTime > m_endTime) {
-	m_endTime = eventEndTime;
+        m_endTime = eventEndTime;
     }
 
     m_segmentEvents.insert(e);
 
     // Notify observers of new selected event
     for (ObserverSet::const_iterator i = m_observers.begin(); i != m_observers.end(); ++i) {
-	(*i)->eventSelected(this, e);
+        (*i)->eventSelected(this, e);
     }
 }
 
@@ -158,6 +158,7 @@ EventSelection::eraseThisEvent(Event *event)
          ++eventIter) {
 
         // If this is the actual one we want to remove...
+        // cppcheck-suppress useStlAlgorithm
         if (*eventIter == event) {
 
             eventIter = m_segmentEvents.erase(eventIter);
@@ -304,6 +305,7 @@ EventSelection::addObserver(EventSelectionObserver *obs) {
 }
 
 void
+// cppcheck-suppress constParameterPointer
 EventSelection::removeObserver(EventSelectionObserver *obs) {
     m_observers.remove(obs);
 }
@@ -319,7 +321,7 @@ void
 EventSelection::addFromSelection(EventSelection *sel)
 {
     for (EventContainer::iterator i = sel->getSegmentEvents().begin();
-	 i != sel->getSegmentEvents().end(); ++i) {
+         i != sel->getSegmentEvents().end(); ++i) {
         // contains() checked a bit deeper now
         addEvent(*i);
     }
@@ -335,11 +337,12 @@ bool
 EventSelection::contains(Event *e) const
 {
     std::pair<EventContainer::const_iterator, EventContainer::const_iterator>
-	interval = m_segmentEvents.equal_range(e);
+        interval = m_segmentEvents.equal_range(e);
 
     for (EventContainer::const_iterator it = interval.first;
          it != interval.second; ++it)
     {
+        // cppcheck-suppress useStlAlgorithm
         if (*it == e) return true;
     }
 
@@ -350,8 +353,9 @@ bool
 EventSelection::contains(const std::string &type) const
 {
     for (EventContainer::const_iterator i = m_segmentEvents.begin();
-	 i != m_segmentEvents.end(); ++i) {
-	if ((*i)->isa(type)) return true;
+         i != m_segmentEvents.end(); ++i) {
+        // cppcheck-suppress useStlAlgorithm
+        if ((*i)->isa(type)) return true;
     }
     return false;
 }
@@ -370,10 +374,10 @@ EventSelection::getNotationStartTime() const
     // inefficient, but the simplest way to be sure (since events are
     // not ordered in notation time)
     for (EventContainer::const_iterator i = m_segmentEvents.begin();
-	 i != m_segmentEvents.end(); ++i) {
-	timeT t = (*i)->getNotationAbsoluteTime();
-	if (first || t < start) start = t;
-	first = false;
+         i != m_segmentEvents.end(); ++i) {
+        timeT t = (*i)->getNotationAbsoluteTime();
+        if (first || t < start) start = t;
+        first = false;
     }
     return start;
 }
@@ -386,10 +390,10 @@ EventSelection::getNotationEndTime() const
     // inefficient, but the simplest way to be sure (since events are
     // not ordered in notation time)
     for (EventContainer::const_iterator i = m_segmentEvents.begin();
-	 i != m_segmentEvents.end(); ++i) {
-	timeT t = (*i)->getNotationAbsoluteTime() + (*i)->getNotationDuration();
-	if (first || t > end) end = t;
-	first = false;
+         i != m_segmentEvents.end(); ++i) {
+        timeT t = (*i)->getNotationAbsoluteTime() + (*i)->getNotationDuration();
+        if (first || t > end) end = t;
+        first = false;
     }
     return end;
 }
@@ -402,12 +406,12 @@ EventSelection::getTotalNotationDuration() const
     // inefficient, but the simplest way to be sure (since events are
     // not ordered in notation time)
     for (EventContainer::const_iterator i = m_segmentEvents.begin();
-	 i != m_segmentEvents.end(); ++i) {
-	timeT t = (*i)->getNotationAbsoluteTime();
-	if (first || t < start) start = t;
-	t += (*i)->getNotationDuration();
-	if (first || t > end) end = t;
-	first = false;
+         i != m_segmentEvents.end(); ++i) {
+        timeT t = (*i)->getNotationAbsoluteTime();
+        if (first || t < start) start = t;
+        t += (*i)->getNotationDuration();
+        if (first || t > end) end = t;
+        first = false;
     }
     return end - start;
 }
@@ -427,10 +431,10 @@ EventSelection::getRanges() const
 
         if (j != i) {
             ranges.push_back(RangeList::value_type(i, j));
-	}
+        }
 
-	for (i = j; i != k && !contains(*i); ++i) { }
-	j = i;
+        for (i = j; i != k && !contains(*i); ++i) { }
+        j = i;
     }
 
     return ranges;
@@ -443,15 +447,15 @@ EventSelection::getRangeTimes() const
     RangeTimeList rangeTimes;
 
     for (RangeList::iterator i = ranges.begin(); i != ranges.end(); ++i) {
-	timeT startTime = m_originalSegment.getEndTime();
-	timeT   endTime = m_originalSegment.getEndTime();
-	if (i->first != m_originalSegment.end()) {
-	    startTime = (*i->first)->getAbsoluteTime();
-	}
-	if (i->second != m_originalSegment.end()) {
-	    endTime = (*i->second)->getAbsoluteTime();
-	}
-	rangeTimes.push_back(RangeTimeList::value_type(startTime, endTime));
+        timeT startTime = m_originalSegment.getEndTime();
+        timeT   endTime = startTime;
+        if (i->first != m_originalSegment.end()) {
+            startTime = (*i->first)->getAbsoluteTime();
+        }
+        if (i->second != m_originalSegment.end()) {
+            endTime = (*i->second)->getAbsoluteTime();
+        }
+        rangeTimes.push_back(RangeTimeList::value_type(startTime, endTime));
     }
 
     return rangeTimes;
@@ -471,7 +475,7 @@ EventSelection::segmentDeleted(const Segment *)
 {
     /*
     RG_DEBUG << "WARNING: EventSelection notified of segment deletion: this is probably a bug "
-	      << "(selection should have been deleted before segment)";
+              << "(selection should have been deleted before segment)";
               */
 }
 
@@ -511,32 +515,32 @@ TimewiseSelection<ElementInfo>::AddToComposition(Composition *composition) const
 
 TimeSignatureSelection::TimeSignatureSelection() { }
 
-TimeSignatureSelection::TimeSignatureSelection(Composition &composition,
-					       timeT beginTime,
-					       timeT endTime,
-					       bool includeOpeningTimeSig)
+TimeSignatureSelection::TimeSignatureSelection(const Composition &composition,
+                                               timeT beginTime,
+                                               timeT endTime,
+                                               bool includeOpeningTimeSig)
 {
     int n = composition.getTimeSignatureNumberAt(endTime);
 
     for (int i = composition.getTimeSignatureNumberAt(beginTime);
-	 i <= n;
-	 ++i) {
+         i <= n;
+         ++i) {
 
-	if (i < 0) continue;
+        if (i < 0) continue;
 
-	std::pair<timeT, TimeSignature> sig =
-	    composition.getTimeSignatureChange(i);
+        std::pair<timeT, TimeSignature> sig =
+            composition.getTimeSignatureChange(i);
 
-	if (sig.first < endTime) {
-	    if (sig.first < beginTime) {
-		if (includeOpeningTimeSig) {
-		    sig.first = beginTime;
-		} else {
-		    continue;
-		}
-	    }
-	    addTimeSignature(sig.first, sig.second);
-	}
+        if (sig.first < endTime) {
+            if (sig.first < beginTime) {
+                if (includeOpeningTimeSig) {
+                    sig.first = beginTime;
+                } else {
+                    continue;
+                }
+            }
+            addTimeSignature(sig.first, sig.second);
+        }
     }
 }
 
@@ -571,34 +575,34 @@ TimeSignatureSelection::AddToComposition(Composition *composition) const
 
 TempoSelection::TempoSelection() { }
 
-TempoSelection::TempoSelection(Composition &composition,
-			       timeT beginTime,
-			       timeT endTime,
-			       bool includeOpeningTempo)
+TempoSelection::TempoSelection(const Composition &composition,
+                               timeT beginTime,
+                               timeT endTime,
+                               bool includeOpeningTempo)
 {
     int n = composition.getTempoChangeNumberAt(endTime);
 
     for (int i = composition.getTempoChangeNumberAt(beginTime);
-	 i <= n;
-	 ++i) {
+         i <= n;
+         ++i) {
 
-	if (i < 0) continue;
+        if (i < 0) continue;
 
-	std::pair<timeT, tempoT> change = composition.getTempoChange(i);
+        std::pair<timeT, tempoT> change = composition.getTempoChange(i);
 
-	if (change.first < endTime) {
-	    if (change.first < beginTime) {
-		if (includeOpeningTempo) {
-		    change.first = beginTime;
-		} else {
-		    continue;
-		}
-	    }
-	    std::pair<bool, tempoT> ramping =
-		composition.getTempoRamping(i, false);
-	    addTempo(change.first, change.second,
-		     ramping.first ? ramping.second : -1);
-	}
+        if (change.first < endTime) {
+            if (change.first < beginTime) {
+                if (includeOpeningTempo) {
+                    change.first = beginTime;
+                } else {
+                    continue;
+                }
+            }
+            std::pair<bool, tempoT> ramping =
+                composition.getTempoRamping(i, false);
+            addTempo(change.first, change.second,
+                     ramping.first ? ramping.second : -1);
+        }
     }
 }
 
@@ -608,7 +612,7 @@ void
 TempoSelection::addTempo(timeT t, tempoT tempo, tempoT targetTempo)
 {
     m_tempos.insert(tempocontainer::value_type
-		    (t, tempochange(tempo, targetTempo)));
+                    (t, tempochange(tempo, targetTempo)));
 }
 
 void
@@ -667,7 +671,7 @@ template class TimewiseSelection<MarkerElementInfo>;
 MarkerSelection::MarkerSelection(Composition &composition, timeT beginTime,
                                  timeT endTime)
 {
-    typedef Composition::markercontainer MarkerContainer;
+    typedef Composition::MarkerVector MarkerContainer;
     const MarkerContainer& markers = composition.getMarkers();
     for (MarkerContainer::const_iterator i = markers.begin();
          i != markers.end();
