@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
     See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
@@ -20,19 +20,18 @@
 #include <algorithm>
 
 #include "Event.h"
-#include "base/Segment.h"
+#include "Segment.h"
 #include "CompositionTimeSliceAdapter.h"
-#include "base/BaseProperties.h"
-#include "base/NotationTypes.h"
-#include "base/MidiTypes.h"
+#include "BaseProperties.h"
+#include "NotationTypes.h"
+#include "MidiTypes.h"
 #include "Quantizer.h"
+
 #include "misc/Debug.h"
 
 namespace Rosegarden
 {
 
-class Quantizer;
-
 /**
  * A "set" in Rosegarden terminology is a collection of elements found
  * in a container (indeed, a subset of that container) all of which
@@ -100,7 +99,8 @@ public:
     Iterator getHighestNote() const     { return m_highest;  }
     Iterator getLowestNote() const      { return m_lowest;   }
 
-    virtual bool contains(const Iterator &) const = 0;
+    // unused
+    //virtual bool contains(const Iterator &) const = 0;
 
     /// Return the pointed-to element, in Event form (public to work around gcc-2.95 bug)
     static Event *getAsEvent(const Iterator &i);
@@ -175,7 +175,8 @@ public:
     virtual int getMarkCountForChord() const;
     virtual std::vector<Mark> getMarksForChord() const;
     virtual std::vector<int> getPitches() const;
-    bool contains(const Iterator &) const override;
+    // unused
+    //bool contains(const Iterator &) const override;
 
     void initialiseFinish() override;
 
@@ -285,7 +286,7 @@ extern bool
 get__String(Event *e, const PropertyName &name, std::string &ref);
 
 extern bool
-isPersistent__Bool(Event *e, const PropertyName &name);
+isPersistent__Bool(const Event *e, const PropertyName &name);
 
 extern void
 setMaybe__Int(Event *e, const PropertyName &name, long value);
@@ -337,16 +338,14 @@ AbstractSet<Element, Container>::initialise()
         if (sample(j, false)) {
             m_initial = j;
             if (AbstractSet::getAsEvent(j)->isa(Note::EventType)) {
-		m_initialNote = j;
-		if (m_finalNote == getContainer().end()) {
-		    m_finalNote = j;
-		}
-	    }
+                m_initialNote = j;
+                if (m_finalNote == getContainer().end()) {
+                    m_finalNote = j;
+                }
+            }
         }
     }
 
-    j = m_baseIterator;
-
     // then scan forwards to find an element not in the desired set,
     // sampling everything as far forward as the one before it
 
@@ -354,11 +353,11 @@ AbstractSet<Element, Container>::initialise()
         if (sample(j, true)) {
             m_final = j;
             if (AbstractSet::getAsEvent(j)->isa(Note::EventType)) {
-		m_finalNote = j;
-		if (m_initialNote == getContainer().end()) {
-		    m_initialNote = j;
-		}
-	    }
+                m_finalNote = j;
+                if (m_initialNote == getContainer().end()) {
+                    m_initialNote = j;
+                }
+            }
         }
     }
 
@@ -436,8 +435,8 @@ initialiseFinish()
 {
     if (std::vector<typename Container::iterator>::size() > 1) {
         std::stable_sort(std::vector<typename Container::iterator>::begin(),
-			 std::vector<typename Container::iterator>::end(),
-			 PitchGreater());
+                         std::vector<typename Container::iterator>::end(),
+                         PitchGreater());
     }
  }
 
@@ -447,11 +446,11 @@ GenericChord<Element, Container, singleStaff>::test(const Iterator &i)
 {
     Event *e = GenericChord::getAsEvent(i);
     if (AbstractSet<Element, Container>::
-	getQuantizer().getQuantizedAbsoluteTime(e) != m_time) {
-	return false;
+        getQuantizer().getQuantizedAbsoluteTime(e) != m_time) {
+        return false;
     }
     if (e->getSubOrdering() != m_subordering) {
-	return false;
+        return false;
     }
 
     // We permit note or rest events etc here, because if a chord is a
@@ -649,17 +648,18 @@ GenericChord<Element, Container, singleStaff>::getPitches() const
 }
 
 
-template <class Element, class Container, bool singleStaff>
-bool
-GenericChord<Element, Container, singleStaff>::contains(const Iterator &itr) const
-{
-    for (typename std::vector<typename Container::iterator>::const_iterator
-             i = std::vector<typename Container::iterator>::begin();
-         i != std::vector<typename Container::iterator>::end(); ++i) {
-        if (*i == itr) return true;
-    }
-    return false;
-}
+// unused
+// template <class Element, class Container, bool singleStaff>
+// bool
+// GenericChord<Element, Container, singleStaff>::contains(const Iterator &itr) const
+// {
+//     for (typename std::vector<typename Container::iterator>::const_iterator
+//              i = std::vector<typename Container::iterator>::begin();
+//          i != std::vector<typename Container::iterator>::end(); ++i) {
+//         if (*i == itr) return true;
+//     }
+//     return false;
+// }
 
 
 template <class Element, class Container, bool singleStaff>
