@@ -16,25 +16,28 @@
 #define RG_MODULE_STRING "[Studio]"
 #define RG_NO_DEBUG_PRINT
 
-#include <iostream>
+#include "Studio.h"
 
-#include "base/Studio.h"
-#include "MidiDevice.h"
 #include "AudioDevice.h"
-#include "SoftSynthDevice.h"
+#include "Composition.h"
 #include "Instrument.h"
+#include "MidiDevice.h"
+#include "SoftSynthDevice.h"
+#include "Track.h"
 
+#include "gui/studio/StudioControl.h"
 #include "base/RecordIn.h"
 #include "base/Segment.h"
 #include "misc/Strings.h"
-#include "Track.h"
-#include "Composition.h"
 #include "sequencer/RosegardenSequencer.h"
 
+#include <QString>
+
+//#include <iostream>
+#include <set>
 #include <sstream>
 #include <string>
-
-#include <QString>
+#include <vector>
 
 
 using std::endl;
@@ -43,6 +46,7 @@ using std::endl;
 namespace Rosegarden
 {
 
+
 Studio::Studio() :
     amwShowAudioFaders(true),
     amwShowSynthFaders(true),
@@ -75,7 +79,7 @@ Studio::Studio() :
 Studio::~Studio()
 {
     RG_DEBUG << "dtor";
-    DeviceListIterator dIt = m_devices.begin();
+    DeviceVector::iterator dIt = m_devices.begin();
 
     for (; dIt != m_devices.end(); ++dIt)
         delete(*dIt);
@@ -135,8 +139,8 @@ Studio::addDevice(const std::string &name,
 void
 Studio::removeDevice(DeviceId id)
 {
-    DeviceListIterator it;
-    for (it = m_devices.begin(); it != m_devices.end(); it++) {
+    DeviceVector::iterator it;
+    for (it = m_devices.begin(); it != m_devices.end(); ++it) {
         if ((*it)->getId() == id) {
             Device* d = *it;
             m_devices.erase(it);
@@ -157,7 +161,7 @@ Studio::resyncDeviceConnections()
     // Sync all the MidiDevice connections to the current connections
     // according to RosegardenSequencer.
 
-    DeviceList *devices = getDevices();
+    DeviceVector *devices = getDevices();
 
     // For each Device
     for (unsigned i = 0; i < devices->size(); ++i) {
@@ -188,11 +192,11 @@ Studio::getSpareDeviceId(InstrumentId &baseInstrumentId)
     bool foundInstrument = false;
 
     std::set<DeviceId> ids;
-    DeviceListIterator it;
-    for (it = m_devices.begin(); it != m_devices.end(); it++) {
+    DeviceVector::iterator it;
+    for (it = m_devices.begin(); it != m_devices.end(); ++it) {
         ids.insert((*it)->getId());
         if ((*it)->getType() == Device::Midi) {
-            InstrumentList il = (*it)->getAllInstruments();
+            InstrumentVector il = (*it)->getAllInstruments();
             for (size_t i = 0; i < il.size(); ++i) {
                 if (il[i]->getId() > highestMidiInstrumentId) {
                     highestMidiInstrumentId = il[i]->getId();
@@ -213,19 +217,19 @@ Studio::getSpareDeviceId(InstrumentId &baseInstrumentId)
     return id;
 }
 
-InstrumentList
+InstrumentVector
 Studio::getAllInstruments()
 {
-    InstrumentList list;
+    InstrumentVector list;
 
-    DeviceListIterator it;
+    DeviceVector::iterator it;
 
     // Append lists
     //
-    for (it = m_devices.begin(); it != m_devices.end(); it++)
+    for (it = m_devices.begin(); it != m_devices.end(); ++it)
     {
         // get sub list
-        InstrumentList subList = (*it)->getAllInstruments();
+        InstrumentVector subList = (*it)->getAllInstruments();
 
         // concetenate
         list.insert(list.end(), subList.begin(), subList.end());
@@ -235,13 +239,13 @@ Studio::getAllInstruments()
 
 }
 
-InstrumentList
+InstrumentVector
 Studio::getPresentationInstruments() const
 {
-    InstrumentList list;
+    InstrumentVector list;
 
     // For each device...
-    for (DeviceList::const_iterator it = m_devices.begin();
+    for (DeviceVector::const_iterator it = m_devices.begin();
          it != m_devices.end();
          ++it) {
         const MidiDevice *midiDevice = dynamic_cast<MidiDevice *>(*it);
@@ -253,7 +257,7 @@ Studio::getPresentationInstruments() const
         }
 
         // get sub list
-        InstrumentList subList = (*it)->getPresentationInstruments();
+        InstrumentVector subList = (*it)->getPresentationInstruments();
 
         // concatenate
         list.insert(list.end(), subList.begin(), subList.end());
@@ -270,9 +274,9 @@ Studio::getInstrumentById(InstrumentId id) const
          deviceIter != m_devices.end();
          ++deviceIter)
     {
-        InstrumentList list = (*deviceIter)->getAllInstruments();
+        InstrumentVector list = (*deviceIter)->getAllInstruments();
 
-        for (InstrumentList::const_iterator instrumentIter = list.begin();
+        for (InstrumentVector::const_iterator instrumentIter = list.begin();
              instrumentIter != list.end();
              ++instrumentIter) {
             if ((*instrumentIter)->getId() == id)
@@ -291,8 +295,8 @@ Instrument*
 Studio::getInstrumentFromList(int index)
 {
     std::vector<Device*>::iterator it;
-    InstrumentList list;
-    InstrumentList::iterator iit;
+    InstrumentVector list;
+    InstrumentVector::iterator iit;
     int count = 0;
 
     for (it = m_devices.begin(); it != m_devices.end(); ++it)
@@ -340,16 +344,10 @@ Studio::getInstrumentFor(const Track *track) const
     return getInstrumentById(iid);
 }
 
-BussList
-Studio::getBusses()
-{
-    return m_busses;
-}
-
 Buss *
-Studio::getBussById(BussId id)
+Studio::getBussById(BussId id) const
 {
-    for (BussList::iterator i = m_busses.begin(); i != m_busses.end(); ++i) {
+    for (BussVector::const_iterator i = m_busses.begin(); i != m_busses.end(); ++i) {
         if ((*i)->getId() == id) return *i;
     }
     return nullptr;
@@ -369,7 +367,7 @@ Studio::addBuss(Buss *buss)
 void
 Studio::removeBuss(BussId id)
 {
-    for (BussList::iterator i = m_busses.begin(); i != m_busses.end(); ++i) {
+    for (BussVector::iterator i = m_busses.begin(); i != m_busses.end(); ++i) {
         if ((*i)->getId() == id) {
             delete *i;
             m_busses.erase(i);
@@ -434,7 +432,7 @@ Studio::getContainerById(InstrumentId id)
 }
 
 RecordIn *
-Studio::getRecordIn(int number)
+Studio::getRecordIn(int number) const
 {
     if (number >= 0  &&  number < int(m_recordIns.size()))
         return m_recordIns[number];
@@ -508,12 +506,12 @@ Studio::toXmlString(const std::vector<DeviceId> &devices) const
     //
     if (devices.empty()) { // export all devices and busses
 
-        for (DeviceListConstIterator it = m_devices.begin();
-             it != m_devices.end(); it++) {
+        for (DeviceVector::const_iterator it = m_devices.begin();
+             it != m_devices.end(); ++it) {
             studio << (*it)->toXmlString() << endl << endl;
         }
 
-        for (BussList::const_iterator it = m_busses.begin();
+        for (BussVector::const_iterator it = m_busses.begin();
              it != m_busses.end(); ++it) {
             studio << (*it)->toXmlString() << endl << endl;
         }
@@ -582,8 +580,8 @@ Studio::assignMidiProgramToInstrument(MidiByte program,
                                       bool percussion)
 {
     std::vector<Device*>::iterator it;
-    Rosegarden::InstrumentList::iterator iit;
-    Rosegarden::InstrumentList instList;
+    Rosegarden::InstrumentVector::iterator iit;
+    Rosegarden::InstrumentVector instList;
 
     // Instruments that we may return
     //
@@ -683,8 +681,8 @@ Studio::unassignAllInstruments()
 {
     AudioDevice *audioDevice;
     std::vector<Device*>::iterator it;
-    Rosegarden::InstrumentList::iterator iit;
-    Rosegarden::InstrumentList instList;
+    Rosegarden::InstrumentVector::iterator iit;
+    Rosegarden::InstrumentVector instList;
     int channel = 0;
 
     for (it = m_devices.begin(); it != m_devices.end(); ++it)
@@ -827,8 +825,8 @@ std::string
 Studio::getSegmentName(InstrumentId id)
 {
     std::vector<Device*>::iterator it;
-    Rosegarden::InstrumentList::iterator iit;
-    Rosegarden::InstrumentList instList;
+    Rosegarden::InstrumentVector::iterator iit;
+    Rosegarden::InstrumentVector instList;
 
     for (it = m_devices.begin(); it != m_devices.end(); ++it)
     {
@@ -881,8 +879,8 @@ Studio::getAudioPreviewInstrument()
 bool
 Studio::haveMidiDevices() const
 {
-    Rosegarden::DeviceListConstIterator it = m_devices.begin();
-    for (; it != m_devices.end(); it++)
+    DeviceVector::const_iterator it = m_devices.begin();
+    for (; it != m_devices.end(); ++it)
     {
         if ((*it)->getType() == Device::Midi) return true;
     }
@@ -918,7 +916,7 @@ Studio::getFirstMIDIInstrument() const
     if (!device)
         return SoftSynthInstrumentBase;
 
-    InstrumentList instruments = device->getPresentationInstruments();
+    InstrumentVector instruments = device->getPresentationInstruments();
 
     if (!instruments.empty()) {
         const Instrument *instrument = instruments[0];
@@ -958,5 +956,228 @@ void Studio::removeObserver(StudioObserver *obs)
     m_observers.remove(obs);
 }
 
+Studio::InvalidInstrumentVector
+Studio::getRecordInInvalid(int newCount) const
+{
+    // Gathers instruments that use record inputs beyond newCount.
+
+    InvalidInstrumentVector invalidInstruments;
+    // get actual count
+    RecordInVector recs = getRecordIns();
+    int oldCount = recs.size();
+
+    // no problem increasing count
+    if (newCount > oldCount)
+        return invalidInstruments;
+
+    InstrumentVector instruments = getPresentationInstruments();
+
+    // For each instrument...
+    for (Instrument *instrument : instruments) {
+        bool isBuss;
+        int channel;
+        int recIn = instrument->getAudioInput(isBuss, channel);
+        // only checking record in
+        if (isBuss)
+            continue;
+        // If this instrument is connected to a record in that is going away...
+        if (recIn >= newCount) {
+            // Add it to the list.
+            InvalidInstrument iu;
+            iu.id = recIn + 1;
+            iu.isInput = true;
+            iu.instrument = instrument;
+            invalidInstruments.push_back(iu);
+        }
+    }
+
+    return invalidInstruments;
+}
+
+Studio::InvalidInstrumentVector
+Studio::getSubmasterInvalid(int newCount) const
+{
+    // Gathers instruments that use submasters beyond newCount.
+
+    InvalidInstrumentVector invalidInstruments;
+    // get actual count
+    BussVector buss = getBusses();
+    int oldCount = buss.size();
+
+    // no problem increasing count
+    if (newCount > oldCount)
+        return invalidInstruments;
+
+    // check for in use
+    InstrumentVector instruments = getPresentationInstruments();
+    // For each instrument
+    for (InstrumentVector::iterator i = instruments.begin();
+         i != instruments.end();
+         ++i) {
+        Instrument *instrument = *i;
+        bool isBuss;
+        int channel;
+        int subm = instrument->getAudioInput(isBuss, channel);
+        if (isBuss && subm > newCount) {
+            InvalidInstrument iu;
+            iu.id = subm;
+            iu.isInput = true;
+            iu.instrument = instrument;
+            invalidInstruments.push_back(iu);
+        }
+        // and outputs
+        subm = instrument->getAudioOutput();
+        if (subm > newCount) {
+            InvalidInstrument iu;
+            iu.id = subm;
+            iu.isInput = false;
+            iu.instrument = instrument;
+            invalidInstruments.push_back(iu);
+        }
+    }
+
+    return invalidInstruments;
+}
+
+void
+Studio::setInput(Instrument *instrument, bool isBuss, int newInput, int newChannel) const
+{
+    bool oldIsBuss;
+    // 0 == left, 1 == right, mono only
+    int oldChannel;
+    int oldInput = instrument->getAudioInput(oldIsBuss, oldChannel);
+
+    // Compute old mapped ID
+
+    MappedObjectId oldMappedId = 0;
+
+    if (oldIsBuss) {
+        const Buss *buss = getBussById(oldInput);
+        if (buss)
+            oldMappedId = buss->getMappedId();
+    } else {
+        const RecordIn *in = getRecordIn(oldInput);
+        if (in)
+            oldMappedId = in->mappedId;
+    }
+
+    // Compute new mapped ID
+
+    MappedObjectId newMappedId = 0;
+
+    if (isBuss) {
+        const Buss *buss = getBussById(newInput);
+        if (!buss)
+            return;
+        newMappedId = buss->getMappedId();
+    } else {
+        const RecordIn *in = getRecordIn(newInput);
+        if (!in)
+            return;
+        newMappedId = in->mappedId;
+    }
+
+    // Update the Studio
+
+    // Disconnect any old connection.
+    if (oldMappedId != 0) {
+        StudioControl::disconnectStudioObjects(
+                oldMappedId, instrument->getMappedId());
+    } else {
+        StudioControl::disconnectStudioObject(
+                instrument->getMappedId());
+    }
+
+    // Connect the new connection.
+
+    StudioControl::setStudioObjectProperty(
+            instrument->getMappedId(),
+            MappedAudioFader::InputChannel,
+            MappedObjectValue(newChannel));
+
+    if (newMappedId != 0) {
+        // Connect the input to the instrument.
+        StudioControl::connectStudioObjects(
+                newMappedId, instrument->getMappedId());
+    }
+
+    // Update the Instrument
+
+    if (isBuss)
+        instrument->setAudioInputToBuss(newInput, newChannel);
+    else
+        instrument->setAudioInputToRecord(newInput, newChannel);
+}
+
+void
+Studio::setOutput(Instrument *instrument, int bussID) const
+{
+    BussId oldBussId = instrument->getAudioOutput();
+    const Buss *oldBuss = getBussById(oldBussId);
+
+    const Buss *newBuss = getBussById(bussID);
+    if (!newBuss)
+        return;
+
+    // Update the Studio
+
+    // Disconnect the old.
+    if (oldBuss) {
+        StudioControl::disconnectStudioObjects(
+                instrument->getMappedId(), oldBuss->getMappedId());
+    } else {
+        StudioControl::disconnectStudioObject(
+                instrument->getMappedId());
+    }
+
+    // Connect the new.
+    StudioControl::connectStudioObjects(
+            instrument->getMappedId(), newBuss->getMappedId());
+
+    // Update the Instrument
+
+    instrument->setAudioOutput(bussID);
+}
+
+void
+Studio::fixRecordIns(int count)
+{
+    InvalidInstrumentVector invalidInstruments =
+            getRecordInInvalid(count);
+
+    // For each instrument with an invalid input, set it to input 1.
+    for (const Studio::InvalidInstrument &invalidInstrument :
+         invalidInstruments) {
+        setInput(invalidInstrument.instrument, false, 0, 0);
+    }
+}
+
+void
+Studio::fixSubmasters(int count)
+{
+    InvalidInstrumentVector invalidInstruments =
+            getSubmasterInvalid(count);
+
+    // For each instrument with an invalid submaster...
+    for (const Studio::InvalidInstrument &invalidInstrument :
+         invalidInstruments) {
+
+        // If the submaster was being used as an input...
+        if (invalidInstrument.isInput) {
+
+            // Switch to "input 1" instead of "master" to avoid feedback
+            // loops.
+            setInput(invalidInstrument.instrument, false, 0, 0);
+
+        } else {
+
+            // submaster was being used as an output...
+            // Switch to "master".
+            setOutput(invalidInstrument.instrument, 0);
+
+        }
+    }
+}
+
 
 }
