@@ -18,18 +18,22 @@
 
 #include <rosegardenprivate_export.h>
 
-#include "Event.h"
 #include "NotationTypes.h"
 #include "PropertyName.h"
 #include "TimeT.h"
 
 #include <list>
+#include <string>
+#include <vector>
 
 
 namespace Rosegarden
 {
 
 
+class Event;
+
+
 typedef std::list<int> DurationList;
 
 /// A time signature represented as a numerator and a denominator.
