@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -24,6 +24,7 @@
 #include "base/NotationQuantizer.h"
 #include "base/NotationRules.h"
 #include "base/NotationTypes.h"
+#include "base/Pitch.h"
 #include "base/Property.h"
 #include "base/Selection.h"
 #include "base/figuration/FigChord.h"
@@ -136,7 +137,7 @@ class ProximityNote : public RelativeEvent
         }
         // Unused now.
         PitchNoOctave getPitch() const { return m_pitch; }
-        int getPenalty(PitchNoOctave pitch)
+        int getPenalty(PitchNoOctave pitch) const
         {
             // Direction of subtraction here isn't important since
             // we'll square it.  We must convert "round the corner"
@@ -144,9 +145,9 @@ class ProximityNote : public RelativeEvent
             int difference = doubleOctaveToBalanced(pitch - m_pitch);
             return difference * difference;
         }
-        static int getMovementPenalty(TonePressure &from,
-                                      TonePressure &to,
-                                      PitchNoOctaveVector &pitches,
+        static int getMovementPenalty(const TonePressure &from,
+                                      const TonePressure &to,
+                                      const PitchNoOctaveVector &pitches,
                                       bool forwards)
         {
             const int index =
@@ -340,6 +341,7 @@ class ProximityNote : public RelativeEvent
 
                 // Add this index to the best match.  TonePressure
                 // maintains the sorting invariant.
+                // cppcheck-suppress nullPointer
                 bestTonePressure->addIndex(*i);
             }
 
@@ -376,8 +378,8 @@ class ProximityNote : public RelativeEvent
                 // at once and do modular lookup.
                 for (size_t i = 0; i < tones.size(); ++i) {
                     const int highIndex = (i + 1) % tones.size();
-                    TonePressure &tonePressureA = tones.at(i);
-                    TonePressure &tonePressureB = tones.at(highIndex);
+                    const TonePressure &tonePressureA = tones.at(i);
+                    const TonePressure &tonePressureB = tones.at(highIndex);
 
                     // Decide what we could do to resolve
                     /// over/underpressure.
@@ -706,7 +708,7 @@ protected:
 class ParamaterizedRelativeEventAdder : public BaseRelativeEventAdder
 {
 public:
-    ParamaterizedRelativeEventAdder(timeT startTime, Segment *s,
+    ParamaterizedRelativeEventAdder(timeT startTime, const Segment *s,
                                     const FigChord *parameterChord) :
         BaseRelativeEventAdder(startTime),
         m_parameterChord(parameterChord),
@@ -736,7 +738,10 @@ public:
         BaseRelativeEventAdder(startTime),
         m_sharedData(new ProximityNote::SharedData)
         {}
-
+    UnparamaterizedRelativeEventAdder
+    (const UnparamaterizedRelativeEventAdder&) =delete;
+    UnparamaterizedRelativeEventAdder& operator=
+    (const UnparamaterizedRelativeEventAdder&) =delete;
     ~UnparamaterizedRelativeEventAdder() override
     {
         // Destroying the adder triggers setting up the shared data,
@@ -767,7 +772,6 @@ private:
         }
     }
 
-    // cppcheck-suppress unusedPrivateFunction
     UnsolvedNote add(Event *e) override
         {
             if (e->isa(Note::EventType)) {
