@@ -1,4 +1,3 @@
-
 /* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */
 
 /*
@@ -19,18 +18,19 @@
 #ifndef RG_ADDMARKERCOMMAND_H
 #define RG_ADDMARKERCOMMAND_H
 
-#include <string>
 #include "document/Command.h"
+#include "base/TimeT.h"
+
 #include <QString>
-#include "base/Event.h"
 #include <QCoreApplication>
 
-
+#include <string>
 
 
 namespace Rosegarden
 {
 
+
 class Marker;
 class Composition;
 
