@@ -1,4 +1,3 @@
-
 /* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */
 
 /*
@@ -20,14 +19,12 @@
 #define RG_COPYCOMMAND_H
 
 #include "document/Command.h"
-#include <QString>
-#include "base/Event.h"
 #include "base/Selection.h"
+
+#include <QString>
 #include <QCoreApplication>
 
 
-
-
 namespace Rosegarden
 {
 
@@ -49,7 +46,7 @@ public:
      * ??? selection should be a const &.  It is copied.  Ownership is
      *     not transferred.
      */
-    CopyCommand(EventSelection *selection,
+    CopyCommand(const EventSelection *selection,
                 Clipboard *clipboard);
 
     CopyCommand(EventSelection *selection1,
