@@ -48,12 +48,6 @@ EraseCommand::EraseCommand(
         m_selection2 = nullptr;
 }
 
-EraseCommand::~EraseCommand()
-{
-    // ??? MEMORY LEAK (confirmed)  delete here isn't a reliable solution.
-    //delete m_selection;
-}
-
 void
 EraseCommand::modifySegment()
 {
@@ -83,7 +77,7 @@ EraseCommand::eraseInSegment(EventSelection *selection)
          ++i) {
 
         if ((*i)->isa(Clef::EventType) ||
-                (*i)->isa(Key ::EventType)) {
+                (*i)->isa(Key::EventType)) {
             erasedLongEffectEvent = true;
         } else if ((*i)->isa(Indication::EventType)) {
 
@@ -119,13 +113,13 @@ EraseCommand::eraseInSegment(EventSelection *selection)
                     minSubOrdering > indicationSubOrdering &&
                     maxDeltaGraceSubOrdering >= graceToAdjust) {
                     int incr = minSubOrdering - indicationSubOrdering;
-                    std::vector<Event *> toInsert, toErase;
+                    std::vector<Event *> toInsert, toErase1;
                     for (Segment::iterator k = h; k != j; ++k) {
                         if ((*k)->has(BaseProperties::IS_GRACE_NOTE) &&
                             (*k)->getSubOrdering() < indicationSubOrdering) {
                             // Subordering of the grace note is incremented to
                             // avoid (a rare) relevant decrement of that value.
-                            toErase.push_back(*k);
+                            toErase1.push_back(*k);
                             toInsert.push_back
                                 (new Event(**k,
                                            (*k)->getAbsoluteTime(),
@@ -135,8 +129,8 @@ EraseCommand::eraseInSegment(EventSelection *selection)
                                            (*k)->getNotationDuration()));
                         }
                     }
-                    for (std::vector<Event *>::iterator k = toErase.begin();
-                         k != toErase.end(); ++k) segment.eraseSingle(*k);
+                    for (std::vector<Event *>::iterator k = toErase1.begin();
+                         k != toErase1.end(); ++k) segment.eraseSingle(*k);
                     for (std::vector<Event *>::iterator k = toInsert.begin();
                          k != toInsert.end(); ++k) segment.insert(*k);
                 }
@@ -144,11 +138,11 @@ EraseCommand::eraseInSegment(EventSelection *selection)
                 Indication indication(**i);
                 if (indication.isOttavaType()) {
 
-                    for (Segment::iterator j = segment.findTime ((*i)->getAbsoluteTime());
-                         j != segment.findTime
+                    for (Segment::iterator j1 = segment.findTime ((*i)->getAbsoluteTime());
+                         j1 != segment.findTime
                              ((*i)->getAbsoluteTime() + indication.getIndicationDuration());
-                         ++j) {
-                        (*j)->unset(NotationProperties::OTTAVA_SHIFT);
+                         ++j1) {
+                        (*j1)->unset(NotationProperties::OTTAVA_SHIFT);
                     }
                 }
             } catch (...) {}
