@@ -23,15 +23,16 @@
 #include "base/TriggerSegment.h"
 #include "document/BasicCommand.h"
 #include "gui/editors/notation/NoteStyle.h"
-#include <string>
-#include "base/Event.h"
 
 #include <QCoreApplication>
 
+#include <string>
+
 
 namespace Rosegarden
 {
 
+
 class Segment;
 
 
@@ -42,14 +43,14 @@ class InsertTriggerNoteCommand : public BasicCommand
 public:
     InsertTriggerNoteCommand(Segment &,
                              timeT time,
-			     timeT duration,
+                             timeT duration,
                              int pitch,
                              int velocity,
-                             NoteStyleName noteStyle,
+                             const NoteStyleName& noteStyle,
                              TriggerSegmentId id,
                              bool retune,
                              const std::string& timeAdjust,
-                             Mark mark);
+                             const Mark& mark);
     ~InsertTriggerNoteCommand() override;
 
 protected:
