@@ -4,7 +4,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -19,16 +19,17 @@
 #ifndef RG_MOVEACROSSSEGMENTSCOMMAND_H
 #define RG_MOVEACROSSSEGMENTSCOMMAND_H
 
-#include <QString>
-#include "base/Event.h"
+#include "base/TimeT.h"
 #include "document/Command.h"
 
 #include <QCoreApplication>
+#include <QString>
 
 
 namespace Rosegarden
 {
 
+
 class Segment;
 class EventSelection;
 class Clipboard;
@@ -52,7 +53,6 @@ private:
 };
     
 
-
 }
 
 #endif
