@@ -20,17 +20,18 @@
 
 #include "base/Track.h"
 #include "document/Command.h"
+#include "base/TimeT.h"
+
 #include <QString>
 #include <QCoreApplication>
+
 #include <vector>
-#include "base/Event.h"
-
-
 
 
 namespace Rosegarden
 {
 
+
 class Segment;
 class Composition;
 class Clipboard;
@@ -44,7 +45,7 @@ class PasteSegmentsCommand : public NamedCommand
 
 public:
     PasteSegmentsCommand(Composition *composition,
-                         Clipboard *clipboard,
+                         const Clipboard *clipboard,
                          timeT pasteTime,
                          TrackId baseTrack,
                          bool useExactTracks);
