@@ -20,25 +20,19 @@
 
 #include "base/Composition.h"
 #include "base/Marker.h"
-#include <QString>
 
 
 namespace Rosegarden
 {
 
+
 RemoveMarkerCommand::RemoveMarkerCommand(Composition *comp,
-        int id,
-        timeT time,
-        const std::string &,
-        const std::string &description):
-        NamedCommand(getGlobalName()),
-        m_composition(comp),
-        m_marker(nullptr),
-        m_id(id),
-        m_time(time),
-        m_descr(description),
-        m_detached(false)
-{}
+                                         int markerID) :
+    NamedCommand(getGlobalName()),
+    m_composition(comp),
+    m_markerID(markerID)
+{
+}
 
 RemoveMarkerCommand::~RemoveMarkerCommand()
 {
@@ -49,17 +43,17 @@ RemoveMarkerCommand::~RemoveMarkerCommand()
 void
 RemoveMarkerCommand::execute()
 {
-    Composition::MarkerVector markers =
-        m_composition->getMarkers();
+    const Composition::MarkerVector &markers =
+            m_composition->getMarkers();
 
-    Composition::MarkerVector::const_iterator it = markers.begin();
-
-    for (; it != markers.end(); ++it) {
-        if ((*it)->getID() == m_id) {
-            m_marker = (*it);
+    // For each marker...
+    for (Marker *marker : markers) {
+        // Found it?  Detach from Composition.
+        if (marker->getID() == m_markerID) {
+            m_marker = marker;
             m_composition->detachMarker(m_marker);
             m_detached = true;
-            return ;
+            return;
         }
     }
 }
@@ -72,4 +66,5 @@ RemoveMarkerCommand::unexecute()
     m_detached = false;
 }
 
+
 }
