@@ -4,10 +4,10 @@
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
     Copyright 2000-2025 the Rosegarden development team.
- 
+
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
- 
+
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
     published by the Free Software Foundation; either version 2 of the
@@ -45,14 +45,15 @@ ChangeStyleCommand::registerCommand(CommandRegistry *r)
 }
 
 NoteStyleName
-ChangeStyleCommand::getArgument(QString actionName, CommandArgumentQuerier &)
+ChangeStyleCommand::getArgument(const QString& actionName,
+                                CommandArgumentQuerier &)
 {
     QString pfx = "style_";
 
     if (actionName.startsWith(pfx)) {
 
         QString remainder = actionName.right(actionName.length() - pfx.length());
-        std::vector<NoteStyleName> styles = 
+        std::vector<NoteStyleName> styles =
             NoteStyleFactory::getAvailableStyleNames();
 
         for (std::vector<NoteStyleName>::iterator i = styles.begin();
