@@ -1,4 +1,3 @@
-
 /* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */
 
 /*
@@ -21,19 +20,21 @@
 
 #include "base/NotationTypes.h"
 #include "document/BasicCommand.h"
-#include <QString>
-#include "base/Event.h"
+#include "base/TimeT.h"
 
 #include <QCoreApplication>
+#include <QString>
 
 
 namespace Rosegarden
 {
 
+
 class Segment;
 class LinkedSegment;
 class Event;
 
+
 class ClefInsertionCommand : public BasicCommand
 {
     Q_DECLARE_TR_FUNCTIONS(Rosegarden::ClefInsertionCommand)
@@ -65,6 +66,7 @@ protected:
 
 class ClefLinkInsertionCommand : public ClefInsertionCommand
 {
+    // cppcheck-suppress duplInheritedMember
     Q_DECLARE_TR_FUNCTIONS(Rosegarden::ClefLinkInsertionCommand)
 
 public:
@@ -76,6 +78,7 @@ public:
     ~ClefLinkInsertionCommand() override;
 
     QString getThisGlobalName(const Clef *clef = nullptr) override;
+    // cppcheck-suppress duplInheritedMember
     static QString getGlobalName(const Clef *clef = nullptr);
 
 protected:
