@@ -20,15 +20,15 @@
 #define RG_ERASEEVENTCOMMAND_H
 
 #include "document/BasicCommand.h"
+#include "base/TimeT.h"
+
 #include <string>
-#include "base/Event.h"
-
-
 
 
 namespace Rosegarden
 {
 
+
 class Segment;
 class Event;
 
