@@ -20,7 +20,7 @@
 
 #include "base/figuration/GeneratedRegion.h"
 #include "document/BasicCommand.h"
-#include "base/Event.h"
+#include "base/TimeT.h"
 
 #include <QCoreApplication>
 
@@ -28,6 +28,7 @@
 namespace Rosegarden
 {
 
+
 class Segment;
 class Event;
 
