@@ -20,7 +20,7 @@
 #define RG_GUITARCHORDINSERTIONCOMMAND_H
 
 #include "document/BasicCommand.h"
-#include "base/Event.h"
+#include "base/TimeT.h"
 #include "gui/editors/guitar/Chord.h"
 
 #include <QCoreApplication>
@@ -29,6 +29,7 @@
 namespace Rosegarden
 {
 
+
 class Segment;
 class Event;
 
