@@ -20,16 +20,16 @@
 #define RG_MAKEREGIONVIABLECOMMAND_H
 
 #include "document/BasicCommand.h"
-#include <QString>
-#include "base/Event.h"
+#include "base/TimeT.h"
+
 #include <QCoreApplication>
-
-
+#include <QString>
 
 
 namespace Rosegarden
 {
 
+
 class Segment;
 
 
