@@ -21,14 +21,13 @@
 
 #include "base/NotationTypes.h"
 #include "NoteInsertionCommand.h"
-#include "base/Event.h"
-
-
+#include "base/TimeT.h"
 
 
 namespace Rosegarden
 {
 
+
 class Segment;
 
 
