@@ -19,9 +19,10 @@
 #ifndef RG_TEXTINSERTIONCOMMAND_H
 #define RG_TEXTINSERTIONCOMMAND_H
 
-#include "base/NotationTypes.h"
 #include "document/BasicCommand.h"
-#include "base/Event.h"
+#include "base/NotationTypes.h"
+#include "base/Selection.h"
+#include "base/TimeT.h"
 
 #include <QCoreApplication>
 
@@ -29,6 +30,7 @@
 namespace Rosegarden
 {
 
+
 class Segment;
 class Event;
 
