@@ -4,10 +4,10 @@
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
     Copyright 2000-2025 the Rosegarden development team.
- 
+
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
- 
+
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
     published by the Free Software Foundation; either version 2 of the
@@ -44,7 +44,7 @@ TieNotesCommand::modifySegment()
     // Move part of this to SegmentNotationHelper?
 
     // For each event in the selection
-    for (Event *event : m_selection->getSegmentEvents()) {
+    for (const Event *event : m_selection->getSegmentEvents()) {
 
         Segment::iterator currNoteIter = segment.findSingle(event);
         Segment::iterator nextNoteIter;
