@@ -20,13 +20,14 @@
 #define RG_ADDTIMESIGNATUREANDNORMALIZECOMMAND_H
 
 #include "base/TimeSignature.h"
-#include "base/Event.h"
+#include "base/TimeT.h"
 #include "document/Command.h"
 
 
 namespace Rosegarden
 {
 
+
 class Composition;
 
 
@@ -35,12 +36,11 @@ class AddTimeSignatureAndNormalizeCommand : public MacroCommand
 public:
     AddTimeSignatureAndNormalizeCommand(Composition *composition,
                                         timeT time,
-                                        TimeSignature timeSig);
+                                        const TimeSignature& timeSig);
     ~AddTimeSignatureAndNormalizeCommand() override;
 };
 
 
-
 }
 
 #endif
