@@ -21,10 +21,10 @@
 
 #include "base/TimeSignature.h"
 #include "document/Command.h"
-#include "base/Event.h"
+#include "base/TimeT.h"
 
-#include <QString>
 #include <QCoreApplication>
+#include <QString>
 
 
 namespace Rosegarden
@@ -41,7 +41,7 @@ class AddTimeSignatureCommand : public NamedCommand
 public:
     AddTimeSignatureCommand(Composition *composition,
                             timeT time,
-                            const TimeSignature& timeSig);
+                            const TimeSignature &timeSig);
     ~AddTimeSignatureCommand() override;
 
     static QString getGlobalName() { return tr("Add Time Si&gnature Change..."); }
@@ -59,8 +59,6 @@ protected:
 };
 
 
-
-
 }
 
 #endif
