@@ -21,7 +21,7 @@
 
 #include "base/TriggerSegment.h"
 #include "document/Command.h"
-#include "base/Event.h"
+#include "base/TimeT.h"
 
 #include <QCoreApplication>
 
@@ -29,6 +29,7 @@
 namespace Rosegarden
 {
 
+
 class Segment;
 class RosegardenDocument;
 class Composition;
