@@ -4,10 +4,10 @@
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
     Copyright 2000-2025 the Rosegarden development team.
- 
+
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
- 
+
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
     published by the Free Software Foundation; either version 2 of the
@@ -99,7 +99,7 @@ AudioSegmentInsertCommand::execute()
 
         // Label by audio file name
         //
-        AudioFile *aF =
+        const AudioFile *aF =
             m_audioFileManager->getAudioFile(m_audioFileId);
 
         if (aF) {
