@@ -19,22 +19,25 @@
 #define RG_AUDIOSEGMENTRESCALECOMMAND_H
 
 #include "document/Command.h"
-#include <QString>
-#include "base/Event.h"
-#include <QCoreApplication>
+#include "base/TimeT.h"
 
+#include <QCoreApplication>
 #include <QPointer>
+#include <QString>
 
 class QProgressDialog;
 
+
 namespace Rosegarden
 {
 
+
 class Segment;
 class AudioFileManager;
 class AudioFileTimeStretcher;
 class RosegardenDocument;
 
+
 class AudioSegmentRescaleCommand : public NamedCommand
 {
     Q_DECLARE_TR_FUNCTIONS(Rosegarden::AudioSegmentRescaleCommand)
@@ -60,6 +63,7 @@ public:
     static QString getGlobalName() { return tr("Stretch or S&quash..."); }
 
 private:
+    // ??? This is unused outside of the ctors.  Remove it.
     AudioFileManager *m_afm;
     AudioFileTimeStretcher *m_stretcher;
     Segment *m_segment;
@@ -73,7 +77,6 @@ private:
 };
 
 
-
 }
 
 #endif
