@@ -36,6 +36,7 @@ namespace Rosegarden
 
 class SegmentGroupDeleteRangeCommand : public LinkedSegmentsCommand
 {
+    // cppcheck-suppress duplInheritedMember
     Q_DECLARE_TR_FUNCTIONS(Rosegarden::SegmentGroupDeleteRangeCommand)
 public:
     typedef std::vector<Segment *> SegmentVec;
@@ -277,7 +278,7 @@ calculateNewSegments()
     for (SegmentVec::const_iterator i = m_originalSegments.begin();
          i != m_originalSegments.end();
          ++i) {
-        Segment *oldSegment = *i;
+        const Segment *oldSegment = *i;
         Segment *newSegment =
             (oldSegment == segment) ?
             segmentFinal :
