@@ -19,16 +19,15 @@
 #define RG_DELETERANGECOMMAND_H
 
 #include "document/Command.h"
-#include "base/Event.h"
-#include <QCoreApplication>
+#include "base/TimeT.h"
 
-#include "SegmentJoinCommand.h"
+#include <QCoreApplication>
 
 
 namespace Rosegarden
 {
 
-class Segment;
+
 class Composition;
 
 
@@ -44,7 +43,6 @@ public:
 };
 
 
-
 }
 
 #endif
