@@ -35,6 +35,7 @@ namespace Rosegarden
 {
 class SegmentGroupInsertRangeCommand : public LinkedSegmentsCommand
 {
+    // cppcheck-suppress duplInheritedMember
     Q_DECLARE_TR_FUNCTIONS(Rosegarden::SegmentGroupInsertRangeCommand)
 public:
     typedef std::vector<Segment *> SegmentVec;
@@ -169,7 +170,7 @@ SegmentGroupInsertRangeCommand::calculateNewSegments()
     for (SegmentVec::const_iterator i = m_originalSegments.begin();
          i != m_originalSegments.end();
          ++i) {
-        Segment *oldSegment = *i;
+        const Segment *oldSegment = *i;
         Segment *newSegment =
             (oldSegment == segment) ?
             segmentFinal :
