@@ -19,26 +19,29 @@
 #ifndef RG_INSERTRANGECOMMAND_H
 #define RG_INSERTRANGECOMMAND_H
 
-#include "base/Event.h"
+#include "base/TimeT.h"
 #include "document/Command.h"
 
 #include <QCoreApplication>
 
+
 namespace Rosegarden
 {
 
+
 class Composition;
 
+
 class InsertRangeCommand : public MacroCommand
 {
     Q_DECLARE_TR_FUNCTIONS(Rosegarden::InsertRangeCommand)
 
 public:
     InsertRangeCommand(Composition *composition,
-		       timeT startTime, timeT duration);
+                       timeT startTime, timeT duration);
     static void addInsertionCommands(MacroCommand *macroCommand,
-				     Composition *composition,
-				     timeT startTime, timeT duration);
+                                     Composition *composition,
+                                     timeT startTime, timeT duration);
 };
     
 
