@@ -21,18 +21,21 @@
 
 #include "base/Selection.h"
 #include "document/Command.h"
-#include <vector>
-#include "base/Event.h"
+#include "base/TimeT.h"
 
 #include <QCoreApplication>
 
+#include <vector>
+
 
 namespace Rosegarden
 {
 
+
 class Segment;
 class Composition;
 
+
 /**
  * Pull all segments, time sigs, tempos etc starting after the end of
  * a given range back by the duration of that range, so as to fill in
@@ -80,7 +83,6 @@ private:
 };
 
 
-
 }
 
 #endif
