@@ -19,7 +19,7 @@
 #ifndef RG_PASTERANGECOMMAND_H
 #define RG_PASTERANGECOMMAND_H
 
-#include "base/Event.h"
+#include "base/TimeT.h"
 #include "document/Command.h"
 
 #include <QCoreApplication>
@@ -28,6 +28,7 @@
 namespace Rosegarden
 {
 
+
 class Composition;
 class Clipboard;
 
@@ -43,7 +44,6 @@ public:
 };
     
 
-
 }
 
 #endif
