@@ -1,4 +1,3 @@
-
 /* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */
 
 /*
@@ -20,20 +19,16 @@
 #define RG_REMOVETEMPOCHANGECOMMAND_H
 
 #include "document/Command.h"
-#include <QString>
-#include "base/Event.h"
+#include "base/TimeT.h"
 #include "base/Composition.h" // for tempoT
+
 #include <QCoreApplication>
-
-
-class Remove;
+#include <QString>
 
 
 namespace Rosegarden
 {
 
-class Composition;
-
 
 class RemoveTempoChangeCommand : public NamedCommand
 {
@@ -46,25 +41,26 @@ public:
         m_composition(composition),
         m_tempoChangeIndex(index),
         m_oldTime(0),
-        m_oldTempo(0){}
+        m_oldTempo(0),
+        m_oldTarget(-1)
+{}
 
     ~RemoveTempoChangeCommand() override {}
 
-    static QString getGlobalName() { return tr("Remove &Tempo Change..."); }
+    static QString getGlobalName()  { return tr("Remove &Tempo Change..."); }
 
     void execute() override;
     void unexecute() override;
 
 private:
     Composition *m_composition;
-    int                      m_tempoChangeIndex;
-    timeT        m_oldTime;
-    tempoT       m_oldTempo;
+    int m_tempoChangeIndex;
+    timeT m_oldTime;
+    tempoT m_oldTempo;
+    tempoT m_oldTarget;
 };
 
 
-
-
 }
 
 #endif
