@@ -19,15 +19,19 @@
 #define RG_SEGMENTCHANGEQUANTIZATIONCOMMAND_H
 
 #include "document/Command.h"
-#include <QString>
-#include <QCoreApplication>
-#include <vector>
-#include "base/Event.h"
+#include "base/TimeT.h"
 #include "gui/editors/notation/NotationStrings.h"
 
+#include <QCoreApplication>
+#include <QString>
+
+#include <vector>
+
+
 namespace Rosegarden
 {
 
+
 class Segment;
 
 
@@ -68,7 +72,6 @@ private:
 };
 
 
-
 }
 
 #endif
