@@ -20,14 +20,15 @@
 #define RG_SEGMENTCHANGETRANSPOSECOMMAND_H
 
 #include "document/Command.h"
-#include <QString>
+
 #include <QCoreApplication>
-#include <vector>
-#include "base/Event.h"
+#include <QString>
+
 
 namespace Rosegarden
 {
 
+
 class Segment;
 
 
@@ -57,7 +58,6 @@ private:
 };
 
 
-
 }
 
 #endif
