@@ -3,11 +3,11 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
- 
+    Copyright 2000-2025 the Rosegarden development team.
+
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
- 
+
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
     published by the Free Software Foundation; either version 2 of the
@@ -26,26 +26,29 @@
 namespace Rosegarden
 {
 
-SegmentCommandRepeat::SegmentCommandRepeat(const std::vector<Segment*>& segments,
-        bool repeat)
-        : SegmentCommand(tr("Repeat Segments"), segments),
-        m_repeatState(repeat)
+SegmentCommandRepeat::SegmentCommandRepeat
+(const std::vector<Segment*>& segments,
+ bool repeat)
+    : SegmentCommand(tr("Repeat Segments"), segments),
+      m_newRepeatState(repeat)
 {}
 
 void SegmentCommandRepeat::execute()
 {
     segmentlist::iterator it;
 
-    for (it = m_segments.begin(); it != m_segments.end(); ++it)
-        (*it)->setRepeating(m_repeatState);
+    for (it = m_segments.begin(); it != m_segments.end(); ++it) {
+        bool oldRepeat = (*it)->isRepeating();
+        m_oldRepeatState.push_back(oldRepeat);
+        (*it)->setRepeating(m_newRepeatState);
+    }
 }
 
 void SegmentCommandRepeat::unexecute()
 {
-    segmentlist::iterator it;
-
-    for (it = m_segments.begin(); it != m_segments.end(); ++it)
-        (*it)->setRepeating(!m_repeatState);
+    for(unsigned int i = 0; i < m_segments.size(); i++) {
+        m_segments[i]->setRepeating(m_oldRepeatState[i]);
+    }
 }
 
 }
