@@ -4,10 +4,10 @@
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
     Copyright 2000-2025 the Rosegarden development team.
- 
+
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
- 
+
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
     published by the Free Software Foundation; either version 2 of the
@@ -16,12 +16,15 @@
 */
 
 #define RG_MODULE_STRING "[SegmentEraseCommand]"
+#define RG_NO_DEBUG_PRINT
 
 #include "SegmentEraseCommand.h"
 
 #include "misc/Debug.h"
 #include "base/Composition.h"
 #include "base/Segment.h"
+#include "document/RosegardenDocument.h"
+#include "sequencer/RosegardenSequencer.h"
 #include "sound/AudioFile.h"
 #include "sound/AudioFileManager.h"
 
@@ -53,7 +56,7 @@ SegmentEraseCommand::SegmentEraseCommand(Segment *segment,
     // the file.
     if (m_segment->getType() == Segment::Audio) {
         unsigned int id = m_segment->getAudioFileId();
-        AudioFile *file = mgr->getAudioFile(id);
+        const AudioFile *file = mgr->getAudioFile(id);
         if (file)
             m_audioFileName = file->getAbsoluteFilePath();
     }
@@ -86,6 +89,7 @@ SegmentEraseCommand::unexecute()
     m_detached = false;
 
     // If we are bringing back an audio segment
+    RG_DEBUG << "unexecute" << m_segment->getType() << m_mgr << m_audioFileName;
     if (m_segment->getType() == Segment::Audio &&
             m_audioFileName != "" &&
             m_mgr) {
@@ -93,14 +97,22 @@ SegmentEraseCommand::unexecute()
         // The user may have deleted and re-added the audio file, which
         // would cause its ID to change.
         int id = m_mgr->fileExists(m_audioFileName);
+        RG_DEBUG << "unexecute fileExists id" << id;
 
         // If the audio file wasn't found, it may have been deleted
         // by the user.  Re-add it.
-        // (When some parts of a system use the command history and others
-        // don't (AudioFileManager), expect evil kludges such as this.)
-        // In my testing, the audio file no longer plays after this.
         if (id == -1)
             id = (int)m_mgr->addFile(m_audioFileName);
+        RG_DEBUG << "unexecute addFile id" << id;
+
+        // we must go through the sequencer to insure the sound driver
+        // has the audio file
+        const AudioFile *aF = RosegardenDocument::currentDocument->
+            getAudioFileManager().getAudioFile(id);
+        if (aF) {
+            RosegardenSequencer::getInstance()->
+                addAudioFile(aF->getAbsoluteFilePath(), aF->getId());
+        }
 
         m_segment->setAudioFileId(id);
     }
