@@ -21,11 +21,13 @@
 
 #include "document/Command.h"
 #include "base/Track.h"
-#include "base/Event.h"
+#include "base/TimeT.h"
 
 #include <QString>
+
 #include <vector>
 
+
 namespace Rosegarden
 {
 
@@ -33,14 +35,15 @@ namespace Rosegarden
 class Composition;
 class Segment;
 
+
 /// Move or resize segments, or change their tracks.
 class SegmentReconfigureCommand : public NamedCommand
 {
 public:
-    SegmentReconfigureCommand(QString name, Composition *composition);
+    SegmentReconfigureCommand(const QString& name, Composition *composition);
     ~SegmentReconfigureCommand() override;
 
-    // rename: addChange()
+    // ??? rename: addChange()
     void addSegment(Segment *segment,
                     timeT newStartTime,
                     timeT newEndMarkerTime,
@@ -64,7 +67,7 @@ private:
 
     // Does the actual work of swapping the changes into the segments.
     timeT swap();
-    
+
     // Command overrides
     void execute() override;
     void unexecute() override;
