@@ -20,16 +20,16 @@
 #define RG_SEGMENTRESCALECOMMAND_H
 
 #include "document/Command.h"
-#include <QString>
-#include "base/Event.h"
+#include "base/TimeT.h"
+
 #include <QCoreApplication>
-
-
+#include <QString>
 
 
 namespace Rosegarden
 {
 
+
 class Segment;
 
 
@@ -65,7 +65,6 @@ private:
 };
 
 
-
 }
 
 #endif
