@@ -20,7 +20,7 @@
 #define RG_SEGMENTSINGLEREPEATTOCOPYCOMMAND_H
 
 #include "document/Command.h"
-#include "base/Event.h"
+#include "base/TimeT.h"
 
 #include <QCoreApplication>
 
@@ -28,6 +28,7 @@
 namespace Rosegarden
 {
 
+
 class Segment;
 class Composition;
 
