@@ -20,10 +20,7 @@
 #define RG_SEGMENTSYNCCLEFCOMMAND_H
 
 #include "document/Command.h"
-#include "base/Event.h"
 #include "base/NotationTypes.h"
-#include "base/Selection.h"
-#include "document/CommandHistory.h"
 
 #include <QCoreApplication>
 
@@ -31,6 +28,7 @@
 namespace Rosegarden
 {
 
+
 class Segment;
 
 
@@ -39,14 +37,15 @@ class SegmentSyncClefCommand : public MacroCommand
     Q_DECLARE_TR_FUNCTIONS(Rosegarden::SegmentSyncClefCommand)
 
 public:
-    SegmentSyncClefCommand(Segment &segment, const Clef& clef);
+    SegmentSyncClefCommand(Segment &segment, const Clef &clef);
 
     ~SegmentSyncClefCommand() override;
 
 protected:
-    void processSegment(Segment &segment, const Clef& clef);
+    void processSegment(Segment &segment, const Clef &clef);
 };
 
+
 }
 
 #endif
