@@ -20,19 +20,16 @@
 #define RG_SEGMENTSYNCCOMMAND_H
 
 #include "document/Command.h"
-#include "base/Composition.h"
-#include "base/Event.h"
 #include "base/NotationTypes.h"
 #include "base/Selection.h"
-#include "document/CommandHistory.h"
+#include "base/Segment.h"
 
 #include <QCoreApplication>
 
+
 namespace Rosegarden
 {
 
-class Segment;
-
 
 class SegmentSyncCommand : public MacroCommand
 {
@@ -45,8 +42,11 @@ public:
     SegmentSyncCommand(SegmentSelection selection,
             int newTranspose, int lowRange, int highRange, const Clef& clef);
 
-    SegmentSyncCommand(std::vector<Segment *> segments,
-            int newTranspose, int lowRange, int highRange, const Clef& clef);
+    SegmentSyncCommand(const std::vector<Segment *>& segments,
+                       int newTranspose,
+                       int lowRange,
+                       int highRange,
+                       const Clef& clef);
 
     SegmentSyncCommand(SegmentMultiSet& segments, TrackId selectedTrack,
             int newTranspose, int lowRange, int highRange, const Clef& clef);
@@ -57,6 +57,7 @@ protected:
     void processSegment(Segment &segment, int newTranspose, int lowRange, int highRange, const Clef& clef);
 };
 
+
 }
 
 #endif
