@@ -4,10 +4,10 @@
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
     Copyright 2000-2025 the Rosegarden development team.
- 
+
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
- 
+
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
     published by the Free Software Foundation; either version 2 of the
@@ -44,7 +44,7 @@ ModifyControlParameterCommand::execute()
         return ;
     }
 
-    ControlParameter *param = md->getControlParameter(m_id);
+    const ControlParameter *param = md->getControlParameter(m_id);
     if (param)
         m_originalControl = *param;
     md->modifyControlParameter(m_control, m_id);
