@@ -3,11 +3,11 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
- 
+    Copyright 2000-2025 the Rosegarden development team.
+
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
- 
+
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
     published by the Free Software Foundation; either version 2 of the
@@ -40,7 +40,7 @@ RemoveControlParameterCommand::execute()
         return;
     }
 
-    ControlParameter *param = midiDevice->getControlParameter(m_controllerIndex);
+    const ControlParameter *param = midiDevice->getControlParameter(m_controllerIndex);
     if (param)
         m_oldControl = *param;
 
