@@ -4,10 +4,10 @@
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
     Copyright 2000-2025 the Rosegarden development team.
- 
+
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
- 
+
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
     published by the Free Software Foundation; either version 2 of the
@@ -24,7 +24,7 @@ namespace Rosegarden
 {
 
 bool
-GzipFile::writeToFile(QString file, QString text)
+GzipFile::writeToFile(const QString& file, const QString& text)
 {
     std::string stext = std::string(text.toUtf8().data());
     const char *ctext = stext.c_str();
@@ -33,14 +33,14 @@ GzipFile::writeToFile(QString file, QString text)
     gzFile fd = gzopen(file.toLocal8Bit().data(), "wb");
     if (!fd) return false;
 
-    int actual = gzwrite(fd, (void *)ctext, csize);
+    int actual = gzwrite(fd, static_cast<void const*>(ctext), csize);
     gzclose(fd);
 
     return ((size_t)actual == csize);
 }
 
 bool
-GzipFile::readFromFile(QString file, QString &text)
+GzipFile::readFromFile(const QString& file, QString& text)
 {
     text = "";
     gzFile fd = gzopen(file.toLocal8Bit().data(), "rb");
@@ -58,8 +58,6 @@ GzipFile::readFromFile(QString file, QString &text)
     gzclose(fd);
     text = QString::fromUtf8(ba);
     return ok;
-}    
-
 }
 
-
+}
