@@ -20,24 +20,23 @@
 
 #include "base/Device.h"
 #include "base/MidiProgram.h"
-#include "base/Event.h"
+#include "base/TimeT.h"
 #include "document/io/XMLHandler.h"
 
 #include <QString>
-#include <QtCore/QSharedPointer>
 #include <QPointer>
 #include <QProgressDialog>
 #include <QSharedPointer>
 
 #include <map>
 #include <set>
-#include <vector>
 #include <string>
 
 
 namespace Rosegarden
 {
 
+
 class XmlStorableEvent;
 class XmlSubHandler;
 class Studio;
@@ -200,11 +199,17 @@ protected:
 
     bool m_hasActiveAudio;
 
-    bool locateAudioFile(const QString& id,
-                         const QString& file,
-                         const QString& label);
+    bool locateAudioFile(const QString &id,
+                         const QString &file,
+                         const QString &label);
     /// Whether the audio skip warning has been issued.
     bool m_audioSkipWarning;
+    /// Insert audio file with check for existence.  Returns false if not found.
+    bool insertAudioFile(const QString &newAudioDirectory,
+                         const QString &id,
+                         const QString &file,
+                         const QString &label);
+
 
     // In case we encounter an old solo attribute at the composition level,
     // hold onto it and use it to set the solo for the proper track.
