@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -27,7 +27,7 @@
 #include "base/Studio.h"
 #include "gui/editors/segment/compositionview/AudioPeaksThread.h"
 #include "sound/AudioFileManager.h"
-#include "base/Event.h"
+#include "base/TimeT.h"
 
 #include <QObject>
 #include <QString>
@@ -36,13 +36,12 @@
 #include <QPointer>
 #include <QSharedPointer>
 
+class QLockFile;
+class QTextStream;
+
 #include <map>
 #include <vector>
 
-class QLockFile;
-class QWidget;
-class QTextStream;
-class NoteOnRecSet;
 
 namespace Rosegarden
 {
@@ -94,12 +93,16 @@ public:
      * that is no longer the case since Thorn.  We need to be able to avoid
      * clearing the command history here, or certain commands wipe out the
      * entire undo history needlessly.
+     *
+     * If the path is not empty the file will be loaded but the document will
+     * still be considered "new"
      */
     RosegardenDocument(QObject *parent,
                        QSharedPointer<AudioPluginManager> audioPluginManager,
                        bool skipAutoload = false,
                        bool clearCommandHistory = true,
-                       bool enableSound = true);
+                       bool enableSound = true,
+                       const QString& path = "");
 
     /// The current document.
     /**
@@ -110,8 +113,8 @@ public:
      * RosegardenDocument, e.g. Composition, beware that the document may
      * have changed when your destructor is called.  In these cases, keep a
      * local copy of the document pointer so that you can detach from the
-     * correct document.  See, e.g. TempoView which uses EditViewBase::m_doc
-     * in this way.
+     * correct document.  See, e.g. TempoAndTimeSignatureEditor which uses
+     * EditViewBase::m_doc in this way.
      *
      * If we are crashing because this is null, be sure that when a document
      * is created, this pointer is set.  The rest of the system depends on
@@ -229,19 +232,22 @@ public:
      *
      * errMsg will be set to a user-readable error message if save fails
      */
-    bool saveDocument(const QString &filename, QString& errMsg,
+    bool saveDocument(const QString &filename, QString &errMsg,
                       bool autosave = false);
 
     /// Save under a new name.
     bool saveAs(const QString &newName, QString &errMsg);
 
+    /// Saves the document to a suitably-named backup file.
+    void autoSave();
+
     /**
      * exports all or part of the studio to a file.  If devices is
      * empty, exports all devices.
      */
     bool exportStudio(const QString &filename,
-		      QString &errMsg,
-                      std::vector<DeviceId> devices =
+                      QString &errMsg,
+                      const std::vector<DeviceId> &devices =
                       std::vector<DeviceId>());
 
     /**
@@ -465,8 +471,6 @@ public:
      */
     QList<RosegardenMainViewWidget*>& getViewList() { return m_viewList; }
 
-    bool isBeingDestroyed() { return m_beingDestroyed; }
-
     static const unsigned int MinNbOfTracks; // 64
 
     /// Verify that the audio path exists and can be written to.
@@ -503,11 +507,6 @@ public slots:
     void slotDocumentModified();
     void slotDocumentRestored();
 
-    /**
-     * saves the document to a suitably-named backup file
-     */
-    void slotAutoSave();
-
     void slotSetPointerPosition(timeT);
 
     void slotDocColoursChanged();
@@ -576,7 +575,7 @@ private:
     /**
      * initializes the document generally
      */
-    void newDocument();
+    void newDocument(const QString& path = "");
 
     /**
      * Autoload
@@ -592,22 +591,11 @@ private:
      * @return false if parsing failed
      * @see RoseXmlHandler
      */
-    bool xmlParse(QString fileContents, QString &errMsg,
+    bool xmlParse(const QString &fileContents,
+                  QString &errMsg,
                   bool permanent,
                   bool &cancelled);
 
-    /**
-     * Set the "auto saved" status of the document
-     * Doc. modification sets it to false, autosaving
-     * sets it to true
-     */
-    void setAutoSaved(bool s) { m_autoSaved = s; }
-
-    /**
-     * Returns whether the document should be auto-saved
-     */
-    bool isAutoSaved() const { return m_autoSaved; }
-
     /**
      * Returns the name of the autosave file
      */
@@ -626,9 +614,9 @@ private:
     /**
      * Save one segment to the given text stream
      */
-    void saveSegment(QTextStream&, Segment*,
-                     long totalNbOfEvents, long &count,
-                     QString extraAttributes = QString());
+    void saveSegment(QTextStream &outStream,
+                     const Segment *segment,
+                     const QString &additionalAttributes);
 
     /// Identifies a specific event within a specific segment.
     /**
@@ -698,15 +686,13 @@ private:
      */
     QList<EditViewBase*> m_editViewList;
 
-    /**
-     * the modified flag of the current document
-     */
     bool m_modified;
 
+    /// Whether an autosave or a regular save has occurred.
     /**
-     * the autosaved status of the current document
+     * This is used by autoSave() to avoid redundant auto-saves.
      */
-    bool m_autoSaved;
+    bool m_autoSaved{false};
 
     /**
      * the title of the current document
@@ -801,9 +787,6 @@ private:
      */
     int m_autoSavePeriod;
 
-    // Set to true when the dtor starts
-    bool m_beingDestroyed;
-
     /**
      * Tells this document whether it should clear the command history upon
      * construction and destruction.  Usually true.  Set this to false for
