@@ -64,6 +64,8 @@ enum {
 
 // Default version used if some error occurs
 const int LILYPOND_VERSION_DEFAULT = LILYPOND_VERSION_TOO_OLD + 1;
+// For the settings the default must be 1 lower. See also the comment in cpp
+const int LILYPOND_VERSION_DEFAULT_SETTINGS = LILYPOND_VERSION_DEFAULT - 1;
 
 // Versions strings associated with the previous enum.
 // They are used inside the LilyPond code.
@@ -146,7 +148,7 @@ private:
 
     void readConfigVariables();
 
-    Event *nextNoteInGroup(Segment *s, Segment::iterator it, const std::string &groupType, int barEnd) const;
+    Event *nextNoteInGroup(const Segment *s, Segment::iterator it, const std::string &groupType, int barEnd) const;
 
     // Return true if the given segment has to be print
     // (readConfigVAriables() should have been called before)
@@ -168,10 +170,10 @@ private:
                                         const std::pair<int, int> &tupletRatio,
                                         bool &overlong);
 
-    void handleStartingPreEvents(eventstartlist &preEventsToStart,
-                                 const Segment *seg,
-                                 const Segment::iterator &j,
-                                 std::ofstream &str);
+    static void handleStartingPreEvents(eventstartlist &preEventsToStart,
+                                        const Segment *seg,
+                                        const Segment::iterator &j,
+                                        std::ofstream &str);
     void handleEndingPreEvents(eventendlist &preEventsInProgress,
                                const Segment::iterator &j,
                                std::ofstream &str);
@@ -291,6 +293,8 @@ private:
     const PropertyName SKIP_PROPERTY;
 
     unsigned int m_paperSize;
+    // ??? These need to be public someplace LilyPondOptionsDialog can get
+    //     to them.  It needs PAPER_A4 and PAPER_LETTER.
     static const unsigned int PAPER_A3      = 0;
     static const unsigned int PAPER_A4      = 1;
     static const unsigned int PAPER_A5      = 2;
