@@ -64,7 +64,7 @@ MusicXMLImportHelper::setStaff(const QString &staff)
         if (!m_tracks.empty()) {
             pos = m_tracks["1"]->getPosition() + m_tracks.size();
             Composition::TrackMap tracks = composition.getTracks();
-            for (Composition::TrackMap::iterator t = tracks.begin(); t != tracks.end(); t++) {
+            for (Composition::TrackMap::iterator t = tracks.begin(); t != tracks.end(); ++t) {
                 if (((*t).second)->getPosition() >= pos) {
                     ((*t).second)->setPosition(((*t).second)->getPosition()+1);
                 }
