@@ -4,13 +4,13 @@
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
     Copyright 2000-2025 the Rosegarden development team.
- 
+
     This file is Copyright 2005
         Toni Arnold         <toni__arnold@bluewin.ch>
- 
+
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
- 
+
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
     published by the Free Software Foundation; either version 2 of the
@@ -121,7 +121,8 @@ LircCommander::command LircCommander::commands[] =
 
 int LircCommander::compareCommandName(const void *c1, const void *c2)
 {
-    return (strcmp(((struct command *)c1)->name, ((struct command *)c2)->name));
+    return (strcmp(static_cast<const struct command *>(c1)->name,
+                   static_cast<const struct command *>(c2)->name));
 }
 
 void LircCommander::slotExecute(const char *command)
@@ -132,10 +133,13 @@ void LircCommander::slotExecute(const char *command)
 
     // find the function for the name
     tmp.name = command;
-    res = (struct command *)bsearch(&tmp, commands,
-                                    sizeof(commands) / sizeof(struct command),
-                                    sizeof(struct command),
-                                    compareCommandName);
+    tmp.code = cmd_play;
+    res = static_cast<struct command *>
+        (bsearch(&tmp,
+                 commands,
+                 sizeof(commands) / sizeof(struct command),
+                 sizeof(struct command),
+                 compareCommandName));
     if (res != nullptr)
     {
         switch (res->code)
@@ -171,40 +175,40 @@ void LircCommander::slotExecute(const char *command)
             emit trackUp();
             break;
         case cmd_trackMute:
-            emit trackMute(); 
+            emit trackMute();
             break;
         case cmd_trackRecord:
-            emit trackRecord(); 
+            emit trackRecord();
             break;
         case cmd_undo:
-            emit undo(); 
+            emit undo();
             break;
         case cmd_redo:
-            emit redo(); 
+            emit redo();
             break;
         case cmd_aboutrg:
-            emit aboutrg(); 
+            emit aboutrg();
             break;
         case cmd_editInEventList:
-            emit editInEventList(); 
+            emit editInEventList();
             break;
         case cmd_editInMatrix:
-            emit editInMatrix(); 
+            emit editInMatrix();
             break;
         case cmd_editInPercussionMatrix:
-            emit editInPercussionMatrix(); 
+            emit editInPercussionMatrix();
             break;
         case cmd_editAsNotation:
-            emit editAsNotation(); 
+            emit editAsNotation();
             break;
         case cmd_quit:
-            emit quit(); 
+            emit quit();
             break;
         case cmd_closeTransport:
-            emit closeTransport(); 
+            emit closeTransport();
             break;
         case cmd_toggleTransportVisibility:
-            emit toggleTransportVisibility(); 
+            emit toggleTransportVisibility();
             break;
         default:
             RG_DEBUG <<  "LircCommander::slotExecute: unhandled command " << command;
