@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -19,24 +19,15 @@
 #define RG_ROSEGARDENAPPLICATION_H
 
 #include <QApplication>
-#include <QByteArray>
-#include <QString>
 
 #include <rosegardenprivate_export.h>
 
-class QSessionManager;
-class QProcess;
-
 
 namespace Rosegarden
 {
 
-/**
- * RosegardenApplication
- *
- * Handles RosegardenMainWindow's perceived uniqueness for us.
- *
- */
+
+/// Handles RosegardenMainWindow's perceived uniqueness for us.
 class ROSEGARDENPRIVATE_EXPORT RosegardenApplication : public QApplication
 {
     Q_OBJECT
@@ -45,8 +36,8 @@ public:
 
     virtual void saveState(QSessionManager&);
     
-    //!!!
-    //@@@ Need session manager commitData() call
+    // !!!
+    // @@@ Need session manager commitData() call
 
 signals:
     // connect this to RosegardenMainWindow
@@ -57,6 +48,7 @@ protected:
     bool notify(QObject * receiver, QEvent * event) override;
 };
 
+
 }
 
 #endif
