@@ -192,7 +192,7 @@ RosegardenMainViewWidget::~RosegardenMainViewWidget()
     delete m_rulerScale;
 }
 
-void RosegardenMainViewWidget::selectTool(QString toolName)
+void RosegardenMainViewWidget::selectTool(const QString& toolName)
 {
     m_trackEditor->getCompositionView()->setTool(toolName);
 }
@@ -261,11 +261,13 @@ void RosegardenMainViewWidget::slotEditSegment(Segment *segment)
         if (client == GeneralConfigurationPage::MatrixView) {
 
             bool isPercussion = false;
-            Track *track = RosegardenDocument::currentDocument->getComposition().getTrackById
+            const Track *track =
+                RosegardenDocument::currentDocument->
+                getComposition().getTrackById
                 (segment->getTrack());
             if (track) {
                 InstrumentId iid = track->getInstrument();
-                Instrument *instrument =
+                const Instrument *instrument =
                     RosegardenDocument::currentDocument->getStudio().getInstrumentById(iid);
                 if (instrument && instrument->isPercussion()) isPercussion = true;
             }
@@ -348,7 +350,7 @@ void
 RosegardenMainViewWidget::createNotationView(const std::vector<Segment *>& segmentsToEdit)
 {
     NotationView *notationView =
-        new NotationView(RosegardenDocument::currentDocument, segmentsToEdit);
+        new NotationView(segmentsToEdit);
 
     connect(notationView, &NotationView::play,
             RosegardenMainWindow::self(), &RosegardenMainWindow::slotPlay);
@@ -380,7 +382,8 @@ RosegardenMainViewWidget::createNotationView(const std::vector<Segment *>& segme
     connect(notationView, &NotationView::editTriggerSegment,
             this, &RosegardenMainViewWidget::slotEditTriggerSegment);
 
-    SequenceManager *sM = RosegardenDocument::currentDocument->getSequenceManager();
+    const SequenceManager *sM =
+        RosegardenDocument::currentDocument->getSequenceManager();
 
     connect(sM, &SequenceManager::insertableNoteOnReceived,
             notationView, &NotationView::slotInsertableNoteOnReceived);
@@ -484,7 +487,7 @@ PitchTrackerView *
 RosegardenMainViewWidget::createPitchTrackerView(const std::vector<Segment *>& segmentsToEdit)
 {
     PitchTrackerView *pitchTrackerView =
-        new PitchTrackerView(RosegardenDocument::currentDocument, segmentsToEdit);
+        new PitchTrackerView(segmentsToEdit);
 
     connect(pitchTrackerView, &NotationView::play,
             RosegardenMainWindow::self(), &RosegardenMainWindow::slotPlay);
@@ -516,7 +519,8 @@ RosegardenMainViewWidget::createPitchTrackerView(const std::vector<Segment *>& s
     connect(pitchTrackerView, &NotationView::editTriggerSegment,
             this, &RosegardenMainViewWidget::slotEditTriggerSegment);
 
-    SequenceManager *sM = RosegardenDocument::currentDocument->getSequenceManager();
+    const SequenceManager *sM =
+        RosegardenDocument::currentDocument->getSequenceManager();
 
     connect(sM, &SequenceManager::insertableNoteOnReceived,
             pitchTrackerView, &PitchTrackerView::slotInsertableNoteOnReceived);
@@ -659,9 +663,8 @@ void RosegardenMainViewWidget::slotEditSegmentsPercussionMatrix(const std::vecto
 void
 RosegardenMainViewWidget::createMatrixView(const std::vector<Segment *>& segmentsToEdit, bool drumMode)
 {
-    MatrixView *matrixView = new MatrixView(RosegardenDocument::currentDocument,
-                                                  segmentsToEdit,
-                                                  drumMode);
+    MatrixView *matrixView = new MatrixView(segmentsToEdit,
+                                            drumMode);
 
     connect(matrixView, &MatrixView::play,
             RosegardenMainWindow::self(), &RosegardenMainWindow::slotPlay);
@@ -693,7 +696,8 @@ RosegardenMainViewWidget::createMatrixView(const std::vector<Segment *>& segment
     connect(matrixView, &MatrixView::openInPitchTracker,
             this, &RosegardenMainViewWidget::slotEditSegmentsPitchTracker);
 
-    SequenceManager *sM = RosegardenDocument::currentDocument->getSequenceManager();
+    const SequenceManager *sM =
+        RosegardenDocument::currentDocument->getSequenceManager();
 
     connect(sM, &SequenceManager::insertableNoteOnReceived,
             matrixView, &MatrixView::slotInsertableNoteOnReceived);
@@ -846,8 +850,8 @@ void RosegardenMainViewWidget::slotEditSegmentAudio(Segment *segment)
         return;
     }
 
-    AudioFile *aF = RosegardenDocument::currentDocument->getAudioFileManager().
-                    getAudioFile(segment->getAudioFileId());
+    const AudioFile *aF = RosegardenDocument::currentDocument->
+            getAudioFileManager().getAudioFile(segment->getAudioFileId());
     if (aF == nullptr) {
         RG_WARNING << "slotEditSegmentAudio() - can't find audio file";
         return ;
@@ -1097,6 +1101,73 @@ void RosegardenMainViewWidget::slotSelectAllSegments()
     emit segmentsSelected(segments);
 }
 
+void
+RosegardenMainViewWidget::slotSelectRelatedSegments()
+{
+    const Composition &comp =
+        RosegardenDocument::currentDocument->getComposition();
+
+    SegmentSelection oldSelection =
+        m_trackEditor->getCompositionView()->getSelectedSegments();
+    SegmentSelection segments; // new selection
+    if (oldSelection.empty()) {
+        // if nothing is selected then select all related segments
+        for (Composition::iterator i = comp.begin(); i != comp.end(); ++i) {
+            oldSelection.insert(*i);
+        }
+    } else {
+        segments = oldSelection; // maintain old selected segments
+    }
+
+    // For each Segment in the Composition
+    for (Composition::iterator i = comp.begin(); i != comp.end(); ++i) {
+        // Check if this segment is linked to a segment in the old selection
+        Segment* cseg = *i;
+        Segment::SegmentType csType = cseg->getType();
+        for(const Segment* selseg : oldSelection) {
+            Segment::SegmentType selsegType = selseg->getType();
+            if (csType == Segment::Audio && selsegType == Segment::Audio) {
+                if (cseg->getAudioFileId() == selseg->getAudioFileId()) {
+                    segments.insert(cseg);
+                }
+            } else {
+                if (cseg->isLinkedTo(selseg)) {
+                    segments.insert(cseg);
+                }
+            }
+        }
+    }
+
+    // Send this signal to the GUI to activate the correct tool
+    // on the toolbar so that we have a SegmentSelector object
+    // to write the Segments into
+    //
+    if (!segments.empty()) {
+        emit activateTool(SegmentSelector::ToolName());
+    }
+
+    // Send the segment list even if it's empty as we
+    // use that to clear any current selection
+    //
+    m_trackEditor->getCompositionView()->selectSegments(segments);
+
+    //!!! similarly, how to set no selected track?
+    //comp.setSelectedTrack(trackId);
+
+    if (!segments.empty()) {
+        emit stateChange("have_selection", true);
+        if (!hasNonAudioSegment(segments)) {
+            emit stateChange("audio_segment_selected", true);
+        }
+    } else {
+        emit stateChange("have_selection", false);
+    }
+
+    // inform
+    //!!! inform what? is this signal actually used?
+    emit segmentsSelected(segments);
+}
+
 void
 RosegardenMainViewWidget::updateMeters()
 {
@@ -1121,7 +1192,7 @@ RosegardenMainViewWidget::updateMeters()
              RosegardenDocument::currentDocument->getComposition().getTracks().begin();
          i != RosegardenDocument::currentDocument->getComposition().getTracks().end(); ++i) {
 
-        Track *track = i->second;
+        const Track *track = i->second;
         if (!track) continue;
 
         InstrumentId instrumentId = track->getInstrument();
@@ -1144,14 +1215,13 @@ RosegardenMainViewWidget::updateMeters()
             recStates[instrumentId] == oldState)
             continue;
 
-        Instrument *instrument =
+        const Instrument *instrument =
             RosegardenDocument::currentDocument->getStudio().getInstrumentById(instrumentId);
         if (!instrument) continue;
 
         // This records the level of this instrument, not necessarily
         // caused by notes on this particular track.
-        LevelInfo &info = levels[instrumentId];
-        LevelInfo &recInfo = recLevels[instrumentId];
+        const LevelInfo &info = levels[instrumentId];
 
         if (instrument->getType() == Instrument::Audio ||
             instrument->getType() == Instrument::SoftSynth) {
@@ -1183,6 +1253,7 @@ RosegardenMainViewWidget::updateMeters()
                 (RosegardenDocument::currentDocument->getSequenceManager()->getTransportStatus()
                  != PLAYING)) {
 
+                const LevelInfo &recInfo = recLevels[instrumentId];
                 if (recInfo.level != 0 || recInfo.levelRight != 0) {
                     recDBleft = AudioLevel::fader_to_dB
                                 (recInfo.level, 127, AudioLevel::LongFader);
@@ -1194,7 +1265,7 @@ RosegardenMainViewWidget::updateMeters()
 
             if (toSet) {
                 RosegardenDocument *doc = RosegardenDocument::currentDocument;
-                Composition &comp = doc->getComposition();
+                const Composition &comp = doc->getComposition();
 
                 InstrumentId selectedInstrumentId = comp.getSelectedInstrumentId();
 
@@ -1244,7 +1315,7 @@ void
 RosegardenMainViewWidget::updateMonitorMeters()
 {
     RosegardenDocument *doc = RosegardenDocument::currentDocument;
-    Composition &comp = doc->getComposition();
+    const Composition &comp = doc->getComposition();
 
     InstrumentId selectedInstrumentId = comp.getSelectedInstrumentId();
 
@@ -1340,7 +1411,7 @@ void RosegardenMainViewWidget::addTrack(
 }
 
 void RosegardenMainViewWidget::slotDeleteTracks(
-    std::vector<TrackId> tracks)
+    const std::vector<TrackId>& tracks)
 {
     RG_DEBUG << "slotDeleteTracks() - deleting " << tracks.size() << " tracks";
 
@@ -1429,7 +1500,7 @@ RosegardenMainViewWidget::slotAddAudioSegmentDefaultPosition(AudioFileId audioFi
 
     if (track) {
         InstrumentId ii = track->getInstrument();
-        Instrument *instrument = studio.getInstrumentById(ii);
+        const Instrument *instrument = studio.getInstrumentById(ii);
 
         if (instrument &&
                 instrument->getType() == Instrument::Audio) {
@@ -1819,8 +1890,7 @@ RosegardenMainViewWidget::createEventView(Segment *segment)
     std::vector<Segment *> segments;
     segments.push_back(segment);
 
-    EventListEditor *eventView = new EventListEditor(
-            RosegardenDocument::currentDocument, segments);
+    EventListEditor *eventView = new EventListEditor(segments);
 
     connect(eventView, &EditViewBase::saveFile,
             RosegardenMainWindow::self(), &RosegardenMainWindow::slotFileSave);
