@@ -21,7 +21,7 @@
 #include "base/MidiProgram.h"
 #include "gui/widgets/ZoomSlider.h"
 #include "gui/general/RecentFiles.h"
-#include "base/Event.h"
+#include "base/TimeT.h"
 #include "base/Selection.h"
 #include "base/Typematic.h"
 #include "sound/AudioFile.h"
@@ -40,11 +40,6 @@
 #include <QSharedPointer>
 #include <QTime>
 
-#include <map>
-#include <set>
-
-#include <rosegardenprivate_export.h>
-
 class QWidget;
 class QTimer;
 class QTextCodec;
@@ -55,6 +50,11 @@ class QTemporaryFile;
 class QProcess;
 class QAction;
 
+#include <map>
+#include <set>
+
+#include <rosegardenprivate_export.h>
+
 
 namespace Rosegarden
 {
@@ -171,24 +171,24 @@ public:
     */
 
     /// merge a file, explicitly specifying its type, allow multiple files
-    void mergeFile(QStringList filePathList, ImportType type);
+    void mergeFile(const QStringList &filePathList, ImportType type);
 
     bool openURL(const QUrl &url, bool replace);
 
-    bool exportMIDIFile(QString file);
+    bool exportMIDIFile(const QString& file);
 
     /// export a Csound scorefile
-    bool exportCsoundFile(QString file);
+    bool exportCsoundFile(const QString &file);
 
-    bool exportMupFile(QString file);
+    bool exportMupFile(const QString &file);
 
     bool exportLilyPondFile(const QString &file, bool forPreview = false);
 
-    bool exportMusicXmlFile(QString file);
+    bool exportMusicXmlFile(const QString &file);
 
     SequenceManager *getSequenceManager() { return m_seqManager; }
 
-    ProgressBar *getCPUBar() { return m_cpuBar; }
+    //ProgressBar *getCPUBar() { return m_cpuBar; }
 
     QPointer<DeviceManagerDialog> getDeviceManager()  { return m_deviceManager; }
 
@@ -243,7 +243,7 @@ public:
      * the audio path for validity, and does not create anything if the audio
      * path does not exist.
      */
-    bool testAudioPath(QString operation); // and open the dialog to set it if unset
+    bool testAudioPath(const QString &operation); // and open the dialog to set it if unset
 
     bool haveAudioImporter() const  { return m_haveAudioImporter; }
 
@@ -253,7 +253,29 @@ public:
 
     void toggleLoop();
 
-protected:
+    /// Open the document properties dialog on the Audio page.
+    void openAudioPathSettings();
+
+signals:
+
+    void startupStatusMessage(QString message);
+
+    /// emitted just before the document is changed
+    void documentAboutToChange();
+
+    /// Emitted when a new document is loaded.
+    void documentLoaded(RosegardenDocument *);
+
+    /// emitted when the set of selected segments changes (relayed from RosegardenMainViewWidget)
+    void segmentsSelected(const SegmentSelection &);
+
+    /// emitted when a plugin dialog selects a plugin
+    void pluginSelected(InstrumentId, int, int);
+
+    /// emitted when a plugin dialog (un)bypasses a plugin
+    void pluginBypassed(InstrumentId, int, bool);
+
+private:
 
     /// Handle activation change.
     /**
@@ -421,7 +443,7 @@ protected:
     /*
      * Return AudioManagerDialog
      */
-    AudioManagerDialog *getAudioManagerDialog() { return m_audioManagerDialog; }
+    //AudioManagerDialog *getAudioManagerDialog() { return m_audioManagerDialog; }
 
     /**
      * Ask the user for a file to save to, and check that it's
@@ -461,7 +483,7 @@ protected:
      * Open a file dialog pointing to directory, if target is empty, this opens
      * a generic file open dialog at the last location the user used
      */
-    void openFileDialogAt(QString target);
+    void openFileDialogAt(const QString &target);
 
     /**
      * Returns a suitable location for storing user data, typically
@@ -473,36 +495,20 @@ protected:
      * Override (non-virtual) ActionFileClient's version to allow for more
      * complex enable/disable behavior.
      */
-    void enterActionState(QString stateName);
+    // cppcheck-suppress duplInheritedMember
+    void enterActionState(QString stateName) override;
     /**
      * Override (non-virtual) ActionFileClient's version to allow for more
      * complex enable/disable behavior.
      */
-    void leaveActionState(QString stateName);
-
-signals:
-    void startupStatusMessage(QString message);
-
-    /// emitted just before the document is changed
-    void documentAboutToChange();
-
-    /// Emitted when a new document is loaded.
-    void documentLoaded(RosegardenDocument *);
-
-    /// emitted when the set of selected segments changes (relayed from RosegardenMainViewWidget)
-    void segmentsSelected(const SegmentSelection &);
-
-    /// emitted when a plugin dialog selects a plugin
-    void pluginSelected(InstrumentId, int, int);
-
-    /// emitted when a plugin dialog (un)bypasses a plugin
-    void pluginBypassed(InstrumentId, int, bool);
+    // cppcheck-suppress duplInheritedMember
+    void leaveActionState(QString stateName) override;
 
 public slots:
 
-    /** Update the title bar to prepend a * to the document title when the
-     * document is modified. (I thought we already did this ages ago, but
-     * apparenty not.)
+    /**
+     * Update the title bar to prepend a * to the document title when the
+     * document is modified.
      */
     void slotUpdateTitle(bool modified = false);
 
@@ -513,110 +519,12 @@ public slots:
      */
     void slotOpenDroppedURL(QString url);
 
-    /**
-     * Open the document properties dialog on the Audio page
-     */
-    void slotOpenAudioPathSettings();
-
-    /**
-     * clears the document in the actual view to reuse it as the new
-     * document
-     */
-    void slotFileNew();
-
-    /**
-     * open a file and load it into the document
-     */
-    void slotFileOpen();
-
-    /**
-     * open a file dialog on the examples directory
-     */
-    void slotFileOpenExample();
-
-    /**
-     * open a file dialog on the templates directory
-     */
-    void slotFileOpenTemplate();
-
-    /**
-     * opens a file from the recent files menu (according to action name)
-     */
-    void slotFileOpenRecent();
-
     /**
      * save a document
      */
     void slotFileSave();
 
-    /**
-     * save a document by a new filename; if asTemplate is true, the file will
-     * be saved read-only, to make it harder to overwrite by accident in the
-     * future
-     */
-    void slotFileSaveAs() { fileSaveAs(false); }
-    void slotFileSaveAsTemplate() { fileSaveAs(true); }
-
-    /**
-     * asks for saving if the file is modified, then closes the actual
-     * file and window
-     */
-    void slotFileClose();
-
-    /**
-     * Let the user select a Rosegarden Project file for import
-     */
-    void slotImportProject();
-
-    /**
-     * Let the user select a MIDI file for import
-     */
-    void slotImportMIDI();
-
-    /**
-     * Revert to last loaded file
-     */
-    void slotRevertToSaved();
-
-    /**
-     * Let the user select a Rosegarden 2.1 file for import
-     */
-    void slotImportRG21();
-
-    /**
-     * Select a Hydrogen drum machine file for import
-     */
-//    void slotImportHydrogen();
-
-    /**
-     * Let the user select a MusicXML file for import
-     */
-    void slotImportMusicXML();
-
-    /**
-     * Let the user select a MIDI file for merge
-     */
-    void slotMerge();
-
-    /**
-     * Let the user select a MIDI file for merge
-     */
-    void slotMergeMIDI();
-
-    /**
-     * Let the user select a MIDI file for merge
-     */
-    void slotMergeRG21();
-
-    /**
-     * Select a Hydrogen drum machine file for merge
-     */
-//    void slotMergeHydrogen();
-
-    /**
-     * Let the user select a MusicXML file for merge
-     */
-    void slotMergeMusicXML();
+    // ??? Need to evaluate the rest of these slots and move to private.
 
     /**
      * Let the user export a Rosegarden Project file
@@ -731,6 +639,11 @@ public slots:
      */
     void slotSelectAll();
 
+    /**
+     * select all segments linked to selected segments
+     */
+    void slotSelectRelatedSegments();
+
     /**
      * delete selected segments, duh
      */
@@ -1268,19 +1181,6 @@ public slots:
     void slotZoomIn();
     void slotZoomOut();
 
-    /**
-     * Add marker
-     */
-    void slotAddMarker(timeT time);
-
-    /**
-     * Remove a marker
-     */
-    void slotDeleteMarker(int id,
-                          timeT time,
-                          const QString& name,
-                          const QString& description);
-
     /**
      * Document modified
      */
@@ -1338,6 +1238,7 @@ public slots:
      */
     void slotManageTriggerSegments();
 
+    /// File > Manage Audio Files...
     /**
      * View the audio file manager - and some associated actions
      */
@@ -1367,8 +1268,7 @@ public slots:
     /// Panic button pressed
     void slotPanic();
 
-    // Auto-save
-    //
+    /// Auto-save timer handler.
     void slotAutoSave();
 
     // Auto-save update interval changes
@@ -1471,11 +1371,11 @@ public slots:
      * happen from an external GUI, we have no way to manage these
      * internally.)
      */
-    void slotChangePluginConfiguration(InstrumentId,
+    void slotChangePluginConfiguration(InstrumentId instrumentId,
                                        int index,
                                        bool global,
-                                       const QString& key,
-                                       const QString& value);
+                                       const QString &configKey,
+                                       const QString &configValue);
     void slotPluginDialogDestroyed(InstrumentId instrumentId,
                                    int index);
     void slotPluginBypassed(InstrumentId,
@@ -1504,8 +1404,8 @@ public slots:
     void slotJumpToQuickMarker();
 
     void slotDisplayWarning(int type,
-                            QString text,
-                            QString informativeText);
+                            const QString& text,
+                            const QString& informativeText);
 
     // slots for save and restore of pointer position
     void slotAboutToExecuteCommand();
@@ -1513,6 +1413,9 @@ public slots:
     void slotCommandRedone();
     void slotUpdatePosition();
 
+    /// Toggles mute state of the currently selected track.
+    void slotToggleMute();
+
 private:
     /** Use QTemporaryFile to obtain a tmp filename that is guaranteed to be
      * unique
@@ -1555,6 +1458,7 @@ private:
     bool m_notPlaying{true};
     bool m_haveSelection{false};
     bool m_haveRange{false};
+    /// More complex action states than the .rc file can handle.
     void updateActions();
 
     RosegardenMainViewWidget *m_view{nullptr};
@@ -1674,8 +1578,10 @@ private:
 
 private slots:
 
+    /// ??? Rename: slotSetupRecentFilesMenu().
     void setupRecentFilesMenu();
 
+    /// ??? A "slot" named "signal"?  Fix this.
     void signalAction(int);
 
     // New routines to handle inputs and UI updates
@@ -1687,12 +1593,105 @@ private slots:
      */
     void slotUpdateCPUMeter();
 
-    /// Toggles mute state of the currently selected track.
-    void slotToggleMute();
     void slotMuteAllTracks();
     void slotUnmuteAllTracks();
 
     void slotCommandExecuted();
+
+    /**
+     * clears the document in the actual view to reuse it as the new
+     * document
+     */
+    void slotFileNew();
+
+    /**
+     * open a file and load it into the document
+     */
+    void slotFileOpen();
+
+    /**
+     * open a file dialog on the examples directory
+     */
+    void slotFileOpenExample();
+
+    /**
+     * open a file dialog on the templates directory
+     */
+    void slotFileOpenTemplate();
+
+    /**
+     * opens a file from the recent files menu (according to action name)
+     */
+    void slotFileOpenRecent();
+
+    /**
+     * save a document by a new filename; if asTemplate is true, the file will
+     * be saved read-only, to make it harder to overwrite by accident in the
+     * future
+     */
+    void slotFileSaveAs() { fileSaveAs(false); }
+    void slotFileSaveAsTemplate() { fileSaveAs(true); }
+
+    /**
+     * asks for saving if the file is modified, then closes the actual
+     * file and window
+     */
+    void slotFileClose();
+
+    /**
+     * Let the user select a Rosegarden Project file for import
+     */
+    void slotImportProject();
+
+    /**
+     * Let the user select a MIDI file for import
+     */
+    void slotImportMIDI();
+
+    /**
+     * Revert to last loaded file
+     */
+    void slotRevertToSaved();
+
+    /**
+     * Let the user select a Rosegarden 2.1 file for import
+     */
+    void slotImportRG21();
+
+    /**
+     * Select a Hydrogen drum machine file for import
+     */
+//    void slotImportHydrogen();
+
+    /**
+     * Let the user select a MusicXML file for import
+     */
+    void slotImportMusicXML();
+
+    /**
+     * Let the user select a MIDI file for merge
+     */
+    void slotMerge();
+
+    /**
+     * Let the user select a MIDI file for merge
+     */
+    void slotMergeMIDI();
+
+    /**
+     * Let the user select a MIDI file for merge
+     */
+    void slotMergeRG21();
+
+    /**
+     * Select a Hydrogen drum machine file for merge
+     */
+//    void slotMergeHydrogen();
+
+    /**
+     * Let the user select a MusicXML file for merge
+     */
+    void slotMergeMusicXML();
 };
 
 
