@@ -43,6 +43,36 @@ namespace Rosegarden
 {
 
 
+// Has to be a member so we can use tr().
+const GeneralConfigurationPage::PDFViewers
+    GeneralConfigurationPage::pdfViewers = {
+        { tr("Okular (KDE)"), "okular" },
+        { tr("Evince (GNOME)"), "evince" },
+        { tr("Adobe Acrobat Reader (non-free)"), "acroread" },
+        { tr("MuPDF"), "mupdf" },
+        { tr("ePDFView"), "epdfview" },
+        { tr("xdg-open (recommended)"), "xdg-open"}
+    };
+
+int GeneralConfigurationPage::getDefaultPDFViewer()
+{
+    return 5;  // xdg-open
+}
+
+// Has to be a member so we can use tr().
+const GeneralConfigurationPage::FilePrinters
+    GeneralConfigurationPage::filePrinters = {
+        { tr("Gtk-LP (GNOME)"), "gtklp" },
+        { tr("lp (no GUI)"), "lp" },
+        { tr("lpr (no GUI)"), "lpr" },
+        { tr("HPLIP (HP Printers)"), "hp-print" }
+    };
+
+int GeneralConfigurationPage::getDefaultFilePrinter()
+{
+    return 2;  // lpr
+}
+
 GeneralConfigurationPage::GeneralConfigurationPage(QWidget *parent) :
     TabbedConfigurationPage(parent)
 {
@@ -92,7 +122,8 @@ GeneralConfigurationPage::GeneralConfigurationPage(QWidget *parent) :
     m_countIn->setMinimum(0);
     m_countIn->setMaximum(10);
     m_countIn->setValue(settings.value("countinbars", 0).toUInt());
-    connect(m_countIn, SIGNAL(valueChanged(int)), this, SLOT(slotModified()));
+    connect(m_countIn, (void(QSpinBox::*)(int))&QSpinBox::valueChanged,
+            this, &GeneralConfigurationPage::slotModified);
     layout->addWidget(m_countIn, row, 1, 1, 2);
 
     ++row;
@@ -339,6 +370,21 @@ GeneralConfigurationPage::GeneralConfigurationPage(QWidget *parent) :
 
     ++row;
 
+    label = new QLabel(tr("Setup LV2 Environment"), frame);
+    tipText = tr(
+            "<qt><p>If set, set environment variables for lv2 plugins on gnome and wayland. In Rosegarden the environment variable XDG_SESSION_TYPE will be set to x11 on wayland displays and QT_QPA_PLATFORMTHEME will be set to gtk2 on non kde desktops. If you don't want this behaviour switch this item off</p></qt>");
+    label->setToolTip(tipText);
+    layout->addWidget(label, row, 0);
+    m_lv2Environment = new QCheckBox(frame);
+    m_lv2Environment->setToolTip(tipText);
+    m_lv2Environment->setChecked(Preferences::getLv2Environment());
+    connect(m_lv2Environment, &QCheckBox::stateChanged,
+            this, &GeneralConfigurationPage::slotModified);
+
+    layout->addWidget(m_lv2Environment, row, 1, 1, 2);
+
+    ++row;
+
     settings.beginGroup(GeneralOptionsConfigGroup);
 
     // Skip a row.  Leave some space for the next field.
@@ -350,7 +396,7 @@ GeneralConfigurationPage::GeneralConfigurationPage(QWidget *parent) :
 
     QString status(tr("Unknown"));
     RosegardenDocument *doc = RosegardenDocument::currentDocument;
-    SequenceManager *mgr = doc->getSequenceManager();
+    const SequenceManager *mgr = doc->getSequenceManager();
     if (mgr) {
         int driverStatus = mgr->getSoundDriverStatus() & (AUDIO_OK | MIDI_OK);
         switch (driverStatus) {
@@ -502,6 +548,7 @@ GeneralConfigurationPage::GeneralConfigurationPage(QWidget *parent) :
 
     m_trackLabelWidth->setCurrentIndex(
         settings.value("track_label_width", 2).toInt());
+    settings.endGroup();
     connect(m_trackLabelWidth, static_cast<void(QComboBox::*)(int)>(
                     &QComboBox::activated),
             this, &GeneralConfigurationPage::slotModified);
@@ -552,15 +599,10 @@ GeneralConfigurationPage::GeneralConfigurationPage(QWidget *parent) :
 
     m_pdfViewer = new QComboBox(frame);
     m_pdfViewer->setToolTip(tipText);
-    m_pdfViewer->addItem(tr("Okular (KDE)"));
-    m_pdfViewer->addItem(tr("Evince (GNOME)"));
-    m_pdfViewer->addItem(tr("Adobe Acrobat Reader (non-free)"));
-    m_pdfViewer->addItem(tr("MuPDF"));
-    m_pdfViewer->addItem(tr("ePDFView"));
-    m_pdfViewer->addItem(tr("xdg-open (recommended)"));
-    settings.endGroup();
-    settings.beginGroup(ExternalApplicationsConfigGroup);
-    m_pdfViewer->setCurrentIndex(settings.value("pdfviewer", xdgOpen).toUInt());
+    for (const PDFViewerInfo &info : pdfViewers) {
+        m_pdfViewer->addItem(info.name);
+    }
+    m_pdfViewer->setCurrentIndex(Preferences::getPDFViewer());
     connect(m_pdfViewer, static_cast<void(QComboBox::*)(int)>(
             &QComboBox::activated),
         this, &GeneralConfigurationPage::slotModified);
@@ -576,13 +618,10 @@ GeneralConfigurationPage::GeneralConfigurationPage(QWidget *parent) :
 
     m_filePrinter = new QComboBox(frame);
     m_filePrinter->setToolTip(tipText);
-    m_filePrinter->addItem(tr("Gtk-LP (GNOME)"));
-    m_filePrinter->addItem(tr("lp (no GUI)"));
-    m_filePrinter->addItem(tr("lpr (no GUI)"));
-    m_filePrinter->addItem(tr("HPLIP (HP Printers)"));
-    // now that I'm actually on KDE 4.2, I see no more KPrinter.  I'll default
-    // to Lpr instead.
-    m_filePrinter->setCurrentIndex(settings.value("fileprinter", Lpr).toUInt());
+    for (const FilePrinterInfo &info : filePrinters) {
+        m_filePrinter->addItem(info.name);
+    }
+    m_filePrinter->setCurrentIndex(Preferences::getFilePrinter());
     connect(m_filePrinter, static_cast<void(QComboBox::*)(int)>(
             &QComboBox::activated),
         this, &GeneralConfigurationPage::slotModified);
@@ -673,6 +712,7 @@ void GeneralConfigurationPage::apply()
     Preferences::setAutoChannels(m_autoChannels->isChecked());
     Preferences::setLV2(m_lv2->isChecked());
     Preferences::setDynamicDrag(m_dynamicDrag->isChecked());
+    Preferences::setLv2Environment(m_lv2Environment->isChecked());
 
     // Presentation tab
 
@@ -710,12 +750,8 @@ void GeneralConfigurationPage::apply()
 
     // External Applications tab
 
-    settings.beginGroup(ExternalApplicationsConfigGroup);
-
-    settings.setValue("pdfviewer", m_pdfViewer->currentIndex());
-    settings.setValue("fileprinter", m_filePrinter->currentIndex());
-
-    settings.endGroup();
+    Preferences::setPDFViewer(m_pdfViewer->currentIndex());
+    Preferences::setFilePrinter(m_filePrinter->currentIndex());
 
     // Restart Warnings
 
