@@ -4,10 +4,10 @@
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
     Copyright 2000-2025 the Rosegarden development team.
- 
+
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
- 
+
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
     published by the Free Software Foundation; either version 2 of the
@@ -144,9 +144,10 @@ MIDIConfigurationPage::MIDIConfigurationPage(QWidget *parent):
     m_controllerType = new QComboBox;
     m_controllerType->addItem(tr("Rosegarden Native"));
     m_controllerType->addItem(tr("Korg nanoKONTROL2"));
+    m_controllerType->addItem(tr("Akai MPK Mini IV (experimental)"));
 
     int controllerType = settings.value("controller_type", 0).toInt();
-    if (controllerType < 0  ||  controllerType > 1)
+    if (controllerType < 0  ||  controllerType > 2)
         controllerType = 0;
     m_controllerType->setCurrentIndex(controllerType);
 
@@ -378,7 +379,7 @@ MIDIConfigurationPage::MIDIConfigurationPage(QWidget *parent):
             this, &MIDIConfigurationPage::slotModified);
 
     layout->addWidget(m_midiMachineControlMode, row, 1);
-    
+
     ++row;
 
     // MIDI Time Code mode
@@ -577,7 +578,7 @@ MIDIConfigurationPage::apply()
     // Update the metronome mapped segment with new clock ticks if needed.
 
     RosegardenDocument *doc = RosegardenDocument::currentDocument;
-    Studio &studio = doc->getStudio();
+    const Studio &studio = doc->getStudio();
     const MidiMetronome *metronome = studio.getMetronomeFromDevice(
             studio.getMetronomeDevice());
 
