@@ -166,7 +166,7 @@ namespace
 void
 AddTracksDialog::initDeviceComboBox()
 {
-    const DeviceList &deviceList =
+    const DeviceVector &deviceList =
             *(RosegardenDocument::currentDocument->getStudio().getDevices());
 
     // Sort them into this set.
@@ -192,13 +192,13 @@ void AddTracksDialog::updateInstrumentComboBox()
 {
     m_instrument->clear();
 
-    Studio &studio = RosegardenDocument::currentDocument->getStudio();
+    const Studio &studio = RosegardenDocument::currentDocument->getStudio();
 
     const Device *device = studio.getDevice(m_device->currentData().toUInt());
     if (!device)
         return;
 
-    InstrumentList instrumentList = device->getPresentationInstruments();
+    InstrumentVector instrumentList = device->getPresentationInstruments();
     if (instrumentList.empty())
         return;
 
@@ -250,7 +250,7 @@ void AddTracksDialog::accept()
     if (m_device->currentIndex() < 0)
         return;
 
-    Studio &studio = RosegardenDocument::currentDocument->getStudio();
+    const Studio &studio = RosegardenDocument::currentDocument->getStudio();
 
     const Device *device = studio.getDevice(m_device->currentData().toUInt());
     if (!device)
@@ -260,7 +260,7 @@ void AddTracksDialog::accept()
 
     InstrumentId startInstrumentId = m_instrument->currentData().toUInt();
 
-    InstrumentList instrumentList = device->getPresentationInstruments();
+    InstrumentVector instrumentList = device->getPresentationInstruments();
     if (instrumentList.empty())
         return;
 
