@@ -4,10 +4,10 @@
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
     Copyright 2000-2025 the Rosegarden development team.
- 
+
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
- 
+
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
     published by the Free Software Foundation; either version 2 of the
@@ -37,7 +37,7 @@ namespace Rosegarden
 
 AudioFileLocationDialog::AudioFileLocationDialog(
         QWidget *parent,
-        QString documentNameDir) :
+        const QString& documentNameDir) :
     QDialog(parent),
     m_documentNameDirStr(documentNameDir)
 {
@@ -143,23 +143,24 @@ AudioFileLocationDialog::AudioFileLocationDialog(
 void
 AudioFileLocationDialog::updateWidgets()
 {
-    const Location location =
-            static_cast<Location>(Preferences::getDefaultAudioLocation());
+    const Preferences::Location location =
+            static_cast<Preferences::Location>(
+                    Preferences::getDefaultAudioLocation());
 
     switch (location) {
-    case AudioDir:
+    case Preferences::AudioDir:
         m_audioDir->setChecked(true);
         break;
-    case DocumentNameDir:
+    case Preferences::DocumentNameDir:
         m_documentNameDir->setChecked(true);
         break;
-    case DocumentDir:
+    case Preferences::DocumentDir:
         m_documentDir->setChecked(true);
         break;
-    case CentralDir:
+    case Preferences::CentralDir:
         m_centralDir->setChecked(true);
         break;
-    case CustomDir:
+    case Preferences::CustomDir:
         m_customDir->setChecked(true);
         break;
     }
@@ -171,18 +172,18 @@ void AudioFileLocationDialog::accept()
 {
     // Copy the user's choices to the Preferences.
 
-    Location location = AudioDir;
+    Preferences::Location location = Preferences::AudioDir;
 
     if (m_audioDir->isChecked())
-        location = AudioDir;
+        location = Preferences::AudioDir;
     if (m_documentNameDir->isChecked())
-        location = DocumentNameDir;
+        location = Preferences::DocumentNameDir;
     if (m_documentDir->isChecked())
-        location = DocumentDir;
+        location = Preferences::DocumentDir;
     if (m_centralDir->isChecked())
-        location = CentralDir;
+        location = Preferences::CentralDir;
     if (m_customDir->isChecked())
-        location = CustomDir;
+        location = Preferences::CustomDir;
 
     Preferences::setDefaultAudioLocation(location);
     Preferences::setCustomAudioLocation(m_customDirText->text());
