@@ -17,6 +17,7 @@
 
 
 #define RG_MODULE_STRING "[AudioManagerDialog]"
+#define RG_NO_DEBUG_PRINT
 
 #include "AudioManagerDialog.h"
 
@@ -121,7 +122,7 @@ AudioManagerDialog::AudioManagerDialog(QWidget *parent,
     m_sampleRate = RosegardenSequencer::getInstance()->getSampleRate();
 
     m_fileList = new AudioListView(centralWidget); // internal class needs parent (?)
-    m_fileList->setSelectionMode(QAbstractItemView::SingleSelection);
+    m_fileList->setSelectionMode(QAbstractItemView::ExtendedSelection);
     m_fileList->setSelectionBehavior(QAbstractItemView::SelectRows);
     m_fileList->setIconSize(QSize(m_maxPreviewWidth, m_previewHeight));
 
@@ -138,32 +139,23 @@ AudioManagerDialog::AudioManagerDialog(QWidget *parent,
     m_wrongSampleRates->hide();
 
     // file menu
-    createAction("add_audio", SLOT(slotAdd()));
-    createAction("export_audio", SLOT(slotExportAudio()));
-    createAction("file_close", SLOT(slotClose()));
+    createAction("add_audio", &AudioManagerDialog::slotAdd);
+    createAction("export_audio", &AudioManagerDialog::slotExportAudio);
+    createAction("file_close", &AudioManagerDialog::slotClose);
 
     // edit menu
-    createAction("remove_audio", SLOT(slotRemove()));
-    createAction("remove_all_audio", SLOT(slotRemoveAll()));
-    createAction("remove_all_unused_audio", SLOT(slotRemoveAllUnused()));
-    createAction("delete_unused_audio", SLOT(slotDeleteUnused()));
+    createAction("remove_audio", &AudioManagerDialog::slotRemove);
+    createAction("remove_all_audio", &AudioManagerDialog::slotRemoveAll);
+    createAction("remove_all_unused_audio", &AudioManagerDialog::slotRemoveAllUnused);
+    createAction("delete_unused_audio", &AudioManagerDialog::slotDeleteUnused);
 
     // action menu
-    createAction("preview_audio", SLOT(slotPlayPreview()));
-    createAction("insert_audio", SLOT(slotInsert()));
-    createAction("distribute_audio", SLOT(slotDistributeOnMidiSegment()));
+    createAction("preview_audio", &AudioManagerDialog::slotPlayPreview);
+    createAction("insert_audio", &AudioManagerDialog::slotInsert);
 
     // help menu
-    createAction("audio_help", SLOT(slotHelpRequested()));
-    createAction("help_about_app", SLOT(slotHelpAbout()));
-
-
-    //!!! oh now hang on, does this one work?
-
-    // (No, I've never heard of it until poking around in this code.  Julie
-    // hadn't either when she redid the old KXMLGUI stuff for us.  I think we've
-    // stumbled across a half eaten bagel here)
-    createAction("distribute_audio", SLOT(slotDistributeOnMidiSegment()));
+    createAction("audio_help", &AudioManagerDialog::slotHelpRequested);
+    createAction("help_about_app", &AudioManagerDialog::slotHelpAbout);
 
     // Set the column names
     //
@@ -188,8 +180,8 @@ AudioManagerDialog::AudioManagerDialog(QWidget *parent,
     connect(m_fileList, &QTreeWidget::itemSelectionChanged,
             this, &AudioManagerDialog::slotSelectionChanged);
 
-    connect(m_fileList, SIGNAL(dropped(QDropEvent*, QTreeWidget*, QList<QUrl>)),
-            SLOT(slotDropped(QDropEvent*, QTreeWidget*, QList<QUrl>)));
+    connect(m_fileList, &AudioListView::dropped,
+            this, &AudioManagerDialog::slotDropped);
 
 
     slotPopulateFileList();
@@ -203,9 +195,9 @@ AudioManagerDialog::AudioManagerDialog(QWidget *parent,
             this, &AudioManagerDialog::slotCancelPlayingAudio);
 
 
-    createMenusAndToolbars("audiomanager.rc"); //@@@ JAS orig. 0
+    createMenusAndToolbars("audiomanager.rc");
 
-    updateActionState(false);
+    updateActionState(0);
 
     QSettings settings;
     settings.beginGroup(WindowGeometryConfigGroup);
@@ -236,23 +228,36 @@ AudioManagerDialog::~AudioManagerDialog()
 void
 AudioManagerDialog::slotPopulateFileList()
 {
+    bool animated = m_fileList->isAnimated();
+    RG_DEBUG << "slotPopulateFileList" << animated;
+    // switch off animation for populate
+    m_fileList->setAnimated(false);
     // create pixmap of given size
-    QPixmap *audioPixmap = new QPixmap(m_maxPreviewWidth, m_previewHeight);
+    std::shared_ptr<QPixmap> audioPixmap{
+            new QPixmap(m_maxPreviewWidth, m_previewHeight)};
 
-    // Store last selected item if we have one
-    //
-    AudioListItem *selectedItem =
-            dynamic_cast<AudioListItem *>(m_fileList->currentItem());
-
-    AudioFileId lastId = 0;
-    Segment *lastSegment = nullptr;
-    bool findSelection = false;
-    bool foundSelection = false;
-
-    if (selectedItem) {
-        lastId = selectedItem->getId();
-        lastSegment = selectedItem->getSegment();
-        findSelection = true;
+    // remember old selection and expansion
+    struct SelectData
+    {
+        AudioFileId id;
+        const Segment *segment;
+        bool expanded;
+        bool selected;
+    };
+    std::list<SelectData> selectDataList;
+    QTreeWidgetItemIterator it(m_fileList);
+    while (*it) {
+        const AudioListItem *aItem = dynamic_cast<AudioListItem*>(*it);
+        if (! aItem) continue;
+        SelectData sd;
+        sd.id = aItem->getId();
+        sd.segment = aItem->getSegment();
+        sd.selected = false;
+        sd.expanded = false;
+        if ((*it)->isSelected()) sd.selected = true;
+        if ((*it)->isExpanded()) sd.expanded = true;
+        selectDataList.push_back(sd);
+        ++it;
     }
 
     // We don't want the selection changes to be propagated
@@ -272,14 +277,14 @@ AudioManagerDialog::slotPopulateFileList()
         m_fileList->setSelectionMode(QAbstractItemView::NoSelection);
 
         m_fileList->blockSignals(false);
-        updateActionState(false);
+        updateActionState(0);
         return ;
     }
 
     // show tree hierarchy
 
     // enable selection
-    m_fileList->setSelectionMode(QAbstractItemView::SingleSelection);
+    m_fileList->setSelectionMode(QAbstractItemView::ExtendedSelection);
 
     // Create a vector of audio Segments only
     //
@@ -309,7 +314,7 @@ AudioManagerDialog::slotPopulateFileList()
                         audioPixmap);
         } catch (const Exception &e) {
             audioPixmap->fill(); // white
-            QPainter p(audioPixmap);
+            QPainter p(audioPixmap.get());
             p.setPen(QColor(Qt::black));
             p.drawText(10, m_previewHeight / 2, QString("<no preview>"));
         }
@@ -323,8 +328,8 @@ AudioManagerDialog::slotPopulateFileList()
 
         // Duration
         const RealTime length = audioFile.getLength();
-        const QString msecs = QString::asprintf("%03d", length.nsec / 1000000);
-        item->setText(1, QString("%1.%2s").arg(length.sec).arg(msecs));
+        const QString audioFileDurationMsecs = QString::asprintf("%03d", length.nsec / 1000000);
+        item->setText(1, QString("%1.%2s").arg(length.sec).arg(audioFileDurationMsecs));
 
         // set start time and duration
         item->setStartTime(RealTime::zero());
@@ -356,17 +361,6 @@ AudioManagerDialog::slotPopulateFileList()
             item->setText(3, sRate);
         }
 
-        // Test audio file element for selection criteria
-        //
-        if (findSelection  &&
-            lastSegment == nullptr  &&
-            lastId == audioFile.getId()) {
-            //m_fileList->setSelected(item, true);
-            m_fileList->setCurrentItem(item);
-
-            findSelection = false;
-        }
-
         // Add children
 
         // For each audio segment
@@ -390,11 +384,11 @@ AudioManagerDialog::slotPopulateFileList()
 
             // Write segment duration
             //
-            const QString msecs =
+            const QString segmentDurationMsecs =
                 QString::asprintf("%03d", segmentDuration.nsec / 1000000);
             childItem->setText(1, QString("%1.%2s")
                                .arg(segmentDuration.sec)
-                               .arg(msecs));
+                               .arg(segmentDurationMsecs));
 
             try {
                 m_doc->getAudioFileManager().
@@ -417,16 +411,34 @@ AudioManagerDialog::slotPopulateFileList()
             //
             childItem->setSegment(segment);
 
-            if (findSelection  &&  lastSegment == segment) {
-                m_fileList->setCurrentItem(childItem);    // select
-                findSelection = false;
-                foundSelection = true;
-            }
-
         }
     }
 
-    updateActionState(foundSelection);
+    // restore selection and expansion
+    int numSelected = 0;
+    QTreeWidgetItemIterator it2(m_fileList);
+    while (*it2) {
+        const AudioListItem *aItem = dynamic_cast<AudioListItem*>(*it2);
+        if (! aItem) continue;
+        AudioFileId id = aItem->getId();
+        const Segment *segment = aItem->getSegment();
+        RG_DEBUG << "restore selection for" << id << segment;
+        for (const SelectData& sd : selectDataList) {
+            if (id == sd.id && segment == sd.segment) {
+                // should it be selected?
+                if (sd.selected) {
+                    (*it2)->setSelected(true);
+                    numSelected++;
+                }
+                if (sd.expanded) {
+                    (*it2)->setExpanded(true);
+                }
+            }
+        }
+        ++it2;
+    }
+
+    updateActionState(numSelected);
 
     if (wrongSampleRates) {
         m_wrongSampleRates->show();
@@ -435,18 +447,21 @@ AudioManagerDialog::slotPopulateFileList()
     }
 
     m_fileList->blockSignals(false);
+    m_fileList->setAnimated(animated);
 }
 
 AudioFile*
 AudioManagerDialog::getCurrentSelection()
 {
-    // try and get the selected item
+    // try and get the selected item. For multiselect this will return
+    // the first selected item. Normally this routine is only called
+    // if a single item is selected.
     QList<QTreeWidgetItem *> til= m_fileList->selectedItems();
     if (til.isEmpty()){
         RG_WARNING << "AudioManagerDialog::getCurrentSelection() - til.isEmpty() so we're returning 0 and this game is over. Fail.";
         return nullptr;
     }
-    AudioListItem *item = dynamic_cast<AudioListItem*>(til[0]);
+    const AudioListItem *item = dynamic_cast<AudioListItem*>(til[0]);
     if (item == nullptr) {
         RG_WARNING << "AudioManagerDialog::getCurrentSelection() - item == 0 so we're returning 0 and this game is over. Epic fail.";
         return nullptr;
@@ -460,105 +475,117 @@ AudioManagerDialog::getCurrentSelection()
         //
         if (item->getId() == (*it)->getId()) {
             return (*it);
-        } else {
-            RG_WARNING << "AudioManagerDialog::getCurrentSelection() - item->getId() of "
-                      << item->getId() << " does not match (*it)->getId() of "
-                      << (*it)->getId() << " so you are basically screwed.  Sorry about that."
-                     ;
         }
     }
-
-    RG_WARNING << "AudioManagerDialog::getCurrentSelection() - we tried so hard, but in the end it was all just bricks in the wall.";
+    RG_WARNING << "AudioManagerDialog::getCurrentSelection() - we tried so hard, but in the end it was all just bricks in the wall." << item->getId();
     return nullptr;
 }
 
 void
 AudioManagerDialog::slotExportAudio()
 {
-    WAVAudioFile *sourceFile =
-            dynamic_cast<WAVAudioFile *>(getCurrentSelection());
+    std::set<AudioFileId> ids;
+    getSelectedIds(ids);
 
-    if (!sourceFile)
-        return;
-
-    QList<QTreeWidgetItem *> selectedItems = m_fileList->selectedItems();
-
-    if (selectedItems.isEmpty()) {
-        RG_WARNING << "slotExportAudio() - nothing selected!";
-        return;
+    // check for valid ids and get WAVAudioFiles
+    std::set<WAVAudioFile*> WavAudioFiles;
+    for (AudioFileId id : ids) {
+        for (AudioFileVector::const_iterator it =
+                 m_doc->getAudioFileManager().cbegin();
+             it != m_doc->getAudioFileManager().cend();
+             ++it) {
+            // If we match then save the valid AudioFile
+            if ((*it)->getId() == id) {
+                AudioFile* audioFile = *it;
+                WAVAudioFile* wavFile = dynamic_cast<WAVAudioFile *>(audioFile);
+                if (wavFile) {
+                    WavAudioFiles.insert(wavFile);
+                    break;
+                }
+            }
+        }
     }
+    // WavAudioFiles now contains all valid wav audio files
 
-    // ??? All we ever look at is the first one.
-    AudioListItem *item = dynamic_cast<AudioListItem *>(selectedItems[0]);
+    if (WavAudioFiles.empty()) return;
 
-    if (!item)
-        return;
+    // default save directory
+    QSettings settings;
+    settings.beginGroup(LastUsedPathsConfigGroup);
+    QString directory = settings.value("save_audio_file",
+                                       QDir::homePath()).toString();
 
-    Segment *segment = item->getSegment();
+    if (WavAudioFiles.size() == 1) {
+        // single file
+        WAVAudioFile* sourceFile = *(WavAudioFiles.begin());
 
-    QString destFileName =
-            FileDialog::getSaveFileName(
-                    this,  // parent
-                    tr("Save File As"),  // caption
-                    QDir::currentPath(),  // dir
-                    sourceFile->getAbsoluteFilePath(),  // defaultName
-                    tr("*.wav|WAV files (*.wav)"));  // filter
+        QString destFileName =
+            FileDialog::getSaveFileName
+            (this,  // parent
+             tr("Save File As"),  // caption
+             directory,
+             sourceFile->getFileName(),  // defaultName
+             tr("*.wav|WAV files (*.wav)"));  // filter
 
-    if (destFileName.isEmpty())
-        return;
+        if (destFileName.isEmpty()) return;
+        // Check for a dot extension and append ".wav" if not found
+        // ??? Should use QFileInfo::suffix() to check for an extension.
+        if (destFileName.contains(".") == 0)
+            destFileName += ".wav";
 
-    // Check for a dot extension and append ".wav" if not found
-    // ??? Should use QFileInfo::suffix() to check for an extension.
-    if (destFileName.contains(".") == 0)
-        destFileName += ".wav";
+        writeWavFile(destFileName, sourceFile);
+        QFileInfo fi(destFileName);
+        QString destDir = fi.absolutePath();
+        settings.setValue("save_audio_file", destDir);
 
-    // Progress Dialog
-    QProgressDialog progressDialog(
-            tr("Exporting audio file..."),  // labelText
-            tr("Cancel"),  // cancelButtonText
-            0, 0,  // min, max
-            this);  // parent
-    progressDialog.setWindowTitle(tr("Rosegarden"));
-    progressDialog.setWindowModality(Qt::WindowModal);
-    // We will close anyway when this object goes out of scope.
-    progressDialog.setAutoClose(false);
-    // No cancel button since appendSamples() doesn't support progress.
-    progressDialog.setCancelButton(nullptr);
-    // Just force the progress dialog up.
-    // Both Qt4 and Qt5 have bugs related to delayed showing of progress
-    // dialogs.  In Qt4, the dialog sometimes won't show.  In Qt5, KDE
-    // based distros might lock up.  See Bug #1546.
-    progressDialog.show();
+    } else {
+        // save multiple files
+        WAVAudioFile* firstFile = *(WavAudioFiles.begin());
+        QString fpath = firstFile->getAbsoluteFilePath();
+        QFileInfo fi(fpath);
+        QString destDir =
+            FileDialog::getExistingDirectory
+            (this,  // parent
+             tr("Save Files To"),  // caption
+             directory);  // dir
 
-    RealTime clipStartTime;
-    RealTime clipDuration = sourceFile->getLength();
+        if (destDir.isEmpty()) return;
+        settings.setValue("save_audio_file", destDir);
 
-    if (segment) {
-        clipStartTime = segment->getAudioStartTime();
-        clipDuration = segment->getAudioEndTime() - clipStartTime;
+        QDir qDestDir(destDir);
+        bool yesToAll = false;
+        for (WAVAudioFile* wavFile : WavAudioFiles) {
+            QString filePath = wavFile->getAbsoluteFilePath();
+            QFileInfo fi(filePath);
+            QString fileName = fi.fileName();
+            QString destFileName = qDestDir.filePath(fileName);
+            // Check for a dot extension and append ".wav" if not found
+            // ??? Should use QFileInfo::suffix() to check for an extension.
+            if (destFileName.contains(".") == 0)
+                destFileName += ".wav";
+
+            // check for overwrite
+            QFileInfo checkFile(destFileName);
+            // check if file exists
+            if (checkFile.exists() && ! yesToAll) {
+                QString question =
+                        tr("The file %1 already exists.  Do you wish to overwrite it?").
+                                arg(destFileName);
+                int reply = QMessageBox::warning
+                    (this,
+                     tr("Rosegarden"),
+                     question,
+                     QMessageBox::YesToAll | QMessageBox::Yes | QMessageBox::No | QMessageBox::Cancel,
+                     QMessageBox::Cancel);
+                if (reply == QMessageBox::No) continue;
+                if (reply == QMessageBox::Cancel) return;
+                if (reply == QMessageBox::YesToAll) yesToAll = true;
+            }
+
+            writeWavFile(destFileName, wavFile);
+        }
     }
-
-    WAVAudioFile destFile(
-            destFileName,
-            sourceFile->getChannels(),
-            sourceFile->getSampleRate(),
-            sourceFile->getBytesPerSecond(),
-            sourceFile->getBytesPerFrame(),
-            sourceFile->getBitsPerSample());
-
-    if (sourceFile->open() == false)
-        return;
-
-    destFile.write();
-
-    sourceFile->scanTo(clipStartTime);
-
-    // appendSamples() takes the longest.  Would be nice if it would
-    // take a progress dialog.
-    destFile.appendSamples(sourceFile->getSampleFrameSlice(clipDuration));
-
-    destFile.close();
-    sourceFile->close();
+    settings.endGroup();
 }
 
 void
@@ -567,90 +594,61 @@ AudioManagerDialog::slotRemove()
     QList<QTreeWidgetItem *> selectedTreeItems = m_fileList->selectedItems();
 
     // If nothing is selected, bail.
-    // ??? Why not disable the action when there is no selection?
-    //     Then this will never happen.
+    // This should never happen as remove is disabled without selection.
     if (selectedTreeItems.isEmpty())
         return;
 
-    AudioListItem *item = dynamic_cast<AudioListItem *>(selectedTreeItems[0]);
-    if (!item)
-        return;
-
-    // If we're on a Segment then delete it from the Composition
-    // and refresh the list.
-    if (item->getSegment()) {
-        // Get the next item to highlight
-        QTreeWidgetItem *newTreeItem = m_fileList->itemBelow(item);
-
-        // Nothing below?  Try above.
-        if (!newTreeItem)
-            newTreeItem = m_fileList->itemAbove(item);
-
-        const AudioListItem *newAudioItem =
-                dynamic_cast<const AudioListItem *>(newTreeItem);
-
-        // If the item was an AudioListItem, and it is a Segment item...
-        if (newAudioItem  &&  newAudioItem->getSegment()) {
-            // Jump to new selection
-            setSelected(newAudioItem->getId(),
-                        newAudioItem->getSegment(),
-                        true);  // propagate
-        }
-
-        // Delete the Segment from the Composition.
-        SegmentSelection selection;
-        selection.insert(item->getSegment());
-        emit deleteSegments(selection);
-
-        return;
-    }
-
-    // An audio file item is selected in the tree...
-
-    const AudioFile *audioFile = getCurrentSelection();
-    if (!audioFile)
-        return;
-
-    // remove segments along with audio file
-    //
-    AudioFileId id = audioFile->getId();
     SegmentSelection selection;
-    Composition &comp = m_doc->getComposition();
+    std::list<AudioFileId> toDelete;
+    for (QTreeWidgetItem* item : selectedTreeItems) {
+        AudioListItem *aItem = dynamic_cast<AudioListItem*>(item);
 
-    bool haveSegments = false;
-    for (Composition::iterator it = comp.begin(); it != comp.end(); ++it) {
-        if ((*it)->getType() == Segment::Audio &&
-                (*it)->getAudioFileId() == id) {
-            haveSegments = true;
-            break;
+        if (item) {
+            if (aItem->getSegment()) {
+                selection.insert(aItem->getSegment());
+            } else {
+                toDelete.push_back(aItem->getId());
+            }
         }
     }
 
-    if (haveSegments) {
+    Composition &comp = m_doc->getComposition();
+    for (AudioFileId id : toDelete) {
+        for (Composition::iterator it = comp.begin(); it != comp.end(); ++it) {
+            if ((*it)->getType() == Segment::Audio &&
+                (*it)->getAudioFileId() == id)
+                // remove segments along with audio file
+                selection.insert(*it);
+        }
+    }
 
-        QString question = tr("This will unload audio file \"%1\" and remove all associated segments.  Are you sure?")
-                           .arg(audioFile->getAbsoluteFilePath());
+    if (selection.empty()) return;
+
+    QString question = tr("All selected segments will be deleted.");
+
+    if (! toDelete.empty()) {
+        question += tr(" Selected audio files will be unloaded and all associated segments deleted.");
+    }
+    question += tr(" Are you sure?");
 
         // Ask the question
-        int reply = QMessageBox::warning(this, tr("Rosegarden"), question, QMessageBox::Yes | QMessageBox::Cancel , QMessageBox::Cancel);
+    int reply = QMessageBox::warning(this,
+                                     tr("Rosegarden"),
+                                     question,
+                                     QMessageBox::Yes | QMessageBox::Cancel,
+                                     QMessageBox::Cancel);
 
-        if (reply != QMessageBox::Yes)
-            return ;
-    }
+    if (reply != QMessageBox::Yes) return;
 
-    for (Composition::iterator it = comp.begin(); it != comp.end(); ++it) {
-        if ((*it)->getType() == Segment::Audio &&
-                (*it)->getAudioFileId() == id)
-            selection.insert(*it);
-    }
     emit deleteSegments(selection);
 
-    m_doc->notifyAudioFileRemoval(id);
+    for (AudioFileId id : toDelete) {
+        m_doc->notifyAudioFileRemoval(id);
+        m_doc->getAudioFileManager().removeFile(id);
 
-    m_doc->getAudioFileManager().removeFile(id);
-
-    // tell the sequencer
-    emit deleteAudioFile(id);
+        // tell the sequencer
+        emit deleteAudioFile(id);
+    }
 
     // repopulate
     slotPopulateFileList();
@@ -659,7 +657,7 @@ AudioManagerDialog::slotRemove()
 void
 AudioManagerDialog::slotPlayPreview()
 {
-    AudioFile *audioFile = getCurrentSelection();
+    const AudioFile *audioFile = getCurrentSelection();
 
     QList<QTreeWidgetItem*> til = m_fileList->selectedItems();
     if (til.isEmpty()) {
@@ -675,6 +673,8 @@ AudioManagerDialog::slotPlayPreview()
     m_playingAudioFile = audioFile->getId();
 
     // tell the sequencer
+    RG_DEBUG << "slotPlayPreview play" << audioFile->getId() <<
+        item->getStartTime() << item->getDuration();
     emit playAudioFile(audioFile->getId(),
                        item->getStartTime(),
                        item->getDuration());
@@ -764,37 +764,59 @@ AudioManagerDialog::slotAdd()
 }
 
 void
-AudioManagerDialog::updateActionState(bool haveSelection)
+AudioManagerDialog::updateActionState(int numSelected)
 {
-    //RG_DEBUG << "updateActionState(" << (haveSelection ? "true" : "false") << ")";
+    RG_DEBUG << "updateActionState" << numSelected;
 
     if (m_doc->getAudioFileManager().cbegin() ==
             m_doc->getAudioFileManager().cend()) {
-        leaveActionState("have_audio_files"); //@@@ JAS orig. KXMLGUIClient::StateReverse
+        leaveActionState("have_audio_files");
     } else {
-        enterActionState("have_audio_files"); //@@@ JAS orig. KXMLGUIClient::StateNoReverse
+        enterActionState("have_audio_files");
     }
 
-    if (haveSelection) {
+    if (isSelectedTrackAudio()) {
+        enterActionState("have_audio_insertable");
+    } else {
+        leaveActionState("have_audio_insertable");
+    }
 
-        enterActionState("have_audio_selected"); //@@@ JAS orig. KXMLGUIClient::StateNoReverse
+    if (numSelected == 1) { // single item selected
+
+        leaveActionState("have_multi_audio_selected");
+        leaveActionState("have_multi_audio_single_id_selected");
+        enterActionState("have_audio_selected");
 
         if (m_audiblePreview) {
-            enterActionState("have_audible_preview"); //@@@ JAS orig. KXMLGUIClient::StateNoReverse
+            enterActionState("have_audible_preview");
         } else {
-            leaveActionState("have_audible_preview"); //@@@ JAS orig. KXMLGUIClient::StateReverse
+            leaveActionState("have_audible_preview");
         }
 
-        if (isSelectedTrackAudio()) {
-            enterActionState("have_audio_insertable"); //@@@ JAS orig. KXMLGUIClient::StateNoReverse
+    } else if (numSelected > 1) { // multiselect
+        // check for multi select with single id
+        std::set<AudioFileId> ids;
+        getSelectedIds(ids);
+        bool singleId = (ids.size() == 1);
+        AudioFileId id = *(ids.begin());
+        RG_DEBUG << "updateActionState singleId" << singleId << id;
+        if (singleId) {
+            leaveActionState("have_audio_selected");
+            leaveActionState("have_multi_audio_selected");
+            enterActionState("have_multi_audio_single_id_selected");
         } else {
-            leaveActionState("have_audio_insertable"); //@@@ JAS orig. KXMLGUIClient::StateReverse
+            leaveActionState("have_audio_selected");
+            leaveActionState("have_multi_audio_single_id_selected");
+            leaveActionState("have_audible_preview");
+            leaveActionState("have_audio_insertable");
+            enterActionState("have_multi_audio_selected");
         }
-
     } else {
-        leaveActionState("have_audio_selected"); //@@@ JAS orig. KXMLGUIClient::StateReverse
-        leaveActionState("have_audio_insertable"); //@@@ JAS orig. KXMLGUIClient::StateReverse
-        leaveActionState("have_audible_preview"); //@@@ JAS orig. KXMLGUIClient::StateReverse
+        leaveActionState("have_audio_selected");
+        leaveActionState("have_multi_audio_selected");
+        leaveActionState("have_multi_audio_single_id_selected");
+        leaveActionState("have_audio_insertable");
+        leaveActionState("have_audible_preview");
     }
 }
 
@@ -965,130 +987,58 @@ AudioManagerDialog::slotDeleteUnused()
     delete dialog;
 }
 
-/* unused
-void
-AudioManagerDialog::slotRename()
-{
-    AudioFile *audioFile = getCurrentSelection();
-
-    if (audioFile == nullptr)
-        return ;
-
-    bool ok = false;
-
-    QString newText = InputDialog::getText(this,
-                          tr("Change Audio File label"),
-                          tr("Enter new label"),
-                          LineEdit::Normal,
-                          QString(audioFile->getLabel().c_str()),
-                          &ok);
-
-    if (ok && !newText.isEmpty())
-        audioFile->setLabel(qstrtostr(newText));
-
-    slotPopulateFileList();
-}
-*/
-
-/*
-void AudioManagerDialog::slotItemChanged(QTreeWidgetItem *current, QTreeWidgetItem *previous)
-{
-    //RG_DEBUG << "Warning: AudioManagerDialog::slotItemChanged not implemented";
-    return;
-}
-*/
-
-//void AudioManagerDialog::slotSelectionChanged(QTreeWidgetItem *item)
 void AudioManagerDialog::slotSelectionChanged()
 {
-    AudioListItem *aItem = nullptr;
-    //AudioListItem *aItem = dynamic_cast<AudioListItem*>(item);
-
-    QList<QTreeWidgetItem *> itemsx = m_fileList->selectedItems();
-    if (itemsx.count() > 0){
-        aItem = dynamic_cast<AudioListItem*>(itemsx.at(0));
-    }
-
-    // en/disable Actions
-    //QAction *ea = findAction("export_audio");
-    //if (ea) ea->setEnabled("false");
-
-    // If we're on a segment then send a "select" signal
-    // and enable appropriate buttons.
-    //
-    if (aItem && aItem->getSegment()) {
-
-        //### required to enable it?
-        //if (ea) ea->setEnabled("true");
-
-        SegmentSelection selection;
-        selection.insert(aItem->getSegment());
-        emit segmentsSelected(selection);
-    }
-
-    updateActionState(aItem != nullptr);
-}
-
-void
-AudioManagerDialog::setSelected(AudioFileId id,
-                                const Segment *segment,
-                                bool propagate)
-{
-    // note: this iterates over topLevelItems and childItems too.
-    // I hope that's what we want to do (?)
-    // otherwise re-code to iterate over topLevelItems only.
-    QTreeWidgetItemIterator treeItemIter(m_fileList,
-                                         QTreeWidgetItemIterator::All);
-
-    QTreeWidgetItem *treeItem = *treeItemIter;
-
-    while (treeItem) {
-
-        AudioListItem *audioItem = dynamic_cast<AudioListItem *>(treeItem);
-
-        if (audioItem) {
-            if ((audioItem->getId() == id)  &&
-                (audioItem->getSegment() == segment)) {
-
-                selectFileListItemNoSignal(treeItem);
-
-                // Only propagate to compositionview if asked to
-                if (propagate) {
-                    SegmentSelection selection;
-                    selection.insert(audioItem->getSegment());
-                    emit segmentsSelected(selection);
+    RG_DEBUG << "selectionChanged";
+    SegmentSelection selection;
+    m_fileList->blockSignals(true); // avoid recursive calls
+    QList<QTreeWidgetItem *> items = m_fileList->selectedItems();
+    // check for selection/deselection of top level elements
+    QTreeWidgetItemIterator it(m_fileList);
+    while (*it) {
+        AudioListItem *aItem = dynamic_cast<AudioListItem*>(*it);
+        if (aItem) {
+            if (! aItem->getSegment()) {
+                // Top level item
+                bool selectedNew = items.contains(aItem);
+                bool selectedOld = aItem->getSelected();
+                aItem->setSelected(selectedNew); // maintain memory
+                if (selectedNew) {
+                    // select all children
+                    for (int i = 0; i < (*it)->childCount (); i++) {
+                        QTreeWidgetItem *child = (*it)->child (i);
+                        child->setSelected(true);
+                    }
+                    // and expand
+                    (*it)->setExpanded(true);
+                } else { // no longer selected
+                    if (selectedOld) { // newly deselectd
+                        // deselect all children
+                        for (int i = 0; i < (*it)->childCount (); i++) {
+                            QTreeWidgetItem *child = (*it)->child (i);
+                            child->setSelected(false);
+                        }
+                    }
                 }
-
-                return;
-
             }
-
         }
-
-        ++treeItemIter;
-        treeItem = *treeItemIter;
-
+        ++it;
     }
-
-}
-
-
-void
-AudioManagerDialog::selectFileListItemNoSignal(QTreeWidgetItem* it)
-{
-    m_fileList->blockSignals(true);
-
-    if (it) {
-//        m_fileList->ensureItemVisible(it);
-        m_fileList->scrollToItem(it, QAbstractItemView::PositionAtTop);
-//        m_fileList->setSelected(it, true);
-        m_fileList->setCurrentItem(it);
-        updateActionState(true);
-    } else {
-        m_fileList->clearSelection();
+    // and now setup the selection
+    items = m_fileList->selectedItems();
+    for (QTreeWidgetItem* item : items) {
+        AudioListItem *aItem = dynamic_cast<AudioListItem*>(item);
+        if (aItem) {
+            if (aItem->getSegment()) {
+                // We have a segment
+                selection.insert(aItem->getSegment());
+            } else {
+            }
+        }
     }
-
     m_fileList->blockSignals(false);
+    emit segmentsSelected(selection);
+    updateActionState(m_fileList->selectedItems().size());
 }
 
 void
@@ -1101,28 +1051,46 @@ void
 AudioManagerDialog::slotSegmentSelection(
     const SegmentSelection &segments)
 {
-    const Segment *segment = nullptr;
-
-    for (SegmentSelection::const_iterator it = segments.begin();
-            it != segments.end(); ++it) {
-        if ((*it)->getType() == Segment::Audio) {
-            // Only get one audio segment
-            if (segment == nullptr)
-                segment = *it;
-            else
-                segment = nullptr;
+    // suppress callbacks
+    m_fileList->blockSignals(true);
+    QTreeWidgetItemIterator firstSelected(m_fileList);
+    bool selectionFound = false;
+    QTreeWidgetItemIterator it(m_fileList);
+    while (*it) {
+        const AudioListItem *aItem = dynamic_cast<AudioListItem*>(*it);
+        if (! aItem) {
+            ++it;
+            continue;
         }
-
+        const Segment* segment = aItem->getSegment();
+        if (! segment) {
+            // always deselect top level items if a segment selection changes
+            (*it)->setSelected(false);
+            ++it;
+            continue;
+        }
+        if (std::find(segments.begin(), segments.end(), segment) !=
+            segments.end()) {
+            (*it)->setSelected(true);
+            // make sure the parent is expanded
+            QTreeWidgetItem* parentItem = (*it)->parent();
+            if (parentItem) parentItem->setExpanded(true);
+            if (! selectionFound) {
+                selectionFound = true;
+                firstSelected = it;
+            }
+        } else {
+            (*it)->setSelected(false);
+        }
+        ++it;
     }
-
-    if (segment) {
-        // We don't propagate this segment setting to the canvas
-        // as we probably got called from there.
-        //
-        setSelected(segment->getAudioFileId(), segment, false);
-    } else {
-        selectFileListItemNoSignal(nullptr);
+    if (selectionFound) {
+        // scroll to first selected item
+        m_fileList->
+            scrollToItem(*firstSelected, QAbstractItemView::PositionAtTop);
     }
+    m_fileList->blockSignals(false);
+    updateActionState(m_fileList->selectedItems().size());
 
 }
 
@@ -1224,7 +1192,7 @@ AudioManagerDialog::slotDropped(QDropEvent* /* event */, QTreeWidget*, const QLi
     if( sl.empty() ) return;
 
     // iterate over dropped URIs
-    for( int i=0; i<sl.count(); i++ ) {
+    for (int i=0; i<sl.count(); i++) {
         //RG_DEBUG << "slotDropped() - Adding DroppedFile " << sl.at(i);
         addFile( sl.at(i) );
     }
@@ -1290,15 +1258,15 @@ AudioManagerDialog::addAudioFile(const QString &filePath)
 bool
 AudioManagerDialog::isSelectedTrackAudio()
 {
-    Composition &comp = m_doc->getComposition();
-    Studio &studio = m_doc->getStudio();
+    const Composition &comp = m_doc->getComposition();
+    const Studio &studio = m_doc->getStudio();
 
     TrackId currentTrackId = comp.getSelectedTrack();
-    Track *track = comp.getTrackById(currentTrackId);
+    const Track *track = comp.getTrackById(currentTrackId);
 
     if (track) {
         InstrumentId ii = track->getInstrument();
-        Instrument *instrument = studio.getInstrumentById(ii);
+        const Instrument *instrument = studio.getInstrumentById(ii);
 
         if (instrument &&
                 instrument->getType() == Instrument::Audio)
@@ -1309,48 +1277,6 @@ AudioManagerDialog::isSelectedTrackAudio()
 
 }
 
-void
-AudioManagerDialog::slotDistributeOnMidiSegment()
-{
-    //RG_DEBUG << "slotDistributeOnMidiSegment()";
-
-    //Composition &comp = m_doc->getComposition();
-
-    QList<RosegardenMainViewWidget*> viewList_ = m_doc->getViewList();
-    QListIterator<RosegardenMainViewWidget*> viewList(viewList_);
-
-    RosegardenMainViewWidget *w = nullptr;
-    SegmentSelection selection;
-
-    viewList.toFront();
-    while (viewList.hasNext()){
-        w = viewList.next();
-        selection = w->getSelection();
-    }
-
-    // Store the insert times in a local vector
-    //
-    std::vector<timeT> insertTimes;
-
-    for (SegmentSelection::iterator i = selection.begin();
-            i != selection.end(); ++i) {
-        // For MIDI (Internal) Segments only of course
-        //
-        if ((*i)->getType() == Segment::Internal) {
-            for (Segment::iterator it = (*i)->begin(); it != (*i)->end(); ++it) {
-                if ((*it)->isa(Note::EventType))
-                    insertTimes.push_back((*it)->getAbsoluteTime());
-            }
-        }
-    }
-
-#if 0
-    for (unsigned int i = 0; i < insertTimes.size(); ++i) {
-        RG_DEBUG << "slotDistributeOnMidiSegment(): Insert audio segment at " << insertTimes[i];
-    }
-#endif
-}
-
 void
 AudioManagerDialog::slotHelpRequested()
 {
@@ -1369,4 +1295,66 @@ AudioManagerDialog::slotHelpAbout()
 {
     new AboutDialog(this);
 }
+
+void AudioManagerDialog::getSelectedIds(std::set<AudioFileId>& ids) const
+{
+    QList<QTreeWidgetItem *> items = m_fileList->selectedItems();
+    ids.clear();
+    for (QTreeWidgetItem* item : items) {
+        AudioListItem *aItem = dynamic_cast<AudioListItem*>(item);
+        if (aItem) {
+            AudioFileId itemId = aItem->getId();
+            ids.insert(itemId);
+        }
+    }
+}
+
+void AudioManagerDialog::writeWavFile(const QString& destFileName,
+                                      WAVAudioFile* sourceFile)
+{
+    // Progress Dialog
+    QProgressDialog progressDialog
+        (tr("Exporting audio file..."),  // labelText
+         tr("Cancel"),  // cancelButtonText
+         0, 0,  // min, max
+         this);  // parent
+    progressDialog.setWindowTitle(tr("Rosegarden"));
+    progressDialog.setWindowModality(Qt::WindowModal);
+    // We will close anyway when this object goes out of scope.
+    progressDialog.setAutoClose(false);
+    // No cancel button since appendSamples() doesn't support progress.
+    progressDialog.setCancelButton(nullptr);
+    // Just force the progress dialog up.
+    // Both Qt4 and Qt5 have bugs related to delayed showing of progress
+    // dialogs.  In Qt4, the dialog sometimes won't show.  In Qt5, KDE
+    // based distros might lock up.  See Bug #1546.
+    progressDialog.show();
+
+    RealTime clipStartTime;
+    RealTime clipDuration = sourceFile->getLength();
+
+    WAVAudioFile destFile
+        (destFileName,
+         sourceFile->getChannels(),
+         sourceFile->getSampleRate(),
+         sourceFile->getBytesPerSecond(),
+         sourceFile->getBytesPerFrame(),
+         sourceFile->getBitsPerSample());
+
+    if (sourceFile->open() == false)
+        return;
+
+    sourceFile->scanTo(clipStartTime);
+
+    destFile.write();
+
+    // appendSamples() takes the longest.  Would be nice if it would
+    // take a progress dialog.
+    destFile.appendSamples(sourceFile->getSampleFrameSlice(clipDuration));
+
+    destFile.close();
+    sourceFile->close();
+}
+
+
 }
