@@ -1,4 +1,3 @@
-
 /* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */
 
 /*
@@ -50,9 +49,15 @@ class RosegardenDocument;
 class RealTime;
 class AudioPlayingDialog;
 class AudioFile;
+class WAVAudioFile;
 class Command;
 
 /// Audio File Manager
+/**
+ * ??? This does not use the command history and the user can end up in
+ *     a really bad situation.  Need to implement all of this functionality
+ *     as commands so they can be undone.
+ */
 class AudioManagerDialog : public QMainWindow, public ActionFileClient
 {
     Q_OBJECT
@@ -70,12 +75,6 @@ public:
     //
     AudioFile* getCurrentSelection();
 
-    // Scroll and expand to show this selected item
-    //
-    void setSelected(AudioFileId id,
-                     const Segment *segment,
-                     bool propagate); // if true then we tell the segmentcanvas
-
     // Pop down playing dialog if it's currently up
     //
     void closePlayingDialog(AudioFileId id);
@@ -135,12 +134,6 @@ public slots:
 
     void slotClose();
 
-    /**
-     * Turn a MIDI segment into a set of audio segments triggered
-     * by the MIDI Note Ons
-     */
-    void slotDistributeOnMidiSegment();
-
 signals:
 
     // Control signals so we can tell the sequencer about our changes
@@ -174,8 +167,7 @@ protected slots:
 protected:
     bool addFile(const QUrl& kurl);
     bool isSelectedTrackAudio();
-    void selectFileListItemNoSignal(QTreeWidgetItem*);
-    void updateActionState(bool haveSelection);
+    void updateActionState(int numSelected);
 
     void closeEvent(QCloseEvent *) override;
 
@@ -195,6 +187,14 @@ protected:
 
     bool                     m_audiblePreview;
     int                      m_sampleRate;
+
+private:
+    // get a list of audio file ids which are selected (either
+    // directly or by the selection of a segment).
+    void getSelectedIds(std::set<AudioFileId>& ids) const;
+
+    void writeWavFile(const QString& destFileName, WAVAudioFile* sourceFile);
+
 };
 
 
