@@ -22,6 +22,7 @@
 
 #include "misc/Debug.h"
 #include "misc/Strings.h"
+#include "misc/ConnectCBActivated.h"
 #include "base/AudioPluginInstance.h"
 #include "base/Instrument.h"
 #include "base/MidiProgram.h"
@@ -344,7 +345,7 @@ void
 AudioPluginDialog::populatePluginCategoryList()
 {
     //RG_DEBUG << "populatePluginCategoryList()";
-    AudioPluginInstance *inst = m_pluginContainer->getPlugin(m_index);
+    const AudioPluginInstance *inst = m_pluginContainer->getPlugin(m_index);
     std::set
         <QString> categories;
     QString currentCategory;
@@ -483,7 +484,7 @@ AudioPluginDialog::populatePluginList()
     }
 
     // Check for plugin and setup as required
-    AudioPluginInstance *plugin = m_pluginContainer->getPlugin(m_index);
+    const AudioPluginInstance *plugin = m_pluginContainer->getPlugin(m_index);
     if (plugin)
         m_bypass->setChecked(plugin->isBypassed());
 
@@ -506,6 +507,7 @@ AudioPluginDialog::populatePluginList()
         QString id = i->second.second->getIdentifier();
         QString type, soname, label, arch;
         PluginIdentifier::parseIdentifier(id, type, soname, label, arch);
+        if (arch == "lv2") type = "lv2";
 
         QString tname = type + ":" + name;
 
@@ -709,14 +711,6 @@ AudioPluginDialog::slotPluginSelected(int index)
             m_insOuts->setText(tr("stereo"));
         else
             m_insOuts->setText(tr("%1 in, %2 out").arg(ins).arg(outs));
-
-        QString shortName(audioPlugin->getName());
-        int parenIdx = shortName.indexOf(" (");
-        if (parenIdx > 0) {
-            shortName = shortName.left(parenIdx);
-            if (shortName == "Null")
-                shortName = "Plugin";
-        }
     }
 
     adjustSize();
@@ -738,8 +732,8 @@ AudioPluginDialog::slotPluginSelected(int index)
             m_programCombo->addItem(tr("<none selected>"));
             m_pluginParamsBoxLayout->addWidget(m_programLabel, 0, 0, Qt::AlignRight);
             m_pluginParamsBoxLayout->addWidget(m_programCombo, 0, 1, Qt::AlignLeft);
-            connect(m_programCombo, SIGNAL(activated(const QString &)),
-                    this, SLOT(slotPluginProgramChanged(const QString &)));
+            ConnectCBActivated(m_programCombo,
+                               this, &AudioPluginDialog::slotPluginProgramChanged);
 
             m_programCombo->clear();
             m_programCombo->addItem(tr("<none selected>"));
@@ -798,7 +792,7 @@ AudioPluginDialog::slotPluginSelected(int index)
                 !hidden) {
                 PluginControl *control =
                     new PluginControl(m_pluginParamsBox,
-                                      PluginControl::Rotary,
+                                      PluginControl::ControlType::Rotary,
                                       *it,
                                       m_pluginManager,
                                       count,
@@ -945,7 +939,7 @@ AudioPluginDialog::updatePluginPortControl(int port)
 {
     AudioPluginInstance *inst = m_pluginContainer->getPlugin(m_index);
     if (inst) {
-        PluginPortInstance *pti = inst->getPort(port);
+        const PluginPortInstance *pti = inst->getPort(port);
         if (pti) {
             for (std::vector<PluginControl *>::iterator i = m_pluginWidgets.begin();
                  i != m_pluginWidgets.end(); ++i) {
@@ -967,13 +961,15 @@ AudioPluginDialog::updatePluginProgramControl()
     if (inst) {
         std::string program = inst->getProgram();
         if (m_programCombo) {
+            // ??? This shouldn't be needed.  activated() is only emitted
+            //     on a user change, not a programmatic change.
             m_programCombo->blockSignals(true);
             m_programCombo->setItemText( m_index, strtoqstr(program) );    //@@@ m_index param correct ? (=index-nr)
             m_programCombo->blockSignals(false);
         }
         for (std::vector<PluginControl *>::iterator i = m_pluginWidgets.begin();
              i != m_pluginWidgets.end(); ++i) {
-            PluginPortInstance *pti = inst->getPort((*i)->getIndex());
+            const PluginPortInstance *pti = inst->getPort((*i)->getIndex());
             if (pti) {
                 (*i)->setValue(pti->value, false); // don't emit
             }
@@ -1017,9 +1013,11 @@ AudioPluginDialog::updatePluginProgramList()
             m_programLabel->show();
             m_programCombo->show();
 
+            // ??? This shouldn't be needed.  activated() is only emitted
+            //     on a user change, not a programmatic change.
             m_programCombo->blockSignals(true);
-            connect(m_programCombo, SIGNAL(activated(const QString &)),
-                    this, SLOT(slotPluginProgramChanged(const QString &)));
+            ConnectCBActivated(m_programCombo,
+                               this, &AudioPluginDialog::slotPluginProgramChanged);
 
         } else {
             return ;
@@ -1075,7 +1073,7 @@ AudioPluginDialog::slotCopy()
 
         clipboard->m_pluginNumber = number;
 
-        AudioPluginInstance *inst = m_pluginContainer->getPlugin(m_index);
+        const AudioPluginInstance *inst = m_pluginContainer->getPlugin(m_index);
         if (inst) {
             clipboard->m_configuration = inst->getConfiguration();
         } else {
@@ -1164,12 +1162,12 @@ AudioPluginDialog::slotPaste()
 void
 AudioPluginDialog::slotDefault()
 {
-    AudioPluginInstance *inst = m_pluginContainer->getPlugin(m_index);
+    const AudioPluginInstance *inst = m_pluginContainer->getPlugin(m_index);
     if (!inst)
         return ;
 
-    int i = m_pluginList->currentIndex();
-    int n = m_pluginsInList[i];
+    int index = m_pluginList->currentIndex();
+    int n = m_pluginsInList[index];
     if (n == 0)
         return ;
 
@@ -1177,14 +1175,16 @@ AudioPluginDialog::slotDefault()
     if (!plugin)
         return ;
 
-    for (std::vector<PluginControl *>::iterator i = m_pluginWidgets.begin();
-         i != m_pluginWidgets.end(); ++i) {
+    for (std::vector<PluginControl *>::iterator pluginControlIter =
+                 m_pluginWidgets.begin();
+         pluginControlIter != m_pluginWidgets.end();
+         ++pluginControlIter) {
 
         for (AudioPlugin::PluginPortVector::iterator pi = plugin->begin();
              pi != plugin->end();
              ++pi) {
-            if ((*pi)->getNumber() == (*i)->getIndex()) {
-                (*i)->setValue((*pi)->getDefaultValue(), true); // and emit
+            if ((*pi)->getNumber() == (*pluginControlIter)->getIndex()) {
+                (*pluginControlIter)->setValue((*pi)->getDefaultValue(), true); // and emit
                 break;
             }
         }
