@@ -20,6 +20,7 @@
 */
 
 #define RG_MODULE_STRING "[EventFilterDialog]"
+#define RG_NO_DEBUG_PRINT
 
 #include "EventFilterDialog.h"
 
@@ -59,12 +60,10 @@
 namespace Rosegarden
 {
 
-EventFilterDialog::EventFilterDialog(QWidget* parent)
-        : QDialog(parent),
-        m_standardQuantizations(Quantizer::getQuantizations())
+
+EventFilterDialog::EventFilterDialog(QWidget *parent) :
+    QDialog(parent)
 {
-    //###JAS next line not needed.  Commented out.
-    //###settings = confq4;
     initDialog();
 }
 
@@ -86,6 +85,9 @@ EventFilterDialog::initDialog()
 
     //----------[ Note Filter Widgets ]-------------------------
 
+    // ??? See suggestions for re-ordering these fields on the wiki:
+    //     https://www.rosegardenmusic.com/wiki/doc:guitar_midi_controller_to_notation#future_direction
+
     // Frame
     QGroupBox* noteFrame = new QGroupBox(tr("Note Events"));
     noteFrame->setContentsMargins(20, 20, 20, 20);
@@ -110,7 +112,7 @@ EventFilterDialog::initDialog()
     noteFrameLayout->addWidget(durationLabel, 3, 1);
 
     QSettings settings;
-    settings.beginGroup( EventFilterDialogConfigGroup );
+    settings.beginGroup(EventFilterDialogConfigGroup);
 
     m_useNotationDuration = new QCheckBox(tr("Use notation duration"));
     noteFrameLayout->addWidget(m_useNotationDuration, 4, 2);   // 4, 1
@@ -150,13 +152,15 @@ EventFilterDialog::initDialog()
     noteFrameLayout->addWidget(m_noteDurationIncludeComboBox, 3, 0);
 
     // Pitch From
+    // ??? This is really painful to use.  Instead of a spin box, use a
+    //     combo box.  See NoteWidget::m_pitchComboBox.
     m_pitchFromSpinBox = new QSpinBox(noteFrame);
     m_pitchFromSpinBox->setMaximum(127);
 
     m_pitchFromSpinBox->setValue( settings.value("pitchfrom", 0).toUInt() );
     noteFrameLayout->addWidget(m_pitchFromSpinBox, 1, 2);
-    connect(m_pitchFromSpinBox, SIGNAL(valueChanged(int)),
-            SLOT(slotPitchFromChanged(int)));
+    connect(m_pitchFromSpinBox, (void(QSpinBox::*)(int))&QSpinBox::valueChanged,
+            this, &EventFilterDialog::slotPitchFromChanged);
 
     m_pitchFromChooserButton = new QPushButton(tr("edit"), noteFrame);
     m_pitchFromChooserButton->setSizePolicy(QSizePolicy(QSizePolicy::Fixed,
@@ -168,13 +172,15 @@ EventFilterDialog::initDialog()
             this, &EventFilterDialog::slotPitchFromChooser);
 
     // Pitch To
+    // ??? This is really painful to use.  Instead of a spin box, use a
+    //     combo box.  See NoteWidget::m_pitchComboBox.
     m_pitchToSpinBox = new QSpinBox(noteFrame);
     m_pitchToSpinBox->setMaximum(127);
 
     m_pitchToSpinBox->setValue( settings.value("pitchto", 127).toUInt() );
     noteFrameLayout->addWidget(m_pitchToSpinBox, 1, 4);
-    connect(m_pitchToSpinBox, SIGNAL(valueChanged(int)),
-            SLOT(slotPitchToChanged(int)));
+    connect(m_pitchToSpinBox, (void(QSpinBox::*)(int))&QSpinBox::valueChanged,
+            this, &EventFilterDialog::slotPitchToChanged);
 
     m_pitchToChooserButton = new QPushButton(tr("edit"), noteFrame);
     m_pitchToChooserButton->setToolTip(tr("choose a pitch using a staff"));
@@ -188,37 +194,40 @@ EventFilterDialog::initDialog()
 
     m_velocityFromSpinBox->setValue( settings.value("velocityfrom", 0).toUInt() );
     noteFrameLayout->addWidget(m_velocityFromSpinBox, 2, 2);
-    connect(m_velocityFromSpinBox, SIGNAL(valueChanged(int)),
-            SLOT(slotVelocityFromChanged(int)));
+    connect(m_velocityFromSpinBox, (void(QSpinBox::*)(int))&QSpinBox::valueChanged,
+            this, &EventFilterDialog::slotVelocityFromChanged);
 
     m_velocityToSpinBox = new QSpinBox(noteFrame);
     m_velocityToSpinBox->setMaximum(127);
 
     m_velocityToSpinBox->setValue( settings.value("velocityto", 127).toUInt() );
     noteFrameLayout->addWidget( m_velocityToSpinBox, 2, 4 );
-    connect(m_velocityToSpinBox, SIGNAL(valueChanged(int)),
-            SLOT(slotVelocityToChanged(int)));
+    connect(m_velocityToSpinBox, (void(QSpinBox::*)(int))&QSpinBox::valueChanged,
+            this, &EventFilterDialog::slotVelocityToChanged);
 
 
-    // Duration From/To
+    // Duration From
     m_noteDurationFromComboBox = new QComboBox(noteFrame);
+    populateDurationCombo(m_noteDurationFromComboBox);
     m_noteDurationFromComboBox->setEditable(false);
-    m_noteDurationFromComboBox->addItem(tr("longest"));
+    m_noteDurationFromComboBox->setCurrentIndex(settings.value(
+            "durationfrom", m_noteDurationFromComboBox->count() - 1).toUInt());
     noteFrameLayout->addWidget(m_noteDurationFromComboBox, 3, 2);
     connect(m_noteDurationFromComboBox,
                 static_cast<void(QComboBox::*)(int)>(&QComboBox::activated),
             this, &EventFilterDialog::slotDurationFromChanged);
 
+    // Duration To
     m_noteDurationToComboBox = new QComboBox(noteFrame);
+    populateDurationCombo(m_noteDurationToComboBox);
     m_noteDurationToComboBox->setEditable(false);
-    m_noteDurationToComboBox->addItem(tr("longest"));
+    m_noteDurationToComboBox->setCurrentIndex(settings.value(
+            "durationto", 0).toUInt());
     noteFrameLayout->addWidget(m_noteDurationToComboBox, 3, 4);
     connect(m_noteDurationToComboBox,
                 static_cast<void(QComboBox::*)(int)>(&QComboBox::activated),
             this, &EventFilterDialog::slotDurationToChanged);
 
-    populateDurationCombos();
-
 
     //---------[ Buttons ]--------------------------------------
     QFrame* privateLayoutWidget = new QFrame(mainWidget);
@@ -240,50 +249,42 @@ EventFilterDialog::initDialog()
     connect(m_buttonAll, &QAbstractButton::clicked, this, &EventFilterDialog::slotToggleAll);
     connect(m_buttonNone, &QAbstractButton::clicked, this, &EventFilterDialog::slotToggleNone);
 
-    settings.endGroup();
-
     privateLayoutWidget->setLayout(buttonLayout);
     noteFrame->setLayout(noteFrameLayout);
     mainWidget->setLayout(mainWidgetLayout);
 
-    QDialogButtonBox *buttonBox
-        = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(
+            QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
     metagrid->addWidget(buttonBox, 1, 0);
     metagrid->setRowStretch(0, 10);
-    connect(buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
+    connect(buttonBox, &QDialogButtonBox::accepted,
+            this, &EventFilterDialog::accept);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
 }
 
 void
-EventFilterDialog::populateDurationCombos()
+EventFilterDialog::populateDurationCombo(QComboBox *durationCombo)
 {
+    // We'll do this twice.  Just clear it.
+    m_comboDurations.clear();
+
+    durationCombo->addItem(tr("longest"));
+    m_comboDurations.push_back(LONG_MAX);
+
     QPixmap noMap = NotePixmapFactory::makeToolbarPixmap("menu-no-note");
+    std::vector<timeT> quantizations = Quantizer::getQuantizations();
 
-    for (unsigned int i = 0; i < m_standardQuantizations.size(); ++i) {
-        timeT time = m_standardQuantizations[i];
+    for (unsigned int i = 0; i < quantizations.size(); ++i) {
+        const timeT duration = quantizations[i];
         timeT error = 0;
-        QString label = NotationStrings::makeNoteMenuLabel(time, true, error);
-        QPixmap pmap = NotePixmapFactory::makeNoteMenuPixmap(time, error);
-        m_noteDurationFromComboBox->addItem(error ? noMap : pmap, label);
-        m_noteDurationToComboBox ->addItem(error ? noMap : pmap, label);
+        QString label = NotationStrings::makeNoteMenuLabel(duration, true, error);
+        QPixmap pmap = NotePixmapFactory::makeNoteMenuPixmap(duration, error);
+        durationCombo->addItem(error ? noMap : pmap, label);
+        m_comboDurations.push_back(duration);
     }
-    m_noteDurationFromComboBox->addItem(tr("shortest"));
-    m_noteDurationToComboBox->addItem(tr("shortest"));
 
-    m_noteDurationFromComboBox->setMaxVisibleItems(
-        m_standardQuantizations.size() + 2);
-    m_noteDurationToComboBox->setMaxVisibleItems(
-        m_standardQuantizations.size() + 2);
-
-    QSettings settings;
-    settings.beginGroup( EventFilterDialogConfigGroup );
-
-    m_noteDurationFromComboBox->setCurrentIndex( settings.value("durationfrom",
-        (m_noteDurationToComboBox->count() - 1)).toUInt() );
-    m_noteDurationToComboBox->setCurrentIndex( settings.value("durationto",
-        0).toUInt());
-
-    settings.endGroup();
+    durationCombo->addItem(tr("shortest"));
+    m_comboDurations.push_back(quantizations.back());
 }
 
 void
@@ -294,9 +295,8 @@ EventFilterDialog::resetValuesToAll()
     m_velocityFromSpinBox->setValue(  0);
     m_velocityToSpinBox  ->setValue(127);
 
-    m_noteDurationFromComboBox->setCurrentIndex(    m_noteDurationToComboBox
-                                                  ->count()
-                                                - 1);
+    m_noteDurationFromComboBox->setCurrentIndex(
+            m_noteDurationToComboBox->count() - 1);
     m_noteDurationToComboBox  ->setCurrentIndex(0);
 }
 
@@ -349,6 +349,7 @@ EventFilterDialog::accept()
 void
 EventFilterDialog::slotPitchFromChanged(int pitch)
 {
+    // Adjust "Pitch To" to make sense.
     if (pitch > m_pitchToSpinBox->value())
         m_pitchToSpinBox->setValue(pitch);
 }
@@ -356,6 +357,12 @@ EventFilterDialog::slotPitchFromChanged(int pitch)
 void
 EventFilterDialog::slotPitchToChanged(int pitch)
 {
+    // Adjust "Pitch From" to make sense.
+    // ??? This is problematic.  If the user enters 34 into the "from" field
+    //     then enters 46 in the "to" field, the "from" field becomes 4.
+    // ??? Changing to a ComboBox would eliminate this.
+    //     See NoteWidget::m_pitchComboBox.  Still, we should probably allow
+    //     mixed up values and either warn the user or just swap them.
     if (pitch < m_pitchFromSpinBox->value())
         m_pitchFromSpinBox->setValue(pitch);
 }
@@ -363,6 +370,7 @@ EventFilterDialog::slotPitchToChanged(int pitch)
 void
 EventFilterDialog::slotVelocityFromChanged(int velocity)
 {
+    // Adjust "Velocity To" to make sense.
     if (velocity > m_velocityToSpinBox->value())
         m_velocityToSpinBox->setValue(velocity);
 }
@@ -370,6 +378,12 @@ EventFilterDialog::slotVelocityFromChanged(int velocity)
 void
 EventFilterDialog::slotVelocityToChanged(int velocity)
 {
+    // Adjust "Velocity From" to make sense.
+    // ??? This is problematic.  If the user enters 34 into the "from" field
+    //     then enters 46 in the "to" field, the "from" field becomes 4.
+    // ??? Changing to a ComboBox would eliminate this.
+    //     See NoteWidget::m_pitchComboBox.  Still, we should probably allow
+    //     mixed up values and either warn the user or just swap them.
     if (velocity < m_velocityFromSpinBox->value())
         m_velocityFromSpinBox->setValue(velocity);
 }
@@ -377,6 +391,7 @@ EventFilterDialog::slotVelocityToChanged(int velocity)
 void
 EventFilterDialog::slotDurationFromChanged(int index)
 {
+    // Adjust "Duration To" to make sense.
     if (index < m_noteDurationToComboBox->currentIndex())
         m_noteDurationToComboBox->setCurrentIndex(index);
 }
@@ -384,11 +399,11 @@ EventFilterDialog::slotDurationFromChanged(int index)
 void
 EventFilterDialog::slotDurationToChanged(int index)
 {
+    // Adjust "Duration From" to make sense.
     if (index > m_noteDurationFromComboBox->currentIndex())
         m_noteDurationFromComboBox->setCurrentIndex(index);
 }
 
-
 void
 EventFilterDialog::slotPitchFromChooser()
 {
@@ -412,21 +427,10 @@ EventFilterDialog::slotPitchToChooser()
 long
 EventFilterDialog::getDurationFromIndex(unsigned index)
 {
-    if (index == 0) {
-        // both combo boxes had addItem("longest") at instantiaion,
-        // prior to populateCombos()
+    if (index >= m_comboDurations.size())
         return LONG_MAX;
-    }
-    else if (index >= m_standardQuantizations.size() + 1) {
-        // number of combo box items is m_standardQuantizations.size() + 2
-        // ("longest" added before, "shortest" after) so this one
-        // is "shortest"
-        return m_standardQuantizations[m_standardQuantizations.size() - 1];
-    }
-    else {
-        // because index == 0 is "longest", as per above
-        return m_standardQuantizations[index - 1];
-    }
+
+    return m_comboDurations[index];
 }
 
 void
@@ -471,13 +475,13 @@ EventFilterDialog::getDuration()
 }
 
 bool
-EventFilterDialog::keepEvent(Event* const &e)
+EventFilterDialog::keepEvent(const Event *event)
 {
-    if ((*e).isa(Note::EventType)) {
+    if (event->isa(Note::EventType)) {
         long property = 0;
 
         // pitch
-        (*e).get<Int>(BaseProperties::PITCH, property);
+        event->get<Int>(BaseProperties::PITCH, property);
         if (!eventInRange(getPitch(), property)) {
             RG_DEBUG << "EventFilterDialog::keepEvent(): rejecting event; pitch " << property
                      << " out of range.";
@@ -486,7 +490,7 @@ EventFilterDialog::keepEvent(Event* const &e)
         property = 0;
 
         // velocity
-        (*e).get<Int>(BaseProperties::VELOCITY, property);
+        event->get<Int>(BaseProperties::VELOCITY, property);
         if (!EventFilterDialog::eventInRange(getVelocity(), property)) {
             RG_DEBUG << "EventFilterDialog::keepEvent(): rejecting event; velocity " << property
                      << " out of range.";
@@ -494,19 +498,18 @@ EventFilterDialog::keepEvent(Event* const &e)
         }
 
         // duration
-        property = m_useNotationDuration->isChecked() ? (*e).getNotationDuration() : (*e).getDuration();
+        property = m_useNotationDuration->isChecked() ? event->getNotationDuration() : event->getDuration();
 
         if (!EventFilterDialog::eventInRange(getDuration(), property)) {
             RG_DEBUG << "EventFilterDialog::keepEvent(): rejecting event; duration " << property
                      << " out of range.";
             return false;
         }
-        property = 0;
 
         return true;
-    } else if ((*e).isa(Note::EventRestType)) {
+    } else if (event->isa(Note::EventRestType)) {
         if (m_selectRests->isChecked()) {
-            long property = m_useNotationDuration->isChecked() ? (*e).getNotationDuration() : (*e).getDuration();
+            long property = m_useNotationDuration->isChecked() ? event->getNotationDuration() : event->getDuration();
 
             if (!EventFilterDialog::eventInRange(getDuration(), property)) {
                 RG_DEBUG << "EventFilterDialog::keepEvent(): rejecting rest; duration " << property
@@ -519,4 +522,5 @@ EventFilterDialog::keepEvent(Event* const &e)
     return false;
 }
 
+
 }
