@@ -234,12 +234,14 @@ ImportDeviceDialog::doImport()
 
     settings.endGroup();
 
-    QDialogButtonBox *buttonBox
-        = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(
+            QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
     metagrid->addWidget(buttonBox, 1, 0);
     metagrid->setRowStretch(0, 10);
-    connect(buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
-    connect(buttonBox, &QDialogButtonBox::rejected, this, &ImportDeviceDialog::slotCancel);
+    connect(buttonBox, &QDialogButtonBox::accepted,
+            this, &ImportDeviceDialog::accept);
+    connect(buttonBox, &QDialogButtonBox::rejected,
+            this, &ImportDeviceDialog::slotCancel);
 
     return true;
 }
@@ -360,23 +362,23 @@ ImportDeviceDialog::importFromRG(const QString& fileName)
     for (int i = 0; i < (int)m_devices.size(); ++i) delete m_devices[i];
     m_devices.clear();
 
-    DeviceList *list = fileDoc.getStudio().getDevices();
+    DeviceVector *list = fileDoc.getStudio().getDevices();
     if (list->size() == 0) {
         return true; // true because we successfully read the document
     }
 
-    for (DeviceListIterator it = list->begin(); it != list->end(); ++it) {
+    for (DeviceVector::iterator it = list->begin(); it != list->end(); ++it) {
 
-        MidiDevice *device = dynamic_cast<MidiDevice*>(*it);
+        const MidiDevice *device = dynamic_cast<MidiDevice*>(*it);
 
         if (device) {
-            std::vector<MidiBank> banks = device->getBanks();
+            const std::vector<MidiBank>& banks = device->getBanks();
 
             // DMM - check for controllers too, because some users have
             // created .rgd files that contain only controllers
             // see bug #1183522
             //
-            std::vector<ControlParameter> controllers =
+            const std::vector<ControlParameter>& controllers =
                 device->getControlParameters();
 
             // We've got a bank on a Device fom this file
@@ -402,9 +404,9 @@ ImportDeviceDialog::importFromSF2(const QString& fileName)
 
         // These exceptions shouldn't happen -- the isSF2File call before this
         // one should have weeded them out
-    } catch (SF2PatchExtractor::FileNotFoundException& e) {
+    } catch (const SF2PatchExtractor::FileNotFoundException& e) {
         return false;
-    } catch (SF2PatchExtractor::WrongFileFormatException& e) {
+    } catch (const SF2PatchExtractor::WrongFileFormatException& e) {
         return false;
     }
 
