@@ -19,23 +19,17 @@
 #ifndef RG_INSERTTUPLETDIALOG_H
 #define RG_INSERTTUPLETDIALOG_H
 
-#include "base/NotationTypes.h"
 #include <QDialog>
-#include "base/Event.h"
-
 
 class QWidget;
-class QString;
 class QSpinBox;
 class QGroupBox;
 
 
-
 namespace Rosegarden
 {
 
 
-
 class InsertTupletDialog : public QDialog
 {
     Q_OBJECT
@@ -61,7 +55,6 @@ protected:
 };
 
 
-
 }
 
 #endif
