@@ -21,6 +21,7 @@
 
 #include "misc/Strings.h"
 #include "misc/Debug.h"
+#include "misc/ConnectCBActivated.h"
 #include "base/NotationTypes.h"
 #include "gui/editors/notation/NotePixmapFactory.h"
 #include "gui/widgets/BigArrowButton.h"
@@ -215,8 +216,8 @@ KeySignatureDialog::KeySignatureDialog(QWidget *parent,
     connect(m_keyCombo,
                 static_cast<void(QComboBox::*)(int)>(&QComboBox::activated),
             this, &KeySignatureDialog::slotKeyNameChanged);
-    QObject::connect(m_majorMinorCombo, SIGNAL(activated(const QString &)),
-                     this, SLOT(slotMajorMinorChanged(const QString &)));
+    ConnectCBActivated(m_majorMinorCombo,
+                       this, &KeySignatureDialog::slotMajorMinorChanged);
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::Help);
     metagrid->addWidget(buttonBox, 1, 0);
     metagrid->setRowStretch(0, 10);
@@ -406,8 +407,8 @@ KeySignatureDialog::slotKeyNameChanged(int index)
     if (m_explanatoryLabel)
         m_explanatoryLabel->hide();
 
-    const QString s = m_keyCombo->itemData(index).toString();
-    std::string name(getKeyName(s, m_key.isMinor()));
+    const QString comboBoxString = m_keyCombo->itemData(index).toString();
+    std::string name(getKeyName(comboBoxString, m_key.isMinor()));
 
     try {
         m_key = Rosegarden::Key(name);
@@ -415,11 +416,12 @@ KeySignatureDialog::slotKeyNameChanged(int index)
 
         int space = name.find(' ');
         if (space > 0)
+            // cppcheck-suppress uselessCallsSubstr
             name = name.substr(0, space);
         m_keyCombo->setEditText(strtoqstr(name));
 
-    } catch (const Rosegarden::Key::BadKeyName &s) {
-        RG_WARNING << s.getMessage();
+    } catch (const Rosegarden::Key::BadKeyName &exception) {
+        RG_WARNING << exception.getMessage();
         setValid(false);
     }
 
@@ -427,19 +429,19 @@ KeySignatureDialog::slotKeyNameChanged(int index)
 }
 
 void
-KeySignatureDialog::slotMajorMinorChanged(const QString &s)
+KeySignatureDialog::slotMajorMinorChanged(const QString &quality)
 {
     if (m_ignoreComboChanges)
         return ;
 
     QString text = m_keyCombo->itemData(m_keyCombo->currentIndex()).toString();
-    std::string name(getKeyName(text, s == tr("Minor")));
+    std::string name(getKeyName(text, quality == tr("Minor")));
 
     try {
         m_key = Rosegarden::Key(name);
         setValid(true);
-    } catch (const Rosegarden::Key::BadKeyName &s) {
-        RG_WARNING << s.getMessage();
+    } catch (const Rosegarden::Key::BadKeyName &exception) {
+        RG_WARNING << exception.getMessage();
         setValid(false);
     }
 
