@@ -4,10 +4,10 @@
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
     Copyright 2000-2025 the Rosegarden development team.
- 
+
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
- 
+
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
     published by the Free Software Foundation; either version 2 of the
@@ -36,7 +36,7 @@ namespace Rosegarden
 {
 
 MakeOrnamentDialog::MakeOrnamentDialog(QWidget *parent,
-                                       QString defaultName,
+                                       const QString& defaultName,
                                        int defaultBasePitch) :
         QDialog(parent)
 {
@@ -56,7 +56,7 @@ MakeOrnamentDialog::MakeOrnamentDialog(QWidget *parent,
     QLabel *lbl =  new QLabel(tr("<qt>The name is used to identify both the ornament "
                                  "and the triggered segment that stores "
                                  "the ornament's notes.</qt>"), nameBox);
-    lbl->setWordWrap(true);                                 
+    lbl->setWordWrap(true);
     nameBoxLayout->addWidget(lbl);
 
     QWidget *hbox = new QWidget;
@@ -64,6 +64,7 @@ MakeOrnamentDialog::MakeOrnamentDialog(QWidget *parent,
     nameBoxLayout->addWidget(hbox);
     nameBox->setLayout(nameBoxLayout);
 
+    // cppcheck-suppress constVariablePointer
     QLabel *child_3 = new QLabel(tr("Name:  "));
     hboxLayout->addWidget(child_3);
 
