@@ -4,10 +4,10 @@
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
     Copyright 2000-2025 the Rosegarden development team.
- 
+
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
- 
+
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
     published by the Free Software Foundation; either version 2 of the
@@ -16,6 +16,7 @@
 */
 
 #define RG_MODULE_STRING "[ManageMetronomeDialog]"
+#define RG_NO_DEBUG_PRINT
 
 #include "ManageMetronomeDialog.h"
 #include "misc/Debug.h"
@@ -52,16 +53,16 @@
 #include <QPushButton>
 
 
-
 namespace Rosegarden
 {
 
+
 ManageMetronomeDialog::ManageMetronomeDialog(QWidget *parent,
-        RosegardenDocument *doc) :
-        QDialog(parent),
-        m_doc(doc),
-        m_buttonBox(new QDialogButtonBox(QDialogButtonBox::Ok | 
-                                         QDialogButtonBox::Close))
+                                             RosegardenDocument *doc) :
+    QDialog(parent),
+    m_doc(doc),
+    m_buttonBox(new QDialogButtonBox(QDialogButtonBox::Ok |
+                                     QDialogButtonBox::Close))
 {
     setModal(true);
     setWindowTitle(tr("Metronome"));
@@ -89,8 +90,8 @@ ManageMetronomeDialog::ManageMetronomeDialog(QWidget *parent,
     m_metronomeDevice->setToolTip(tr("<qt>Choose the device you want to use to play the metronome</qt>"));
     deviceBoxLayout->addWidget(m_metronomeDevice, 0, 1);
 
-    DeviceList *devices = doc->getStudio().getDevices();
-    DeviceListConstIterator it;
+    DeviceVector *devices = doc->getStudio().getDevices();
+    DeviceVector::const_iterator it;
 
     Studio &studio = m_doc->getStudio();
     DeviceId deviceId = studio.getMetronomeDevice();
@@ -149,7 +150,8 @@ ManageMetronomeDialog::ManageMetronomeDialog(QWidget *parent,
     m_metronomeBarVely->setToolTip(tr("<qt>Controls how forcefully the bar division notes will be struck.  (These are typically the loudest of all.)</qt>"));
     m_metronomeBarVely->setMinimum(0);
     m_metronomeBarVely->setMaximum(127);
-    connect(m_metronomeBarVely, SIGNAL(valueChanged(int)), this, SLOT(slotSetModified()));
+    connect(m_metronomeBarVely, (void(QSpinBox::*)(int))&QSpinBox::valueChanged,
+            this, &ManageMetronomeDialog::slotSetModified);
     beatBoxLayout->addWidget(m_metronomeBarVely, 1, 1);
 
     beatBoxLayout->addWidget(new QLabel(tr("Beat velocity"), beatBox), 2, 0);
@@ -157,7 +159,8 @@ ManageMetronomeDialog::ManageMetronomeDialog(QWidget *parent,
     m_metronomeBeatVely->setToolTip(tr("<qt>Controls how forcefully the beat division notes will be struck.  (These are typically more quiet than beat division notes.)</qt>"));
     m_metronomeBeatVely->setMinimum(0);
     m_metronomeBeatVely->setMaximum(127);
-    connect(m_metronomeBeatVely, SIGNAL(valueChanged(int)), this, SLOT(slotSetModified()));
+    connect(m_metronomeBeatVely, (void(QSpinBox::*)(int))&QSpinBox::valueChanged,
+            this, &ManageMetronomeDialog::slotSetModified);
     beatBoxLayout->addWidget(m_metronomeBeatVely, 2, 1);
 
     beatBoxLayout->addWidget(new QLabel(tr("Sub-beat velocity"), beatBox), 3, 0);
@@ -165,7 +168,8 @@ ManageMetronomeDialog::ManageMetronomeDialog(QWidget *parent,
     m_metronomeSubBeatVely->setToolTip(tr("<qt>Controls how forcefully the sub-beat division notes will be struck.  (These are typically the most quiet of all, and are not heard unless you are working in compound time.)</qt>"));
     m_metronomeSubBeatVely->setMinimum(0);
     m_metronomeSubBeatVely->setMaximum(127);
-    connect(m_metronomeSubBeatVely, SIGNAL(valueChanged(int)), this, SLOT(slotSetModified()));
+    connect(m_metronomeSubBeatVely, (void(QSpinBox::*)(int))&QSpinBox::valueChanged,
+            this, &ManageMetronomeDialog::slotSetModified);
     beatBoxLayout->addWidget(m_metronomeSubBeatVely, 3, 1);
     beatBox->setLayout(beatBoxLayout);
 
@@ -180,8 +184,10 @@ ManageMetronomeDialog::ManageMetronomeDialog(QWidget *parent,
     m_metronomePitch = new PitchChooser(tr("Pitch"), vbox , 60);
     m_metronomePitch->setToolTip(tr("<qt>It is typical to use a percussion instrument for the metronome, so the pitch normally controls which sort of drum will sound for each tick.  You may configure a different pitch for each of the bar, beat, and sub-beat ticks.</qt>"));
     vboxLayout->addWidget(m_metronomePitch);
-    connect(m_metronomePitch, &PitchChooser::pitchChanged, this, &ManageMetronomeDialog::slotPitchChanged);
-    connect(m_metronomePitch, &PitchChooser::preview, this, &ManageMetronomeDialog::slotPreviewPitch);
+    connect(m_metronomePitch, &PitchChooser::pitchChanged,
+            this, &ManageMetronomeDialog::slotPitchChanged);
+    connect(m_metronomePitch, &PitchChooser::preview,
+            this, &ManageMetronomeDialog::slotPreviewPitch);
 
     m_metronomePitchSelector = new QComboBox();
     m_metronomePitchSelector->addItem(tr("for Bar"));
@@ -199,8 +205,10 @@ ManageMetronomeDialog::ManageMetronomeDialog(QWidget *parent,
     enableBoxLayout->addWidget(m_playEnabled);
     m_recordEnabled = new QCheckBox(tr("Recording"), enableBox);
     enableBoxLayout->addWidget(m_recordEnabled);
-    connect(m_playEnabled, &QAbstractButton::clicked, this, &ManageMetronomeDialog::slotSetModified);
-    connect(m_recordEnabled, &QAbstractButton::clicked, this, &ManageMetronomeDialog::slotSetModified);
+    connect(m_playEnabled, &QAbstractButton::clicked,
+            this, &ManageMetronomeDialog::slotSetModified);
+    connect(m_recordEnabled, &QAbstractButton::clicked,
+            this, &ManageMetronomeDialog::slotSetModified);
     enableBox->setLayout(enableBoxLayout);
 
     vbox->setLayout(vboxLayout);
@@ -219,7 +227,9 @@ ManageMetronomeDialog::ManageMetronomeDialog(QWidget *parent,
 
     metagrid->addWidget(m_buttonBox, 1, 0);
     metagrid->setRowStretch(0, 10);
-    connect(m_buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
+
+    connect(m_buttonBox, &QDialogButtonBox::accepted,
+            this, &ManageMetronomeDialog::accept);
     connect(m_buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
 
     setModified(false);
@@ -238,9 +248,9 @@ ManageMetronomeDialog::populate(int deviceIndex)
 {
     m_metronomeInstrument->clear();
 
-    DeviceList *devices = m_doc->getStudio().getDevices();
-    DeviceListConstIterator it;
-    int count = 0;
+    DeviceVector *devices = m_doc->getStudio().getDevices();
+    DeviceVector::const_iterator it;
+    int deviceCount = 0;
     Device *dev = nullptr;
 
     for (it = devices->begin(); it != devices->end(); it++) {
@@ -248,18 +258,18 @@ ManageMetronomeDialog::populate(int deviceIndex)
         dev = *it;
         if (!isSuitable(dev)) continue;
 
-        if (count == deviceIndex) break;
-        count++;
+        if (deviceCount == deviceIndex) break;
+        deviceCount++;
     }
 
     // sanity
-    if (count < 0 || dev == nullptr || !isSuitable(dev)) {
+    if (deviceCount < 0 || dev == nullptr || !isSuitable(dev)) {
         return ;
     }
 
     // populate instrument list
-    InstrumentList list = dev->getPresentationInstruments();
-    InstrumentList::iterator iit;
+    InstrumentVector instruments = dev->getPresentationInstruments();
+    InstrumentVector::iterator iit;
 
     const MidiMetronome *metronome = getMetronome(dev);
 
@@ -267,7 +277,7 @@ ManageMetronomeDialog::populate(int deviceIndex)
     if (metronome == nullptr) {
         InstrumentId id = SystemInstrumentBase;
 
-        for (iit = list.begin(); iit != list.end(); ++iit) {
+        for (iit = instruments.begin(); iit != instruments.end(); ++iit) {
             if ((*iit)->isPercussion()) {
                 id = (*iit)->getId();
                 break;
@@ -282,9 +292,9 @@ ManageMetronomeDialog::populate(int deviceIndex)
     // metronome should now be set but we still check it
     if (metronome) {
         int position = 0;
-        int count = 0;
+        int instrumentCount = 0;
 
-        for (iit = list.begin(); iit != list.end(); ++iit) {
+        for (iit = instruments.begin(); iit != instruments.end(); ++iit) {
 
             QString iname(QObject::tr((*iit)->getName().c_str()));
             QString ipname((*iit)->getLocalizedPresentationName());
@@ -300,7 +310,7 @@ ManageMetronomeDialog::populate(int deviceIndex)
                                                           "Synth plugin "), "");
                 programName = "";
 
-                AudioPluginInstance *plugin = (*iit)->getPlugin
+                const AudioPluginInstance *plugin = (*iit)->getPlugin
                     (Instrument::SYNTH_PLUGIN_POSITION);
                 if (plugin)
                     programName = strtoqstr(plugin->getDisplayName());
@@ -319,9 +329,9 @@ ManageMetronomeDialog::populate(int deviceIndex)
             m_metronomeInstrument->addItem(text);
 
             if ((*iit)->getId() == metronome->getInstrument()) {
-                position = count;
+                position = instrumentCount;
             }
-            count++;
+            instrumentCount++;
         }
         m_metronomeInstrument->setCurrentIndex(position);
 
@@ -366,8 +376,8 @@ ManageMetronomeDialog::slotApply()
 {
     Studio &studio = m_doc->getStudio();
 
-    DeviceList *devices = m_doc->getStudio().getDevices();
-    DeviceListConstIterator it;
+    DeviceVector *devices = m_doc->getStudio().getDevices();
+    DeviceVector::const_iterator it;
     int count = 0;
     Device *dev = nullptr;
 
@@ -395,9 +405,9 @@ ManageMetronomeDialog::slotApply()
     MidiMetronome metronome(*getMetronome(dev));
 
     // get instrument
-    InstrumentList list = dev->getPresentationInstruments();
+    InstrumentVector list = dev->getPresentationInstruments();
 
-    Instrument *inst =
+    const Instrument *inst =
         list[m_metronomeInstrument->currentIndex()];
 
     if (inst) {
@@ -425,7 +435,9 @@ ManageMetronomeDialog::slotApply()
     m_doc->getComposition().setPlayMetronome(m_playEnabled->isChecked());
     m_doc->getComposition().setRecordMetronome(m_recordEnabled->isChecked());
 
-    m_doc->getSequenceManager()->metronomeChanged(inst->getId(), true);
+    if (inst) {
+        m_doc->getSequenceManager()->metronomeChanged(inst->getId(), true);
+    }
     m_doc->slotDocumentModified();
     setModified(false);
 }
@@ -435,8 +447,8 @@ ManageMetronomeDialog::slotPreviewPitch(int pitch)
 {
     RG_DEBUG << "ManageMetronomeDialog::slotPreviewPitch";
 
-    DeviceList *devices = m_doc->getStudio().getDevices();
-    DeviceListConstIterator it;
+    DeviceVector *devices = m_doc->getStudio().getDevices();
+    DeviceVector::const_iterator it;
     int count = 0;
     Device *dev = nullptr;
 
@@ -454,7 +466,7 @@ ManageMetronomeDialog::slotPreviewPitch(int pitch)
     const MidiMetronome *metronome = getMetronome(dev);
     if (metronome == nullptr) return;
 
-    InstrumentList list = dev->getPresentationInstruments();
+    InstrumentVector list = dev->getPresentationInstruments();
 
     Instrument *inst =
         list[m_metronomeInstrument->currentIndex()];
