@@ -1,10 +1,9 @@
-
 /* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */
 
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -21,7 +20,6 @@
 
 #include <QDialog>
 
-
 class QWidget;
 
 
@@ -29,14 +27,16 @@ namespace Rosegarden
 {
 
 
-
+/// Simple dialog to display the audit log.
 class ShowSequencerStatusDialog : public QDialog
 {
     Q_OBJECT
 public:
     explicit ShowSequencerStatusDialog(QWidget *parent);
-};
+    ~ShowSequencerStatusDialog();
 
+    QSize sizeHint() const override  { return QSize(700, 700); }
+};
 
 
 }
