@@ -19,20 +19,20 @@
 #define RG_NO_DEBUG_PRINT
 
 #include "TempoDialog.h"
+
 #include "misc/Debug.h"
 #include "base/Composition.h"
 #include "base/NotationTypes.h"
 #include "base/RealTime.h"
 #include "document/RosegardenDocument.h"
 #include "gui/editors/notation/NotePixmapFactory.h"
-#include "gui/widgets/TimeWidget.h"
+#include "gui/widgets/TimeWidget2.h"
 
 #include <QDialog>
 #include <QDialogButtonBox>
 #include <QGroupBox>
 #include <QDoubleSpinBox>
 #include <QCheckBox>
-#include <QFrame>
 #include <QLabel>
 #include <QRadioButton>
 #include <QPushButton>
@@ -40,15 +40,14 @@
 #include <QWidget>
 #include <QVBoxLayout>
 #include <QHBoxLayout>
-#include <QLayout>
 #include <QUrl>
 #include <QDesktopServices>
 
 
-
 namespace Rosegarden
 {
 
+
 TempoDialog::TempoDialog(QWidget *parent, RosegardenDocument *doc,
                          bool timeEditable):
     QDialog(parent),
@@ -76,8 +75,9 @@ TempoDialog::TempoDialog(QWidget *parent, RosegardenDocument *doc,
     m_tempoValueSpinBox->setMinimum(1);
     m_tempoValueSpinBox->setSingleStep(1);
     m_tempoValueSpinBox->setValue(120); // will set properly below
-    connect(m_tempoValueSpinBox, SIGNAL(valueChanged(double)),
-            SLOT(slotTempoChanged(double)));
+    connect(m_tempoValueSpinBox, (void(QDoubleSpinBox::*)(double))
+                    &QDoubleSpinBox::valueChanged,
+            this, &TempoDialog::slotTempoChanged);
     tempoLayout->addWidget(m_tempoValueSpinBox, 0, 2);
 
     // Tap
@@ -123,20 +123,22 @@ TempoDialog::TempoDialog(QWidget *parent, RosegardenDocument *doc,
     m_tempoTargetSpinBox->setMinimum(1);
     m_tempoTargetSpinBox->setSingleStep(1);
     m_tempoTargetSpinBox->setValue(120);
-    connect(m_tempoTargetSpinBox, SIGNAL(valueChanged(double)),
-            SLOT(slotTargetChanged(double)));
+    // ??? slotTargetChanged() is empty.
+    //connect(m_tempoTargetSpinBox, (void(QDoubleSpinBox::*)(double))
+    //             &QDoubleSpinBox::valueChanged,
+    //        this, &TempoDialog::slotTargetChanged);
     tempoLayout->addWidget(m_tempoTargetSpinBox, 3, 2);
 
     if (timeEditable) {
 
-        m_timeEditor = new TimeWidget(
+        m_timeWidget = new TimeWidget2(
                 tr("Time of tempo change"),  // title
                 this,  // parent
-                &m_doc->getComposition(),  // composition
                 0,  // initialTime
-                true);  // editable
-
-        vboxLayout->addWidget(m_timeEditor);
+                true);  // constrainToCompositionDuration
+        connect(m_timeWidget, &TimeWidget2::signalIsValid,
+                this, &TempoDialog::slotIsValid);
+        vboxLayout->addWidget(m_timeWidget);
 
     } else {
 
@@ -151,8 +153,8 @@ TempoDialog::TempoDialog(QWidget *parent, RosegardenDocument *doc,
         QVBoxLayout * currentBoxLayout = scopeBoxLayout;
         QWidget * currentBox = scopeGroup;
 
-        QLabel *child_15 = new QLabel(tr("The pointer is currently at "), currentBox);
-        currentBoxLayout->addWidget(child_15);
+        currentBoxLayout->addWidget(new QLabel(
+                tr("The pointer is currently at "), currentBox));
         m_tempoTimeLabel = new QLabel(currentBox);
         currentBoxLayout->addWidget(m_tempoTimeLabel);
         m_tempoBarLabel = new QLabel(currentBox);
@@ -201,8 +203,7 @@ TempoDialog::TempoDialog(QWidget *parent, RosegardenDocument *doc,
         changeWhereVBoxLayout->addWidget(optionHBox);
         changeWhereVBox->setLayout(changeWhereVBoxLayout);
         QHBoxLayout *optionHBoxLayout = new QHBoxLayout;
-        QLabel *child_6 = new QLabel("         ", optionHBox);
-        optionHBoxLayout->addWidget(child_6);
+        optionHBoxLayout->addWidget(new QLabel("         ", optionHBox));
         m_defaultBox = new QCheckBox(
                 tr("Also make this the default tempo"), optionHBox);
         optionHBoxLayout->addWidget(m_defaultBox);
@@ -226,22 +227,18 @@ TempoDialog::TempoDialog(QWidget *parent, RosegardenDocument *doc,
         m_defaultBox->setEnabled(false);
     }
 
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(
+    m_buttonBox = new QDialogButtonBox(
             QDialogButtonBox::Ok | QDialogButtonBox::Cancel |
             QDialogButtonBox::Help);
-    vboxLayout->addWidget(buttonBox);
-
-    connect(buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
-    connect(buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
-    connect(buttonBox, &QDialogButtonBox::helpRequested,
+    connect(m_buttonBox, &QDialogButtonBox::accepted, this, &TempoDialog::accept);
+    connect(m_buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
+    connect(m_buttonBox, &QDialogButtonBox::helpRequested,
             this, &TempoDialog::slotHelpRequested);
+    vboxLayout->addWidget(m_buttonBox);
 
     populateTempo();
 }
 
-TempoDialog::~TempoDialog()
-{}
-
 void
 TempoDialog::setTempoPosition(timeT time)
 {
@@ -292,8 +289,8 @@ TempoDialog::populateTempo()
 
     updateBeatLabels(comp.getTempoQpm(tempo));
 
-    if (m_timeEditor) {
-        m_timeEditor->slotSetTime(m_tempoTime);
+    if (m_timeWidget) {
+        m_timeWidget->setTime(m_tempoTime);
         return ;
     }
 
@@ -400,11 +397,12 @@ TempoDialog::slotTempoChanged(double val)
     updateBeatLabels(val);
 }
 
+#if 0
 void
 TempoDialog::slotTargetChanged(double)
 {
-    //...
 }
+#endif
 
 void
 TempoDialog::slotTempoConstantClicked()
@@ -452,9 +450,9 @@ TempoDialog::accept()
 
     RG_DEBUG << "Target is " << m_targetTempo;
 
-    if (m_timeEditor) {
+    if (m_timeWidget) {
 
-        m_tempoTime = m_timeEditor->getTime();
+        m_tempoTime = m_timeWidget->getTime();
 
         emit changeTempo(m_tempoTime,
                          m_tempo,
@@ -514,7 +512,12 @@ TempoDialog::slotTapClicked()
     m_tapMinusOne = now;
 }
 
-
+void
+TempoDialog::slotIsValid(bool valid)
+{
+    QPushButton *okButton = m_buttonBox->button(QDialogButtonBox::Ok);
+    okButton->setEnabled(valid);
+}
 
 void
 TempoDialog::slotHelpRequested()
@@ -527,4 +530,6 @@ TempoDialog::slotHelpRequested()
     QString helpURL = tr("http://rosegardenmusic.com/wiki/doc:tempoDialog-en");
     QDesktopServices::openUrl(QUrl(helpURL));
 }
+
+
 }
