@@ -16,11 +16,14 @@
 */
 
 #define RG_MODULE_STRING "[TextEventDialog]"
+#define RG_NO_DEBUG_PRINT
 
 #include "TextEventDialog.h"
+
 #include "misc/Strings.h"
 #include "misc/Debug.h"
 #include "misc/ConfigGroups.h"
+#include "misc/ConnectCBActivated.h"
 #include "base/NotationTypes.h"
 #include "gui/editors/notation/NotePixmapFactory.h"
 #include "gui/widgets/LineEdit.h"
@@ -41,7 +44,7 @@
 #include <QStackedWidget>
 #include <QVBoxLayout>
 #include <QSpinBox>
-#include <QApplication>
+//#include <QApplication>
 #include <QUrl>
 #include <QDesktopServices>
 
@@ -49,6 +52,7 @@
 namespace Rosegarden
 {
 
+
 TextEventDialog::TextEventDialog(QWidget *parent,
                                  NotePixmapFactory *npf,
                                  const Text& defaultText,
@@ -63,12 +67,12 @@ TextEventDialog::TextEventDialog(QWidget *parent,
     setSizePolicy(QSizePolicy(QSizePolicy::Maximum, QSizePolicy::Maximum));
 
     QVBoxLayout *vboxLayout = new QVBoxLayout;
-    QWidget *vbox = dynamic_cast<QWidget*>( this );
-    vbox->setLayout( vboxLayout );
+    QWidget *vbox = dynamic_cast<QWidget*>(this);
+    vbox->setLayout(vboxLayout);
 
-    QGroupBox *entryBox = new QGroupBox( tr("Specification"), vbox );
+    QGroupBox *entryBox = new QGroupBox(tr("Specification"), vbox);
     vboxLayout->addWidget(entryBox);
-    QGroupBox *exampleBox = new QGroupBox( tr("Preview"), vbox );
+    QGroupBox *exampleBox = new QGroupBox(tr("Preview"), vbox);
     QVBoxLayout *exampleBoxLayout = new QVBoxLayout;
     exampleBox->setLayout(exampleBoxLayout);
 
@@ -357,25 +361,28 @@ TextEventDialog::TextEventDialog(QWidget *parent,
     m_prevLyric = settings.value("previous_lyric", "").toString();
     m_prevAnnotation = settings.value("previous_annotation", "").toString();
 
-    QObject::connect(m_text, &QLineEdit::textChanged,
-                     this, &TextEventDialog::slotTextChanged);
-    QObject::connect(m_typeCombo, SIGNAL(activated(const QString &)),
-                     this, SLOT(slotTypeChanged(const QString &)));
-    QObject::connect(m_dynamicShortcutCombo, SIGNAL(activated(const QString &)),
-                     this, SLOT(slotDynamicShortcutChanged(const QString &)));
-    QObject::connect(m_directionShortcutCombo, SIGNAL(activated(const QString &)),
-                     this, SLOT(slotDirectionShortcutChanged(const QString &)));
-    QObject::connect(m_localDirectionShortcutCombo, SIGNAL(activated(const QString &)),
-                     this, SLOT(slotLocalDirectionShortcutChanged(const QString &)));
-    QObject::connect(m_tempoShortcutCombo, SIGNAL(activated(const QString &)),
-                     this, SLOT(slotTempoShortcutChanged(const QString &)));
-    QObject::connect(m_localTempoShortcutCombo, SIGNAL(activated(const QString &)),
-                     this, SLOT(slotLocalTempoShortcutChanged(const QString &)));
-    QObject::connect(m_lilyPondDirectiveCombo, SIGNAL(activated(const QString &)),
-                     this, SLOT(slotLilyPondDirectiveChanged(const QString &)));
+    connect(m_text, &QLineEdit::textChanged,
+            this, &TextEventDialog::slotTextChanged);
 
-    QObject::connect(m_optionLabel, &QStackedWidget::currentChanged, this, &TextEventDialog::slotUpdateSize);
-    QObject::connect(m_optionWidget, &QStackedWidget::currentChanged, this, &TextEventDialog::slotUpdateSize);
+    ConnectCBActivated(m_typeCombo,
+                       this, &TextEventDialog::slotTypeChanged);
+    ConnectCBActivated(m_dynamicShortcutCombo,
+                       this, &TextEventDialog::slotDynamicShortcutChanged);
+    ConnectCBActivated(m_directionShortcutCombo,
+                       this, &TextEventDialog::slotDirectionShortcutChanged);
+    ConnectCBActivated(m_localDirectionShortcutCombo,
+                       this, &TextEventDialog::slotLocalDirectionShortcutChanged);
+    ConnectCBActivated(m_tempoShortcutCombo,
+                       this, &TextEventDialog::slotTempoShortcutChanged);
+    ConnectCBActivated(m_localTempoShortcutCombo,
+                       this, &TextEventDialog::slotLocalTempoShortcutChanged);
+    ConnectCBActivated(m_lilyPondDirectiveCombo,
+                       this, &TextEventDialog::slotLilyPondDirectiveChanged);
+
+    connect(m_optionLabel, &QStackedWidget::currentChanged,
+            this, &TextEventDialog::slotUpdateSize);
+    connect(m_optionWidget, &QStackedWidget::currentChanged,
+            this, &TextEventDialog::slotUpdateSize);
 
     m_text->setFocus();
     slotTypeChanged(strtoqstr(getTextType()));
