@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -16,12 +16,14 @@
 */
 
 #define RG_MODULE_STRING "[TransportDialog]"
+#define RG_NO_DEBUG_PRINT
 
 #include "TransportDialog.h"
 
 #include "base/Composition.h"
 #include "base/Configuration.h"  // DocumentConfiguration
 #include "base/NotationTypes.h"
+#include "base/Pitch.h"
 #include "base/RealTime.h"
 #include "misc/Debug.h"
 #include "misc/Strings.h"
@@ -29,8 +31,7 @@
 #include "sequencer/RosegardenSequencer.h"
 #include "sound/SequencerDataBlock.h"
 #include "gui/application/TransportStatus.h"
-#include "gui/application/RosegardenApplication.h"
-#include "gui/general/MidiPitchLabel.h"
+#include "gui/general/EditTempoController.h"
 #include "gui/general/IconLoader.h"
 #include "gui/studio/StudioControl.h"
 #include "gui/widgets/Label.h"
@@ -305,7 +306,6 @@ TransportDialog::TransportDialog(QWidget *parent):
                       m_enableMIDILabels ? 1 : 0);
 
     settings.endGroup();
-
 }
 
 TransportDialog::~TransportDialog()
@@ -314,15 +314,25 @@ TransportDialog::~TransportDialog()
     // saved if we are hidden.
     if (isVisible())
         saveGeo();
+
+    RosegardenDocument *doc = RosegardenDocument::currentDocument;
+    if (!doc)
+        return;
+    Composition &comp = doc->getComposition();
+    comp.removeObserver(this);
 }
 
 void TransportDialog::init()
 {
+    RG_DEBUG << "init";
     RosegardenDocument *doc = RosegardenDocument::currentDocument;
     if (!doc)
         return;
 
     Composition &comp = doc->getComposition();
+    RG_DEBUG << "add observer";
+    comp.addObserver(this);
+    RG_DEBUG << "observer added";
 
     setEnabled(true);
 
@@ -871,10 +881,9 @@ TransportDialog::slotMidiInLabel(const MappedEvent *mE)
         if (mE->getVelocity() == 0)
             return ;
 
-        MidiPitchLabel mPL(mE->getPitch());
-        ui->InDisplay->setText
-            (mPL.getQString() +
-             QString("  %1").arg(mE->getVelocity()));
+        ui->InDisplay->setText(
+                Pitch::toStringOctave(mE->getPitch()) +
+                QString("  %1").arg(mE->getVelocity()));
     }
     break;
 
@@ -968,10 +977,9 @@ TransportDialog::slotMidiOutLabel(const MappedEvent *mE)
     case MappedEvent::MidiNote:
     case MappedEvent::MidiNoteOneShot:
     {
-        MidiPitchLabel mPL(mE->getPitch());
-        ui->OutDisplay->setText
-            (mPL.getQString() +
-             QString("  %1").arg(mE->getVelocity()));
+        ui->OutDisplay->setText(
+                Pitch::toStringOctave(mE->getPitch()) +
+                QString("  %1").arg(mE->getVelocity()));
     }
     break;
 
@@ -1050,7 +1058,7 @@ TransportDialog::slotClearMidiOutLabel()
 }
 
 void
-TransportDialog::closeEvent(QCloseEvent * /*e*/)
+TransportDialog::closeEvent(QCloseEvent * /*closeEvent*/)
 {
     emit closed();
 
@@ -1221,7 +1229,13 @@ TransportDialog::isExpanded()
 void
 TransportDialog::slotEditTempo()
 {
-    emit editTempo(this);
+    const timeT atTime =
+            RosegardenDocument::currentDocument->getComposition().getPosition();
+
+    EditTempoController::self()->editTempo(
+            this,  // parent
+            atTime,  // atTime
+            false);  // timeEditable
 }
 
 void
@@ -1365,5 +1379,47 @@ void TransportDialog::updateMetronomeTimer()
     // for us and stop the timer.
 }
 
+void TransportDialog::keyPressEvent(QKeyEvent *keyEvent)
+{
+    if (!keyEvent)
+        return;
+
+    RosegardenMainWindow *rmw = RosegardenMainWindow::self();
+    if (!rmw) {
+        QDialog::keyPressEvent(keyEvent);
+        return;
+    }
+
+    const int key = keyEvent->key();
+
+    if (key == Qt::Key_PageUp)
+        rmw->slotRewind();
+    else if (key == Qt::Key_PageDown)
+        rmw->slotFastforward();
+    else if (key == Qt::Key_Home)
+        rmw->slotRewindToBeginning();
+    else if (key == Qt::Key_End)
+        rmw->slotFastForwardToEnd();
+
+    QDialog::keyPressEvent(keyEvent);
+}
+
+// Composition Observer
+void TransportDialog::timeSignatureChanged(const Composition *comp)
+{
+    RG_DEBUG << "timeSignatureChanged";
+    // reset pointer position to recalculate display
+    RosegardenMainWindow *rmw = RosegardenMainWindow::self();
+    rmw->slotSetPointerPosition(comp->getPosition());
+}
+
+void TransportDialog::tempoChanged(const Composition *comp)
+{
+    RG_DEBUG << "tempoChanged";
+    // reset pointer position to recalculate display
+    RosegardenMainWindow *rmw = RosegardenMainWindow::self();
+    rmw->slotSetPointerPosition(comp->getPosition());
+}
+
 
 }
