@@ -1,4 +1,3 @@
-
 /* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */
 
 /*
@@ -20,9 +19,9 @@
 #define RG_TUPLETDIALOG_H
 
 #include "base/NotationTypes.h"
-#include <QDialog>
-#include "base/Event.h"
+#include "base/TimeT.h"
 
+#include <QDialog>
 
 class QWidget;
 class QString;
@@ -36,7 +35,6 @@ namespace Rosegarden
 {
 
 
-
 class TupletDialog : public QDialog
 {
     Q_OBJECT
@@ -87,7 +85,6 @@ protected:
 };
 
 
-
 }
 
 #endif
