@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -28,7 +28,7 @@ namespace Rosegarden {
 class TrivialVelocityDialog : public QDialog
 {
 public:
-    TrivialVelocityDialog(QWidget *parent, QString label, int deft);
+    TrivialVelocityDialog(QWidget *parent, QString label, int velocity);
 
     int getVelocity();
 
