@@ -19,18 +19,21 @@
 #define RG_CHORD_H
 
 #include "Fingering.h"
-#include "base/Event.h"
+#include "base/TimeT.h"
 #include "misc/Debug.h"
 
 #include <QString>
 
 #include <rosegardenprivate_export.h>
 
+
 namespace Rosegarden
 {
 
+
 class Event;
 
+
 namespace Guitar
 {
 
@@ -91,6 +94,7 @@ bool operator<(const Chord&, const Chord&);
 
 ROSEGARDENPRIVATE_EXPORT QDebug operator<<(QDebug, const Rosegarden::Guitar::Chord &);
 
+
 }
 
 #endif /*RG_CHORD_H*/
