@@ -18,17 +18,19 @@
 #ifndef RG_MATRIX_MOUSE_EVENT_H
 #define RG_MATRIX_MOUSE_EVENT_H
 
-#include <QString>
+#include "base/TimeT.h"
+
 #include <QPoint>
 
-#include "base/Event.h" // for timeT
 
 namespace Rosegarden
 {
 
+
 class MatrixViewSegment;
 class MatrixElement;
 
+
 class MatrixMouseEvent
 {
 public:
@@ -59,6 +61,7 @@ public:
         modifiers(), buttons() { }
 };
 
+
 }
 
 #endif
