@@ -126,17 +126,16 @@ namespace Rosegarden
 {
 
 
-MatrixView::MatrixView(RosegardenDocument *doc,
-                       const std::vector<Segment *>& segments,
+MatrixView::MatrixView(const std::vector<Segment *>& segments,
                        bool drumMode) :
     EditViewBase(segments),
     m_quantizations(Quantizer::getQuantizations()),
     m_drumMode(drumMode),
     m_inChordMode(false)
 {
-    m_document = doc;
     m_matrixWidget = new MatrixWidget(m_drumMode);
     setCentralWidget(m_matrixWidget);
+    RosegardenDocument* doc = RosegardenDocument::currentDocument;
     m_matrixWidget->setSegments(doc, segments);
 
     // Many actions are created here
@@ -191,12 +190,12 @@ MatrixView::MatrixView(RosegardenDocument *doc,
         MATRIX_DEBUG << "newest state for action '" << toolAction->objectName() << "' is " << toolAction->isChecked();
     }
 
-    m_scrollToFollow = m_document->getComposition().getEditorFollowPlayback();
+    m_scrollToFollow = doc->getComposition().getEditorFollowPlayback();
     findAction("scroll_to_follow")->setChecked(m_scrollToFollow);
     m_matrixWidget->setScrollToFollowPlayback(m_scrollToFollow);
 
     slotUpdateWindowTitle();
-    connect(m_document, &RosegardenDocument::documentModified,
+    connect(doc, &RosegardenDocument::documentModified,
             this, &MatrixView::slotUpdateWindowTitle);
 
     // Set initial visibility ...
@@ -276,8 +275,7 @@ MatrixView::MatrixView(RosegardenDocument *doc,
     enableAutoRepeat("Transport Toolbar", "cursor_back");
     enableAutoRepeat("Transport Toolbar", "cursor_forward");
 
-    connect(RosegardenDocument::currentDocument,
-                &RosegardenDocument::loopChanged,
+    connect(doc, &RosegardenDocument::loopChanged,
             this, &MatrixView::slotLoopChanged);
     // Make sure we are in sync.
     slotLoopChanged();
@@ -440,6 +438,8 @@ MatrixView::setupActions()
 
     createAction("toggle_velocity_ruler", &MatrixView::slotToggleVelocityRuler);
     createAction("toggle_pitchbend_ruler", &MatrixView::slotTogglePitchbendRuler);
+    createAction("toggle_keypressure_ruler", &MatrixView::slotToggleKeyPressureRuler);
+    createAction("toggle_channelpressure_ruler", &MatrixView::slotToggleChannelPressureRuler);
     createAction("add_control_ruler", "");
 
     createAction("add_tempo_change", &MatrixView::slotAddTempo);
@@ -461,7 +461,7 @@ MatrixView::setupActions()
     createAction("jog_left", &MatrixView::slotJogLeft);
     createAction("jog_right", &MatrixView::slotJogRight);
 
-    QMenu *addControlRulerMenu = new QMenu;
+    QMenu *addControlRulerMenu = new QMenu(this);
     Controllable *c =
         dynamic_cast<MidiDevice *>(getCurrentDevice());
     if (!c) {
@@ -605,6 +605,40 @@ MatrixView::setupActions()
             createAction(actionName, &MatrixView::slotSetSnapFromAction);
         }
     }
+
+    // check ruler availability
+    // enbale the ruler if any segment uses a device with that control
+    bool pitchBendEnabled = false;
+    bool channelPressureEnabled = false;
+    bool keyPressureEnabled = false;
+    for(const Segment* segment : m_segments) {
+        RosegardenDocument* doc = RosegardenDocument::currentDocument;
+        Track *track = doc->getComposition().getTrackById(segment->getTrack());
+
+        Instrument *instrument = doc->getStudio().
+            getInstrumentById(track->getInstrument());
+
+        if (instrument) {
+            const Controllable *controllable =
+                instrument->getDevice()->getControllable();
+
+            if (controllable) {
+
+                for (const ControlParameter &cp :
+                         controllable->getControlParameters()) {
+                    if (cp.getType() == PitchBend::EventType)
+                        pitchBendEnabled = true;
+                    if (cp.getType() == ChannelPressure::EventType)
+                        channelPressureEnabled = true;
+                    if (cp.getType() == KeyPressure::EventType)
+                        keyPressureEnabled = true;
+                }
+            }
+        }
+    }
+    findAction("toggle_pitchbend_ruler")->setEnabled(pitchBendEnabled);
+    findAction("toggle_keypressure_ruler")->setEnabled(keyPressureEnabled);
+    findAction("toggle_channelpressure_ruler")->setEnabled(channelPressureEnabled);
 }
 
 
@@ -735,6 +769,8 @@ MatrixView::initRulersToolbar()
     // set the "ruler n" tool button to pop up its menu instantly
     QToolButton *tb = dynamic_cast<QToolButton *>(findToolbar("Rulers Toolbar")->widgetForAction(findAction("add_control_ruler")));
     tb->setPopupMode(QToolButton::InstantPopup);
+
+
 }
 
 void
@@ -914,8 +950,9 @@ MatrixView::getRulerSelection() const
 timeT
 MatrixView::getInsertionTime() const
 {
-    if (!m_document) return 0;
-    return m_document->getComposition().getPosition();
+    RosegardenDocument* doc = RosegardenDocument::currentDocument;
+    if (!doc) return 0;
+    return doc->getComposition().getPosition();
 }
 
 const SnapGrid *
@@ -1067,7 +1104,7 @@ MatrixView::slotQuantizeSelection(int q)
     if (!selection) return;
 
     if (unit) {
-        if (selection && selection->getAddedEvents()) {
+        if (selection && selection->size()) {
             CommandHistory::getInstance()->addCommand
                 (new EventQuantizeCommand(*selection, quant));
         } else {
@@ -1210,8 +1247,8 @@ MatrixView::slotPlaceControllers()
     ControlParameter *cp = cr->getControlParameter();
     if (!cp) { return; }
 
-    const Instrument *instrument =
-        RosegardenDocument::currentDocument->getInstrument(getCurrentSegment());
+    RosegardenDocument* doc = RosegardenDocument::currentDocument;
+    const Instrument *instrument = doc->getInstrument(getCurrentSegment());
     if (!instrument) { return; }
 
     PlaceControllersCommand *command =
@@ -1227,7 +1264,8 @@ MatrixView::slotTriggerSegment()
 {
     if (!getSelection()) return;
 
-    TriggerSegmentDialog dialog(this, &m_document->getComposition());
+    RosegardenDocument* doc = RosegardenDocument::currentDocument;
+    TriggerSegmentDialog dialog(this, &doc->getComposition());
     if (dialog.exec() != QDialog::Accepted) return;
 
     CommandHistory::getInstance()->addCommand
@@ -1277,12 +1315,13 @@ MatrixView::slotPreviewSelection()
     if (!getSelection())
         return;
 
-    Composition &composition = m_document->getComposition();
+    RosegardenDocument* doc = RosegardenDocument::currentDocument;
+    Composition &composition = doc->getComposition();
 
     composition.setLoopMode(Composition::LoopOn);
     composition.setLoopStart(getSelection()->getStartTime());
     composition.setLoopEnd(getSelection()->getEndTime());
-    emit m_document->loopChanged();
+    emit doc->loopChanged();
 }
 
 void
@@ -1291,11 +1330,12 @@ MatrixView::slotClearLoop()
     // ??? Not sure why there is a Move > Clear Loop.  The LoopRuler
     //     is available.  One has full control of looping from there.
 
-    Composition &composition = m_document->getComposition();
+    RosegardenDocument* doc = RosegardenDocument::currentDocument;
+    Composition &composition = doc->getComposition();
 
     // Less destructive.  Just turn it off.
     composition.setLoopMode(Composition::LoopOff);
-    emit m_document->loopChanged();
+    emit doc->loopChanged();
 }
 
 void
@@ -1390,7 +1430,8 @@ MatrixView::slotScrollToFollow()
 {
     m_scrollToFollow = !m_scrollToFollow;
     m_matrixWidget->setScrollToFollowPlayback(m_scrollToFollow);
-    m_document->getComposition().setEditorFollowPlayback(m_scrollToFollow);
+    RosegardenDocument* doc = RosegardenDocument::currentDocument;
+    doc->getComposition().setEditorFollowPlayback(m_scrollToFollow);
 }
 
 void
@@ -1437,6 +1478,20 @@ MatrixView::slotTogglePitchbendRuler()
     slotUpdateMenuStates();
 }
 
+void
+MatrixView::slotToggleKeyPressureRuler()
+{
+    m_matrixWidget->showKeyPressureRuler();
+    slotUpdateMenuStates();
+}
+
+void
+MatrixView::slotToggleChannelPressureRuler()
+{
+    m_matrixWidget->showChannelPressureRuler();
+    slotUpdateMenuStates();
+}
+
 void
 MatrixView::slotAddControlRuler(QAction *action)
 {
@@ -1552,15 +1607,13 @@ void MatrixView::slotRescale()
     EventSelection *selection = getSelection();
     if (!selection) return;
 
-    RescaleDialog dialog(this,
-                         &RosegardenDocument::currentDocument->getComposition(),
-                         selection->getStartTime(),
-                         selection->getEndTime() -
-                             selection->getStartTime(),
-                         1,
-                         true,
-                         true
-                        );
+    RescaleDialog dialog(
+            this,  // parent
+            selection->getStartTime(),  // startTime
+            selection->getEndTime() - selection->getStartTime(),  // originalDuration
+            1,  // minimumDuration
+            true,  // showCloseGapOption
+            true);  // constrainToCompositionDuration
 
     if (dialog.exec() == QDialog::Accepted) {
         CommandHistory::getInstance()->addCommand(new RescaleCommand
@@ -1793,10 +1846,11 @@ MatrixView::slotStepBackward()
 
     time = getSnapGrid()->snapTime(time - 1, SnapGrid::SnapLeft);
 
+    RosegardenDocument* doc = RosegardenDocument::currentDocument;
     if (time < segment->getStartTime()){
-        m_document->slotSetPointerPosition(segment->getStartTime());
+        doc->slotSetPointerPosition(segment->getStartTime());
     } else {
-        m_document->slotSetPointerPosition(time);
+        doc->slotSetPointerPosition(time);
     }
 }
 
@@ -1819,10 +1873,11 @@ MatrixView::stepForward(bool force)
 
     time = getSnapGrid()->snapTime(time + 1, SnapGrid::SnapRight);
 
+    RosegardenDocument* doc = RosegardenDocument::currentDocument;
     if (!force && (time > segment->getEndMarkerTime())){
-        m_document->slotSetPointerPosition(segment->getEndMarkerTime());
+        doc->slotSetPointerPosition(segment->getEndMarkerTime());
     } else {
-        m_document->slotSetPointerPosition(time);
+        doc->slotSetPointerPosition(time);
     }
 }
 
@@ -1932,7 +1987,7 @@ MatrixView::slotInsertableNoteEventReceived(int pitch, int velocity, bool noteOn
     CommandHistory::getInstance()->addCommand(command);
 
     if (!m_inChordMode) {
-        m_document->slotSetPointerPosition(endTime);
+        RosegardenDocument::currentDocument->slotSetPointerPosition(endTime);
     }
 }
 
@@ -2051,7 +2106,7 @@ MatrixView::slotInsertNoteFromAction()
     CommandHistory::getInstance()->addCommand(command);
 
     if (!m_inChordMode) {
-        m_document->slotSetPointerPosition(endTime);
+        RosegardenDocument::currentDocument->slotSetPointerPosition(endTime);
     }
 
     emit noteInsertedFromKeyboard(segment, pitch);
