@@ -17,28 +17,29 @@
 
 #include "ClefInserter.h"
 
-#include "commands/notation/ClefInsertionCommand.h"
-
 #include "NotationTool.h"
 #include "NotationWidget.h"
 #include "NotationElement.h"
 #include "NotationStaff.h"
 #include "NotationScene.h"
 #include "NotationMouseEvent.h"
-#include "gui/widgets/Panned.h"
 
+#include "commands/notation/ClefInsertionCommand.h"
+#include "gui/widgets/Panned.h"
 #include "document/CommandHistory.h"
 
+
 namespace Rosegarden
 {
 
+
 ClefInserter::ClefInserter(NotationWidget *widget) :
     NotationTool("clefinserter.rc", "ClefInserter", widget),
     m_clef(Clef::Treble)
 {
-    createAction("select", SLOT(slotSelectSelected()));
-    createAction("erase", SLOT(slotEraseSelected()));
-    createAction("notes", SLOT(slotNotesSelected()));
+    createAction("select", &ClefInserter::slotSelectSelected);
+    createAction("erase", &ClefInserter::slotEraseSelected);
+    createAction("notes", &ClefInserter::slotNotesSelected);
 }
 
 void
@@ -63,7 +64,7 @@ void
 ClefInserter::ready()
 {
     m_widget->setCanvasCursor(Qt::CrossCursor);
-//!!!    m_nParentView->setHeightTracking(false);
+    // !!! m_nParentView->setHeightTracking(false);
 
     // The clef tool doesn't use the wheel.
     m_widget->getView()->setWheelZoomPan(true);
