@@ -20,7 +20,6 @@
 
 #include "base/NotationTypes.h"
 #include "NotationTool.h"
-#include "base/Event.h"
 
 #include <QString>
 
@@ -28,9 +27,11 @@
 namespace Rosegarden
 {
 
-class ViewElement;
+
+class NotationMouseEvent;
 class NotationWidget;
 
+
 /**
  * This tool will insert clefs on mouse click events
  */
@@ -45,11 +46,6 @@ public:
 
     void handleLeftButtonPress(const NotationMouseEvent *) override;
 
-
-
-    /**
-     * Useful to get the tool name from a NotationTool object
-     */
     const QString getToolName() override { return ToolName(); }
 
     bool needsWheelEvents() override { return false; }
@@ -57,7 +53,7 @@ public:
     static QString ToolName();
 
 public slots:
-    void slotSetClef(const Clef& clefType);
+    void slotSetClef(const Clef &clefType);
 
 protected slots:
     void slotNotesSelected();
@@ -69,6 +65,7 @@ protected:
     Clef m_clef;
 };
 
+
 }
 
 #endif
