@@ -19,17 +19,18 @@
 #define RG_GUITAR_CHORD_INSERTER_H
 
 #include "NotationTool.h"
-#include "base/Event.h"
+#include "base/TimeT.h"
 
 
 namespace Rosegarden
 {
 
-class ViewElement;
+
 class NotationWidget;
 class GuitarChordSelectorDialog;
 class NotationStaff;
 
+
 /**
  * This tool will insert guitar chord on mouse click events
 */
@@ -65,12 +66,13 @@ protected:
     explicit GuitarChordInserter(NotationWidget *);
 
 private:
-    void handleSelectedGuitarChord(const NotationMouseEvent *e);
+    void handleSelectedGuitarChord(const NotationMouseEvent *event);
     void createNewGuitarChord(const NotationMouseEvent *e);
 
     bool processDialog(NotationStaff *staff, timeT &insertionTime);
 };
 
+
 }
 
 #endif
