@@ -31,9 +31,11 @@
 #include <QSettings>
 #include <QAction>
 
+
 namespace Rosegarden
 {
 
+
 NotationEraser::NotationEraser(NotationWidget *widget) :
     NotationTool("notationeraser.rc", "NotationEraser", widget),
     m_collapseRest(false)
@@ -43,12 +45,13 @@ NotationEraser::NotationEraser(NotationWidget *widget) :
 
     m_collapseRest = qStrToBool(settings.value("collapse", "false"));
 
-    QAction *a = createAction("toggle_rest_collapse", SLOT(slotToggleRestCollapse()));
+    QAction *a = createAction("toggle_rest_collapse",
+                              &NotationEraser::slotToggleRestCollapse);
     a->setCheckable(true);
     a->setChecked(m_collapseRest);
 
-    createAction("select", SLOT(slotSelectSelected()));
-    createAction("insert", SLOT(slotInsertSelected()));
+    createAction("select", &NotationEraser::slotSelectSelected);
+    createAction("insert", &NotationEraser::slotInsertSelected);
 
     settings.endGroup();
 }
@@ -57,7 +60,7 @@ void
 NotationEraser::ready()
 {
     m_widget->setCanvasCursor(Qt::PointingHandCursor);
-//!!!    m_nParentView->setHeightTracking(false);
+    // !!! m_nParentView->setHeightTracking(false);
 
     // The eraser tool doesn't use the wheel.
     m_widget->getView()->setWheelZoomPan(true);
