@@ -19,11 +19,14 @@
 #define RG_NOTATIONERASER_H
 
 #include "NotationTool.h"
-#include "base/Event.h"
+
+#include <QString>
+
 
 namespace Rosegarden
 {
 
+
 /**
  * This tool will erase a note on mouse click events
  */
@@ -59,6 +62,7 @@ protected:
     bool m_collapseRest;
 };
 
+
 }
 
 #endif
