@@ -19,15 +19,19 @@
 #define RG_NOTATION_MOUSE_EVENT_H
 
 #include "base/NotationTypes.h"
-#include "base/Event.h"
-#include <QString>
+#include "base/TimeT.h"
+
+#include <Qt>
+
 
 namespace Rosegarden
 {
 
+
 class NotationStaff;
 class NotationElement;
 
+
 class NotationMouseEvent
 {
 public:
@@ -52,6 +56,7 @@ public:
         modifiers(), buttons() { }
 };
 
+
 }
 
 #endif
