@@ -488,16 +488,16 @@ NotationScene::getStaffForSceneCoords(double x, int y) const
 {
     // (i)  Do not change staff, if mouse was clicked within the current staff.
 
-    StaffLayout *s = nullptr;
+    StaffLayout *staffLayout1 = nullptr;
 
     if (m_currentStaff < (int)m_staffs.size()) {
-        s = m_staffs[m_currentStaff];
+        staffLayout1 = m_staffs[m_currentStaff];
     }
 
-    if (s && s->containsSceneCoords(x, y)) {
+    if (staffLayout1 && staffLayout1->containsSceneCoords(x, y)) {
 
         StaffLayout::StaffLayoutCoords coords =
-            s->getLayoutCoordsForSceneCoords(x, y);
+            staffLayout1->getLayoutCoordsForSceneCoords(x, y);
 
         timeT t = m_hlayout->getTimeForX(coords.first);
 
@@ -515,16 +515,16 @@ NotationScene::getStaffForSceneCoords(double x, int y) const
             if (m_staffs[i]->getSegment().isTmp()) continue;
         }
 
-        StaffLayout *s = m_staffs[i];
+        StaffLayout *staffLayout2 = m_staffs[i];
 
-        if (s->containsSceneCoords(x, y)) {
+        if (staffLayout2->containsSceneCoords(x, y)) {
 
             StaffLayout::StaffLayoutCoords coords =
-                s->getLayoutCoordsForSceneCoords(x, y);
+                staffLayout2->getLayoutCoordsForSceneCoords(x, y);
 
-	    timeT t = m_hlayout->getTimeForX(coords.first);
+            timeT t = m_hlayout->getTimeForX(coords.first);
 
-	    if (m_staffs[i]->includesTime(t)) {
+            if (m_staffs[i]->includesTime(t)) {
                 return m_staffs[i];
             }
         }
@@ -534,25 +534,25 @@ NotationScene::getStaffForSceneCoords(double x, int y) const
 }
 
 NotationStaff *
-NotationScene::getStaffAbove(timeT t)
+NotationScene::getStaffAbove(timeT t) const
 {
     return getNextStaffVertically(-1, t);
 }
 
 NotationStaff *
-NotationScene::getStaffBelow(timeT t)
+NotationScene::getStaffBelow(timeT t) const
 {
     return getNextStaffVertically(1, t);
 }
 
 NotationStaff *
-NotationScene::getPriorStaffOnTrack()
+NotationScene::getPriorStaffOnTrack() const
 {
     return getNextStaffHorizontally(-1, false);
 }
 
 NotationStaff *
-NotationScene::getNextStaffOnTrack()
+NotationScene::getNextStaffOnTrack() const
 {
     return getNextStaffHorizontally(1, false);
 }
@@ -571,7 +571,7 @@ NotationScene::getStaffBySegmentMarking(const QString& marking) const
 }
 
 NotationStaff *
-NotationScene::getStaffbyTrackAndTime(const Track *track, timeT targetTime)
+NotationScene::getStaffbyTrackAndTime(const Track *track, timeT targetTime) const
 {
     // Prepare a fallback: If this is the right track but no staff
     // includes time t, we'll return the fallback instead.  We
@@ -608,7 +608,7 @@ NotationScene::getStaffbyTrackAndTime(const Track *track, timeT targetTime)
 // lower-numbered ones are.
 // t is a time that the found staff should contain if possible.
 NotationStaff *
-NotationScene::getNextStaffVertically(int direction, timeT t)
+NotationScene::getNextStaffVertically(int direction, timeT t) const
 {
     if (m_staffs.size() < 2 || m_currentStaff >= (int)m_staffs.size()) return nullptr;
 
@@ -630,7 +630,7 @@ NotationScene::getNextStaffVertically(int direction, timeT t)
 }
 
 NotationStaff *
-NotationScene::getNextStaffHorizontally(int direction, bool cycle)
+NotationScene::getNextStaffHorizontally(int direction, bool cycle) const
 {
     if (m_staffs.size() < 2 || m_currentStaff >= (int)m_staffs.size()) return nullptr;
 
@@ -731,14 +731,16 @@ NotationScene::getCurrentSegment()
 bool
 NotationScene::segmentsContainNotes() const
 {
-    for (unsigned int i = 0; i < m_segments.size(); ++i) {
+    for (unsigned int segmentIndex = 0;
+         segmentIndex < m_segments.size();
+         ++segmentIndex) {
 
-        const Segment *segment = m_segments[i];
+        const Segment *segment = m_segments[segmentIndex];
 
-        for (Segment::const_iterator i = segment->begin();
-             segment->isBeforeEndMarker(i); ++i) {
+        for (Segment::const_iterator eventIter = segment->begin();
+             segment->isBeforeEndMarker(eventIter); ++eventIter) {
 
-            if (((*i)->getType() == Note::EventType)) {
+            if (((*eventIter)->getType() == Note::EventType)) {
                 return true;
             }
         }
