@@ -63,38 +63,24 @@ using namespace BaseProperties;
 
 NotationSelector::NotationSelector(NotationWidget *widget, bool ties) :
     NotationTool("notationselector.rc", "NotationSelector", widget),
-    m_selectionRect(nullptr),
-    m_updateRect(false),
-    m_selectedStaff(nullptr),
-    m_clickedElement(nullptr),
-    m_selectionToMerge(nullptr),
-    m_justSelectedBar(false),
-    m_wholeStaffSelectionComplete(false),
-    m_ties(ties),
-    m_doubleClick(false),
-    m_tripleClick(false),
-    m_pointerStaff(nullptr),
-    m_pointerTime(0),
-    m_releaseTimer(nullptr)
+    m_ties(ties)
 {
-    //connect(m_widget, SIGNAL(usedSelection()),
-    //        this, SLOT(slotHideSelection()));
-
     connect(this, &NotationSelector::editElement,
             m_widget, &NotationWidget::editElement);
 
-    createAction("insert", SLOT(slotInsertSelected()));
-    createAction("erase", SLOT(slotEraseSelected()));
-    createAction("collapse_rests_aggressively", SLOT(slotCollapseRestsHard()));
-    createAction("respell_flat", SLOT(slotRespellFlat()));
-    createAction("respell_sharp", SLOT(slotRespellSharp()));
-    createAction("respell_natural", SLOT(slotRespellNatural()));
-    createAction("collapse_notes", SLOT(slotCollapseNotes()));
-    createAction("interpret", SLOT(slotInterpret()));
-    createAction("move_events_up_staff", SLOT(slotStaffAbove()));
-    createAction("move_events_down_staff", SLOT(slotStaffBelow()));
-    createAction("make_invisible", SLOT(slotMakeInvisible()));
-    createAction("make_visible", SLOT(slotMakeVisible()));
+    createAction("insert", &NotationSelector::slotInsertSelected);
+    createAction("erase", &NotationSelector::slotEraseSelected);
+    createAction("collapse_rests_aggressively",
+                 &NotationSelector::slotCollapseRestsHard);
+    createAction("respell_flat", &NotationSelector::slotRespellFlat);
+    createAction("respell_sharp", &NotationSelector::slotRespellSharp);
+    createAction("respell_natural", &NotationSelector::slotRespellNatural);
+    createAction("collapse_notes", &NotationSelector::slotCollapseNotes);
+    createAction("interpret", &NotationSelector::slotInterpret);
+    createAction("move_events_up_staff", &NotationSelector::slotStaffAbove);
+    createAction("move_events_down_staff", &NotationSelector::slotStaffBelow);
+    createAction("make_invisible", &NotationSelector::slotMakeInvisible);
+    createAction("make_visible", &NotationSelector::slotMakeVisible);
 
     createMenu();
 
@@ -634,14 +620,6 @@ void NotationSelector::handleEventRemoved(Event *event)
     }
 }
 
-/* unused
-void NotationSelector::slotHideSelection()
-{
-    if (!m_selectionRect) return;
-    m_selectionRect->hide();
-}
-*/
-
 void NotationSelector::slotInsertSelected()
 {
     invokeInParentView("draw");
@@ -826,7 +804,7 @@ NotationSelector::getEventsInSelectionRect
        }
     }
 
-    if (selection->getAddedEvents() > 0) {
+    if (selection->size() > 0) {
         return selection;
     } else {
         delete selection;
