@@ -21,17 +21,16 @@
 
 #include "base/Exception.h"
 #include "base/NotationTypes.h"
-#include <QString>
-#include "base/Event.h"
+#include "base/TimeT.h"
 
 #include <QCoreApplication>
+#include <QString>
 
 
 namespace Rosegarden
 {
 
 
-
 /**
  * String factory for note names, etc. used in the GUI
  * Replaces use of base/NotationTypes.h strings which should
@@ -111,6 +110,7 @@ private:
 
 };    
 
+
 }
 
 #endif
