@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -606,7 +606,7 @@ NotationVLayout::positionSlur(NotationStaff &staff,
     bool above = true;
 
     if ((*i)->event()->has(NotationProperties::SLUR_ABOVE) &&
-            (*i)->event()->isPersistent<Bool>(NotationProperties::SLUR_ABOVE)) {
+            (*i)->event()->isPersistent(NotationProperties::SLUR_ABOVE)) {
 
         (*i)->event()->get
         <Bool>(NotationProperties::SLUR_ABOVE, above);
