@@ -56,8 +56,7 @@ class ROSEGARDENPRIVATE_EXPORT NotationView : public EditViewBase,
 public:
     typedef std::vector<Segment *> SegmentVector;
     typedef void (NotationView::*opOnEvent) (Event* e, Segment *containing);
-    NotationView(RosegardenDocument *doc,
-                 const std::vector<Segment *>& segments);
+    explicit NotationView(const std::vector<Segment *>& segments);
 
     ~NotationView() override;
 
@@ -283,6 +282,8 @@ protected slots:
 
     void slotToggleVelocityRuler();
     void slotTogglePitchbendRuler();
+    void slotToggleKeyPressureRuler();
+    void slotToggleChannelPressureRuler();
     void slotAddControlRuler(QAction*);
 
     void slotAddTempo();
@@ -425,6 +426,15 @@ private:
      */
     Device *getCurrentDevice();
 
+    /// Move the selected events to another staff
+    /**
+     * @param upStaff
+     *   if true, move them to the staff above this one, otherwise to the
+     *   staff below.
+     * @param useDialog
+     *   Whether to use a dialog, otherwise use default values and no
+     *   interaction.
+     */
     void generalMoveEventsToStaff(bool upStaff, bool useDialog);
 
     /**
@@ -490,9 +500,6 @@ private:
 
 // FIXME: likely to be debated. --gp     Used for subclassing in pitchtracker
 protected:
-    // !!! Duplicates m_doc in base class
-    RosegardenDocument *m_document;
-
     NotationWidget *m_notationWidget;
     EventSelection *getRulerSelection() const;
 
