@@ -19,6 +19,7 @@
 #define RG_NO_DEBUG_PRINT 1
 
 #include "NotationWidget.h"
+
 #include "NotationScene.h"
 #include "NotationToolBox.h"
 #include "NoteRestInserter.h"
@@ -32,6 +33,7 @@
 #include "StaffLayout.h"
 #include "HeadersGroup.h"
 #include "NotationStaff.h"
+#include "NotationView.h"
 
 #include "base/RulerScale.h"
 #include "base/BaseProperties.h"
@@ -67,6 +69,7 @@
 #include "gui/rulers/ChordNameRuler.h"
 #include "gui/rulers/RawNoteRuler.h"
 #include "gui/rulers/LoopRuler.h"
+#include "gui/rulers/MarkerRuler.h"
 
 #include "gui/seqmanager/SequenceManager.h"
 
@@ -434,15 +437,6 @@ NotationWidget::setSegments(RosegardenDocument *document,
     connect(m_scene, &NotationScene::sceneNeedsRebuilding,
             this, &NotationWidget::sceneNeedsRebuilding, Qt::QueuedConnection);
 
-    // To fix this, create a new slot called slotCurrentStaffChanged() and
-    // have it call slotUpdatePointerPosition(true).
-    //connect(m_scene, SIGNAL(currentStaffChanged()),
-    //        this, SLOT(slotUpdatePointerPosition(true)));
-
-    // There is a Panner::updateScene(), but it's not a slot.
-    //connect(m_scene, SIGNAL(selectionChanged()),
-    //        m_view, SLOT(updateScene()));
-
     m_view->setScene(m_scene);
 
     m_toolBox->setScene(m_scene);
@@ -462,11 +456,13 @@ NotationWidget::setSegments(RosegardenDocument *document,
     if (m_controlRulerWidget) delete m_controlRulerWidget;
     if (m_segmentLabel) delete m_segmentLabel;
 
+    // ControlRulerWidget
     m_controlRulerWidget = new ControlRulerWidget;
     m_layout->addWidget(m_controlRulerWidget, CONTROLS_ROW, MAIN_COL, 1, 1);
     m_controlRulerWidget->setViewSegment(
             dynamic_cast<ViewSegment *>(m_scene->getCurrentStaff()));
     m_controlRulerWidget->setRulerScale(m_referenceScale, m_leftGutter);
+    m_controlRulerWidget->setAutoScroller(&m_autoScroller);
 
     connect(m_view, &Panned::viewportChanged,
             m_controlRulerWidget, &ControlRulerWidget::slotSetPannedRect);
@@ -494,73 +490,59 @@ NotationWidget::setSegments(RosegardenDocument *document,
     connect(this, &NotationWidget::toolChanged,
             m_controlRulerWidget, &ControlRulerWidget::slotSetTool);
 
-    // Connect ControlRulerWidget for Auto-Scroll.
-    connect(m_controlRulerWidget, &ControlRulerWidget::mousePress,
-            this, &NotationWidget::slotCRWMousePress);
-    connect(m_controlRulerWidget, &ControlRulerWidget::mouseMove,
-            this, &NotationWidget::slotCRWMouseMove);
-    connect(m_controlRulerWidget, &ControlRulerWidget::mouseRelease,
-            this, &NotationWidget::slotCRWMouseRelease);
-
     m_segmentLabel = new QLabel("Segment Label");
     m_segmentLabel->setAlignment(Qt::AlignHCenter);
     m_segmentLabel->setAutoFillBackground(true);
     m_layout->addWidget(m_segmentLabel, SEGMENTLABEL_ROW, MAIN_COL, 1, 1);
 
-    m_topStandardRuler = new StandardRuler(document,
-                                           m_referenceScale,
-                                           false);
-
-    m_bottomStandardRuler = new StandardRuler(document,
-                                              m_referenceScale,
-                                              true);
+    // ChordNameRuler
+    m_chordNameRuler = new ChordNameRuler(m_referenceScale,
+                                          document,
+                                          segments,
+                                          24);     // height
+    m_layout->addWidget(m_chordNameRuler, CHORDNAMERULER_ROW, MAIN_COL, 1, 1);
 
+    // TempoRuler
     m_tempoRuler = new TempoRuler(m_referenceScale,
                                   document,
                                   24,     // height
                                   true,   // small
                                   ThornStyle::isEnabled());
+    m_tempoRuler->setAutoScroller(&m_autoScroller);
+    m_layout->addWidget(m_tempoRuler, TEMPORULER_ROW, MAIN_COL, 1, 1);
 
-    m_chordNameRuler = new ChordNameRuler(m_referenceScale,
-                                          document,
-                                          segments,
-                                          24);     // height
-
+    // RawNoteRuler
     m_rawNoteRuler = new RawNoteRuler(m_referenceScale,
                                       segments[0],
                                       20);  // why not 24 as other rulers ?
-
-    m_layout->addWidget(m_topStandardRuler, TOPRULER_ROW, MAIN_COL, 1, 1);
-    m_layout->addWidget(m_bottomStandardRuler, BOTTOMRULER_ROW, MAIN_COL, 1, 1);
-    m_layout->addWidget(m_tempoRuler, TEMPORULER_ROW, MAIN_COL, 1, 1);
-    m_layout->addWidget(m_chordNameRuler, CHORDNAMERULER_ROW, MAIN_COL, 1, 1);
     m_layout->addWidget(m_rawNoteRuler, RAWNOTERULER_ROW, MAIN_COL, 1, 1);
 
+    // Top StandardRuler
+    m_topStandardRuler = new StandardRuler(document,
+                                           m_referenceScale,
+                                           false);  // invert
+    m_topStandardRuler->setDocument(document);
+    NotationView *mainWindow = dynamic_cast<NotationView *>(parent());
+    m_topStandardRuler->setMainWindow(mainWindow);
+    m_topStandardRuler->setAutoScroller(&m_autoScroller);
     connect(m_topStandardRuler, &StandardRuler::dragPointerToPosition,
             this, &NotationWidget::slotStandardRulerDrag);
+    m_layout->addWidget(m_topStandardRuler, TOPRULER_ROW, MAIN_COL, 1, 1);
+
+    // Bottom StandardRuler
+    m_bottomStandardRuler = new StandardRuler(document,
+                                              m_referenceScale,
+                                              true);  // invert
+    m_bottomStandardRuler->setDocument(document);
+    m_bottomStandardRuler->setMainWindow(mainWindow);
+    m_bottomStandardRuler->setAutoScroller(&m_autoScroller);
     connect(m_bottomStandardRuler, &StandardRuler::dragPointerToPosition,
             this, &NotationWidget::slotStandardRulerDrag);
-
-    connect(m_topStandardRuler->getLoopRuler(), &LoopRuler::startMouseMove,
-            this, &NotationWidget::slotSRStartMouseMove);
-    connect(m_topStandardRuler->getLoopRuler(), &LoopRuler::stopMouseMove,
-            this, &NotationWidget::slotSRStopMouseMove);
-    connect(m_bottomStandardRuler->getLoopRuler(), &LoopRuler::startMouseMove,
-            this, &NotationWidget::slotSRStartMouseMove);
-    connect(m_bottomStandardRuler->getLoopRuler(), &LoopRuler::stopMouseMove,
-            this, &NotationWidget::slotSRStopMouseMove);
-
-    connect(m_tempoRuler, &TempoRuler::mousePress,
-            this, &NotationWidget::slotTRMousePress);
-    connect(m_tempoRuler, &TempoRuler::mouseRelease,
-            this, &NotationWidget::slotTRMouseRelease);
+    m_layout->addWidget(m_bottomStandardRuler, BOTTOMRULER_ROW, MAIN_COL, 1, 1);
 
     connect(m_document, &RosegardenDocument::pointerPositionChanged,
             this, &NotationWidget::slotPointerPositionChanged);
 
-    m_topStandardRuler->connectRulerToDocPointer(document);
-    m_bottomStandardRuler->connectRulerToDocPointer(document);
-
     m_chordNameRuler->setReady();
 
     slotUpdateSegmentChangerBackground();
@@ -760,9 +742,10 @@ NotationWidget::slotSetMultiPageMode()
 }
 
 void
-NotationWidget::slotSetFontName(QString name)
+NotationWidget::slotSetFontName(const QString &name)
 {
-    if (m_scene) m_scene->setFontName(name);
+    if (m_scene)
+        m_scene->setFontName(name);
 
     // Note: See slotSetFontSize, if standard rulers and position do not refresh
 }
@@ -844,23 +827,24 @@ NotationWidget::slotSetRestInserter()
 void
 NotationWidget::slotSetInsertedNote(Note::Type type, int dots)
 {
-    NoteRestInserter *ni = dynamic_cast<NoteRestInserter *>(m_currentTool);
-    if (ni) {
+    NoteRestInserter *noteRestInserter =
+            dynamic_cast<NoteRestInserter *>(m_currentTool);
+    if (noteRestInserter) {
 
-        ni->slotSetNote(type);
-        ni->slotSetDots(dots);
+        noteRestInserter->setNote(type);
+        noteRestInserter->setDots(dots);
         return;
     }
 }
 
 void
-NotationWidget::slotSetAccidental(Accidental accidental, bool follow)
+NotationWidget::slotSetAccidental(const Accidental &accidental, bool follow)
 {
     // You don't have to be in note insertion mode to change the accidental
-    NoteRestInserter *ni = dynamic_cast<NoteRestInserter *>
+    NoteRestInserter *noteRestInserter = dynamic_cast<NoteRestInserter *>
         (m_toolBox->getTool(NoteRestInserter::ToolName()));
-    if (ni) {
-        ni->slotSetAccidental(accidental, follow);
+    if (noteRestInserter) {
+        noteRestInserter->setAccidental(accidental, follow);
         return;
     }
 }
@@ -872,10 +856,11 @@ NotationWidget::slotSetClefInserter()
 }
 
 void
-NotationWidget::slotSetInsertedClef(Clef type)
+NotationWidget::slotSetInsertedClef(const Clef &type)
 {
     ClefInserter *ci = dynamic_cast<ClefInserter *>(m_currentTool);
-    if (ci) ci->slotSetClef(type);
+    if (ci)
+        ci->slotSetClef(type);
 }
 
 void
@@ -921,6 +906,8 @@ NotationWidget::updatePointer(timeT t)
     if (!m_scene)
         return;
 
+    RG_DEBUG << "updatePointer: " << t;
+
     SequenceManager *seqMgr = m_document->getSequenceManager();
 
     const bool rolling =
@@ -951,7 +938,6 @@ NotationWidget::updatePointer(timeT t)
 
     // p will also contain sensible Y (although not 100% sensible yet)
     double pointerX = p.x1();
-    double pointerY = std::min(p.y1(), p.y2());
     double pointerHeight = fabs(p.dy());
 
     double sceneXMin = m_scene->sceneRect().left();
@@ -963,6 +949,7 @@ NotationWidget::updatePointer(timeT t)
         m_view->hidePositionPointer();
         m_hpanner->slotHidePositionPointer();
     } else {
+        double pointerY = std::min(p.y1(), p.y2());
         m_view->showPositionPointer(QPointF(pointerX, pointerY),
                                     pointerHeight);
         m_hpanner->slotShowPositionPointer(QPointF(pointerX, pointerY),
@@ -985,50 +972,6 @@ NotationWidget::slotStandardRulerDrag(timeT t)
     updatePointer(t);
 }
 
-void
-NotationWidget::slotSRStartMouseMove()
-{
-    m_autoScroller.setFollowMode(FOLLOW_HORIZONTAL);
-    m_autoScroller.start();
-}
-
-void
-NotationWidget::slotSRStopMouseMove()
-{
-    m_autoScroller.stop();
-}
-
-void
-NotationWidget::slotCRWMousePress()
-{
-    m_autoScroller.start();
-}
-
-void
-NotationWidget::slotCRWMouseMove(FollowMode followMode)
-{
-    m_autoScroller.setFollowMode(followMode);
-}
-
-void
-NotationWidget::slotCRWMouseRelease()
-{
-    m_autoScroller.stop();
-}
-
-void
-NotationWidget::slotTRMousePress()
-{
-    m_autoScroller.setFollowMode(FOLLOW_HORIZONTAL);
-    m_autoScroller.start();
-}
-
-void
-NotationWidget::slotTRMouseRelease()
-{
-    m_autoScroller.stop();
-}
-
 void
 NotationWidget::dispatchMousePress(const NotationMouseEvent *e)
 {
@@ -1310,7 +1253,7 @@ NotationWidget::slotHScroll()
     m_bottomStandardRuler->slotScrollHoriz(x);
     m_tempoRuler->slotScrollHoriz(x);
     m_chordNameRuler->slotScrollHoriz(x);
-    m_rawNoteRuler->slotScrollHoriz(x);
+    m_rawNoteRuler->scrollHoriz(x);
 
     // Update staff headers
     m_headersGroup->slotUpdateAllHeaders(xs);
@@ -1671,6 +1614,18 @@ NotationWidget::slotTogglePitchbendRuler()
     m_controlRulerWidget->togglePitchBendRuler();
 }
 
+void
+NotationWidget::slotToggleKeyPressureRuler()
+{
+    m_controlRulerWidget->toggleKeyPressureRuler();
+}
+
+void
+NotationWidget::slotToggleChannelPressureRuler()
+{
+    m_controlRulerWidget->toggleChannelPressureRuler();
+}
+
 void
 NotationWidget::slotAddControlRuler(QAction *action)
 {
@@ -1701,7 +1656,6 @@ NotationWidget::slotAddControlRuler(QAction *action)
 
     const ControlList &list = c->getControlParameters();
 
-    QString itemStr;
 //  int i = 0;
 
     for (ControlList::const_iterator it = list.begin();
