@@ -20,6 +20,8 @@
 
 #include "FontViewFrame.h"
 
+#include "misc/ConnectCBActivated.h"
+
 #include <QComboBox>
 #include <QDialog>
 #include <QDialogButtonBox>
@@ -34,6 +36,7 @@
 namespace Rosegarden
 {
 
+
 // 	void NoteFontViewer::slotViewChanged( QDialogButtonBox::int i )
 void NoteFontViewer::slotViewChanged( int i )
 {
@@ -117,15 +120,13 @@ NoteFontViewer::NoteFontViewer(QWidget *parent, QString noteFontName,
     m_frame = new FontViewFrame(pixelSize, box );
     boxLayout->addWidget(m_frame);
 
-    connect(m_font, SIGNAL(activated(const QString &)),
-            this, SLOT(slotFontChanged(const QString &)));
+    ConnectCBActivated(m_font, this, &NoteFontViewer::slotFontChanged);
 
     connect(m_view,
                 static_cast<void(QComboBox::*)(int)>(&QComboBox::activated),
             this, &NoteFontViewer::slotViewChanged);
 
-    connect(m_rows, SIGNAL(activated(const QString &)),
-            this, SLOT(slotRowChanged(const QString &)));
+    ConnectCBActivated(m_rows, this, &NoteFontViewer::slotRowChanged);
 
     slotFontChanged(m_font->currentText());
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close);
@@ -135,4 +136,5 @@ NoteFontViewer::NoteFontViewer(QWidget *parent, QString noteFontName,
     connect(buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
 }
 
+
 }
