@@ -46,6 +46,7 @@
 #include "NotePixmapFactory.h"
 #include "NoteStyleFactory.h"
 #include "document/Command.h"
+#include "base/SegmentNotationHelper.h"
 
 #include <QApplication>
 #include <QAction>
@@ -118,17 +119,7 @@ NoteRestInserter::synchronizeWheel()
 
 NoteRestInserter::NoteRestInserter(NotationWidget* widget) :
     NotationTool("noterestinserter.rc", "NoteRestInserter", widget),
-    m_noteType(Note::Quaver),
-    m_noteDots(0),
     m_autoBeam(true),
-    m_leftButtonDown(false),
-    m_accidental(Accidentals::NoAccidental),
-    m_lastAccidental(Accidentals::NoAccidental),
-    m_followAccidental(false),
-    m_isaRestInserter(false),
-    m_wheelIndex(0),
-    m_processingWheelTurned(false),
-    m_ready(false),
     m_previousPreviewStaff(nullptr)
 {
     QIcon icon;
@@ -159,7 +150,7 @@ NoteRestInserter::NoteRestInserter(NotationWidget* widget) :
 
     QAction *a;
 
-    a = createAction("toggle_auto_beam", SLOT(slotToggleAutoBeam()));
+    a = createAction("toggle_auto_beam", &NoteRestInserter::slotToggleAutoBeam);
     if (m_autoBeam) { a->setCheckable(true); a->setChecked(true); }
 
 //  Obsolete?
@@ -167,16 +158,16 @@ NoteRestInserter::NoteRestInserter(NotationWidget* widget) :
 //        a = createAction(m_actionsAccidental[i][1], m_actionsAccidental[i][0]);
 //    }
 
-    createAction("switch_dots_on", SLOT(slotToggleDot()));
-    createAction("switch_dots_off", SLOT(slotToggleDot()));
+    createAction("switch_dots_on", &NoteRestInserter::slotToggleDot);
+    createAction("switch_dots_off", &NoteRestInserter::slotToggleDot);
 
-    createAction("select", SLOT(slotSelectSelected()));
-    createAction("erase", SLOT(slotEraseSelected()));
-    createAction("switch_to_notes", SLOT(slotNotesSelected()));
-    createAction("switch_to_rests", SLOT(slotRestsSelected()));
+    createAction("select", &NoteRestInserter::slotSelectSelected);
+    createAction("erase", &NoteRestInserter::slotEraseSelected);
+    createAction("switch_to_notes", &NoteRestInserter::slotNotesSelected);
+    createAction("switch_to_rests", &NoteRestInserter::slotRestsSelected);
 
-    //connect(m_widget, SIGNAL(changeAccidental(Accidental, bool)),
-    //        this, SLOT(slotSetAccidental(Accidental, bool)));
+    //connect(m_widget, &NotationWidget::changeAccidental,
+    //        this, &NoteRestInserter::slotSetAccidental);
 
     // Push down the default RadioAction on Accidentals.
     invokeInParentView("no_accidental");
@@ -185,25 +176,15 @@ NoteRestInserter::NoteRestInserter(NotationWidget* widget) :
     synchronizeWheel();
 }
 
-NoteRestInserter::NoteRestInserter(const QString& rcFileName,
-                                   const QString& menuName,
-                                   NotationWidget* widget) :
+NoteRestInserter::NoteRestInserter(const QString &rcFileName,
+                                   const QString &menuName,
+                                   NotationWidget *widget) :
     NotationTool(rcFileName, menuName, widget),
-    m_noteType(Note::Quaver),  //OverRide value with NotationView::initializeNoteRestInserter.
-    m_noteDots(0),
     m_autoBeam(false),
-    m_leftButtonDown(false),
-    m_clickHappened(false),
-    m_accidental(Accidentals::NoAccidental),
-    m_lastAccidental(Accidentals::NoAccidental),
-    m_followAccidental(false),
-    m_isaRestInserter(false),
-    m_wheelIndex(0),
-    m_processingWheelTurned(false),
-    m_ready(false)
+    m_clickHappened(false)
 {
-    //connect(m_widget, SIGNAL(changeAccidental(Accidental, bool)),
-    //        this, SLOT(slotSetAccidental(Accidental, bool)));
+    //connect(m_widget, &NotationWidget::changeAccidental,
+    //        this, &NoteRestInserter::slotSetAccidental);
 
     // Push down the default RadioAction on Accidentals.
     invokeInParentView("no_accidental");
@@ -216,9 +197,6 @@ NoteRestInserter::NoteRestInserter(const QString& rcFileName,
     synchronizeWheel();
 }
 
-NoteRestInserter::~NoteRestInserter()
-{}
-
 void NoteRestInserter::ready()
 {
     m_ready = true;
@@ -394,11 +372,11 @@ NoteRestInserter::setCursorShape()
         params.setDots(getCurrentNote().getDots());
         params.setForcedColor(GUIPalette::PreviewColor);
 
-        QGraphicsPixmapItem * gitem =
-            dynamic_cast<QGraphicsPixmapItem *>(pixmapFactory->makeRest(params));
-        NOTATION_DEBUG << "rest: gitem =" << gitem;
+        std::unique_ptr<QGraphicsPixmapItem> graphicsPixmapItem(
+            dynamic_cast<QGraphicsPixmapItem *>(pixmapFactory->makeRest(params)));
+        NOTATION_DEBUG << "rest: graphicsPixmapItem =" << graphicsPixmapItem;
 
-        QPixmap pixmap = gitem->pixmap();
+        QPixmap pixmap = graphicsPixmapItem->pixmap();
         QCursor cursor(pixmap);
         m_widget->setCanvasCursor(cursor);
     } else {
@@ -542,7 +520,17 @@ NoteRestInserter::insertNote(Segment &segment,
             // Since a note could have been split and tied, we need to rely on
             // the full duration of the original note calculate the position of
             // the pointer.
-            timeT nextLocation = insertionTime + note.getDuration();
+            timeT trueDuration = note.getDuration();
+            if (m_widget->isInTupletMode()) {
+                // find start of tuple
+                SegmentNotationHelper helper(segment);
+                trueDuration =
+                    helper.getTupletNoteDuration(note.getDuration(),
+                                                 insertionTime,
+                                                 m_widget->getTupledCount(),
+                                                 m_widget->getUntupledCount());
+            }
+            timeT nextLocation = insertionTime + trueDuration;
             m_widget->setPointerPosition(nextLocation);
         }
     }
@@ -779,16 +767,16 @@ void NoteRestInserter::showPreview(bool play)
 
         // Prepare to get the elements of the bar in reverse order
         typedef std::reverse_iterator<Segment::iterator> RevIt;
-        RevIt rit(it);
-        RevIt last(itFirst);
+        RevIt reverseEventIter1(it);
+        RevIt last1(itFirst);
 
         // While done is false whe have to look back to some previous event
         // which may modify the accidental preview
         bool done = false;
 
         // Walk through the bar
-        for ( ; rit != last; ++rit) {
-            Event *ev = *rit;
+        for ( ; reverseEventIter1 != last1; ++reverseEventIter1) {
+            Event *ev = *reverseEventIter1;
             bool lookForNoteOnSameOctave = false;
 
             if (ev->isa(Key::EventType)) {
@@ -997,12 +985,12 @@ void NoteRestInserter::showPreview(bool play)
             itFirst = segment.findTime(startOfPreviousBar);
 
             // Prepare to get the elements of the previous bar in reverse order
-            RevIt rit(itLast);
-            RevIt last(itFirst);
+            RevIt reverseEventIter2(itLast);
+            RevIt last2(itFirst);
 
             // Walk through the bar
-            for ( ; rit != last; ++rit) {
-                Event *ev = *rit;
+            for ( ; reverseEventIter2 != last2; ++reverseEventIter2) {
+                Event *ev = *reverseEventIter2;
 
                 if (ev->isa(Key::EventType)) {
                     // Stop looking for notes as soon as a key signature is found
@@ -1189,7 +1177,13 @@ NoteRestInserter::doAddCommand(Segment &segment, timeT time, timeT endTime,
 
     // #1046934: make it possible to insert triplet at end of segment!
     if (m_widget->isInTupletMode()) {
-        noteEnd = time + (note.getDuration() * m_widget->getTupledCount() / m_widget->getUntupledCount());
+        SegmentNotationHelper helper(segment);
+        timeT noteDuration =
+            helper.getTupletNoteDuration(note.getDuration(),
+                                         time,
+                                         m_widget->getTupledCount(),
+                                         m_widget->getUntupledCount());
+        noteEnd = time + noteDuration;
     }
 
     if (time < segment.getStartTime() ||
@@ -1199,7 +1193,8 @@ NoteRestInserter::doAddCommand(Segment &segment, timeT time, timeT endTime,
     }
 
     if (isaRestInserter()) {
-        insertionCommand = new RestInsertionCommand(segment, time, endTime, note);
+        insertionCommand =
+            new RestInsertionCommand(segment, time, noteEnd, note);
     } else {
         pitch += getOttavaShift(segment, time) * 12;
 
@@ -1209,7 +1204,7 @@ NoteRestInserter::doAddCommand(Segment &segment, timeT time, timeT endTime,
         }
 
         insertionCommand = new NoteInsertionCommand
-            (segment, time, endTime, note, pitch, accidental,
+            (segment, time, noteEnd, note, pitch, accidental,
              (m_autoBeam && !m_widget->isInTupletMode() && !m_widget->isInGraceMode()) ?
              NoteInsertionCommand::AutoBeamOn : NoteInsertionCommand::AutoBeamOff,
              m_autoTieBarlines ?
@@ -1276,17 +1271,17 @@ NoteRestInserter::doAddCommand(Segment &segment, timeT time, timeT endTime,
     return insertionCommand->getLastInsertedEvent();
 }
 
-void NoteRestInserter::slotSetNote(Note::Type nt)
+void NoteRestInserter::setNote(Note::Type nt)
 {
     m_noteType = nt;
 }
 
-void NoteRestInserter::slotSetDots(unsigned int dots)
+void NoteRestInserter::setDots(unsigned int dots)
 {
     m_noteDots = dots;
 }
 
-void NoteRestInserter::slotSetAccidental(const Accidental& accidental,
+void NoteRestInserter::setAccidental(const Accidental& accidental,
                                          bool follow)
 {
     NOTATION_DEBUG << "NoteRestInserter::setAccidental: accidental is "
