@@ -18,19 +18,23 @@
 #ifndef RG_STAFFLAYOUT_H
 #define RG_STAFFLAYOUT_H
 
-#include "base/Event.h"
+#include "base/TimeT.h"
 #include "base/ViewElement.h"
+
 #include <QRect>
+
+class QGraphicsScene;
+class QGraphicsItem;
+
+#include <set>
 #include <utility>
 #include <vector>
 
-class QGraphicsScene;
-class QGraphicsLineItem;
-class QGraphicsItem;
 
 namespace Rosegarden
 {
 
+
 class BarLineItem;
 class TimeSignature;
 class SnapGrid;
@@ -619,8 +623,6 @@ protected:
 
 protected:
 
-    //--------------- Data members ---------------------------------
-
     QGraphicsScene *m_scene;
     ViewSegment *m_viewSegment;
     SnapGrid *m_snapGrid;
