@@ -23,6 +23,7 @@
 
 #include "TrackParameterBox.h"
 
+#include "gui/editors/segment/TrackButtons.h"
 #include "base/AudioPluginInstance.h"
 #include "gui/general/ClefIndex.h"  // Clef enum
 #include "gui/widgets/CollapsingFrame.h"
@@ -43,6 +44,7 @@
 #include "gui/dialogs/PitchPickerDialog.h"
 #include "sound/PluginIdentifier.h"
 #include "gui/general/PresetHandlerDialog.h"
+#include "document/CommandHistory.h"
 #include "document/RosegardenDocument.h"
 #include "gui/application/RosegardenMainWindow.h"
 #include "gui/application/RosegardenMainViewWidget.h"
@@ -491,8 +493,8 @@ TrackParameterBox::setDocument(RosegardenDocument *doc)
     // Detect when the document colours are updated.
     // Document colors can never be updated.  See explanation in
     // slotDocColoursChanged().
-    //connect(m_doc, SIGNAL(docColoursChanged()),
-    //        this, SLOT(slotDocColoursChanged()));
+    //connect(m_doc, &RosegardenDocument::docColoursChanged,
+    //        this, &TrackParameterBox::slotDocColoursChanged);
 
     updateWidgets2();
 }
@@ -555,7 +557,7 @@ TrackParameterBox::slotPlaybackDeviceChanged(int index)
         return;
 
     // Query the Studio to get an Instrument for this Device.
-    InstrumentList instrumentList = device->getPresentationInstruments();
+    InstrumentVector instrumentList = device->getPresentationInstruments();
 
     // Try to preserve the Instrument number (channel) if possible.
     int instrumentIndex = m_instrument->currentIndex();
@@ -986,7 +988,7 @@ TrackParameterBox::getTrack()
 void
 TrackParameterBox::updatePlaybackDevice(DeviceId deviceId)
 {
-    const DeviceList &deviceList = *(m_doc->getStudio().getDevices());
+    const DeviceVector &deviceList = *(m_doc->getStudio().getDevices());
 
     // Generate local device name and ID lists to compare against the members.
 
@@ -1054,7 +1056,7 @@ TrackParameterBox::updateInstrument(const Instrument *instrument)
     const DeviceId deviceId = instrument->getDevice()->getId();
     const Device &device = *(m_doc->getStudio().getDevice(deviceId));
 
-    const InstrumentList instrumentList = device.getPresentationInstruments();
+    const InstrumentVector instrumentList = device.getPresentationInstruments();
 
     // Generate local instrument name and ID lists to compare against the
     // members.
@@ -1145,7 +1147,7 @@ TrackParameterBox::updateRecordingDevice(DeviceId deviceId)
     // others.  Cache names and IDs and only reload if a real change is
     // detected.
 
-    const DeviceList &deviceList = *(m_doc->getStudio().getDevices());
+    const DeviceVector &deviceList = *(m_doc->getStudio().getDevices());
 
     // Generate local recording device name and ID lists to compare against
     // the members.
