@@ -18,7 +18,15 @@
 #ifndef RG_PITCH_HISTORY_H
 #define RG_PITCH_HISTORY_H
 
-#include "QList"
+#include "base/RealTime.h"
+#include "base/TimeT.h"
+
+#include <QList>
+
+
+namespace Rosegarden
+{
+
 
 /**
  * \addtogroup Codicil
@@ -36,15 +44,9 @@
  * \author Nick Bailey nick@n-ism.org
  * \date Apr 2010
  */
-
-#include "base/Event.h"
-
-namespace Rosegarden {
-
-struct RealTime;
-
-class PitchHistory {
-  public:
+class PitchHistory
+{
+public:
     void clear();
     
     QList<double>   m_detectFreqs;
@@ -58,6 +60,7 @@ class PitchHistory {
 };
 /**\@}*/
 
+
 }
 
 #endif
