@@ -23,6 +23,7 @@
 #include "TrackVUMeter.h"
 
 #include "misc/Debug.h"
+#include "misc/Preferences.h"
 #include "misc/Strings.h"
 #include "base/AudioPluginInstance.h"
 #include "base/Composition.h"
@@ -40,28 +41,20 @@
 #include "gui/general/IconLoader.h"
 #include "gui/seqmanager/SequenceManager.h"
 #include "gui/widgets/LedButton.h"
-#include "sound/AudioFileManager.h"
+//#include "sound/AudioFileManager.h"
 #include "sound/ControlBlock.h"
 #include "sound/PluginIdentifier.h"
 #include "sequencer/RosegardenSequencer.h"
-#include "misc/Preferences.h"
 
 #include <QApplication>
-#include <QLayout>
-#include <QMessageBox>
+#include <QVBoxLayout>
 #include <QCursor>
 #include <QFrame>
 #include <QIcon>
-#include <QLabel>
-#include <QObject>
 #include <QPixmap>
 #include <QMenu>
 #include <QSignalMapper>
 #include <QString>
-#include <QTimer>
-#include <QWidget>
-#include <QStackedWidget>
-#include <QToolTip>
 
 
 namespace
@@ -166,7 +159,7 @@ TrackButtons::TrackButtons(int trackCellHeight,
     m_layout->addStretch(20);
 
     // connect signal mappers
-#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 15, 0))
     connect(m_recordSigMapper, &QSignalMapper::mappedInt,
             this, &TrackButtons::slotToggleRecord);
     connect(m_muteSigMapper, &QSignalMapper::mappedInt,
@@ -178,16 +171,16 @@ TrackButtons::TrackButtons(int trackCellHeight,
     connect(m_clickedSigMapper, &QSignalMapper::mappedInt,
             this, &TrackButtons::slotTrackSelected);
 #else
-    connect(m_recordSigMapper, SIGNAL(mapped(int)),
-            this, SLOT(slotToggleRecord(int)));
-    connect(m_muteSigMapper, SIGNAL(mapped(int)),
-            this, SLOT(slotToggleMute(int)));
-    connect(m_soloSigMapper, SIGNAL(mapped(int)),
-            this, SLOT(slotToggleSolo(int)));
-    connect(m_instListSigMapper, SIGNAL(mapped(int)),
-            this, SLOT(slotInstrumentMenu(int)));
-    connect(m_clickedSigMapper, SIGNAL(mapped(int)),
-            this, SLOT(slotTrackSelected(int)));
+    connect(m_recordSigMapper, static_cast<void(QSignalMapper::*)(int)>(&QSignalMapper::mapped),
+            this, &TrackButtons::slotToggleRecord);
+    connect(m_muteSigMapper, static_cast<void(QSignalMapper::*)(int)>(&QSignalMapper::mapped),
+            this, &TrackButtons::slotToggleMute);
+    connect(m_soloSigMapper, static_cast<void(QSignalMapper::*)(int)>(&QSignalMapper::mapped),
+            this, &TrackButtons::slotToggleSolo);
+    connect(m_instListSigMapper, static_cast<void(QSignalMapper::*)(int)>(&QSignalMapper::mapped),
+            this, &TrackButtons::slotInstrumentMenu);
+    connect(m_clickedSigMapper, static_cast<void(QSignalMapper::*)(int)>(&QSignalMapper::mapped),
+            this, &TrackButtons::slotTrackSelected);
 #endif
 
     // We have to force the height for the moment
@@ -672,7 +665,8 @@ TrackButtons::getHighlightedTracks()
 #endif
 
 void
-TrackButtons::slotRenameTrack(QString longLabel, QString shortLabel, TrackId trackId)
+TrackButtons::slotRenameTrack(
+        const QString &longLabel, const QString &shortLabel, TrackId trackId)
 {
     if (!RosegardenDocument::currentDocument) return;
 
@@ -680,7 +674,7 @@ TrackButtons::slotRenameTrack(QString longLabel, QString shortLabel, TrackId tra
 
     if (!track) return;
 
-    TrackLabel *label = m_trackLabels[track->getPosition()];
+    const TrackLabel *label = m_trackLabels[track->getPosition()];
 
     // If neither label is changing, skip it
     if (label->getTrackName() == longLabel &&
@@ -803,10 +797,10 @@ TrackButtons::populateInstrumentPopup(Instrument *thisTrackInstr, QMenu* instrum
 
     // Get the list
     Studio &studio = RosegardenDocument::currentDocument->getStudio();
-    InstrumentList list = studio.getPresentationInstruments();
+    InstrumentVector list = studio.getPresentationInstruments();
 
     // For each instrument
-    for (InstrumentList::iterator instrumentIter = list.begin();
+    for (InstrumentVector::iterator instrumentIter = list.begin();
          instrumentIter != list.end();
          ++instrumentIter) {
 
@@ -919,8 +913,9 @@ TrackButtons::populateInstrumentPopup(Instrument *thisTrackInstr, QMenu* instrum
             instrumentPopup->addMenu(subMenu);
 
             // Connect the submenu to slotInstrumentSelected()
-            connect(subMenu, SIGNAL(triggered(QAction*)),
-                    this, SLOT(slotInstrumentSelected(QAction*)));
+            connect(subMenu, &QMenu::triggered,
+                    this, static_cast<void(TrackButtons::*)(QAction *)>(
+                            &TrackButtons::slotInstrumentSelected));
 
             currentSubMenu = subMenu;
 
@@ -1236,8 +1231,8 @@ TrackButtons::makeButton(Track *track)
     mute->setToolTip(tr("Mute track"));
     hblayout->addWidget(mute);
 
-    connect(mute, SIGNAL(stateChanged(bool)),
-            m_muteSigMapper, SLOT(map()));
+    connect(mute, &LedButton::stateChanged,
+            m_muteSigMapper, (void(QSignalMapper::*)())&QSignalMapper::map);
     m_muteSigMapper->setMapping(mute, track->getPosition());
 
     m_muteLeds.push_back(mute);
@@ -1254,8 +1249,8 @@ TrackButtons::makeButton(Track *track)
     record->setToolTip(tr("Record on this track"));
     hblayout->addWidget(record);
 
-    connect(record, SIGNAL(stateChanged(bool)),
-            m_recordSigMapper, SLOT(map()));
+    connect(record, &LedButton::stateChanged,
+            m_recordSigMapper, (void(QSignalMapper::*)())&QSignalMapper::map);
     m_recordSigMapper->setMapping(record, track->getPosition());
 
     m_recordLeds.push_back(record);
@@ -1270,8 +1265,8 @@ TrackButtons::makeButton(Track *track)
     solo->setToolTip(tr("Solo track"));
     hblayout->addWidget(solo);
 
-    connect(solo, SIGNAL(stateChanged(bool)),
-            m_soloSigMapper, SLOT(map()));
+    connect(solo, &LedButton::stateChanged,
+            m_soloSigMapper, (void(QSignalMapper::*)())&QSignalMapper::map);
     m_soloSigMapper->setMapping(solo, track->getPosition());
 
     m_soloLeds.push_back(solo);
@@ -1301,10 +1296,12 @@ TrackButtons::makeButton(Track *track)
     // Connect it
     setButtonMapping(trackLabel, trackId);
 
-    connect(trackLabel, SIGNAL(changeToInstrumentList()),
-            m_instListSigMapper, SLOT(map()));
-    connect(trackLabel, SIGNAL(clicked()),
-            m_clickedSigMapper, SLOT(map()));
+    connect(trackLabel, &TrackLabel::changeToInstrumentList,
+            m_instListSigMapper, static_cast<void(QSignalMapper::*)()>(
+                    &QSignalMapper::map));
+    connect(trackLabel, &TrackLabel::clicked,
+            m_clickedSigMapper, static_cast<void(QSignalMapper::*)()>(
+                    &QSignalMapper::map));
 
 
     // Squash it down to its smallest width.
