@@ -15,9 +15,8 @@
     COPYING included with this distribution for more information.
 */
 
-
-
 #define RG_MODULE_STRING "[TrackEditor]"
+#define RG_NO_DEBUG_PRINT
 
 #include "TrackEditor.h"
 #include "TrackButtons.h"
@@ -48,6 +47,7 @@
 #include "gui/rulers/ChordNameRuler.h"
 #include "gui/rulers/TempoRuler.h"
 #include "gui/rulers/LoopRuler.h"
+#include "gui/rulers/MarkerRuler.h"
 #include "gui/widgets/DeferScrollArea.h"
 #include "sound/AudioFile.h"
 #include "document/Command.h"
@@ -157,7 +157,8 @@ TrackEditor::init(RosegardenMainViewWidget *mainViewWidget)
                                      false,
                                      true,
                                      this);
-    m_topStandardRuler->connectRulerToDocPointer(m_doc);
+    m_topStandardRuler->setDocument(m_doc);
+    m_topStandardRuler->setMainWindow(RosegardenMainWindow::self());
     grid->addWidget(m_topStandardRuler, 2, 1);
 
     // Segment Canvas (CompositionView)
@@ -178,7 +179,8 @@ TrackEditor::init(RosegardenMainViewWidget *mainViewWidget)
                                         true,
                                         true,
                                         m_compositionView);
-    m_bottomStandardRuler->connectRulerToDocPointer(m_doc);
+    m_bottomStandardRuler->setDocument(m_doc);
+    m_bottomStandardRuler->setMainWindow(RosegardenMainWindow::self());
 
     m_compositionView->setBottomRuler(m_bottomStandardRuler);
 
@@ -220,8 +222,10 @@ TrackEditor::init(RosegardenMainViewWidget *mainViewWidget)
 
     // Connections
 
-    //connect(m_trackButtons, SIGNAL(widthChanged()),
-    //        this, SLOT(slotTrackButtonsWidthChanged()));
+    // Many of these cannot be done above as they depend on m_compositionView.
+
+    //connect(m_trackButtons, &TrackButtons::widthChanged,
+    //        this, &TrackEditor::slotTrackButtonsWidthChanged);
 
     connect(m_trackButtons, &TrackButtons::trackSelected,
             mainViewWidget, &RosegardenMainViewWidget::slotSelectTrackSegments);
@@ -230,36 +234,13 @@ TrackEditor::init(RosegardenMainViewWidget *mainViewWidget)
             mainViewWidget, &RosegardenMainViewWidget::stateChange);
 
     // No such signal.  Was there ever?
-//    connect(m_trackButtons, SIGNAL(modified()),
-//            m_doc, SLOT(slotDocumentModified()));
+//    connect(m_trackButtons, &TrackButtons::modified,
+//            m_doc, &RosegardenDocument::slotDocumentModified);
 
-    // Connect for all standard ruler mouse move starts and stops.  This
-    // allows for auto-scroll while the user drags (pointer or loop) in
-    // a StandardRuler.
-    connect(m_topStandardRuler->getLoopRuler(), &LoopRuler::startMouseMove,
-            this, &TrackEditor::slotSRStartMouseMove);
-    connect(m_topStandardRuler->getLoopRuler(), &LoopRuler::stopMouseMove,
-            this, &TrackEditor::slotSRStopMouseMove);
-    connect(m_bottomStandardRuler->getLoopRuler(), &LoopRuler::startMouseMove,
-            this, &TrackEditor::slotSRStartMouseMove);
-    connect(m_bottomStandardRuler->getLoopRuler(), &LoopRuler::stopMouseMove,
-            this, &TrackEditor::slotSRStopMouseMove);
-
-    // Connect for TempoRuler mouse press/release to allow for
-    // auto-scroll while the user drags in the TempoRuler.
-    connect(m_tempoRuler, &TempoRuler::mousePress,
-            this, &TrackEditor::slotTRMousePress);
-    connect(m_tempoRuler, &TempoRuler::mouseRelease,
-            this, &TrackEditor::slotTRMouseRelease);
-
-    //&&&  Interesting one here.  Q(3)ScrollArea had a contentsMoving signal we
-    // used to grab for some purpose.  Q(Abstract)ScrollArea has no usable
-    // signals whatsoever.  I think this is why autoscrolling is still slightly
-    // wonky in Thorn, but I don't reckon there's much to do about this one
-    // unless we write a custom widget or something.
-    //
-    //connect(m_compositionView, SIGNAL(contentsMoving(int, int)),
-    //        this, SLOT(slotCanvasScrolled(int, int)));
+    // Have to do this after CompositionView is created.
+    m_tempoRuler->setAutoScroller(m_compositionView->getAutoScroller());
+    m_topStandardRuler->setAutoScroller(m_compositionView->getAutoScroller());
+    m_bottomStandardRuler->setAutoScroller(m_compositionView->getAutoScroller());
 
     // Synchronize TrackButtons scroll area (m_trackButtonScroll) with
     // segment canvas's vertical scrollbar.
@@ -268,10 +249,14 @@ TrackEditor::init(RosegardenMainViewWidget *mainViewWidget)
     connect(m_compositionView->verticalScrollBar(), &QAbstractSlider::sliderMoved,
             this, &TrackEditor::slotVerticalScrollTrackButtons);
 
-    // Connect scrolling with the mouse wheel in the TrackButtons to
-    // scrolling the CompositionView.
+    // Connect scrolling with the mouse wheel and key events in the
+    // TrackButtons to the CompositionView.
     connect(m_trackButtonScroll, &DeferScrollArea::gotWheelEvent,
             m_compositionView, &CompositionView::slotExternalWheelEvent);
+    connect(m_trackButtonScroll, &DeferScrollArea::gotKeyPressEvent,
+            m_compositionView, &CompositionView::slotExternalKeyPressEvent);
+    connect(m_trackButtonScroll, &DeferScrollArea::gotKeyReleaseEvent,
+            m_compositionView, &CompositionView::slotExternalKeyReleaseEvent);
 
     // Synchronize the rulers with the horizontal scrollbar.
 
@@ -295,9 +280,9 @@ TrackEditor::init(RosegardenMainViewWidget *mainViewWidget)
     connect(m_compositionView->horizontalScrollBar(), &QAbstractSlider::sliderMoved,
             m_chordNameRuler, &ChordNameRuler::slotScrollHoriz);
 
-    // Was only emitted from dead code.
-    //connect(this, SIGNAL(needUpdate()),
-    //        m_compositionView, SLOT(slotUpdateAll()));
+    // Was only emitted from unused code.
+    //connect(this, &TrackEditor::needUpdate,
+    //        m_compositionView, &CompositionView::slotUpdateAll);
 
     connect(m_compositionView->getModel(),
             &CompositionModelImpl::selectionChanged,
@@ -460,31 +445,6 @@ TrackEditor::slotPointerDraggedToPosition(timeT position)
     m_compositionView->drawPointer(static_cast<int>(newPosition));
 }
 
-void
-TrackEditor::slotSRStartMouseMove()
-{
-    m_compositionView->setFollowMode(FOLLOW_HORIZONTAL);
-    m_compositionView->startAutoScroll();
-}
-
-void TrackEditor::slotSRStopMouseMove()
-{
-    m_compositionView->stopAutoScroll();
-}
-
-void
-TrackEditor::slotTRMousePress()
-{
-    m_compositionView->setFollowMode(FOLLOW_HORIZONTAL);
-    m_compositionView->startAutoScroll();
-}
-
-void
-TrackEditor::slotTRMouseRelease()
-{
-    m_compositionView->stopAutoScroll();
-}
-
 void
 TrackEditor::scrollToFollow()
 {
