@@ -18,30 +18,26 @@
 #ifndef RG_TRACKEDITOR_H
 #define RG_TRACKEDITOR_H
 
-#include "base/MidiProgram.h"
-#include "base/Event.h"
-#include "gui/editors/segment/TrackButtons.h"
+#include "base/Instrument.h"
+#include "base/TimeT.h"
+#include "base/Track.h"
 
 #include <QString>
 #include <QWidget>
-#include <QScrollArea>
+
+class QDropEvent;
+class QDragEnterEvent;
 
 #include <vector>
 
 
-class QPaintEvent;
-class QDropEvent;
-class QDragEnterEvent;
-class QScrollBar;
-class QScrollArea;
-
 namespace Rosegarden
 {
 
+
 class Command;
 class TrackButtons;
 class TempoRuler;
-class Segment;
 class SimpleRulerScale;
 class RosegardenDocument;
 class RosegardenMainViewWidget;
@@ -51,6 +47,7 @@ class CompositionModelImpl;
 class ChordNameRuler;
 class StandardRuler;
 
+
 /// Holds the CompositionView, TrackButtons, and Rulers.
 /**
  * An object of this class is created and owned by RosegardenMainViewWidget.
@@ -163,14 +160,6 @@ private slots:
      */
     void slotPointerDraggedToPosition(timeT position);
 
-    // StandardRuler mouse move for auto-scroll.
-    void slotSRStartMouseMove();
-    void slotSRStopMouseMove();
-
-    // TempoRuler mouse press/release for auto-scroll.
-    void slotTRMousePress();
-    void slotTRMouseRelease();
-
     /// Scroll the track buttons along with the segment canvas
     void slotVerticalScrollTrackButtons(int y);
 
