@@ -43,7 +43,6 @@
 #include "gui/general/ThornStyle.h"
 #include "misc/Preferences.h"
 
-
 #include <QBrush>
 #include <QColor>
 #include <QEvent>
@@ -154,10 +153,12 @@ CompositionView::CompositionView(RosegardenDocument *doc,
     connect(m_toolBox, &BaseToolBox::showContextHelp,
             this, &CompositionView::slotToolHelpChanged);
 
-    connect(m_model, SIGNAL(needUpdate()),
-            this, SLOT(slotUpdateAll()));
-    connect(m_model, SIGNAL(needUpdate(const QRect&)),
-            this, SLOT(slotAllNeedRefresh(const QRect&)));
+    connect(m_model, (void(CompositionModelImpl::*)())
+                    &CompositionModelImpl::needUpdate,
+            this, &CompositionView::slotUpdateAll);
+    connect(m_model, (void(CompositionModelImpl::*)(const QRect &))
+                    &CompositionModelImpl::needUpdate,
+            this, &CompositionView::slotAllNeedRefresh);
     connect(m_model, &CompositionModelImpl::needArtifactsUpdate,
             this, &CompositionView::slotUpdateArtifacts);
     connect(m_model, &CompositionModelImpl::needSizeUpdate,
@@ -352,6 +353,22 @@ void CompositionView::slotExternalWheelEvent(QWheelEvent *e)
     e->accept();
 }
 
+void CompositionView::slotExternalKeyPressEvent(QKeyEvent *e)
+{
+    // Pass it up to RosegardenScrollView.
+    keyPressEvent(e);
+    // We've got this.  No need to propagate.
+    e->accept();
+}
+
+void CompositionView::slotExternalKeyReleaseEvent(QKeyEvent *e)
+{
+    // Pass it up to RosegardenScrollView.
+    keyReleaseEvent(e);
+    // We've got this.  No need to propagate.
+    e->accept();
+}
+
 void CompositionView::slotUpdateAll()
 {
     Profiler profiler("CompositionView::slotUpdateAll()");
@@ -1099,10 +1116,14 @@ void CompositionView::drawCompRectLabel(
 void CompositionView::drawRect(QPainter *painter, const QRect &clipRect,
         const QRect &rect, bool isSelected, int intersectLvl)
 {
+    RG_DEBUG << "drawRect" << rect << clipRect;
     // If the rect isn't in the clip rect, bail.
     if (!rect.intersects(clipRect))
         return;
 
+    // ignore zero width rectangles
+    if (rect.width() == 0) return;
+
     painter->save();
 
     // Since we do partial updates when scrolling, make sure we don't
@@ -1345,7 +1366,8 @@ void CompositionView::leaveEvent(QEvent *)
     // Ask RosegardenMainWindow to clear the context help in the status bar.
     emit showContextHelp("");
     m_contextHelpShown = false;
-    clearFocus();
+    // no need to clear focus
+    //clearFocus();
 }
 
 void CompositionView::slotToolHelpChanged(const QString &text)
@@ -1370,7 +1392,7 @@ void CompositionView::mousePressEvent(QMouseEvent *e)
     // ??? Would it be better to push this down into the tools?
     if (e->button() == Qt::LeftButton  ||
         e->button() == Qt::MiddleButton)
-        startAutoScroll();
+        m_autoScroller.start();
 
     // Delegate to current tool
     if (m_currentTool)
@@ -1380,7 +1402,7 @@ void CompositionView::mousePressEvent(QMouseEvent *e)
 void CompositionView::mouseReleaseEvent(QMouseEvent *e)
 {
     // In case there is no tool, and auto scroll is running.
-    stopAutoScroll();
+    m_autoScroller.stop();
 
     if (m_currentTool)
         m_currentTool->mouseReleaseEvent(e);;
@@ -1429,7 +1451,7 @@ void CompositionView::mouseMoveEvent(QMouseEvent *e)
 
     // ??? Can we push the rest of this down into the tools?
 
-    setFollowMode(followMode);
+    m_autoScroller.setFollowMode(followMode);
 }
 
 void CompositionView::keyPressEvent(QKeyEvent *e)
