@@ -89,6 +89,8 @@ public:
     /// Scroll in such a way that the track position is visible.
     void makeTrackPosVisible(int trackPos);
 
+    AutoScroller *getAutoScroller()  { return &m_autoScroller; }
+
     // *** Segments
 
     /// Enables/disables display of the text labels on each segment.
@@ -228,6 +230,24 @@ public slots:
      */
     void slotExternalWheelEvent(QWheelEvent *);
 
+    /// Handle TrackButtons scroll key events.
+    /**
+     * Forwards the events to RosegardenScrollView to make sure we are
+     * synced up with TrackButtons.
+     *
+     * @see TrackEditor::m_trackButtonScroll
+     */
+    void slotExternalKeyPressEvent(QKeyEvent *);
+
+    /// Handle TrackButtons scroll key events.
+    /**
+     * Forwards the events to RosegardenScrollView to make sure we are
+     * synced up with TrackButtons.
+     *
+     * @see TrackEditor::m_trackButtonScroll
+     */
+    void slotExternalKeyReleaseEvent(QKeyEvent *);
+
     /// Redraw everything.  Segments and artifacts.
     /**
      * This is called in many places after making changes that affect the
