@@ -20,9 +20,10 @@
 #define RG_SEGMENTSPLITTER_H
 
 #include "SegmentTool.h"
-#include <QString>
-#include "base/Event.h"
 
+#include "base/TimeT.h"
+
+#include <QString>
 
 class QMouseEvent;
 
@@ -30,6 +31,7 @@ class QMouseEvent;
 namespace Rosegarden
 {
 
+
 class Segment;
 class RosegardenDocument;
 class CompositionView;
