@@ -16,6 +16,7 @@
 */
 
 #define RG_MODULE_STRING "[ProjectPackager]"
+#define RG_NO_DEBUG_PRINT
 
 #include "ProjectPackager.h"
 
@@ -90,7 +91,7 @@ RG_DEBUG << "ProjectPackager::ProjectPackager():  mode: " << mode <<
     layout->addWidget(m_progress, 1, 1);
 
     QPushButton *ok = new QPushButton(tr("Cancel"), this);
-    connect(ok, SIGNAL(clicked()), this, SLOT(reject()));
+    connect(ok, &QPushButton::clicked, this, &ProjectPackager::reject);
     layout->addWidget(ok, 3, 1);
 
     sanityCheck();
@@ -554,8 +555,9 @@ ProjectPackager::sanityCheck() {
         puke(tr("<qt><p>The <b>wvunpack</b> command was not found.</p><p>WavPack is an audio compression format used to reduce the size of Rosegarden project packages with no loss of audio quality.  Please install WavPack and try again.  This utility is typically available to most distros as part of a package called \"wavpack\".</p>"));
         return;
     }
-    connect(m_process, SIGNAL(finished(int, QProcess::ExitStatus)),
-            this, SLOT(runPackUnpack(int, QProcess::ExitStatus)));
+    connect(m_process, (void(QProcess::*)(int, QProcess::ExitStatus))
+                    &QProcess::finished,
+            this, &ProjectPackager::runPackUnpack);
 }
 
 void
@@ -599,8 +601,8 @@ RG_DEBUG << "ProjectPackager::runPack()";
     m_packTmpDirName = QString("%1/rosegarden-project-packager-tmp").arg(QDir::homePath());
 
     // the data directory where audio and other files will go
-    QFileInfo fi(m_filename);
-    m_packDataDirName = fi.baseName();
+    QFileInfo fileInfo1(m_filename);
+    m_packDataDirName = fileInfo1.baseName();
 
 RG_DEBUG << "using tmp data directory: " << m_packTmpDirName << "/" <<
     m_packDataDirName;
@@ -614,8 +616,8 @@ RG_DEBUG << "using tmp data directory: " << m_packTmpDirName << "/" <<
     //
     // m_filename comes in already having an .rgp extension, but the file
     // was saved .rg
-    QString oldName = QString("%1/%2.rg").arg(fi.path()).arg(fi.baseName());
-    QString newName = QString("%1/%2.rg").arg(m_packTmpDirName).arg(fi.baseName());
+    QString oldName = QString("%1/%2.rg").arg(fileInfo1.path()).arg(fileInfo1.baseName());
+    QString newName = QString("%1/%2.rg").arg(m_packTmpDirName).arg(fileInfo1.baseName());
 
     // if the tmp directory already exists, just hose it
     rmdirRecursive(m_packTmpDirName);
@@ -850,8 +852,9 @@ ProjectPackager::startAudioEncoder(QStringList files)
     m_process = new QProcess;
     m_process->setWorkingDirectory(m_packTmpDirName);
     m_process->start("bash", QStringList() << scriptName);
-    connect(m_process, SIGNAL(finished(int, QProcess::ExitStatus)),
-            this, SLOT(finishPack(int, QProcess::ExitStatus)));
+    connect(m_process, (void(QProcess::*)(int, QProcess::ExitStatus))
+                    &QProcess::finished,
+            this, &ProjectPackager::finishPack);
 }
 
 void
@@ -1032,9 +1035,9 @@ ProjectPackager::startAudioDecoder(QStringList flacFiles, QStringList wavpackFil
 
     // The working directory must be the key to why tar is not failing, but
     // failing to do anything detectable.  Let's cut apart m_filename...
-    QFileInfo fi(m_filename);
-    QString dirname = fi.path();
-    QString basename = QString("%1.%2").arg(fi.baseName()).arg(fi.completeSuffix());
+    QFileInfo fileInfo1(m_filename);
+    QString dirname = fileInfo1.path();
+    QString basename = QString("%1.%2").arg(fileInfo1.baseName()).arg(fileInfo1.completeSuffix());
 
     // There were mysterious stupid problems running tar xf in a separate
     // QProcess step, so screw it, let's just throw it into this script!
@@ -1088,8 +1091,9 @@ RG_DEBUG << "flad -d " << o1 << " -o " << o2;
     // was apparently the reason why tar always failed to do anything
     m_process->setWorkingDirectory(dirname);
     m_process->start("bash", QStringList() << scriptName);
-    connect(m_process, SIGNAL(finished(int, QProcess::ExitStatus)),
-            this, SLOT(finishUnpack(int, QProcess::ExitStatus)));
+    connect(m_process, (void(QProcess::*)(int, QProcess::ExitStatus))
+                    &QProcess::finished,
+            this, &ProjectPackager::finishUnpack);
 
     // wait up to 30 seconds for process to start
     m_info->setText(tr("Decoding audio files..."));
