@@ -89,6 +89,13 @@ public:
 
     virtual void reconfigure();
 
+    void setActive(bool active);
+    bool active() const;
+
+    // to maintain copy of map key
+    void setXKey(double x) { m_xKey = x; }
+    double xKey() const { return m_xKey; }
+
 protected:
 
     //--------------- Data members ---------------------------------
@@ -107,8 +114,14 @@ protected:
     ControlRuler* m_controlRuler;
     Event* m_event;
 
+    bool m_active;
+
     static const unsigned int BorderThickness;
     static const unsigned int DefaultWidth;
+
+private:
+    // a true copy of the key in the ControlItemMap for efficient item- lookup
+    double m_xKey;
 };
 
 typedef std::multimap<double /* xStart */, QSharedPointer<ControlItem>>
