@@ -18,14 +18,14 @@
 #ifndef RG_CONTROL_MOUSE_EVENT_H
 #define RG_CONTROL_MOUSE_EVENT_H
 
-#include <QPoint>
+#include "ControlItem.h"
+
+#include <Qt>
 
-#include "base/Event.h" // for timeT
 
 namespace Rosegarden
 {
 
-class ControlItem;
 
 class ControlMouseEvent
 {
@@ -56,6 +56,7 @@ public:
         modifiers(e->modifiers), buttons(e->buttons) { }
 };
 
+
 }
 
 #endif
