@@ -65,17 +65,33 @@ ControlMover::handleLeftButtonPress(const ControlMouseEvent *e)
     if (m_overItem) {
         m_ruler->setCursor(Qt::BlankCursor);
 
-        ControlItemVector::const_iterator it = e->itemList.begin();
-        if ((*it)->isSelected()) {
+        bool activeFound = false;
+        ControlItemVector::const_iterator controlItemIter1 = e->itemList.begin();
+        while (controlItemIter1 != e->itemList.end()) {
+            if ((*controlItemIter1)->active()) {
+                activeFound = true;
+                break;
+            }
+            controlItemIter1++;
+        }
+        if (! activeFound) {
+            if (!(e->modifiers & (Qt::ShiftModifier))) {
+                // No add to selection modifiers so clear the current selection
+                m_ruler->clearSelectedItems();
+            }
+            return;
+        }
+
+        if ((*controlItemIter1)->isSelected()) {
             if (e->modifiers & (Qt::ShiftModifier))
-                m_ruler->removeFromSelection(*it);
+                m_ruler->removeFromSelection(*controlItemIter1);
         } else {
             if (!(e->modifiers & (Qt::ShiftModifier))) {
                 // No add to selection modifiers so clear the current selection
                 m_ruler->clearSelectedItems();
             }
 
-            m_ruler->addToSelection(*it);
+            m_ruler->addToSelection(*controlItemIter1);
         }
 
         m_startPointList.clear();
@@ -199,7 +215,14 @@ void ControlMover::setCursor(const ControlMouseEvent *e)
 {
     bool isOverItem = false;
 
-    if (e->itemList.size()) isOverItem = true;
+    ControlItemVector::const_iterator it = e->itemList.begin();
+    while (it != e->itemList.end()) {
+        if ((*it)->active()) {
+            isOverItem = true;
+            break;
+        }
+        it++;
+    }
 
     if (!m_overItem) {
         if (isOverItem) {
