@@ -15,6 +15,9 @@
     COPYING included with this distribution for more information.
 */
 
+#define RG_MODULE_STRING "[ControlPainter]"
+#define RG_NO_DEBUG_PRINT
+
 #include "ControlPainter.h"
 
 #include "base/BaseProperties.h"
@@ -25,7 +28,6 @@
 #include "base/ViewElement.h"
 #include "document/CommandHistory.h"
 #include "ControlItem.h"
-#include "ControlRuler.h"
 #include "ControllerEventsRuler.h"
 #include "ControlTool.h"
 #include "ControlMouseEvent.h"
@@ -56,19 +58,30 @@ ControlPainter::ControlPainter(ControlRuler *parent) :
 void
 ControlPainter::handleLeftButtonPress(const ControlMouseEvent *e)
 {
+    ControllerEventsRuler *ruler1 =
+        static_cast <ControllerEventsRuler*> (m_ruler);
+    float xmin1, xmax1;
+    ruler1->getLimits(xmin1, xmax1);
+    RG_DEBUG << "handleLeftButtonPress limits" << xmin1 << xmax1 << e->x <<
+        e->snappedXLeft << e->snappedXRight;
+    if ((e->x - e->snappedXLeft) > (e->snappedXRight - e->x)) { // using right
+        if (e->snappedXRight < xmin1 || e->snappedXRight >= xmax1) return;
+    } else { // using left
+        if (e->snappedXLeft < xmin1 || e->snappedXLeft >= xmax1) return;
+    }
     if (e->itemList.size()) {
-        ControllerEventsRuler *ruler = static_cast <ControllerEventsRuler*> (m_ruler);
         ControlItemVector::const_iterator it = e->itemList.begin();
-        ruler->clearSelectedItems();
-        ruler->addToSelection(*it);
-        ruler->eraseControllerEvent();
+        ruler1->clearSelectedItems();
+        ruler1->addToSelection(*it);
+        ruler1->eraseControllerEvent();
 
         m_ruler->setCursor(Qt::CrossCursor);
     }
     else {
         // Make new control event here
         // This tool should not be applied to a PropertyControlRuler but in case it is
-        ControllerEventsRuler* ruler = dynamic_cast <ControllerEventsRuler*>(m_ruler);
+        ControllerEventsRuler *ruler =
+                dynamic_cast<ControllerEventsRuler *>(m_ruler);
         //if (ruler) ruler->insertControllerEvent(e->x,e->y);
         if (ruler) {
             double xscale = m_ruler->getXScale();
@@ -104,12 +117,11 @@ ControlPainter::handleLeftButtonPress(const ControlMouseEvent *e)
             } else {
 
                 QSharedPointer<ControlItem> item =
-                        ruler->addControlItem2(x,e->y);
-                // ??? MEMORY LEAK (confirmed)
-                ControlMouseEvent *newevent = new ControlMouseEvent(e);
-                newevent->itemList.push_back(item);
+                        ruler->addControlItem2(x, e->y);
+                ControlMouseEvent newevent(e);
+                newevent.itemList.push_back(item);
                 m_overItem = true;
-                ControlMover::handleLeftButtonPress(newevent);
+                ControlMover::handleLeftButtonPress(&newevent);
             }
 
             // Save these coordinates for next time
