@@ -19,16 +19,18 @@
 #define RG_CONTROLPAINTER_H
 
 #include "ControlMover.h"
-//#include <QString>
-//#include "base/Event.h"
+
+#include <QString>
 
 
 namespace Rosegarden
 {
 
+
 class Event;
 class ControlRuler;
 
+
 class ControlPainter : public ControlMover
 {
     Q_OBJECT
