@@ -16,7 +16,7 @@
 */
 
 #define RG_MODULE_STRING "[ControlRuler]"
-#define RG_NO_DEBUG_PRINT 1
+#define RG_NO_DEBUG_PRINT
 
 #include "ControlRuler.h"
 
@@ -61,41 +61,15 @@ namespace Rosegarden
 {
 
 ControlRuler::ControlRuler(ViewSegment * /*viewsegment*/,
-                           RulerScale* rulerScale,
-                           QWidget* parent) :
+                           RulerScale *rulerScale,
+                           QWidget *parent) :
     QWidget(parent),
     m_rulerScale(rulerScale),
-    m_eventSelection(nullptr),
-    m_viewSegment(nullptr),
-    m_notationStaff(nullptr),
-    m_segment(nullptr),
     m_controlItemMap(),
     m_firstVisibleItem(m_controlItemMap.end()),
     m_lastVisibleItem(m_controlItemMap.end()),
     m_nextItemLeft(m_controlItemMap.end()),
-    m_selectedItems(),
-    m_visibleItems(),
-    m_currentIndex(nullptr),
-    m_currentTool(nullptr),
-    m_currentToolName(),
-    m_pannedRect(),
-    m_xScale(1.0),
-    m_yScale(1.0),
-    m_maxItemValue(127),
-    m_minItemValue(0),
-    m_viewSegmentOffset(0),
-    m_xOffset(0),
-    m_currentX(0.0),
-    m_lastEventPos(),
-    m_itemMoved(false),
-    m_selecting(false),
-    m_selector(nullptr),
-    m_selectionRect(nullptr),
-    m_rulerMenu(nullptr),
-    m_snapName(""),
-    m_snapTimeFromEditor(SnapGrid::NoSnap),
-    //m_hposUpdatePending(false),
-    m_selectedEvents()
+    m_snapTimeFromEditor(SnapGrid::NoSnap)
 {
     setFixedHeight(sizeHint().height());
     setMouseTracking(true);
@@ -104,22 +78,22 @@ ControlRuler::ControlRuler(ViewSegment * /*viewsegment*/,
     connect(m_toolBox, &BaseToolBox::showContextHelp,
             this, &ControlRuler::showContextHelp);
 
-    createAction("snap_none", SLOT(slotSnap()));
-    createAction("snap_editor", SLOT(slotSnap()));
-    createAction("snap_unit", SLOT(slotSnap()));
-    createAction("snap_64", SLOT(slotSnap()));
-    createAction("snap_48", SLOT(slotSnap()));
-    createAction("snap_32", SLOT(slotSnap()));
-    createAction("snap_24", SLOT(slotSnap()));
-    createAction("snap_16", SLOT(slotSnap()));
-    createAction("snap_12", SLOT(slotSnap()));
-    createAction("snap_8", SLOT(slotSnap()));
-    createAction("snap_dotted_8", SLOT(slotSnap()));
-    createAction("snap_4", SLOT(slotSnap()));
-    createAction("snap_dotted_4", SLOT(slotSnap()));
-    createAction("snap_2", SLOT(slotSnap()));
-    createAction("snap_beat", SLOT(slotSnap()));
-    createAction("snap_bar", SLOT(slotSnap()));
+    createAction("snap_none", &ControlRuler::slotSnap);
+    createAction("snap_editor", &ControlRuler::slotSnap);
+    createAction("snap_unit", &ControlRuler::slotSnap);
+    createAction("snap_64", &ControlRuler::slotSnap);
+    createAction("snap_48", &ControlRuler::slotSnap);
+    createAction("snap_32", &ControlRuler::slotSnap);
+    createAction("snap_24", &ControlRuler::slotSnap);
+    createAction("snap_16", &ControlRuler::slotSnap);
+    createAction("snap_12", &ControlRuler::slotSnap);
+    createAction("snap_8", &ControlRuler::slotSnap);
+    createAction("snap_dotted_8", &ControlRuler::slotSnap);
+    createAction("snap_4", &ControlRuler::slotSnap);
+    createAction("snap_dotted_4", &ControlRuler::slotSnap);
+    createAction("snap_2", &ControlRuler::slotSnap);
+    createAction("snap_beat", &ControlRuler::slotSnap);
+    createAction("snap_bar", &ControlRuler::slotSnap);
 
     m_snapGrid = new SnapGrid(m_rulerScale);
     QSettings settings;
@@ -186,12 +160,24 @@ ControlItemMap::iterator ControlRuler::findControlItem(const Event *event)
 
 ControlItemMap::iterator ControlRuler::findControlItem(const ControlItem* item)
 {
-    // Basic loop through until I get the equal_range thing working properly
-    ControlItemMap::iterator it;
-    for (it = m_controlItemMap.begin(); it != m_controlItemMap.end(); ++it) {
-        if (it->second == item) break;
+    double xstart = item->xKey();
+
+    std::pair<ControlItemMap::iterator, ControlItemMap::iterator>
+        range = m_controlItemMap.equal_range(xstart);
+
+    // now find in this range
+    if (range.first != m_controlItemMap.end()) {
+        for(ControlItemMap::iterator it = range.first;
+            it != range.second;
+            ++it) {
+            if (it->second == item) {
+                RG_DEBUG << "findControlItem equal_range1 found item";
+                return it;
+            }
+        }
     }
-    return it;
+
+    return m_controlItemMap.end();
 }
 
 void ControlRuler::addControlItem(QSharedPointer<ControlItem> item)
@@ -201,6 +187,7 @@ void ControlRuler::addControlItem(QSharedPointer<ControlItem> item)
     //RG_DEBUG << "addControlItem(): ControlItem added: " << hex << (long)item;
 
     // ControlItem may not have an assigned event but must have x position
+    item->setXKey(item->xStart());
     ControlItemMap::iterator it =
             m_controlItemMap.insert(
                     ControlItemMap::value_type(item->xStart(), item));
@@ -358,6 +345,7 @@ void ControlRuler::moveItem(ControlItem *item)
 
     removeCheckVisibleLimits(it);
     m_controlItemMap.erase(it);
+    item2->setXKey(item2->xStart());
     it = m_controlItemMap.insert(
             ControlItemMap::value_type(item2->xStart(), item2));
     addCheckVisibleLimits(it);
@@ -400,8 +388,7 @@ void ControlRuler::updateSegment()
 
     QString commandLabel = "Adjust control/property";
 
-    // ??? MEMORY LEAK (confirmed) Probably due to return from middle.
-    MacroCommand *macro = new MacroCommand(commandLabel);
+    std::unique_ptr<MacroCommand> macro(new MacroCommand(commandLabel));
 
     // Find the extent of the selected items
     float xmin=FLT_MAX,xmax=-1.0;
@@ -423,14 +410,12 @@ void ControlRuler::updateSegment()
     start = getRulerScale()->getTimeForX(xmin);
     end = getRulerScale()->getTimeForX(xmax)+durationAdd;
 
-    RG_DEBUG << "updateSegment added events:" <<
-        m_eventSelection->getAddedEvents();
-    if (m_eventSelection->getAddedEvents() == 0) {
+    RG_DEBUG << "updateSegment(): added events" << m_eventSelection->size();
+
+    if (m_eventSelection->size() == 0) {
         // We do not have a valid set of selected events to update
-        if (m_selectedItems.size() == 0) {
-            // There are no selected items, nothing to update
+        if (m_selectedItems.empty())
             return;
-        }
 
         // Events will be added by the controlItem->updateSegment methods
         commandLabel = "Add control";
@@ -449,30 +434,34 @@ void ControlRuler::updateSegment()
         }
     }
 
-    EventSelection *eventsToErase = new EventSelection(*m_segment);
-    if (! allowSimultaneousEvents()) {
+    EventSelection eventsToErase(*m_segment);
+
+    if (!allowSimultaneousEvents()) {
         // check for events at the same time and delete them
         // For each selected item...
         for (QSharedPointer<const ControlItem> cItem : m_selectedItems) {
             const double xItem = cItem->xStart();
-            RG_DEBUG << "updateSegment check for event at" << xItem;
+
+            RG_DEBUG << "updateSegment(): check for event at" << xItem;
+
             // For each control item starting at xItem...
             for (ControlItemMap::const_iterator otherItemIter =
                      m_controlItemMap.lower_bound(xItem);
                  otherItemIter != m_controlItemMap.end();
                  ++otherItemIter) {
+                // ignore inactive items
+                if (! otherItemIter->second->active()) continue;
                 // If this is the same as the item we are checking,
                 // try the next.
                 if (cItem == otherItemIter->second) {
-                    RG_DEBUG << "updateSegment ignoring new item";
+                    RG_DEBUG << "updateSegment(): ignoring new item";
                     continue;
                 }
                 const double xOther = otherItemIter->first;
                 // ??? This should never happen due to lower_bound().
                 //     Can we remove?
                 if (xOther < xItem) {
-                    RG_DEBUG << "updateSegment ignoring" << xOther <<
-                        "before" << xItem;
+                    RG_DEBUG << "updateSegment(): ignoring" << xOther << "before" << xItem;
                     continue;
                 }
                 // If we are past the original item position, we're done.
@@ -480,27 +469,29 @@ void ControlRuler::updateSegment()
                     break;
 
                 // Found a duplicate, add to eventsToErase.
-                RG_DEBUG << "updateSegment erase old event at" << xOther;
+
+                RG_DEBUG << "updateSegment(): erase old event at" << xOther;
+
                 Event *eventToDelete = otherItemIter->second->getEvent();
-                eventsToErase->addEvent(eventToDelete, false);
+                eventsToErase.addEvent(eventToDelete, false);
             }
         }
     }
 
+    RG_DEBUG << "updateSegment(): selectedItems:" << m_selectedItems.size();
+
     // Add change command to macro
     // ControlChangeCommand calls each selected items updateSegment method
     // Note that updateSegment deletes and renews the event whether it has moved or not
-    RG_DEBUG << "updateSegment selectedItems:" << m_selectedItems.size();
     macro->addCommand(new ControlChangeCommand(m_selectedItems,
                                                *m_segment,
                                                start,
                                                end));
 
-    if (eventsToErase->getAddedEvents() != 0) {
-        macro->addCommand(new EraseCommand(eventsToErase));
-    }
+    if (eventsToErase.size() != 0)
+        macro->addCommand(new EraseCommand(&eventsToErase));
 
-    CommandHistory::getInstance()->addCommand(macro);
+    CommandHistory::getInstance()->addCommand(macro.release());
 
     updateSelection();
 }
@@ -602,7 +593,7 @@ void ControlRuler::paintEvent(QPaintEvent * /*event*/)
             double width = x1 - x0;
 
             double gridLines = double(timeSig.getBarDuration()) /
-                double(m_snapGrid->getSnapTime(x0));
+                double(m_snapGrid->getSnapTimeForX(x0));
 
             double dx = width / gridLines;
             double x = x0;
@@ -752,11 +743,11 @@ ControlMouseEvent ControlRuler::createControlMouseEvent(QMouseEvent* e)
     controlMouseEvent.snappedXRight =
         m_rulerScale->getXForTime(rightTime) * m_xScale;
 
-    RG_DEBUG << "createControlMouseEvent snap" <<
-        controlMouseEvent.x << mtime <<
-        controlMouseEvent.snappedXLeft << leftTime <<
-        controlMouseEvent.snappedXRight << rightTime <<
-        m_xScale;
+    //RG_DEBUG << "createControlMouseEvent(): snap" <<
+    //    controlMouseEvent.x << mtime <<
+    //    controlMouseEvent.snappedXLeft << leftTime <<
+    //    controlMouseEvent.snappedXRight << rightTime <<
+    //    m_xScale;
 
     for (ControlItemList::iterator it = m_visibleItems.begin();
             it != m_visibleItems.end(); ++it) {
@@ -790,7 +781,8 @@ void ControlRuler::mousePressEvent(QMouseEvent* e)
         }
     }
 
-    emit mousePress();
+    if (m_autoScroller)
+        m_autoScroller->start();
 }
 
 void ControlRuler::createRulerMenu()
@@ -807,7 +799,8 @@ void ControlRuler::mouseReleaseEvent(QMouseEvent* e)
         m_currentTool->handleMouseRelease(&controlMouseEvent);
     }
 
-    emit mouseRelease();
+    if (m_autoScroller)
+        m_autoScroller->stop();
 }
 
 void ControlRuler::mouseMoveEvent(QMouseEvent* e)
@@ -816,9 +809,12 @@ void ControlRuler::mouseMoveEvent(QMouseEvent* e)
         return;
 
     ControlMouseEvent controlMouseEvent = createControlMouseEvent(e);
+    // ??? Isn't this always FOLLOW_HORIZONTAL?  I don't think we can
+    //     scroll anything vertically within the control rulers.
     FollowMode mode = m_currentTool->handleMouseMove(&controlMouseEvent);
 
-    emit mouseMove(mode);
+    if (m_autoScroller)
+        m_autoScroller->setFollowMode(mode);
 }
 
 void
