@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -24,6 +24,7 @@
 #include "ControlRulerTabBar.h"
 #include "ControllerEventsRuler.h"
 #include "PropertyControlRuler.h"
+#include "KeyPressureRuler.h"
 
 #include "base/BaseProperties.h"
 #include "base/Composition.h"
@@ -35,7 +36,6 @@
 #include "base/MidiTypes.h"  // for PitchBend::EventType
 #include "base/PropertyName.h"
 #include "document/RosegardenDocument.h"
-#include "gui/application/RosegardenMainWindow.h"
 #include "base/Segment.h"
 #include "base/Selection.h"  // for EventSelection
 #include "base/parameterpattern/SelectionSituation.h"
@@ -55,13 +55,6 @@ namespace Rosegarden
 
 
 ControlRulerWidget::ControlRulerWidget() :
-    m_viewSegment(nullptr),
-    m_controlRulerList(),
-    m_scale(nullptr),
-    m_leftMargin(0),
-    m_currentToolName(),
-    m_pannedRect(),
-    m_selectedElements(),
     m_editorSnap(SnapGrid::NoSnap)
 {
     QVBoxLayout *layout = new QVBoxLayout;
@@ -204,6 +197,12 @@ ControlRulerWidget::launchRulers()
         } else if (ruler.type == PitchBend::EventType) {
             RG_DEBUG << "launchInitialRulers(): Launching pitchbend ruler";
             addControlRuler(ControlParameter::getPitchBend());
+        } else if (ruler.type == ChannelPressure::EventType) {
+            RG_DEBUG << "launchInitialRulers(): Launching channelpressure ruler";
+            addControlRuler(ControlParameter::getChannelPressure());
+        } else if (ruler.type == KeyPressure::EventType) {
+            RG_DEBUG << "launchInitialRulers(): Launching keypressure ruler";
+            addControlRuler(ControlParameter::getKeyPressure());
         } else if (ruler.type == BaseProperties::VELOCITY.getName()) {
             RG_DEBUG << "launchInitialRulers(): Launching velocity ruler";
             addPropertyRuler(static_cast<PropertyName>(ruler.type));
@@ -267,46 +266,9 @@ ControlRulerWidget::togglePropertyRuler(const PropertyName &propertyName)
     addPropertyRuler(propertyName);
 }
 
-namespace
-{
-    bool hasPitchBend(Segment *segment)
-    {
-        RosegardenDocument *document = RosegardenDocument::currentDocument;
-
-        Track *track =
-                document->getComposition().getTrackById(segment->getTrack());
-
-        Instrument *instrument = document->getStudio().
-            getInstrumentById(track->getInstrument());
-
-        if (!instrument)
-            return false;
-
-        const Controllable *controllable = instrument->getDevice()->getControllable();
-
-        if (!controllable)
-            return false;
-
-        // Check whether the device has a pitchbend controller
-        // ??? Why not use
-        //     Controllable::getControlParameter(type, controllerNumber)?
-        for (const ControlParameter &cp : controllable->getControlParameters()) {
-            if (cp.getType() == PitchBend::EventType)
-                return true;
-        }
-
-        return false;
-    }
-}
-
 void
 ControlRulerWidget::togglePitchBendRuler()
 {
-    // No pitch bend?  Bail.
-    // ??? Rude.  We should gray the menu item instead of this.
-    if (!hasPitchBend(&(m_viewSegment->getSegment())))
-        return;
-
     // Check whether we already have a pitchbend ruler
 
     // For each ruler...
@@ -331,6 +293,61 @@ ControlRulerWidget::togglePitchBendRuler()
     addControlRuler(ControlParameter::getPitchBend());
 }
 
+void
+ControlRulerWidget::toggleChannelPressureRuler()
+{
+    // Check whether we already have a channel pressure ruler
+
+    // For each ruler...
+    for (ControlRuler *ruler : m_controlRulerList) {
+        ControllerEventsRuler *eventRuler =
+                dynamic_cast<ControllerEventsRuler*>(ruler);
+
+        // Not a ControllerEventsRuler?  Try the next one.
+        if (!eventRuler)
+            continue;
+
+        // If we already have a ruler, remove it.
+        if (eventRuler->getControlParameter()->getType() ==
+            ChannelPressure::EventType)
+        {
+            removeRuler(ruler);
+            return;
+        }
+    }
+
+    // We don't already have a ruler, make one now.
+    addControlRuler(ControlParameter::getChannelPressure());
+}
+
+void
+ControlRulerWidget::toggleKeyPressureRuler()
+{
+    // Check whether we already have a key pressure ruler
+
+    // For each ruler...
+    for (ControlRuler *ruler : m_controlRulerList) {
+        ControllerEventsRuler *eventRuler =
+                dynamic_cast<ControllerEventsRuler*>(ruler);
+
+        // Not a ControllerEventsRuler?  Try the next one.
+        if (!eventRuler)
+            continue;
+
+        // If we already have a ruler, remove it.
+        if (eventRuler->getControlParameter()->getType() ==
+            KeyPressure::EventType)
+        {
+            removeRuler(ruler);
+            return;
+        }
+    }
+
+    // We don't already have a ruler, make one now.
+    addControlRuler(ControlParameter::getKeyPressure());
+}
+
+
 namespace
 {
     // Non-O-O approach.  This could be pushed into ControlRuler
@@ -438,19 +455,20 @@ ControlRulerWidget::addControlRuler(const ControlParameter &controlParameter)
     if (!m_viewSegment)
         return;
 
-    ControlRuler *controlRuler = new ControllerEventsRuler(
-            m_viewSegment, m_scale, this, &controlParameter);
+    ControlRuler *controlRuler;
+    if (controlParameter == ControlParameter::getKeyPressure()) {
+        KeyPressureRuler *keyPressureRuler = new KeyPressureRuler(
+                m_viewSegment, m_scale, this, &controlParameter);
+        keyPressureRuler->setElementSelection(m_selectedElements);
+        controlRuler = keyPressureRuler;
+    } else {
+        controlRuler = new ControllerEventsRuler(
+                m_viewSegment, m_scale, this, &controlParameter);
+    }
 
+    controlRuler->setAutoScroller(m_autoScroller);
     controlRuler->setXOffset(m_leftMargin);
 
-    // Mouse signals.  Forward them from the current ControlRuler.
-    connect(controlRuler, &ControlRuler::mousePress,
-            this, &ControlRulerWidget::mousePress);
-    connect(controlRuler, &ControlRuler::mouseMove,
-            this, &ControlRulerWidget::mouseMove);
-    connect(controlRuler, &ControlRuler::mouseRelease,
-            this, &ControlRulerWidget::mouseRelease);
-
     connect(controlRuler, &ControlRuler::rulerSelectionChanged,
             this, &ControlRulerWidget::slotChildRulerSelectionChanged);
 
@@ -547,11 +565,13 @@ ControlRulerWidget::slotSelectionChanged(EventSelection *eventSelection)
             ViewElementList::iterator viewElementIter =
                     m_viewSegment->findEvent(event);
             // Add it to m_selectedElements.
-            m_selectedElements.push_back(*viewElementIter);
+            if (viewElementIter != m_viewSegment->getViewElementList()->end())
+                m_selectedElements.push_back(*viewElementIter);
         }
     }
 
     // Send new selection to all PropertyControlRulers.  IOW the velocity ruler.
+    // Also the KeyPressureRuler needs the element selection
     // For each ruler...
     for (ControlRuler *ruler : m_controlRulerList) {
         PropertyControlRuler *propertyRuler =
@@ -559,7 +579,14 @@ ControlRulerWidget::slotSelectionChanged(EventSelection *eventSelection)
         // Is this the velocity ruler?  Then pass on the selection.
         if (propertyRuler)
             propertyRuler->updateSelection(m_selectedElements);
+
+        KeyPressureRuler *keyPressureRuler =
+            dynamic_cast<KeyPressureRuler *>(ruler);
+        if (keyPressureRuler)
+            keyPressureRuler->setElementSelection(m_selectedElements);
     }
+
+    //
 }
 
 void
