@@ -20,14 +20,15 @@
 #define RG_LOOPRULER_H
 
 #include "base/SnapGrid.h"
-//#include "base/Event.h"
 
+#include <QPen>
+#include <QPointer>
 #include <QSize>
 #include <QWidget>
-#include <QPen>
 
 class QPaintEvent;
 class QPainter;
+class QMainWindow;
 class QMouseEvent;
 
 
@@ -35,6 +36,7 @@ namespace Rosegarden
 {
 
 
+class AutoScroller;
 class RulerScale;
 class RosegardenDocument;
 
@@ -59,6 +61,13 @@ public:
               QWidget *parent);
     ~LoopRuler() override;
 
+    void setAutoScroller(QPointer<AutoScroller> autoScroller)
+            { m_autoScroller = autoScroller; }
+
+    /// For status text.
+    void setMainWindow(QPointer<QMainWindow> mainWindow)
+            { m_mainWindow = mainWindow; }
+
     void setSnapGrid(const SnapGrid *grid);
 
     QSize sizeHint() const override;
@@ -93,11 +102,6 @@ signals:
      */
     void setPlayPosition(timeT);
 
-    // These signals are used by Notation, Matrix, and the Segment Canvas
-    // for auto scroll.
-    void startMouseMove(int directionConstraint);
-    void stopMouseMove();
-
 protected:
 
     // QWidget overrides
@@ -114,6 +118,7 @@ private slots:
 
 private:
 
+    QMainWindow *m_mainWindow{nullptr};
     RosegardenDocument *m_doc;
 
     /**
@@ -142,8 +147,10 @@ private:
     RulerScale *m_rulerScale;
     void drawBarSections(QPainter *);
 
+    // Default grid in case the client doesn't supply one.
     SnapGrid m_defaultGrid;
     SnapGrid *m_loopGrid;
+    // Grid sent in by the client via setSnapGrid().
     const SnapGrid *m_grid;
 
     /// Whether we are dragging and drawing a loop.
@@ -157,6 +164,8 @@ private:
     /// between loop positions
     void drawLoopMarker(QPainter *);
 
+    QPointer<AutoScroller> m_autoScroller;
+
 };
 
 
