@@ -4,7 +4,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -24,7 +24,6 @@
 #include <QSharedPointer>
 #include <QSize>
 
-
 class QWidget;
 class QPaintEvent;
 class QMouseEvent;
@@ -32,10 +31,13 @@ class QFontMetrics;
 class QFont;
 class QEvent;
 
+#include <memory>
+
 
 namespace Rosegarden
 {
 
+
 class MidiKeyMapping;
 
 
@@ -81,8 +83,8 @@ protected:
     int                       m_highlightPitch;
     int                       m_lastHighlightPitch;
 
-    QFont                    *m_font;
-    QFontMetrics             *m_fontMetrics;
+    std::unique_ptr<QFont> m_font;
+    std::unique_ptr<QFontMetrics> m_fontMetrics;
 };
 
 
