@@ -19,13 +19,19 @@
 #ifndef RG_STANDARDRULER_H
 #define RG_STANDARDRULER_H
 
+#include "base/TimeT.h"
+
+#include <QPointer>
 #include <QWidget>
-#include "base/Event.h"
+
+class QMainWindow;
+
 
 namespace Rosegarden
 {
 
 
+class AutoScroller;
 class RulerScale;
 class RosegardenDocument;
 class LoopRuler;
@@ -41,13 +47,15 @@ class StandardRuler : public QWidget
 public:
     StandardRuler(RosegardenDocument *doc,
                   RulerScale *rulerScale,
-                  bool invert = false, // draw upside-down
+                  bool invert,  // draw upside-down for bottom rulers
                   bool isForMainWindow = false,
-                  QWidget* parent = nullptr);
+                  QWidget *parent = nullptr);
 
     void setSnapGrid(const SnapGrid *grid);
+    void setMainWindow(QPointer<QMainWindow> mainWindow);
+    void setAutoScroller(QPointer<AutoScroller> autoScroller);
 
-    LoopRuler* getLoopRuler() { return m_loopRuler; }
+    LoopRuler *getLoopRuler()  { return m_loopRuler; }
 
     /**
      * Make connections from the LoopRuler to the document's
@@ -55,7 +63,7 @@ public:
      * If you don't call this, you'll have to connect the
      * LoopRuler's signals up to something yourself.
      */
-    void connectRulerToDocPointer(RosegardenDocument *doc);
+    void setDocument(RosegardenDocument *doc);
     
     void setMinimumWidth(int width);
 
@@ -74,18 +82,17 @@ signals:
     void dragPointerToPosition(timeT);
 
 private:
-    //--------------- Data members ---------------------------------
+
     bool m_invert;
-    bool m_isForMainWindow;
     int m_currentXOffset;
 
-    RosegardenDocument       *m_doc;
+    RosegardenDocument *m_doc;
     RulerScale *m_rulerScale;
 
     MarkerRuler *m_markerRuler;
     LoopRuler *m_loopRuler;
-};
 
+};
 
 
 }
