@@ -16,6 +16,7 @@
 */
 
 #define RG_MODULE_STRING "[AudioMixerWindow2]"
+#define RG_NO_DEBUG_PRINT
 
 #include "AudioMixerWindow2.h"
 
@@ -27,21 +28,27 @@
 #include "gui/general/IconLoader.h"
 #include "base/Instrument.h"
 #include "base/InstrumentStaticSignals.h"
+#include "base/RecordIn.h"
+#include "sound/MappedCommon.h"
 #include "sound/MappedEvent.h"
+#include "sound/MappedStudio.h"
 #include "sound/Midi.h"
 #include "document/RosegardenDocument.h"
 #include "gui/application/RosegardenMainWindow.h"
+#include "gui/studio/StudioControl.h"
 #include "base/Studio.h"
 
 #include <QDesktopServices>
 #include <QHBoxLayout>
+#include <QMessageBox>
+
 
 namespace Rosegarden
 {
 
 
-AudioMixerWindow2::AudioMixerWindow2(QWidget *parent) :
-        QMainWindow(parent),
+AudioMixerWindow2::AudioMixerWindow2() :
+        QMainWindow(RosegardenMainWindow::self()),
         m_centralWidget(new QWidget),
         m_layout(new QHBoxLayout(m_centralWidget)),
         m_masterStrip(new AudioStrip(this, 0))
@@ -73,57 +80,67 @@ AudioMixerWindow2::AudioMixerWindow2(QWidget *parent) :
             this, &AudioMixerWindow2::slotControlChange);
 
     // File > Close
-    createAction("file_close", SLOT(slotClose()));
+    createAction("file_close", &AudioMixerWindow2::slotClose);
 
     // Transport Menu
-    createAction("play", RosegardenMainWindow::self(), SLOT(slotPlay()));
-    createAction("stop", RosegardenMainWindow::self(), SLOT(slotStop()));
-    createAction("playback_pointer_back_bar", RosegardenMainWindow::self(), SLOT(slotRewind()));
-    createAction("playback_pointer_forward_bar", RosegardenMainWindow::self(), SLOT(slotFastforward()));
-    createAction("playback_pointer_start", RosegardenMainWindow::self(), SLOT(slotRewindToBeginning()));
-    createAction("playback_pointer_end", RosegardenMainWindow::self(), SLOT(slotFastForwardToEnd()));
-    createAction("record", RosegardenMainWindow::self(), SLOT(slotRecord()));
-    createAction("panic", RosegardenMainWindow::self(), SLOT(slotPanic()));
+    createAction("play", RosegardenMainWindow::self(),
+                 &RosegardenMainWindow::slotPlay);
+    createAction("stop", RosegardenMainWindow::self(),
+                 &RosegardenMainWindow::slotStop);
+    createAction("playback_pointer_back_bar", RosegardenMainWindow::self(),
+                 &RosegardenMainWindow::slotRewind);
+    createAction("playback_pointer_forward_bar", RosegardenMainWindow::self(),
+                 &RosegardenMainWindow::slotFastforward);
+    createAction("playback_pointer_start", RosegardenMainWindow::self(),
+                 &RosegardenMainWindow::slotRewindToBeginning);
+    createAction("playback_pointer_end", RosegardenMainWindow::self(),
+                 &RosegardenMainWindow::slotFastForwardToEnd);
+    createAction("record", RosegardenMainWindow::self(),
+                 &RosegardenMainWindow::slotRecord);
+    createAction("panic", RosegardenMainWindow::self(),
+                 &RosegardenMainWindow::slotPanic);
 
     // "Settings > Number of Stereo Inputs" Actions
     // For i in {1,2,4,8,16}
     for (int i = 1; i <= 16; i *= 2) {
         createAction(QString("inputs_%1").arg(i),
-                     SLOT(slotNumberOfStereoInputs()));
+                     &AudioMixerWindow2::slotNumberOfStereoInputs);
     }
 
     // "Settings > Number of Submasters" Actions
-    createAction("submasters_0", SLOT(slotNumberOfSubmasters()));
-    createAction("submasters_2", SLOT(slotNumberOfSubmasters()));
-    createAction("submasters_4", SLOT(slotNumberOfSubmasters()));
-    createAction("submasters_8", SLOT(slotNumberOfSubmasters()));
+    createAction("submasters_0", &AudioMixerWindow2::slotNumberOfSubmasters);
+    createAction("submasters_2", &AudioMixerWindow2::slotNumberOfSubmasters);
+    createAction("submasters_4", &AudioMixerWindow2::slotNumberOfSubmasters);
+    createAction("submasters_8", &AudioMixerWindow2::slotNumberOfSubmasters);
 
     // "Settings > Panning Law" Actions
     // ??? Can we do something easier to understand than panlaw_0,
     //     panlaw_1, etc...?  E.g. panlaw_0dB, panlaw_-3dB, panlaw_-6dB,
     //     panlaw_alt-3dB.
-    createAction("panlaw_0", SLOT(slotPanningLaw()));
-    createAction("panlaw_1", SLOT(slotPanningLaw()));
-    createAction("panlaw_2", SLOT(slotPanningLaw()));
-    createAction("panlaw_3", SLOT(slotPanningLaw()));
+    createAction("panlaw_0", &AudioMixerWindow2::slotPanningLaw);
+    createAction("panlaw_1", &AudioMixerWindow2::slotPanningLaw);
+    createAction("panlaw_2", &AudioMixerWindow2::slotPanningLaw);
+    createAction("panlaw_3", &AudioMixerWindow2::slotPanningLaw);
 
     // Settings > Show Audio Faders
-    createAction("show_audio_faders", SLOT(slotShowAudioFaders()));
+    createAction("show_audio_faders", &AudioMixerWindow2::slotShowAudioFaders);
 
     // Settings > Show Synth Faders
-    createAction("show_synth_faders", SLOT(slotShowSynthFaders()));
+    createAction("show_synth_faders", &AudioMixerWindow2::slotShowSynthFaders);
 
     // Settings > Show Audio Submasters
-    createAction("show_audio_submasters", SLOT(slotShowAudioSubmasters()));
+    createAction("show_audio_submasters",
+                 &AudioMixerWindow2::slotShowAudioSubmasters);
 
     // Settings > Show Unassigned Faders
-    createAction("show_unassigned_faders", SLOT(slotShowUnassignedFaders()));
+    createAction("show_unassigned_faders",
+                 &AudioMixerWindow2::slotShowUnassignedFaders);
 
     // Help > Help
-    createAction("mixer_help", SLOT(slotHelp()));
+    createAction("mixer_help", &AudioMixerWindow2::slotHelp);
 
     // Help > About Rosegarden
-    createAction("help_about_app", SLOT(slotAboutRosegarden()));
+    createAction("help_about_app", &AudioMixerWindow2::slotAboutRosegarden);
 
     createMenusAndToolbars("mixer.rc");
 
@@ -142,6 +159,12 @@ AudioMixerWindow2::AudioMixerWindow2(QWidget *parent) :
     updateWidgets();
 
     show();
+
+    // ??? Ideally, we need to allow resizing, scale the controls, and
+    //     store/restore the window size on close/open.
+    //     MMW needs this ability as well.
+    setFixedSize(geometry().size());
+
 }
 
 AudioMixerWindow2::~AudioMixerWindow2()
@@ -156,14 +179,14 @@ AudioMixerWindow2::updateStripCounts()
 
     // Verify Input Strips
 
-    InstrumentList instruments = studio.getPresentationInstruments();
+    InstrumentVector instruments = studio.getPresentationInstruments();
     std::vector<InstrumentId> instrumentIds;
 
     // For each instrument
-    for (InstrumentList::iterator i = instruments.begin();
+    for (InstrumentVector::iterator i = instruments.begin();
          i != instruments.end();
          ++i) {
-        Instrument *instrument = *i;
+        const Instrument *instrument = *i;
 
         // Not audio or softsynth, try the next.
         if (instrument->getType() != Instrument::Audio  &&
@@ -272,9 +295,14 @@ AudioMixerWindow2::updateStripCounts()
     // If either Strip count was wrong, recreate the layout.
     if (recreateLayout) {
         // Remove the widgets from the layout.
-        while (m_layout->takeAt(0) != nullptr) {
-            // Do nothing.  Normally, we might delete the child widgets.
-            // But we're about to re-add them below.
+        while (true) {
+            QLayoutItem *layoutItem = m_layout->takeAt(0);
+            if (!layoutItem)
+                break;
+
+            // Keep the child widgets as we will reuse them below.
+
+            delete layoutItem;
         }
 
         // Add the input strips
@@ -377,18 +405,55 @@ AudioMixerWindow2::slotNumberOfStereoInputs()
         return;
 
     QString name = action->objectName();
+    RG_DEBUG << "slotNumberOfStereoInputs" << name;
 
     // Not the expected action name?  Bail.
     if (name.left(7) != "inputs_")
         return;
 
     // Extract the number of inputs from the action name.
-    unsigned count = name.mid(7).toUInt();
+    const unsigned recordInCount = name.mid(7).toUInt();
 
     RosegardenDocument *doc = RosegardenDocument::currentDocument;
     Studio &studio = doc->getStudio();
 
-    studio.setRecordInCount(count);
+    // Check for instruments pointing to record inputs that are now invalid.
+
+    const Studio::InvalidInstrumentVector invalidInstruments =
+                studio.getRecordInInvalid(recordInCount);
+
+    // If we've got some instruments pointing to invalid inputs....
+    if (invalidInstruments.size() > 0) {
+        QString warnText = tr("The following instruments are using inputs you are removing:\n");
+        int lineCount{0};
+        for (const Studio::InvalidInstrument &invalidInstrument :
+             invalidInstruments) {
+            warnText += tr("  %1 : input %2\n").
+                    arg(invalidInstrument.instrument->getName().c_str()).
+                    arg(invalidInstrument.id);
+            // Limit the list.
+            if (++lineCount == 30) {
+                warnText += "  ...\n";
+                break;
+            }
+        }
+        warnText += tr("These will be set to input 1.  Are you sure?");
+        QMessageBox::StandardButton reply =
+            QMessageBox::warning(this,
+                                 tr("Rosegarden"),
+                                 warnText,
+                                 QMessageBox::Ok | QMessageBox::Cancel,
+                                 QMessageBox::Cancel);
+        if (reply == QMessageBox::Cancel) {
+            updateWidgets(); // to reset the active menu item
+            return;
+        }
+
+        studio.fixRecordIns(recordInCount);
+
+    }
+
+    studio.setRecordInCount(recordInCount);
 
     // Set the mapped IDs for the RecordIns.
     // ??? Overkill?  Can we do better?
@@ -406,19 +471,56 @@ AudioMixerWindow2::slotNumberOfSubmasters()
         return;
 
     QString name = action->objectName();
+    RG_DEBUG << "slotNumberOfSubmasters" << name;
 
     // Not the expected action name?  Bail.
     if (name.left(11) != "submasters_")
         return;
 
     // Extract the count from the name.
-    int count = name.mid(11).toInt();
+    const int submasterCount = name.mid(11).toInt();
+
+    // check for submasters in use
 
     RosegardenDocument *doc = RosegardenDocument::currentDocument;
     Studio &studio = doc->getStudio();
 
+    const Studio::InvalidInstrumentVector invalidInstruments =
+            studio.getSubmasterInvalid(submasterCount);
+    if (invalidInstruments.size() > 0) {
+        QString warnText =
+            tr("The following instruments are using submasters you are removing:\n");
+        int lineCount{0};
+        for (const Studio::InvalidInstrument &invalidInstrument :
+             invalidInstruments) {
+            std::string iname = invalidInstrument.instrument->getName();
+            warnText += tr("  %1 : submaster %2\n").
+                    arg(QString(iname.c_str())).
+                    arg(invalidInstrument.id);
+            // Limit the list.
+            if (++lineCount == 30) {
+                warnText += "  ...\n";
+                break;
+            }
+        }
+        warnText += tr("Outputs will be set to master and inputs will be set to input 1.\nAre you sure?");
+        QMessageBox::StandardButton reply =
+            QMessageBox::warning(this,
+                                 tr("Rosegarden"),
+                                 warnText,
+                                 QMessageBox::Ok | QMessageBox::Cancel,
+                                 QMessageBox::Cancel);
+        if (reply == QMessageBox::Cancel) {
+            updateWidgets(); // to reset the active menu item
+            return;
+        }
+
+        studio.fixSubmasters(submasterCount);
+
+    }
+
     // Add one for the master buss.
-    studio.setBussCount(count + 1);
+    studio.setBussCount(submasterCount + 1);
 
     doc->initialiseStudio();
 
@@ -557,16 +659,17 @@ AudioMixerWindow2::slotExternalController(const MappedEvent *event)
 }
 
 void
-AudioMixerWindow2::slotControlChange(Instrument *instrument, int cc)
+AudioMixerWindow2::slotControlChange(Instrument *instrument, int controllerNumber)
 {
     InstrumentId instrumentId = instrument->getId();
 
     // for each input strip
-    // ??? Performance: LINEAR SEARCH.  std::map<id, strip> might be better.
+    // ??? Performance: LINEAR SEARCH.  std::map<InstrumentId, stripIndex>
+    //     might be better.  See MidiMixerWindow::m_instrumentIDToStripIndex.
     for (unsigned i = 0; i < m_inputStrips.size(); ++i) {
         // If this is the one
         if (m_inputStrips[i]->getId() == instrumentId) {
-            m_inputStrips[i]->controlChange(cc);
+            m_inputStrips[i]->controlChange(controllerNumber);
             break;
         }
     }
