@@ -4,7 +4,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -20,8 +20,8 @@
 #define RG_AUDIOPLUGINOSCGUIMANAGER_H
 
 #include "base/MidiProgram.h"
+#include "base/Instrument.h"
 #include "sound/RingBuffer.h"
-#include "gui/application/RosegardenMainWindow.h"
 
 #include <QString>
 #include <QCoreApplication>
@@ -33,6 +33,7 @@
 namespace Rosegarden
 {
 
+
 class TimerCallbackAssistant;
 class Studio;
 class RosegardenMainWindow;
