@@ -221,21 +221,21 @@ void
 BankEditorDialog::setupActions()
 {
     // File
-    createAction("file_import", SLOT(slotImport()));
-    createAction("file_export", SLOT(slotExport()));
-    createAction("file_close", SLOT(slotFileClose()));
+    createAction("file_import", &BankEditorDialog::slotImport);
+    createAction("file_export", &BankEditorDialog::slotExport);
+    createAction("file_close", &BankEditorDialog::slotFileClose);
 
     // Edit
-    createAction("add_bank", SLOT(slotAddBank()));
-    createAction("add_key_mapping", SLOT(slotAddKeyMapping()));
-    createAction("edit_copy", SLOT(slotCopy()));
-    createAction("edit_paste", SLOT(slotPaste()));
-    createAction("edit_delete", SLOT(slotDelete()));
-    createAction("edit_delete_all", SLOT(slotDeleteAll()));
+    createAction("add_bank", &BankEditorDialog::slotAddBank);
+    createAction("add_key_mapping", &BankEditorDialog::slotAddKeyMapping);
+    createAction("edit_copy", &BankEditorDialog::slotCopy);
+    createAction("edit_paste", &BankEditorDialog::slotPaste);
+    createAction("edit_delete", &BankEditorDialog::slotDelete);
+    createAction("edit_delete_all", &BankEditorDialog::slotDeleteAll);
 
     // Help
-    createAction("bank_help", SLOT(slotHelpRequested()));
-    createAction("help_about_app", SLOT(slotHelpAbout()));
+    createAction("bank_help", &BankEditorDialog::slotHelpRequested);
+    createAction("help_about_app", &BankEditorDialog::slotHelpAbout);
 
     createMenusAndToolbars("bankeditor.rc");
 }
@@ -321,9 +321,9 @@ BankEditorDialog::updateDialog()
     //       cleared it.  That's very helpful.
     m_treeWidget->clear();
 
-    MidiDeviceTreeWidgetItem *selectDeviceItem{nullptr};
+    MidiDeviceTreeWidgetItem *selectDeviceItem2{nullptr};
 
-    DeviceList *devices = m_studio->getDevices();
+    DeviceVector *devices = m_studio->getDevices();
 
     // For each Device in the Studio...
     for (Device *device : *devices) {
@@ -359,7 +359,7 @@ BankEditorDialog::updateDialog()
         // Is this the parent Device item of the selected item?
         // Save it if so.
         if (deviceItem->getDevice() == parentDevice)
-            selectDeviceItem = deviceItem;
+            selectDeviceItem2 = deviceItem;
     }
 
     m_treeWidget->blockSignals(false);
@@ -373,22 +373,22 @@ BankEditorDialog::updateDialog()
         return;
 
     // Device is gone?  No selection.
-    if (!selectDeviceItem)
+    if (!selectDeviceItem2)
         return;
 
     // The device itself is selected?
     if (selectedType == SelectedType::DEVICE) {
-        m_treeWidget->setCurrentItem(selectDeviceItem);
+        m_treeWidget->setCurrentItem(selectDeviceItem2);
         return;
     }
 
     // Bank or Keymap?
     if (selectedType == SelectedType::BANK  ||
         selectedType == SelectedType::KEYMAP) {
-        int childCount = selectDeviceItem->childCount();
+        int childCount = selectDeviceItem2->childCount();
         // For each child (bank and key map) of the selected Device item...
         for (int i=0; i < childCount; ++i) {
-            QTreeWidgetItem *childItem = selectDeviceItem->child(i);
+            QTreeWidgetItem *childItem = selectDeviceItem2->child(i);
 
             // ??? This is polymorphism like above.  Express this in the
             //     class hierarchy so we can reduce this to a single "if":
@@ -419,10 +419,10 @@ BankEditorDialog::updateDialog()
             }
         }
 
-        RG_DEBUG << "updateDialog() punting, going with device" << selectDeviceItem->getName();
+        RG_DEBUG << "updateDialog() punting, going with device" << selectDeviceItem2->getName();
 
         // No suitable child item found - select device.
-        m_treeWidget->setCurrentItem(selectDeviceItem);
+        m_treeWidget->setCurrentItem(selectDeviceItem2);
     }
 }
 
