@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -394,7 +394,7 @@ DeviceManagerDialog::updateDevicesList
     QString outPort;
     QList < MidiDevice * >midiDevices;
 
-    DeviceList *devices = m_studio->getDevices();
+    DeviceVector *devices = m_studio->getDevices();
 
     // observe any devices we are not yet observing
     for(Device* device : *devices) {
@@ -738,16 +738,16 @@ DeviceManagerDialog::updatePortsList(QTreeWidget * treeWid,
 
     // create a list of all listed portNames
     int cnt = treeWid->topLevelItemCount();
-    int i = 0;
-    while (i < cnt) {
-        twItem = treeWid->topLevelItem(i);
+    int itemIndex = 0;
+    while (itemIndex < cnt) {
+        twItem = treeWid->topLevelItem(itemIndex);
 
         portName = twItem->text(0);
 
         if (!portNamesAvail.contains(portName)) {
             // port disappeared, remove entry
 
-            twItem = treeWid->takeTopLevelItem(i); // remove list entry
+            twItem = treeWid->takeTopLevelItem(itemIndex); // remove list entry
             //
             delete(twItem);
             cnt = treeWid->topLevelItemCount(); // update count
@@ -756,7 +756,7 @@ DeviceManagerDialog::updatePortsList(QTreeWidget * treeWid,
 
         portNamesListed << portName;    // append to list
         //
-        i += 1;
+        itemIndex += 1;
     }
 
     portNamesAvail << m_noPortName; // add nullPort
@@ -866,10 +866,10 @@ DeviceManagerDialog::slotDeletePlaybackDevice()
 
     Composition &composition =
             RosegardenDocument::currentDocument->getComposition();
-    const Composition::trackcontainer &tracks = composition.getTracks();
+    const Composition::TrackMap &tracks = composition.getTracks();
 
     // For each Track in the Composition...
-    for (const Composition::trackcontainer::value_type &pair : tracks) {
+    for (const Composition::TrackMap::value_type &pair : tracks) {
         const Track *track = pair.second;
         if (!track)
             continue;
@@ -1057,49 +1057,38 @@ DeviceManagerDialog::connectSignalsToSlots()
     // which is send by the AlsaDriver, when devices have been added or removed,
     // or if AlsaDriver::checkForNewClients() found any news
     //
-    connect(
-        RosegardenDocument::currentDocument,
-            &RosegardenDocument::devicesResyncd,
-        this,
-            &DeviceManagerDialog::slotResyncDevicesReceived );
+    connect(RosegardenDocument::currentDocument,
+                    &RosegardenDocument::devicesResyncd,
+            this, &DeviceManagerDialog::slotResyncDevicesReceived );
 
-//     //
-//     connect( m_doc,
-//         SIGNAL(signalAlsaSeqPortConnectionChanged()), this,
-//         SLOT(slotResyncDevicesReceived()) );
+    //connect(m_doc, &RosegardenDocument::signalAlsaSeqPortConnectionChanged,
+    //        this, &DeviceManagerDialog::slotResyncDevicesReceived);
 
 
     // playback devices
-    connect(m_treeWidget_outputPorts,
-            &QTreeWidget::itemClicked, this,
-            &DeviceManagerDialog::slotOutputPortClicked);
+    connect(m_treeWidget_outputPorts, &QTreeWidget::itemClicked,
+            this, &DeviceManagerDialog::slotOutputPortClicked);
 
-    connect(m_treeWidget_playbackDevices,
-            &QTreeWidget::itemSelectionChanged, this,
-            &DeviceManagerDialog::slotPlaybackDeviceSelected);
+    connect(m_treeWidget_playbackDevices, &QTreeWidget::itemSelectionChanged,
+            this, &DeviceManagerDialog::slotPlaybackDeviceSelected);
 
-    connect(m_treeWidget_playbackDevices,
-            &QTreeWidget::itemChanged, this,
-            &DeviceManagerDialog::slotDeviceItemChanged);
+    connect(m_treeWidget_playbackDevices, &QTreeWidget::itemChanged,
+            this, &DeviceManagerDialog::slotDeviceItemChanged);
 
-    connect(m_treeWidget_playbackDevices,
-            &QTreeWidget::itemDoubleClicked,
+    connect(m_treeWidget_playbackDevices, &QTreeWidget::itemDoubleClicked,
             this, &DeviceManagerDialog::slotEdit);
 
     // record devices
-    connect(m_treeWidget_inputPorts,
-            &QTreeWidget::itemClicked, this,
-            &DeviceManagerDialog::slotInputPortClicked);
+    connect(m_treeWidget_inputPorts, &QTreeWidget::itemClicked,
+            this, &DeviceManagerDialog::slotInputPortClicked);
 
     connect(m_treeWidget_recordDevices, &QTreeWidget::itemSelectionChanged,
             this, &DeviceManagerDialog::slotRecordDeviceSelected);
 
-    connect(m_treeWidget_recordDevices,
-            &QTreeWidget::itemChanged, this,
-            &DeviceManagerDialog::slotDeviceItemChanged);
+    connect(m_treeWidget_recordDevices, &QTreeWidget::itemChanged,
+            this, &DeviceManagerDialog::slotDeviceItemChanged);
 
-    connect(m_treeWidget_recordDevices,
-            &QTreeWidget::itemDoubleClicked,
+    connect(m_treeWidget_recordDevices, &QTreeWidget::itemDoubleClicked,
             this, &DeviceManagerDialog::slotEdit);
 
     // refresh buttons
@@ -1112,23 +1101,24 @@ DeviceManagerDialog::connectSignalsToSlots()
     QDialogButtonBox *bbox;
     // connect help button
     bbox = findChild < QDialogButtonBox * >("buttonBox");
-    connect(bbox, &QDialogButtonBox::helpRequested, this,
-            &DeviceManagerDialog::slotHelpRequested);
+    connect(bbox, &QDialogButtonBox::helpRequested,
+            this, &DeviceManagerDialog::slotHelpRequested);
     // connect close button
     QPushButton *pbClose;
     pbClose = bbox->button(QDialogButtonBox::Close);
-    connect(pbClose, &QAbstractButton::clicked, this, &DeviceManagerDialog::slotCloseButtonPress);
+    connect(pbClose, &QAbstractButton::clicked,
+            this, &DeviceManagerDialog::slotCloseButtonPress);
 
     // buttons
-    connect(pushButton_newPlaybackDevice, &QAbstractButton::clicked, this,
-            &DeviceManagerDialog::slotAddPlaybackDevice);
-    connect(pushButton_newRecordDevice, &QAbstractButton::clicked, this,
-            &DeviceManagerDialog::slotAddRecordDevice);
+    connect(pushButton_newPlaybackDevice, &QAbstractButton::clicked,
+            this, &DeviceManagerDialog::slotAddPlaybackDevice);
+    connect(pushButton_newRecordDevice, &QAbstractButton::clicked,
+            this, &DeviceManagerDialog::slotAddRecordDevice);
 
-    connect(pushButton_deletePlaybackDevice, &QAbstractButton::clicked, this,
-            &DeviceManagerDialog::slotDeletePlaybackDevice);
-    connect(pushButton_deleteRecordDevice, &QAbstractButton::clicked, this,
-            &DeviceManagerDialog::slotDeleteRecordDevice);
+    connect(pushButton_deletePlaybackDevice, &QAbstractButton::clicked,
+            this, &DeviceManagerDialog::slotDeletePlaybackDevice);
+    connect(pushButton_deleteRecordDevice, &QAbstractButton::clicked,
+            this, &DeviceManagerDialog::slotDeleteRecordDevice);
 
     connect(pushButton_manageBanksOfPlaybackDevice, &QAbstractButton::clicked,
             this, &DeviceManagerDialog::slotManageBanksOfPlaybackDevice);
