@@ -4,7 +4,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -33,17 +33,13 @@ namespace Rosegarden
 class MidiMixerVUMeter : public VUMeter
 {
 public:
-    MidiMixerVUMeter(QWidget *parent = nullptr,
-                     VUMeterType type = Plain,
-                     int width = 0,
-                     int height = 0);
-
-protected:
-     void meterStart() override;
-     void meterStop() override;
+    MidiMixerVUMeter(QWidget *parent,
+                     VUMeterType type,
+                     int width,
+                     int height);
 
 private:
-     int m_textHeight;
+    int m_textHeight;
 
 }; 
 
