@@ -31,11 +31,20 @@ class QComboBox;
 namespace Rosegarden
 {
 
-class Command;
 
+class Command;
 class RosegardenDocument;
 
 
+/// The "Remap Instrument assignments..." dialog.
+/**
+ * From the main window: Tracks > Remap Instruments...
+ *
+ * This lets the user quickly change either the Device or Instrument on a
+ * number of tracks at the same time.  E.g. if you want to change all
+ * tracks using the General MIDI device to instead use Soft Synths, this
+ * dialog can do that.
+ */
 class RemapInstrumentDialog : public QDialog
 {
     Q_OBJECT
@@ -64,8 +73,8 @@ protected:
     QComboBox           *m_fromCombo;
     QComboBox           *m_toCombo;
 
-    DeviceList m_devices;
-    InstrumentList m_instruments;
+    DeviceVector m_devices;
+    InstrumentVector m_instruments;
 };
 
 
