@@ -81,8 +81,8 @@ AudioFaderBox::AudioFaderBox(QWidget *parent,
 
         m_plugins.push_back(plugin);
         m_signalMapper->setMapping(plugin, i);
-        connect(plugin, SIGNAL(clicked()),
-                m_signalMapper, SLOT(map()));
+        connect(plugin, &PluginPushButton::clicked,
+                m_signalMapper, (void(QSignalMapper::*)())&QSignalMapper::map);
     }
     pluginVbox->setLayout(pluginVboxLayout);
 
@@ -133,8 +133,17 @@ AudioFaderBox::AudioFaderBox(QWidget *parent,
     m_monoPixmap = IconLoader::loadPixmap("mono");
     m_stereoPixmap = IconLoader::loadPixmap("stereo");
 
-    m_pan = new Rotary(this, -100.0, 100.0, 1.0, 5.0, 0.0, 22,
-                       Rotary::NoTicks, false, true);
+    m_pan = new Rotary(this,  // parent
+                       -100.0,  // minimum
+                       100.0,  // maximum
+                       1.0,  // step
+                       5.0,  // pageStep
+                       0.0,  // initialPosition
+                       22,  // size
+                       Rotary::NoTicks,  // ticks
+                       true,  // centred
+                       false);  // logarithmic
+    m_pan->setLabel(tr("Pan"));
 
     // same as the knob colour on the MIDI pan
     m_pan->setKnobColour(GUIPalette::getColour(GUIPalette::RotaryPastelGreen));
@@ -164,7 +173,6 @@ AudioFaderBox::AudioFaderBox(QWidget *parent,
         m_audioOutput = nullptr;
     }
 
-    m_pan->setToolTip(tr("Set the audio pan position in the stereo field"));
     m_synthGUIButton->setToolTip(tr("Open the synth plugin's native editor"));
     m_stereoButton->setToolTip(tr("Mono or Stereo Instrument"));
     m_recordFader->setToolTip(tr("Record level"));
