@@ -33,18 +33,54 @@ class AudioListItem : public QTreeWidgetItem
 {
 public:
     //    AudioListItem(QTreeWidget *parent):QTreeWidgetItem(), m_segment(0) {;}
- AudioListItem( const QStringList &strings, int type = Type ) : QTreeWidgetItem(strings, type), m_id(0), m_segment(nullptr) {  }
+    explicit AudioListItem(const QStringList &strings,
+                           int type = Type ) :
+        QTreeWidgetItem(strings, type),
+        m_id(0),
+        m_segment(nullptr),
+        m_selected(false)
+    {  }
 
     // without m_id
- AudioListItem( QTreeWidget *parent, const QStringList &strings, int type=Type ) : QTreeWidgetItem(parent, strings, type), m_id(0), m_segment(nullptr) {  }
+    AudioListItem(QTreeWidget *parent,
+                  const QStringList &strings,
+                  int type=Type ) :
+        QTreeWidgetItem(parent, strings, type),
+        m_id(0),
+        m_segment(nullptr),
+        m_selected(false)
+    {  }
 
- AudioListItem( AudioListItem *parent, const QStringList &strings, int type=Type ) : QTreeWidgetItem(parent, strings, type), m_id(0), m_segment(nullptr) {  }
+    AudioListItem(AudioListItem *parent,
+                  const QStringList &strings,
+                  int type=Type ) :
+        QTreeWidgetItem(parent, strings, type),
+        m_id(0),
+        m_segment(nullptr),
+        m_selected(false)
+    {  }
 
 
     // with m_id
-    AudioListItem( QTreeWidget *parent, const QStringList &strings, AudioFileId id, int type=Type ) :QTreeWidgetItem(parent, strings, type ), m_id(id), m_segment(nullptr) {;}
+    AudioListItem(QTreeWidget *parent,
+                  const QStringList &strings,
+                  AudioFileId id,
+                  int type=Type ) :
+        QTreeWidgetItem(parent, strings, type ),
+        m_id(id),
+        m_segment(nullptr),
+        m_selected(false)
+    {  }
 
-    AudioListItem( AudioListItem *parent, const QStringList &strings, AudioFileId id, int type=Type ) :QTreeWidgetItem(parent, strings, type ), m_id(id), m_segment(nullptr) {;}
+    AudioListItem(AudioListItem *parent,
+                  const QStringList &strings,
+                  AudioFileId id,
+                  int type=Type ) :
+        QTreeWidgetItem(parent, strings, type ),
+        m_id(id),
+        m_segment(nullptr),
+        m_selected(false)
+    {  }
 
 
 
@@ -73,17 +109,20 @@ public:
 
     void setStartTime(const RealTime &time)
         { m_startTime = time; }
-    RealTime getStartTime() { return m_startTime; }
+    RealTime getStartTime() const { return m_startTime; }
 
     void setDuration(const RealTime &time)
         { m_duration = time; }
-    RealTime getDuration() { return m_duration; }
+    RealTime getDuration() const { return m_duration; }
 
     void setSegment(Segment *segment)
         { m_segment = segment; }
-    Segment *getSegment()  { return m_segment; }
+    Segment *getSegment() { return m_segment; }
     const Segment *getSegment() const  { return m_segment; }
 
+    bool getSelected() const { return m_selected; }
+    void setSelected(bool s) { m_selected = s; };
+
 protected:
     AudioFileId m_id;
 
@@ -94,6 +133,8 @@ protected:
     // pointer to a segment
     Segment *m_segment;
 
+    bool m_selected; // memory for selection
+
 };
 
 }
