@@ -145,8 +145,9 @@ AudioRouteMenu::slotShowMenu()
         a->setObjectName(QString("%1").arg(i));
     }
 
-    connect(menu, SIGNAL(triggered(QAction *)),
-            SLOT(slotEntrySelected(QAction *)));
+    connect(menu, &QMenu::triggered,
+            this, (void(AudioRouteMenu::*)(QAction *))
+                    &AudioRouteMenu::slotEntrySelected);
 
     // Compute the position for the pop-up menu.
 
@@ -323,7 +324,7 @@ AudioRouteMenu::slotEntrySelected(QAction *a)
 }
 
 void
-AudioRouteMenu::slotEntrySelected(int i)
+AudioRouteMenu::slotEntrySelected(int entryIndex)
 {
     if (m_instrumentId == NoInstrument)
         return;
@@ -338,24 +339,6 @@ AudioRouteMenu::slotEntrySelected(int i)
     switch (m_direction) {
 
     case In: {
-            bool oldIsBuss;
-            // 0 == left, 1 == right, mono only
-            int oldChannel;
-            int oldInput = instrument->getAudioInput(oldIsBuss, oldChannel);
-
-            // Compute old mapped ID
-
-            MappedObjectId oldMappedId = 0;
-
-            if (oldIsBuss) {
-                Buss *buss = studio.getBussById(oldInput);
-                if (buss)
-                    oldMappedId = buss->getMappedId();
-            } else {
-                RecordIn *in = studio.getRecordIn(oldInput);
-                if (in)
-                    oldMappedId = in->mappedId;
-            }
 
             // Compute selected (new) entry's input and channel.
 
@@ -368,66 +351,23 @@ AudioRouteMenu::slotEntrySelected(int i)
             int newInput;
 
             if (stereo) {
-                newIsBuss = (i >= recordIns);
+                newIsBuss = (entryIndex >= recordIns);
                 if (newIsBuss) {
-                    newInput = i - recordIns;
+                    newInput = entryIndex - recordIns;
                 } else {
-                    newInput = i;
+                    newInput = entryIndex;
                 }
             } else {
-                newIsBuss = (i >= recordIns * 2);
-                newChannel = i % 2;
+                newIsBuss = (entryIndex >= recordIns * 2);
+                newChannel = entryIndex % 2;
                 if (newIsBuss) {
-                    newInput = i / 2 - recordIns;
+                    newInput = entryIndex / 2 - recordIns;
                 } else {
-                    newInput = i / 2;
+                    newInput = entryIndex / 2;
                 }
             }
 
-            // Compute new mapped ID
-
-            MappedObjectId newMappedId = 0;
-
-            if (newIsBuss) {
-                Buss *buss = studio.getBussById(newInput);
-                if (!buss)
-                    return;
-                newMappedId = buss->getMappedId();
-            } else {
-                RecordIn *in = studio.getRecordIn(newInput);
-                if (!in)
-                    return;
-                newMappedId = in->mappedId;
-            }
-
-            // Update the Studio
-
-            if (oldMappedId != 0) {
-                StudioControl::disconnectStudioObjects(
-                        oldMappedId, instrument->getMappedId());
-            } else {
-                StudioControl::disconnectStudioObject(
-                        instrument->getMappedId());
-            }
-
-            StudioControl::setStudioObjectProperty(
-                    instrument->getMappedId(),
-                    MappedAudioFader::InputChannel,
-                    MappedObjectValue(newChannel));
-
-            if (newMappedId != 0) {
-                // Connect the input to the instrument.
-                StudioControl::connectStudioObjects(
-                        newMappedId, instrument->getMappedId());
-            }
-
-            // Update the Instrument
-
-            if (newIsBuss) {
-                instrument->setAudioInputToBuss(newInput, newChannel);
-            } else {
-                instrument->setAudioInputToRecord(newInput, newChannel);
-            }
+            studio.setInput(instrument, newIsBuss, newInput, newChannel);
 
             doc->slotDocumentModified();
 
@@ -435,30 +375,7 @@ AudioRouteMenu::slotEntrySelected(int i)
         }
 
     case Out: {
-            BussId bussId = instrument->getAudioOutput();
-            Buss *oldBuss = studio.getBussById(bussId);
-
-            Buss *newBuss = studio.getBussById(i);
-            if (!newBuss)
-                return;
-
-            // Update the Studio
-
-            if (oldBuss) {
-                StudioControl::disconnectStudioObjects(
-                        instrument->getMappedId(), oldBuss->getMappedId());
-            } else {
-                StudioControl::disconnectStudioObject(
-                        instrument->getMappedId());
-            }
-
-            StudioControl::connectStudioObjects(
-                    instrument->getMappedId(), newBuss->getMappedId());
-
-            // Update the Instrument
-
-            instrument->setAudioOutput(i);
-
+            studio.setOutput(instrument, entryIndex);
             doc->slotDocumentModified();
 
             break;
