@@ -18,9 +18,11 @@
 #ifndef RG_AUDIOFILEMANAGER_H
 #define RG_AUDIOFILEMANAGER_H
 
-#include <string>
-#include <vector>
-#include <set>
+#include "AudioFile.h"
+#include "PeakFileManager.h"
+
+#include "base/XmlExportable.h"
+#include "base/Exception.h"
 
 #include <QObject>
 #include <QUrl>
@@ -29,11 +31,10 @@
 
 class QPixmap;
 
-#include "AudioFile.h"
-#include "PeakFileManager.h"
-
-#include "base/XmlExportable.h"
-#include "base/Exception.h"
+#include <memory>
+#include <set>
+#include <string>
+#include <vector>
 
 
 namespace Rosegarden
@@ -110,6 +111,7 @@ public:
                     AudioFileId id);
     /// We have audio files at load time, assume user has set location.
     void setAudioLocationConfirmed()  { m_audioLocationConfirmed = true; }
+    bool getAudioLocationConfirmed() const  { return m_audioLocationConfirmed; }
 
     /// Does a specific file id exist?
     bool fileExists(AudioFileId id);
@@ -147,7 +149,8 @@ public:
     void clear();
 
     /// Set the relative audio file path.  E.g. "./audio"
-    void setRelativeAudioPath(const QString &newPath, bool doMoveFiles = false);
+    void setRelativeAudioPath(
+            const QString &newPath, bool create, bool doMoveFiles);
     QString getRelativeAudioPath() const  { return m_relativeAudioPath; }
     /// Get the absolute audio path.  E.g. "/home/ted/Documents/project1/audio/"
     QString getAbsoluteAudioPath() const;
@@ -234,7 +237,7 @@ public:
     void drawPreview(AudioFileId id,
                      const RealTime &startTime,
                      const RealTime &endTime,
-                     QPixmap *pixmap);
+                     std::shared_ptr<QPixmap> pixmap);
 
     /**
      * Usually used to show how an audio Segment makes up part of
@@ -247,7 +250,7 @@ public:
                                 const RealTime &endTime,
                                 const RealTime &highlightStart,
                                 const RealTime &highlightEnd,
-                                QPixmap *pixmap);
+                                std::shared_ptr<QPixmap> pixmap);
 
     /// Get a split point vector from a peak file
     /**
@@ -300,9 +303,9 @@ public:
     };
 
 private:
-    // Hide copy ctor and op=.
-    AudioFileManager(const AudioFileManager &aFM);
-    AudioFileManager &operator=(const AudioFileManager &);
+    // Delete copy ctor and op=.
+    AudioFileManager(const AudioFileManager &aFM) = delete;
+    AudioFileManager &operator=(const AudioFileManager &) = delete;
 
     // We can't use RosegardenDocument::currentDocument as it might
     // be pointing to the wrong document.
@@ -342,12 +345,6 @@ private:
      */
     int convertAudioFile(const QString &inFile, const QString &outFile);
 
-    /// Convert a relative path or file path to absolute.
-    /**
-     * Expands "~" and "." to an absolute path.
-     */
-    QString toAbsolute(const QString &relativePath) const;
-
     /// Get a short file name from a long one (with '/'s)
     QString getShortFilename(const QString &fileName) const;
 
@@ -360,7 +357,7 @@ private:
     /// Fetch a new unique Audio File ID.
     AudioFileId getUniqueAudioFileID();
     /// Last Audio File ID that was handed out by getUniqueAudioFileID().
-    unsigned int m_lastAudioFileID;
+    unsigned int m_lastAudioFileID{0};
 
     /// Always in internal format with either a "." or a "~".
     /**
@@ -375,7 +372,7 @@ private:
     QString m_relativeAudioPath;
 
     /// Whether the user has confirmed the audio file path.
-    bool m_audioLocationConfirmed;
+    bool m_audioLocationConfirmed{false};
 
     void moveFiles(const QString &newPath);
 
@@ -388,7 +385,7 @@ private:
     std::set<AudioFile *> m_recordedAudioFiles;
     std::set<AudioFile *> m_derivedAudioFiles;
 
-    int m_expectedSampleRate;
+    int m_expectedSampleRate{0};
 
     /// Progress Dialog passed in by clients.
     QPointer<QProgressDialog> m_progressDialog;
@@ -397,4 +394,4 @@ private:
 
 }
 
-#endif // RG_AUDIOFILEMANAGER_H
+#endif
