@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2024 the Rosegarden development team.
+    Copyright 2000-2025 the Rosegarden development team.
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
@@ -38,6 +38,8 @@
 #include <lv2/urid/urid.h>
 #include <lv2/patch/patch.h>
 
+#include <alsa/asoundlib.h>
+
 //#include <QtGlobal>
 #include <QJsonDocument>
 #include <QJsonArray>
@@ -212,6 +214,8 @@ LV2PluginInstance::init(int idealChannelCount)
                     LV2_Atom_Sequence* atomIn =
                         reinterpret_cast<LV2_Atom_Sequence*>(dbuf);
                     lv2_atom_sequence_clear(atomIn);
+                    LV2_URID type = LV2URIDMapper::uridMap(LV2_ATOM__Sequence);
+                    atomIn->atom.type = type;
                     ap.atomSeq = atomIn;
                     RG_DEBUG << "created atom sequence" << atomIn;
                     m_atomInputPorts.push_back(ap);
