@@ -15,8 +15,10 @@
 #define RG_MODULE_STRING "[MappedEvent]"
 
 #include "MappedEvent.h"
-#include "base/BaseProperties.h"
 #include "Midi.h"
+
+#include "base/BaseProperties.h"
+#include "base/Event.h"
 #include "base/MidiTypes.h"
 #include "base/NotationTypes.h" // for Note::EventType
 #include "misc/Debug.h"
@@ -117,19 +119,19 @@ MappedEvent::MappedEvent(const Event &e)
             m_type = InvalidMappedEvent;
         }
 
-    } catch (const Event::NoData &d) {
+    } catch (const Event::NoData &noData) {
 
 #ifdef DEBUG_MAPPEDEVENT
         RG_WARNING << "Caught Event::NoData in MappedEvent ctor, message is:\n" << d.getMessage();
 #endif
 
-    } catch (const Event::BadType &b) {
+    } catch (const Event::BadType &badType) {
 
 #ifdef DEBUG_MAPPEDEVENT
         RG_WARNING << "Caught Event::BadType in MappedEvent ctor, message is:\n" << b.getMessage();
 #endif
 
-    } catch (const SystemExclusive::BadEncoding &e) {
+    } catch (const SystemExclusive::BadEncoding &badEncoding) {
 
 #ifdef DEBUG_MAPPEDEVENT
         RG_WARNING << "Caught bad SysEx encoding in MappedEvent ctor";
@@ -345,8 +347,7 @@ DataBlockFile::~DataBlockFile()
 {
     if (m_cleared) {
 //        std::cerr << "~DataBlockFile : removing " << m_fileName.toLatin1().data() << std::endl;
-        QFile::remove
-            (m_fileName);
+        QFile::remove(m_fileName);
     }
 
 }
@@ -529,8 +530,7 @@ void DataBlockRepository::clear()
 
     for (unsigned int i = 0; i < segmentsDir.count(); ++i) {
         QString segmentName = tmpPath + '/' + segmentsDir[i];
-        QFile::remove
-            (segmentName);
+        QFile::remove(segmentName);
     }
 }
 
