@@ -16,15 +16,16 @@
 #ifndef RG_SEQUENCERDATABLOCK_H
 #define RG_SEQUENCERDATABLOCK_H
 
-#include "ControlBlock.h"
 #include "base/RealTime.h"
 #include "MappedEvent.h"
 
 #include <QMutex>
 
+
 namespace Rosegarden
 {
 
+
 /**
  * ONLY PUT PLAIN DATA HERE - NO POINTERS EVER
  * (and this struct mustn't have a constructor)
@@ -38,6 +39,7 @@ struct LevelInfo
     int levelRight; // if stereo audio
 };
 
+
 class MappedEventList;
 
 
@@ -45,6 +47,7 @@ class MappedEventList;
 #define SEQUENCER_DATABLOCK_MAX_NB_SUBMASTERS   64 // can't be a symbol
 #define SEQUENCER_DATABLOCK_RECORD_BUFFER_SIZE 1024 // MIDI events
 
+
 /// Holds MIDI data going from RosegardenSequencer to RosegardenMainWindow
 /**
  * This class contains recorded data that is being passed from sequencer
@@ -159,7 +162,12 @@ protected:
     int m_getVisualIndex;
     bool m_haveVisualEvent;
     /// MIDI OUT event for display on the transport during playback.
-    char m_visualEvent[sizeof(MappedEvent)];
+    /**
+     * ??? This is a character buffer because this used to be shared memory.
+     *     Now that it isn't, we should be able to make this a MappedEvent
+     *     object.
+     */
+    char m_visualEvent[sizeof(MappedEvent)]{};
 
     /// Index of the next available position in m_recordBuffer.
     /**
@@ -206,6 +214,7 @@ protected:
     LevelInfo m_masterLevel;
 };
 
+
 }
 
 #endif
