@@ -383,12 +383,13 @@ Tuning::Tuning(const std::string& name,
                     setRefNote(p, 440);
 }
 
+#if 0
 Tuning::Tuning(const Tuning *tuning) :
     m_name(tuning->getName()),
     m_rootPitch(tuning->getRootPitch()),
     m_refPitch(tuning->getRefPitch()),
     m_intervals(tuning->getIntervalList()),
-    m_size(m_intervals->size()),
+    m_size(tuning->getIntervalList()->size()),
     m_spellings(tuning->getSpellingList())
 {
 #   if (TUNING_DEBUG > 1)
@@ -422,7 +423,7 @@ Tuning::Tuning(const Tuning *tuning) :
     << m_rootPitch.getDisplayAccidental(keyofc)
    ;
 }
-
+#endif
 
 
 
